// Copyright 2025 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import type {protobuf as $protobuf} from "google-gax";
import Long = require("long");
/** Namespace google. */
export namespace google {

    /** Namespace cloud. */
    namespace cloud {

        /** Namespace documentai. */
        namespace documentai {

            /** Namespace v1. */
            namespace v1 {

                /** Properties of a Barcode. */
                interface IBarcode {

                    /** Barcode format */
                    format?: (string|null);

                    /** Barcode valueFormat */
                    valueFormat?: (string|null);

                    /** Barcode rawValue */
                    rawValue?: (string|null);
                }

                /** Represents a Barcode. */
                class Barcode implements IBarcode {

                    /**
                     * Constructs a new Barcode.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IBarcode);

                    /** Barcode format. */
                    public format: string;

                    /** Barcode valueFormat. */
                    public valueFormat: string;

                    /** Barcode rawValue. */
                    public rawValue: string;

                    /**
                     * Creates a new Barcode instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Barcode instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IBarcode): google.cloud.documentai.v1.Barcode;

                    /**
                     * Encodes the specified Barcode message. Does not implicitly {@link google.cloud.documentai.v1.Barcode.verify|verify} messages.
                     * @param message Barcode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Barcode message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Barcode.verify|verify} messages.
                     * @param message Barcode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Barcode message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Barcode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Barcode;

                    /**
                     * Decodes a Barcode message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Barcode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Barcode;

                    /**
                     * Verifies a Barcode message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Barcode message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Barcode
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Barcode;

                    /**
                     * Creates a plain object from a Barcode message. Also converts values to other types if specified.
                     * @param message Barcode
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.Barcode, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Barcode to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Barcode
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Document. */
                interface IDocument {

                    /** Document uri */
                    uri?: (string|null);

                    /** Document content */
                    content?: (Uint8Array|string|null);

                    /** Document mimeType */
                    mimeType?: (string|null);

                    /** Document text */
                    text?: (string|null);

                    /** Document textStyles */
                    textStyles?: (google.cloud.documentai.v1.Document.IStyle[]|null);

                    /** Document pages */
                    pages?: (google.cloud.documentai.v1.Document.IPage[]|null);

                    /** Document entities */
                    entities?: (google.cloud.documentai.v1.Document.IEntity[]|null);

                    /** Document entityRelations */
                    entityRelations?: (google.cloud.documentai.v1.Document.IEntityRelation[]|null);

                    /** Document textChanges */
                    textChanges?: (google.cloud.documentai.v1.Document.ITextChange[]|null);

                    /** Document shardInfo */
                    shardInfo?: (google.cloud.documentai.v1.Document.IShardInfo|null);

                    /** Document error */
                    error?: (google.rpc.IStatus|null);

                    /** Document revisions */
                    revisions?: (google.cloud.documentai.v1.Document.IRevision[]|null);

                    /** Document documentLayout */
                    documentLayout?: (google.cloud.documentai.v1.Document.IDocumentLayout|null);

                    /** Document chunkedDocument */
                    chunkedDocument?: (google.cloud.documentai.v1.Document.IChunkedDocument|null);
                }

                /** Represents a Document. */
                class Document implements IDocument {

                    /**
                     * Constructs a new Document.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDocument);

                    /** Document uri. */
                    public uri?: (string|null);

                    /** Document content. */
                    public content?: (Uint8Array|string|null);

                    /** Document mimeType. */
                    public mimeType: string;

                    /** Document text. */
                    public text: string;

                    /** Document textStyles. */
                    public textStyles: google.cloud.documentai.v1.Document.IStyle[];

                    /** Document pages. */
                    public pages: google.cloud.documentai.v1.Document.IPage[];

                    /** Document entities. */
                    public entities: google.cloud.documentai.v1.Document.IEntity[];

                    /** Document entityRelations. */
                    public entityRelations: google.cloud.documentai.v1.Document.IEntityRelation[];

                    /** Document textChanges. */
                    public textChanges: google.cloud.documentai.v1.Document.ITextChange[];

                    /** Document shardInfo. */
                    public shardInfo?: (google.cloud.documentai.v1.Document.IShardInfo|null);

                    /** Document error. */
                    public error?: (google.rpc.IStatus|null);

                    /** Document revisions. */
                    public revisions: google.cloud.documentai.v1.Document.IRevision[];

                    /** Document documentLayout. */
                    public documentLayout?: (google.cloud.documentai.v1.Document.IDocumentLayout|null);

                    /** Document chunkedDocument. */
                    public chunkedDocument?: (google.cloud.documentai.v1.Document.IChunkedDocument|null);

                    /** Document source. */
                    public source?: ("uri"|"content");

                    /**
                     * Creates a new Document instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Document instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDocument): google.cloud.documentai.v1.Document;

                    /**
                     * Encodes the specified Document message. Does not implicitly {@link google.cloud.documentai.v1.Document.verify|verify} messages.
                     * @param message Document message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Document message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.verify|verify} messages.
                     * @param message Document message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Document message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Document
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document;

                    /**
                     * Decodes a Document message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Document
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document;

                    /**
                     * Verifies a Document message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Document message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Document
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document;

                    /**
                     * Creates a plain object from a Document message. Also converts values to other types if specified.
                     * @param message Document
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.Document, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Document to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Document
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Document {

                    /** Properties of a ShardInfo. */
                    interface IShardInfo {

                        /** ShardInfo shardIndex */
                        shardIndex?: (number|Long|string|null);

                        /** ShardInfo shardCount */
                        shardCount?: (number|Long|string|null);

                        /** ShardInfo textOffset */
                        textOffset?: (number|Long|string|null);
                    }

                    /** Represents a ShardInfo. */
                    class ShardInfo implements IShardInfo {

                        /**
                         * Constructs a new ShardInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IShardInfo);

                        /** ShardInfo shardIndex. */
                        public shardIndex: (number|Long|string);

                        /** ShardInfo shardCount. */
                        public shardCount: (number|Long|string);

                        /** ShardInfo textOffset. */
                        public textOffset: (number|Long|string);

                        /**
                         * Creates a new ShardInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ShardInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IShardInfo): google.cloud.documentai.v1.Document.ShardInfo;

                        /**
                         * Encodes the specified ShardInfo message. Does not implicitly {@link google.cloud.documentai.v1.Document.ShardInfo.verify|verify} messages.
                         * @param message ShardInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IShardInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ShardInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.ShardInfo.verify|verify} messages.
                         * @param message ShardInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IShardInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a ShardInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ShardInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.ShardInfo;

                        /**
                         * Decodes a ShardInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ShardInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.ShardInfo;

                        /**
                         * Verifies a ShardInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a ShardInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ShardInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.ShardInfo;

                        /**
                         * Creates a plain object from a ShardInfo message. Also converts values to other types if specified.
                         * @param message ShardInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.ShardInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ShardInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ShardInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a Style. */
                    interface IStyle {

                        /** Style textAnchor */
                        textAnchor?: (google.cloud.documentai.v1.Document.ITextAnchor|null);

                        /** Style color */
                        color?: (google.type.IColor|null);

                        /** Style backgroundColor */
                        backgroundColor?: (google.type.IColor|null);

                        /** Style fontWeight */
                        fontWeight?: (string|null);

                        /** Style textStyle */
                        textStyle?: (string|null);

                        /** Style textDecoration */
                        textDecoration?: (string|null);

                        /** Style fontSize */
                        fontSize?: (google.cloud.documentai.v1.Document.Style.IFontSize|null);

                        /** Style fontFamily */
                        fontFamily?: (string|null);
                    }

                    /** Represents a Style. */
                    class Style implements IStyle {

                        /**
                         * Constructs a new Style.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IStyle);

                        /** Style textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1.Document.ITextAnchor|null);

                        /** Style color. */
                        public color?: (google.type.IColor|null);

                        /** Style backgroundColor. */
                        public backgroundColor?: (google.type.IColor|null);

                        /** Style fontWeight. */
                        public fontWeight: string;

                        /** Style textStyle. */
                        public textStyle: string;

                        /** Style textDecoration. */
                        public textDecoration: string;

                        /** Style fontSize. */
                        public fontSize?: (google.cloud.documentai.v1.Document.Style.IFontSize|null);

                        /** Style fontFamily. */
                        public fontFamily: string;

                        /**
                         * Creates a new Style instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Style instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IStyle): google.cloud.documentai.v1.Document.Style;

                        /**
                         * Encodes the specified Style message. Does not implicitly {@link google.cloud.documentai.v1.Document.Style.verify|verify} messages.
                         * @param message Style message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IStyle, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Style message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Style.verify|verify} messages.
                         * @param message Style message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IStyle, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Style message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Style
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Style;

                        /**
                         * Decodes a Style message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Style
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Style;

                        /**
                         * Verifies a Style message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Style message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Style
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Style;

                        /**
                         * Creates a plain object from a Style message. Also converts values to other types if specified.
                         * @param message Style
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.Style, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Style to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Style
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Style {

                        /** Properties of a FontSize. */
                        interface IFontSize {

                            /** FontSize size */
                            size?: (number|null);

                            /** FontSize unit */
                            unit?: (string|null);
                        }

                        /** Represents a FontSize. */
                        class FontSize implements IFontSize {

                            /**
                             * Constructs a new FontSize.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Style.IFontSize);

                            /** FontSize size. */
                            public size: number;

                            /** FontSize unit. */
                            public unit: string;

                            /**
                             * Creates a new FontSize instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FontSize instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Style.IFontSize): google.cloud.documentai.v1.Document.Style.FontSize;

                            /**
                             * Encodes the specified FontSize message. Does not implicitly {@link google.cloud.documentai.v1.Document.Style.FontSize.verify|verify} messages.
                             * @param message FontSize message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Style.IFontSize, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FontSize message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Style.FontSize.verify|verify} messages.
                             * @param message FontSize message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Style.IFontSize, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FontSize message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FontSize
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Style.FontSize;

                            /**
                             * Decodes a FontSize message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FontSize
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Style.FontSize;

                            /**
                             * Verifies a FontSize message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FontSize message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FontSize
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Style.FontSize;

                            /**
                             * Creates a plain object from a FontSize message. Also converts values to other types if specified.
                             * @param message FontSize
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Style.FontSize, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FontSize to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FontSize
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a Page. */
                    interface IPage {

                        /** Page pageNumber */
                        pageNumber?: (number|null);

                        /** Page image */
                        image?: (google.cloud.documentai.v1.Document.Page.IImage|null);

                        /** Page transforms */
                        transforms?: (google.cloud.documentai.v1.Document.Page.IMatrix[]|null);

                        /** Page dimension */
                        dimension?: (google.cloud.documentai.v1.Document.Page.IDimension|null);

                        /** Page layout */
                        layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                        /** Page detectedLanguages */
                        detectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);

                        /** Page blocks */
                        blocks?: (google.cloud.documentai.v1.Document.Page.IBlock[]|null);

                        /** Page paragraphs */
                        paragraphs?: (google.cloud.documentai.v1.Document.Page.IParagraph[]|null);

                        /** Page lines */
                        lines?: (google.cloud.documentai.v1.Document.Page.ILine[]|null);

                        /** Page tokens */
                        tokens?: (google.cloud.documentai.v1.Document.Page.IToken[]|null);

                        /** Page visualElements */
                        visualElements?: (google.cloud.documentai.v1.Document.Page.IVisualElement[]|null);

                        /** Page tables */
                        tables?: (google.cloud.documentai.v1.Document.Page.ITable[]|null);

                        /** Page formFields */
                        formFields?: (google.cloud.documentai.v1.Document.Page.IFormField[]|null);

                        /** Page symbols */
                        symbols?: (google.cloud.documentai.v1.Document.Page.ISymbol[]|null);

                        /** Page detectedBarcodes */
                        detectedBarcodes?: (google.cloud.documentai.v1.Document.Page.IDetectedBarcode[]|null);

                        /** Page imageQualityScores */
                        imageQualityScores?: (google.cloud.documentai.v1.Document.Page.IImageQualityScores|null);

                        /** Page provenance */
                        provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);
                    }

                    /** Represents a Page. */
                    class Page implements IPage {

                        /**
                         * Constructs a new Page.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IPage);

                        /** Page pageNumber. */
                        public pageNumber: number;

                        /** Page image. */
                        public image?: (google.cloud.documentai.v1.Document.Page.IImage|null);

                        /** Page transforms. */
                        public transforms: google.cloud.documentai.v1.Document.Page.IMatrix[];

                        /** Page dimension. */
                        public dimension?: (google.cloud.documentai.v1.Document.Page.IDimension|null);

                        /** Page layout. */
                        public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                        /** Page detectedLanguages. */
                        public detectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                        /** Page blocks. */
                        public blocks: google.cloud.documentai.v1.Document.Page.IBlock[];

                        /** Page paragraphs. */
                        public paragraphs: google.cloud.documentai.v1.Document.Page.IParagraph[];

                        /** Page lines. */
                        public lines: google.cloud.documentai.v1.Document.Page.ILine[];

                        /** Page tokens. */
                        public tokens: google.cloud.documentai.v1.Document.Page.IToken[];

                        /** Page visualElements. */
                        public visualElements: google.cloud.documentai.v1.Document.Page.IVisualElement[];

                        /** Page tables. */
                        public tables: google.cloud.documentai.v1.Document.Page.ITable[];

                        /** Page formFields. */
                        public formFields: google.cloud.documentai.v1.Document.Page.IFormField[];

                        /** Page symbols. */
                        public symbols: google.cloud.documentai.v1.Document.Page.ISymbol[];

                        /** Page detectedBarcodes. */
                        public detectedBarcodes: google.cloud.documentai.v1.Document.Page.IDetectedBarcode[];

                        /** Page imageQualityScores. */
                        public imageQualityScores?: (google.cloud.documentai.v1.Document.Page.IImageQualityScores|null);

                        /** Page provenance. */
                        public provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                        /**
                         * Creates a new Page instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Page instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IPage): google.cloud.documentai.v1.Document.Page;

                        /**
                         * Encodes the specified Page message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.verify|verify} messages.
                         * @param message Page message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IPage, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Page message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.verify|verify} messages.
                         * @param message Page message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IPage, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Page message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Page
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page;

                        /**
                         * Decodes a Page message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Page
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page;

                        /**
                         * Verifies a Page message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Page message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Page
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page;

                        /**
                         * Creates a plain object from a Page message. Also converts values to other types if specified.
                         * @param message Page
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.Page, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Page to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Page
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Page {

                        /** Properties of a Dimension. */
                        interface IDimension {

                            /** Dimension width */
                            width?: (number|null);

                            /** Dimension height */
                            height?: (number|null);

                            /** Dimension unit */
                            unit?: (string|null);
                        }

                        /** Represents a Dimension. */
                        class Dimension implements IDimension {

                            /**
                             * Constructs a new Dimension.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IDimension);

                            /** Dimension width. */
                            public width: number;

                            /** Dimension height. */
                            public height: number;

                            /** Dimension unit. */
                            public unit: string;

                            /**
                             * Creates a new Dimension instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Dimension instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IDimension): google.cloud.documentai.v1.Document.Page.Dimension;

                            /**
                             * Encodes the specified Dimension message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Dimension.verify|verify} messages.
                             * @param message Dimension message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IDimension, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Dimension message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Dimension.verify|verify} messages.
                             * @param message Dimension message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IDimension, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Dimension message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Dimension
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Dimension;

                            /**
                             * Decodes a Dimension message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Dimension
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Dimension;

                            /**
                             * Verifies a Dimension message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Dimension message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Dimension
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Dimension;

                            /**
                             * Creates a plain object from a Dimension message. Also converts values to other types if specified.
                             * @param message Dimension
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Dimension, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Dimension to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Dimension
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of an Image. */
                        interface IImage {

                            /** Image content */
                            content?: (Uint8Array|string|null);

                            /** Image mimeType */
                            mimeType?: (string|null);

                            /** Image width */
                            width?: (number|null);

                            /** Image height */
                            height?: (number|null);
                        }

                        /** Represents an Image. */
                        class Image implements IImage {

                            /**
                             * Constructs a new Image.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IImage);

                            /** Image content. */
                            public content: (Uint8Array|string);

                            /** Image mimeType. */
                            public mimeType: string;

                            /** Image width. */
                            public width: number;

                            /** Image height. */
                            public height: number;

                            /**
                             * Creates a new Image instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Image instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IImage): google.cloud.documentai.v1.Document.Page.Image;

                            /**
                             * Encodes the specified Image message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Image.verify|verify} messages.
                             * @param message Image message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IImage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Image message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Image.verify|verify} messages.
                             * @param message Image message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IImage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes an Image message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Image
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Image;

                            /**
                             * Decodes an Image message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Image
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Image;

                            /**
                             * Verifies an Image message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates an Image message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Image
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Image;

                            /**
                             * Creates a plain object from an Image message. Also converts values to other types if specified.
                             * @param message Image
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Image, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Image to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Image
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Matrix. */
                        interface IMatrix {

                            /** Matrix rows */
                            rows?: (number|null);

                            /** Matrix cols */
                            cols?: (number|null);

                            /** Matrix type */
                            type?: (number|null);

                            /** Matrix data */
                            data?: (Uint8Array|string|null);
                        }

                        /** Represents a Matrix. */
                        class Matrix implements IMatrix {

                            /**
                             * Constructs a new Matrix.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IMatrix);

                            /** Matrix rows. */
                            public rows: number;

                            /** Matrix cols. */
                            public cols: number;

                            /** Matrix type. */
                            public type: number;

                            /** Matrix data. */
                            public data: (Uint8Array|string);

                            /**
                             * Creates a new Matrix instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Matrix instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IMatrix): google.cloud.documentai.v1.Document.Page.Matrix;

                            /**
                             * Encodes the specified Matrix message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Matrix.verify|verify} messages.
                             * @param message Matrix message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IMatrix, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Matrix message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Matrix.verify|verify} messages.
                             * @param message Matrix message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IMatrix, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Matrix message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Matrix
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Matrix;

                            /**
                             * Decodes a Matrix message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Matrix
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Matrix;

                            /**
                             * Verifies a Matrix message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Matrix message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Matrix
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Matrix;

                            /**
                             * Creates a plain object from a Matrix message. Also converts values to other types if specified.
                             * @param message Matrix
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Matrix, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Matrix to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Matrix
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Layout. */
                        interface ILayout {

                            /** Layout textAnchor */
                            textAnchor?: (google.cloud.documentai.v1.Document.ITextAnchor|null);

                            /** Layout confidence */
                            confidence?: (number|null);

                            /** Layout boundingPoly */
                            boundingPoly?: (google.cloud.documentai.v1.IBoundingPoly|null);

                            /** Layout orientation */
                            orientation?: (google.cloud.documentai.v1.Document.Page.Layout.Orientation|keyof typeof google.cloud.documentai.v1.Document.Page.Layout.Orientation|null);
                        }

                        /** Represents a Layout. */
                        class Layout implements ILayout {

                            /**
                             * Constructs a new Layout.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.ILayout);

                            /** Layout textAnchor. */
                            public textAnchor?: (google.cloud.documentai.v1.Document.ITextAnchor|null);

                            /** Layout confidence. */
                            public confidence: number;

                            /** Layout boundingPoly. */
                            public boundingPoly?: (google.cloud.documentai.v1.IBoundingPoly|null);

                            /** Layout orientation. */
                            public orientation: (google.cloud.documentai.v1.Document.Page.Layout.Orientation|keyof typeof google.cloud.documentai.v1.Document.Page.Layout.Orientation);

                            /**
                             * Creates a new Layout instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Layout instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.ILayout): google.cloud.documentai.v1.Document.Page.Layout;

                            /**
                             * Encodes the specified Layout message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Layout.verify|verify} messages.
                             * @param message Layout message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.ILayout, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Layout message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Layout.verify|verify} messages.
                             * @param message Layout message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.ILayout, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Layout message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Layout
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Layout;

                            /**
                             * Decodes a Layout message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Layout
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Layout;

                            /**
                             * Verifies a Layout message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Layout message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Layout
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Layout;

                            /**
                             * Creates a plain object from a Layout message. Also converts values to other types if specified.
                             * @param message Layout
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Layout, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Layout to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Layout
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Layout {

                            /** Orientation enum. */
                            enum Orientation {
                                ORIENTATION_UNSPECIFIED = 0,
                                PAGE_UP = 1,
                                PAGE_RIGHT = 2,
                                PAGE_DOWN = 3,
                                PAGE_LEFT = 4
                            }
                        }

                        /** Properties of a Block. */
                        interface IBlock {

                            /** Block layout */
                            layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Block detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);

                            /** Block provenance */
                            provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);
                        }

                        /** Represents a Block. */
                        class Block implements IBlock {

                            /**
                             * Constructs a new Block.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IBlock);

                            /** Block layout. */
                            public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Block detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                            /** Block provenance. */
                            public provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                            /**
                             * Creates a new Block instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Block instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IBlock): google.cloud.documentai.v1.Document.Page.Block;

                            /**
                             * Encodes the specified Block message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Block.verify|verify} messages.
                             * @param message Block message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Block message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Block.verify|verify} messages.
                             * @param message Block message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Block message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Block
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Block;

                            /**
                             * Decodes a Block message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Block
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Block;

                            /**
                             * Verifies a Block message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Block message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Block
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Block;

                            /**
                             * Creates a plain object from a Block message. Also converts values to other types if specified.
                             * @param message Block
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Block, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Block to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Block
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Paragraph. */
                        interface IParagraph {

                            /** Paragraph layout */
                            layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Paragraph detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);

                            /** Paragraph provenance */
                            provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);
                        }

                        /** Represents a Paragraph. */
                        class Paragraph implements IParagraph {

                            /**
                             * Constructs a new Paragraph.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IParagraph);

                            /** Paragraph layout. */
                            public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Paragraph detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                            /** Paragraph provenance. */
                            public provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                            /**
                             * Creates a new Paragraph instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Paragraph instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IParagraph): google.cloud.documentai.v1.Document.Page.Paragraph;

                            /**
                             * Encodes the specified Paragraph message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Paragraph.verify|verify} messages.
                             * @param message Paragraph message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IParagraph, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Paragraph message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Paragraph.verify|verify} messages.
                             * @param message Paragraph message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IParagraph, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Paragraph message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Paragraph
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Paragraph;

                            /**
                             * Decodes a Paragraph message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Paragraph
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Paragraph;

                            /**
                             * Verifies a Paragraph message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Paragraph message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Paragraph
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Paragraph;

                            /**
                             * Creates a plain object from a Paragraph message. Also converts values to other types if specified.
                             * @param message Paragraph
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Paragraph, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Paragraph to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Paragraph
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Line. */
                        interface ILine {

                            /** Line layout */
                            layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Line detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);

                            /** Line provenance */
                            provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);
                        }

                        /** Represents a Line. */
                        class Line implements ILine {

                            /**
                             * Constructs a new Line.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.ILine);

                            /** Line layout. */
                            public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Line detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                            /** Line provenance. */
                            public provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                            /**
                             * Creates a new Line instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Line instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.ILine): google.cloud.documentai.v1.Document.Page.Line;

                            /**
                             * Encodes the specified Line message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Line.verify|verify} messages.
                             * @param message Line message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.ILine, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Line message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Line.verify|verify} messages.
                             * @param message Line message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.ILine, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Line message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Line
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Line;

                            /**
                             * Decodes a Line message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Line
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Line;

                            /**
                             * Verifies a Line message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Line message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Line
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Line;

                            /**
                             * Creates a plain object from a Line message. Also converts values to other types if specified.
                             * @param message Line
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Line, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Line to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Line
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Token. */
                        interface IToken {

                            /** Token layout */
                            layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Token detectedBreak */
                            detectedBreak?: (google.cloud.documentai.v1.Document.Page.Token.IDetectedBreak|null);

                            /** Token detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);

                            /** Token provenance */
                            provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                            /** Token styleInfo */
                            styleInfo?: (google.cloud.documentai.v1.Document.Page.Token.IStyleInfo|null);
                        }

                        /** Represents a Token. */
                        class Token implements IToken {

                            /**
                             * Constructs a new Token.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IToken);

                            /** Token layout. */
                            public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Token detectedBreak. */
                            public detectedBreak?: (google.cloud.documentai.v1.Document.Page.Token.IDetectedBreak|null);

                            /** Token detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                            /** Token provenance. */
                            public provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                            /** Token styleInfo. */
                            public styleInfo?: (google.cloud.documentai.v1.Document.Page.Token.IStyleInfo|null);

                            /**
                             * Creates a new Token instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Token instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IToken): google.cloud.documentai.v1.Document.Page.Token;

                            /**
                             * Encodes the specified Token message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Token.verify|verify} messages.
                             * @param message Token message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IToken, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Token message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Token.verify|verify} messages.
                             * @param message Token message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IToken, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Token message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Token
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Token;

                            /**
                             * Decodes a Token message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Token
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Token;

                            /**
                             * Verifies a Token message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Token message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Token
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Token;

                            /**
                             * Creates a plain object from a Token message. Also converts values to other types if specified.
                             * @param message Token
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Token, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Token to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Token
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Token {

                            /** Properties of a DetectedBreak. */
                            interface IDetectedBreak {

                                /** DetectedBreak type */
                                type?: (google.cloud.documentai.v1.Document.Page.Token.DetectedBreak.Type|keyof typeof google.cloud.documentai.v1.Document.Page.Token.DetectedBreak.Type|null);
                            }

                            /** Represents a DetectedBreak. */
                            class DetectedBreak implements IDetectedBreak {

                                /**
                                 * Constructs a new DetectedBreak.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.Page.Token.IDetectedBreak);

                                /** DetectedBreak type. */
                                public type: (google.cloud.documentai.v1.Document.Page.Token.DetectedBreak.Type|keyof typeof google.cloud.documentai.v1.Document.Page.Token.DetectedBreak.Type);

                                /**
                                 * Creates a new DetectedBreak instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns DetectedBreak instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.Page.Token.IDetectedBreak): google.cloud.documentai.v1.Document.Page.Token.DetectedBreak;

                                /**
                                 * Encodes the specified DetectedBreak message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Token.DetectedBreak.verify|verify} messages.
                                 * @param message DetectedBreak message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.Page.Token.IDetectedBreak, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified DetectedBreak message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Token.DetectedBreak.verify|verify} messages.
                                 * @param message DetectedBreak message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.Token.IDetectedBreak, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a DetectedBreak message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns DetectedBreak
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Token.DetectedBreak;

                                /**
                                 * Decodes a DetectedBreak message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns DetectedBreak
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Token.DetectedBreak;

                                /**
                                 * Verifies a DetectedBreak message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a DetectedBreak message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns DetectedBreak
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Token.DetectedBreak;

                                /**
                                 * Creates a plain object from a DetectedBreak message. Also converts values to other types if specified.
                                 * @param message DetectedBreak
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.Page.Token.DetectedBreak, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this DetectedBreak to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for DetectedBreak
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            namespace DetectedBreak {

                                /** Type enum. */
                                enum Type {
                                    TYPE_UNSPECIFIED = 0,
                                    SPACE = 1,
                                    WIDE_SPACE = 2,
                                    HYPHEN = 3
                                }
                            }

                            /** Properties of a StyleInfo. */
                            interface IStyleInfo {

                                /** StyleInfo fontSize */
                                fontSize?: (number|null);

                                /** StyleInfo pixelFontSize */
                                pixelFontSize?: (number|null);

                                /** StyleInfo letterSpacing */
                                letterSpacing?: (number|null);

                                /** StyleInfo fontType */
                                fontType?: (string|null);

                                /** StyleInfo bold */
                                bold?: (boolean|null);

                                /** StyleInfo italic */
                                italic?: (boolean|null);

                                /** StyleInfo underlined */
                                underlined?: (boolean|null);

                                /** StyleInfo strikeout */
                                strikeout?: (boolean|null);

                                /** StyleInfo subscript */
                                subscript?: (boolean|null);

                                /** StyleInfo superscript */
                                superscript?: (boolean|null);

                                /** StyleInfo smallcaps */
                                smallcaps?: (boolean|null);

                                /** StyleInfo fontWeight */
                                fontWeight?: (number|null);

                                /** StyleInfo handwritten */
                                handwritten?: (boolean|null);

                                /** StyleInfo textColor */
                                textColor?: (google.type.IColor|null);

                                /** StyleInfo backgroundColor */
                                backgroundColor?: (google.type.IColor|null);
                            }

                            /** Represents a StyleInfo. */
                            class StyleInfo implements IStyleInfo {

                                /**
                                 * Constructs a new StyleInfo.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.Page.Token.IStyleInfo);

                                /** StyleInfo fontSize. */
                                public fontSize: number;

                                /** StyleInfo pixelFontSize. */
                                public pixelFontSize: number;

                                /** StyleInfo letterSpacing. */
                                public letterSpacing: number;

                                /** StyleInfo fontType. */
                                public fontType: string;

                                /** StyleInfo bold. */
                                public bold: boolean;

                                /** StyleInfo italic. */
                                public italic: boolean;

                                /** StyleInfo underlined. */
                                public underlined: boolean;

                                /** StyleInfo strikeout. */
                                public strikeout: boolean;

                                /** StyleInfo subscript. */
                                public subscript: boolean;

                                /** StyleInfo superscript. */
                                public superscript: boolean;

                                /** StyleInfo smallcaps. */
                                public smallcaps: boolean;

                                /** StyleInfo fontWeight. */
                                public fontWeight: number;

                                /** StyleInfo handwritten. */
                                public handwritten: boolean;

                                /** StyleInfo textColor. */
                                public textColor?: (google.type.IColor|null);

                                /** StyleInfo backgroundColor. */
                                public backgroundColor?: (google.type.IColor|null);

                                /**
                                 * Creates a new StyleInfo instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns StyleInfo instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.Page.Token.IStyleInfo): google.cloud.documentai.v1.Document.Page.Token.StyleInfo;

                                /**
                                 * Encodes the specified StyleInfo message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Token.StyleInfo.verify|verify} messages.
                                 * @param message StyleInfo message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.Page.Token.IStyleInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified StyleInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Token.StyleInfo.verify|verify} messages.
                                 * @param message StyleInfo message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.Token.IStyleInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a StyleInfo message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns StyleInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Token.StyleInfo;

                                /**
                                 * Decodes a StyleInfo message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns StyleInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Token.StyleInfo;

                                /**
                                 * Verifies a StyleInfo message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a StyleInfo message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns StyleInfo
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Token.StyleInfo;

                                /**
                                 * Creates a plain object from a StyleInfo message. Also converts values to other types if specified.
                                 * @param message StyleInfo
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.Page.Token.StyleInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this StyleInfo to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for StyleInfo
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }

                        /** Properties of a Symbol. */
                        interface ISymbol {

                            /** Symbol layout */
                            layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Symbol detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a Symbol. */
                        class Symbol implements ISymbol {

                            /**
                             * Constructs a new Symbol.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.ISymbol);

                            /** Symbol layout. */
                            public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Symbol detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new Symbol instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Symbol instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.ISymbol): google.cloud.documentai.v1.Document.Page.Symbol;

                            /**
                             * Encodes the specified Symbol message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Symbol.verify|verify} messages.
                             * @param message Symbol message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.ISymbol, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Symbol message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Symbol.verify|verify} messages.
                             * @param message Symbol message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.ISymbol, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Symbol message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Symbol
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Symbol;

                            /**
                             * Decodes a Symbol message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Symbol
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Symbol;

                            /**
                             * Verifies a Symbol message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Symbol message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Symbol
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Symbol;

                            /**
                             * Creates a plain object from a Symbol message. Also converts values to other types if specified.
                             * @param message Symbol
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Symbol, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Symbol to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Symbol
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a VisualElement. */
                        interface IVisualElement {

                            /** VisualElement layout */
                            layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** VisualElement type */
                            type?: (string|null);

                            /** VisualElement detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a VisualElement. */
                        class VisualElement implements IVisualElement {

                            /**
                             * Constructs a new VisualElement.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IVisualElement);

                            /** VisualElement layout. */
                            public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** VisualElement type. */
                            public type: string;

                            /** VisualElement detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new VisualElement instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns VisualElement instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IVisualElement): google.cloud.documentai.v1.Document.Page.VisualElement;

                            /**
                             * Encodes the specified VisualElement message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.VisualElement.verify|verify} messages.
                             * @param message VisualElement message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IVisualElement, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified VisualElement message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.VisualElement.verify|verify} messages.
                             * @param message VisualElement message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IVisualElement, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a VisualElement message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns VisualElement
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.VisualElement;

                            /**
                             * Decodes a VisualElement message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns VisualElement
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.VisualElement;

                            /**
                             * Verifies a VisualElement message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a VisualElement message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns VisualElement
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.VisualElement;

                            /**
                             * Creates a plain object from a VisualElement message. Also converts values to other types if specified.
                             * @param message VisualElement
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.VisualElement, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this VisualElement to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for VisualElement
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Table. */
                        interface ITable {

                            /** Table layout */
                            layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Table headerRows */
                            headerRows?: (google.cloud.documentai.v1.Document.Page.Table.ITableRow[]|null);

                            /** Table bodyRows */
                            bodyRows?: (google.cloud.documentai.v1.Document.Page.Table.ITableRow[]|null);

                            /** Table detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);

                            /** Table provenance */
                            provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);
                        }

                        /** Represents a Table. */
                        class Table implements ITable {

                            /**
                             * Constructs a new Table.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.ITable);

                            /** Table layout. */
                            public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** Table headerRows. */
                            public headerRows: google.cloud.documentai.v1.Document.Page.Table.ITableRow[];

                            /** Table bodyRows. */
                            public bodyRows: google.cloud.documentai.v1.Document.Page.Table.ITableRow[];

                            /** Table detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                            /** Table provenance. */
                            public provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                            /**
                             * Creates a new Table instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Table instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.ITable): google.cloud.documentai.v1.Document.Page.Table;

                            /**
                             * Encodes the specified Table message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Table.verify|verify} messages.
                             * @param message Table message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.ITable, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Table message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Table.verify|verify} messages.
                             * @param message Table message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.ITable, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Table message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Table
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Table;

                            /**
                             * Decodes a Table message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Table
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Table;

                            /**
                             * Verifies a Table message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Table message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Table
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Table;

                            /**
                             * Creates a plain object from a Table message. Also converts values to other types if specified.
                             * @param message Table
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.Table, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Table to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Table
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Table {

                            /** Properties of a TableRow. */
                            interface ITableRow {

                                /** TableRow cells */
                                cells?: (google.cloud.documentai.v1.Document.Page.Table.ITableCell[]|null);
                            }

                            /** Represents a TableRow. */
                            class TableRow implements ITableRow {

                                /**
                                 * Constructs a new TableRow.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.Page.Table.ITableRow);

                                /** TableRow cells. */
                                public cells: google.cloud.documentai.v1.Document.Page.Table.ITableCell[];

                                /**
                                 * Creates a new TableRow instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns TableRow instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.Page.Table.ITableRow): google.cloud.documentai.v1.Document.Page.Table.TableRow;

                                /**
                                 * Encodes the specified TableRow message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Table.TableRow.verify|verify} messages.
                                 * @param message TableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.Page.Table.ITableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified TableRow message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Table.TableRow.verify|verify} messages.
                                 * @param message TableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.Table.ITableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a TableRow message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns TableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Table.TableRow;

                                /**
                                 * Decodes a TableRow message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns TableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Table.TableRow;

                                /**
                                 * Verifies a TableRow message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a TableRow message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns TableRow
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Table.TableRow;

                                /**
                                 * Creates a plain object from a TableRow message. Also converts values to other types if specified.
                                 * @param message TableRow
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.Page.Table.TableRow, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this TableRow to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for TableRow
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a TableCell. */
                            interface ITableCell {

                                /** TableCell layout */
                                layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                                /** TableCell rowSpan */
                                rowSpan?: (number|null);

                                /** TableCell colSpan */
                                colSpan?: (number|null);

                                /** TableCell detectedLanguages */
                                detectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);
                            }

                            /** Represents a TableCell. */
                            class TableCell implements ITableCell {

                                /**
                                 * Constructs a new TableCell.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.Page.Table.ITableCell);

                                /** TableCell layout. */
                                public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                                /** TableCell rowSpan. */
                                public rowSpan: number;

                                /** TableCell colSpan. */
                                public colSpan: number;

                                /** TableCell detectedLanguages. */
                                public detectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                                /**
                                 * Creates a new TableCell instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns TableCell instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.Page.Table.ITableCell): google.cloud.documentai.v1.Document.Page.Table.TableCell;

                                /**
                                 * Encodes the specified TableCell message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Table.TableCell.verify|verify} messages.
                                 * @param message TableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.Page.Table.ITableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified TableCell message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.Table.TableCell.verify|verify} messages.
                                 * @param message TableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.Table.ITableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a TableCell message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns TableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.Table.TableCell;

                                /**
                                 * Decodes a TableCell message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns TableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.Table.TableCell;

                                /**
                                 * Verifies a TableCell message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a TableCell message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns TableCell
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.Table.TableCell;

                                /**
                                 * Creates a plain object from a TableCell message. Also converts values to other types if specified.
                                 * @param message TableCell
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.Page.Table.TableCell, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this TableCell to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for TableCell
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }

                        /** Properties of a FormField. */
                        interface IFormField {

                            /** FormField fieldName */
                            fieldName?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** FormField fieldValue */
                            fieldValue?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** FormField nameDetectedLanguages */
                            nameDetectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);

                            /** FormField valueDetectedLanguages */
                            valueDetectedLanguages?: (google.cloud.documentai.v1.Document.Page.IDetectedLanguage[]|null);

                            /** FormField valueType */
                            valueType?: (string|null);

                            /** FormField correctedKeyText */
                            correctedKeyText?: (string|null);

                            /** FormField correctedValueText */
                            correctedValueText?: (string|null);

                            /** FormField provenance */
                            provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);
                        }

                        /** Represents a FormField. */
                        class FormField implements IFormField {

                            /**
                             * Constructs a new FormField.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IFormField);

                            /** FormField fieldName. */
                            public fieldName?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** FormField fieldValue. */
                            public fieldValue?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** FormField nameDetectedLanguages. */
                            public nameDetectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                            /** FormField valueDetectedLanguages. */
                            public valueDetectedLanguages: google.cloud.documentai.v1.Document.Page.IDetectedLanguage[];

                            /** FormField valueType. */
                            public valueType: string;

                            /** FormField correctedKeyText. */
                            public correctedKeyText: string;

                            /** FormField correctedValueText. */
                            public correctedValueText: string;

                            /** FormField provenance. */
                            public provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                            /**
                             * Creates a new FormField instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FormField instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IFormField): google.cloud.documentai.v1.Document.Page.FormField;

                            /**
                             * Encodes the specified FormField message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.FormField.verify|verify} messages.
                             * @param message FormField message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IFormField, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FormField message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.FormField.verify|verify} messages.
                             * @param message FormField message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IFormField, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FormField message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FormField
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.FormField;

                            /**
                             * Decodes a FormField message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FormField
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.FormField;

                            /**
                             * Verifies a FormField message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FormField message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FormField
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.FormField;

                            /**
                             * Creates a plain object from a FormField message. Also converts values to other types if specified.
                             * @param message FormField
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.FormField, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FormField to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FormField
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a DetectedBarcode. */
                        interface IDetectedBarcode {

                            /** DetectedBarcode layout */
                            layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** DetectedBarcode barcode */
                            barcode?: (google.cloud.documentai.v1.IBarcode|null);
                        }

                        /** Represents a DetectedBarcode. */
                        class DetectedBarcode implements IDetectedBarcode {

                            /**
                             * Constructs a new DetectedBarcode.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IDetectedBarcode);

                            /** DetectedBarcode layout. */
                            public layout?: (google.cloud.documentai.v1.Document.Page.ILayout|null);

                            /** DetectedBarcode barcode. */
                            public barcode?: (google.cloud.documentai.v1.IBarcode|null);

                            /**
                             * Creates a new DetectedBarcode instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns DetectedBarcode instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IDetectedBarcode): google.cloud.documentai.v1.Document.Page.DetectedBarcode;

                            /**
                             * Encodes the specified DetectedBarcode message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.DetectedBarcode.verify|verify} messages.
                             * @param message DetectedBarcode message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IDetectedBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified DetectedBarcode message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.DetectedBarcode.verify|verify} messages.
                             * @param message DetectedBarcode message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IDetectedBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a DetectedBarcode message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns DetectedBarcode
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.DetectedBarcode;

                            /**
                             * Decodes a DetectedBarcode message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns DetectedBarcode
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.DetectedBarcode;

                            /**
                             * Verifies a DetectedBarcode message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a DetectedBarcode message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns DetectedBarcode
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.DetectedBarcode;

                            /**
                             * Creates a plain object from a DetectedBarcode message. Also converts values to other types if specified.
                             * @param message DetectedBarcode
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.DetectedBarcode, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this DetectedBarcode to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for DetectedBarcode
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a DetectedLanguage. */
                        interface IDetectedLanguage {

                            /** DetectedLanguage languageCode */
                            languageCode?: (string|null);

                            /** DetectedLanguage confidence */
                            confidence?: (number|null);
                        }

                        /** Represents a DetectedLanguage. */
                        class DetectedLanguage implements IDetectedLanguage {

                            /**
                             * Constructs a new DetectedLanguage.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IDetectedLanguage);

                            /** DetectedLanguage languageCode. */
                            public languageCode: string;

                            /** DetectedLanguage confidence. */
                            public confidence: number;

                            /**
                             * Creates a new DetectedLanguage instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns DetectedLanguage instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IDetectedLanguage): google.cloud.documentai.v1.Document.Page.DetectedLanguage;

                            /**
                             * Encodes the specified DetectedLanguage message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.DetectedLanguage.verify|verify} messages.
                             * @param message DetectedLanguage message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IDetectedLanguage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified DetectedLanguage message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.DetectedLanguage.verify|verify} messages.
                             * @param message DetectedLanguage message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IDetectedLanguage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a DetectedLanguage message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns DetectedLanguage
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.DetectedLanguage;

                            /**
                             * Decodes a DetectedLanguage message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns DetectedLanguage
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.DetectedLanguage;

                            /**
                             * Verifies a DetectedLanguage message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a DetectedLanguage message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns DetectedLanguage
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.DetectedLanguage;

                            /**
                             * Creates a plain object from a DetectedLanguage message. Also converts values to other types if specified.
                             * @param message DetectedLanguage
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.DetectedLanguage, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this DetectedLanguage to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for DetectedLanguage
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of an ImageQualityScores. */
                        interface IImageQualityScores {

                            /** ImageQualityScores qualityScore */
                            qualityScore?: (number|null);

                            /** ImageQualityScores detectedDefects */
                            detectedDefects?: (google.cloud.documentai.v1.Document.Page.ImageQualityScores.IDetectedDefect[]|null);
                        }

                        /** Represents an ImageQualityScores. */
                        class ImageQualityScores implements IImageQualityScores {

                            /**
                             * Constructs a new ImageQualityScores.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Page.IImageQualityScores);

                            /** ImageQualityScores qualityScore. */
                            public qualityScore: number;

                            /** ImageQualityScores detectedDefects. */
                            public detectedDefects: google.cloud.documentai.v1.Document.Page.ImageQualityScores.IDetectedDefect[];

                            /**
                             * Creates a new ImageQualityScores instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns ImageQualityScores instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Page.IImageQualityScores): google.cloud.documentai.v1.Document.Page.ImageQualityScores;

                            /**
                             * Encodes the specified ImageQualityScores message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.ImageQualityScores.verify|verify} messages.
                             * @param message ImageQualityScores message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Page.IImageQualityScores, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified ImageQualityScores message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.ImageQualityScores.verify|verify} messages.
                             * @param message ImageQualityScores message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.IImageQualityScores, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes an ImageQualityScores message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns ImageQualityScores
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.ImageQualityScores;

                            /**
                             * Decodes an ImageQualityScores message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns ImageQualityScores
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.ImageQualityScores;

                            /**
                             * Verifies an ImageQualityScores message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates an ImageQualityScores message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns ImageQualityScores
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.ImageQualityScores;

                            /**
                             * Creates a plain object from an ImageQualityScores message. Also converts values to other types if specified.
                             * @param message ImageQualityScores
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Page.ImageQualityScores, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this ImageQualityScores to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for ImageQualityScores
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace ImageQualityScores {

                            /** Properties of a DetectedDefect. */
                            interface IDetectedDefect {

                                /** DetectedDefect type */
                                type?: (string|null);

                                /** DetectedDefect confidence */
                                confidence?: (number|null);
                            }

                            /** Represents a DetectedDefect. */
                            class DetectedDefect implements IDetectedDefect {

                                /**
                                 * Constructs a new DetectedDefect.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.Page.ImageQualityScores.IDetectedDefect);

                                /** DetectedDefect type. */
                                public type: string;

                                /** DetectedDefect confidence. */
                                public confidence: number;

                                /**
                                 * Creates a new DetectedDefect instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns DetectedDefect instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.Page.ImageQualityScores.IDetectedDefect): google.cloud.documentai.v1.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Encodes the specified DetectedDefect message. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.ImageQualityScores.DetectedDefect.verify|verify} messages.
                                 * @param message DetectedDefect message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.Page.ImageQualityScores.IDetectedDefect, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified DetectedDefect message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Page.ImageQualityScores.DetectedDefect.verify|verify} messages.
                                 * @param message DetectedDefect message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.Page.ImageQualityScores.IDetectedDefect, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a DetectedDefect message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns DetectedDefect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Decodes a DetectedDefect message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns DetectedDefect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Verifies a DetectedDefect message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a DetectedDefect message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns DetectedDefect
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Creates a plain object from a DetectedDefect message. Also converts values to other types if specified.
                                 * @param message DetectedDefect
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.Page.ImageQualityScores.DetectedDefect, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this DetectedDefect to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for DetectedDefect
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }
                    }

                    /** Properties of an Entity. */
                    interface IEntity {

                        /** Entity textAnchor */
                        textAnchor?: (google.cloud.documentai.v1.Document.ITextAnchor|null);

                        /** Entity type */
                        type?: (string|null);

                        /** Entity mentionText */
                        mentionText?: (string|null);

                        /** Entity mentionId */
                        mentionId?: (string|null);

                        /** Entity confidence */
                        confidence?: (number|null);

                        /** Entity pageAnchor */
                        pageAnchor?: (google.cloud.documentai.v1.Document.IPageAnchor|null);

                        /** Entity id */
                        id?: (string|null);

                        /** Entity normalizedValue */
                        normalizedValue?: (google.cloud.documentai.v1.Document.Entity.INormalizedValue|null);

                        /** Entity properties */
                        properties?: (google.cloud.documentai.v1.Document.IEntity[]|null);

                        /** Entity provenance */
                        provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                        /** Entity redacted */
                        redacted?: (boolean|null);
                    }

                    /** Represents an Entity. */
                    class Entity implements IEntity {

                        /**
                         * Constructs a new Entity.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IEntity);

                        /** Entity textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1.Document.ITextAnchor|null);

                        /** Entity type. */
                        public type: string;

                        /** Entity mentionText. */
                        public mentionText: string;

                        /** Entity mentionId. */
                        public mentionId: string;

                        /** Entity confidence. */
                        public confidence: number;

                        /** Entity pageAnchor. */
                        public pageAnchor?: (google.cloud.documentai.v1.Document.IPageAnchor|null);

                        /** Entity id. */
                        public id: string;

                        /** Entity normalizedValue. */
                        public normalizedValue?: (google.cloud.documentai.v1.Document.Entity.INormalizedValue|null);

                        /** Entity properties. */
                        public properties: google.cloud.documentai.v1.Document.IEntity[];

                        /** Entity provenance. */
                        public provenance?: (google.cloud.documentai.v1.Document.IProvenance|null);

                        /** Entity redacted. */
                        public redacted: boolean;

                        /**
                         * Creates a new Entity instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Entity instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IEntity): google.cloud.documentai.v1.Document.Entity;

                        /**
                         * Encodes the specified Entity message. Does not implicitly {@link google.cloud.documentai.v1.Document.Entity.verify|verify} messages.
                         * @param message Entity message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IEntity, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Entity message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Entity.verify|verify} messages.
                         * @param message Entity message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IEntity, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an Entity message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Entity
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Entity;

                        /**
                         * Decodes an Entity message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Entity
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Entity;

                        /**
                         * Verifies an Entity message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an Entity message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Entity
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Entity;

                        /**
                         * Creates a plain object from an Entity message. Also converts values to other types if specified.
                         * @param message Entity
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.Entity, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Entity to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Entity
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Entity {

                        /** Properties of a NormalizedValue. */
                        interface INormalizedValue {

                            /** NormalizedValue moneyValue */
                            moneyValue?: (google.type.IMoney|null);

                            /** NormalizedValue dateValue */
                            dateValue?: (google.type.IDate|null);

                            /** NormalizedValue datetimeValue */
                            datetimeValue?: (google.type.IDateTime|null);

                            /** NormalizedValue addressValue */
                            addressValue?: (google.type.IPostalAddress|null);

                            /** NormalizedValue booleanValue */
                            booleanValue?: (boolean|null);

                            /** NormalizedValue integerValue */
                            integerValue?: (number|null);

                            /** NormalizedValue floatValue */
                            floatValue?: (number|null);

                            /** NormalizedValue text */
                            text?: (string|null);
                        }

                        /** Represents a NormalizedValue. */
                        class NormalizedValue implements INormalizedValue {

                            /**
                             * Constructs a new NormalizedValue.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Entity.INormalizedValue);

                            /** NormalizedValue moneyValue. */
                            public moneyValue?: (google.type.IMoney|null);

                            /** NormalizedValue dateValue. */
                            public dateValue?: (google.type.IDate|null);

                            /** NormalizedValue datetimeValue. */
                            public datetimeValue?: (google.type.IDateTime|null);

                            /** NormalizedValue addressValue. */
                            public addressValue?: (google.type.IPostalAddress|null);

                            /** NormalizedValue booleanValue. */
                            public booleanValue?: (boolean|null);

                            /** NormalizedValue integerValue. */
                            public integerValue?: (number|null);

                            /** NormalizedValue floatValue. */
                            public floatValue?: (number|null);

                            /** NormalizedValue text. */
                            public text: string;

                            /** NormalizedValue structuredValue. */
                            public structuredValue?: ("moneyValue"|"dateValue"|"datetimeValue"|"addressValue"|"booleanValue"|"integerValue"|"floatValue");

                            /**
                             * Creates a new NormalizedValue instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns NormalizedValue instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Entity.INormalizedValue): google.cloud.documentai.v1.Document.Entity.NormalizedValue;

                            /**
                             * Encodes the specified NormalizedValue message. Does not implicitly {@link google.cloud.documentai.v1.Document.Entity.NormalizedValue.verify|verify} messages.
                             * @param message NormalizedValue message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Entity.INormalizedValue, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified NormalizedValue message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Entity.NormalizedValue.verify|verify} messages.
                             * @param message NormalizedValue message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Entity.INormalizedValue, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a NormalizedValue message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns NormalizedValue
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Entity.NormalizedValue;

                            /**
                             * Decodes a NormalizedValue message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns NormalizedValue
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Entity.NormalizedValue;

                            /**
                             * Verifies a NormalizedValue message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a NormalizedValue message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns NormalizedValue
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Entity.NormalizedValue;

                            /**
                             * Creates a plain object from a NormalizedValue message. Also converts values to other types if specified.
                             * @param message NormalizedValue
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Entity.NormalizedValue, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this NormalizedValue to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for NormalizedValue
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of an EntityRelation. */
                    interface IEntityRelation {

                        /** EntityRelation subjectId */
                        subjectId?: (string|null);

                        /** EntityRelation objectId */
                        objectId?: (string|null);

                        /** EntityRelation relation */
                        relation?: (string|null);
                    }

                    /** Represents an EntityRelation. */
                    class EntityRelation implements IEntityRelation {

                        /**
                         * Constructs a new EntityRelation.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IEntityRelation);

                        /** EntityRelation subjectId. */
                        public subjectId: string;

                        /** EntityRelation objectId. */
                        public objectId: string;

                        /** EntityRelation relation. */
                        public relation: string;

                        /**
                         * Creates a new EntityRelation instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns EntityRelation instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IEntityRelation): google.cloud.documentai.v1.Document.EntityRelation;

                        /**
                         * Encodes the specified EntityRelation message. Does not implicitly {@link google.cloud.documentai.v1.Document.EntityRelation.verify|verify} messages.
                         * @param message EntityRelation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IEntityRelation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified EntityRelation message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.EntityRelation.verify|verify} messages.
                         * @param message EntityRelation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IEntityRelation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an EntityRelation message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns EntityRelation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.EntityRelation;

                        /**
                         * Decodes an EntityRelation message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns EntityRelation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.EntityRelation;

                        /**
                         * Verifies an EntityRelation message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an EntityRelation message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns EntityRelation
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.EntityRelation;

                        /**
                         * Creates a plain object from an EntityRelation message. Also converts values to other types if specified.
                         * @param message EntityRelation
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.EntityRelation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this EntityRelation to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for EntityRelation
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a TextAnchor. */
                    interface ITextAnchor {

                        /** TextAnchor textSegments */
                        textSegments?: (google.cloud.documentai.v1.Document.TextAnchor.ITextSegment[]|null);

                        /** TextAnchor content */
                        content?: (string|null);
                    }

                    /** Represents a TextAnchor. */
                    class TextAnchor implements ITextAnchor {

                        /**
                         * Constructs a new TextAnchor.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.ITextAnchor);

                        /** TextAnchor textSegments. */
                        public textSegments: google.cloud.documentai.v1.Document.TextAnchor.ITextSegment[];

                        /** TextAnchor content. */
                        public content: string;

                        /**
                         * Creates a new TextAnchor instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns TextAnchor instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.ITextAnchor): google.cloud.documentai.v1.Document.TextAnchor;

                        /**
                         * Encodes the specified TextAnchor message. Does not implicitly {@link google.cloud.documentai.v1.Document.TextAnchor.verify|verify} messages.
                         * @param message TextAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.ITextAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified TextAnchor message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.TextAnchor.verify|verify} messages.
                         * @param message TextAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.ITextAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a TextAnchor message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns TextAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.TextAnchor;

                        /**
                         * Decodes a TextAnchor message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns TextAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.TextAnchor;

                        /**
                         * Verifies a TextAnchor message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a TextAnchor message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns TextAnchor
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.TextAnchor;

                        /**
                         * Creates a plain object from a TextAnchor message. Also converts values to other types if specified.
                         * @param message TextAnchor
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.TextAnchor, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this TextAnchor to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for TextAnchor
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace TextAnchor {

                        /** Properties of a TextSegment. */
                        interface ITextSegment {

                            /** TextSegment startIndex */
                            startIndex?: (number|Long|string|null);

                            /** TextSegment endIndex */
                            endIndex?: (number|Long|string|null);
                        }

                        /** Represents a TextSegment. */
                        class TextSegment implements ITextSegment {

                            /**
                             * Constructs a new TextSegment.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.TextAnchor.ITextSegment);

                            /** TextSegment startIndex. */
                            public startIndex: (number|Long|string);

                            /** TextSegment endIndex. */
                            public endIndex: (number|Long|string);

                            /**
                             * Creates a new TextSegment instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns TextSegment instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.TextAnchor.ITextSegment): google.cloud.documentai.v1.Document.TextAnchor.TextSegment;

                            /**
                             * Encodes the specified TextSegment message. Does not implicitly {@link google.cloud.documentai.v1.Document.TextAnchor.TextSegment.verify|verify} messages.
                             * @param message TextSegment message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.TextAnchor.ITextSegment, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified TextSegment message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.TextAnchor.TextSegment.verify|verify} messages.
                             * @param message TextSegment message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.TextAnchor.ITextSegment, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a TextSegment message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns TextSegment
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.TextAnchor.TextSegment;

                            /**
                             * Decodes a TextSegment message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns TextSegment
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.TextAnchor.TextSegment;

                            /**
                             * Verifies a TextSegment message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a TextSegment message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns TextSegment
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.TextAnchor.TextSegment;

                            /**
                             * Creates a plain object from a TextSegment message. Also converts values to other types if specified.
                             * @param message TextSegment
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.TextAnchor.TextSegment, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this TextSegment to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for TextSegment
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a PageAnchor. */
                    interface IPageAnchor {

                        /** PageAnchor pageRefs */
                        pageRefs?: (google.cloud.documentai.v1.Document.PageAnchor.IPageRef[]|null);
                    }

                    /** Represents a PageAnchor. */
                    class PageAnchor implements IPageAnchor {

                        /**
                         * Constructs a new PageAnchor.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IPageAnchor);

                        /** PageAnchor pageRefs. */
                        public pageRefs: google.cloud.documentai.v1.Document.PageAnchor.IPageRef[];

                        /**
                         * Creates a new PageAnchor instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns PageAnchor instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IPageAnchor): google.cloud.documentai.v1.Document.PageAnchor;

                        /**
                         * Encodes the specified PageAnchor message. Does not implicitly {@link google.cloud.documentai.v1.Document.PageAnchor.verify|verify} messages.
                         * @param message PageAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IPageAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified PageAnchor message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.PageAnchor.verify|verify} messages.
                         * @param message PageAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IPageAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a PageAnchor message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns PageAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.PageAnchor;

                        /**
                         * Decodes a PageAnchor message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns PageAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.PageAnchor;

                        /**
                         * Verifies a PageAnchor message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a PageAnchor message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns PageAnchor
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.PageAnchor;

                        /**
                         * Creates a plain object from a PageAnchor message. Also converts values to other types if specified.
                         * @param message PageAnchor
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.PageAnchor, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this PageAnchor to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for PageAnchor
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace PageAnchor {

                        /** Properties of a PageRef. */
                        interface IPageRef {

                            /** PageRef page */
                            page?: (number|Long|string|null);

                            /** PageRef layoutType */
                            layoutType?: (google.cloud.documentai.v1.Document.PageAnchor.PageRef.LayoutType|keyof typeof google.cloud.documentai.v1.Document.PageAnchor.PageRef.LayoutType|null);

                            /** PageRef layoutId */
                            layoutId?: (string|null);

                            /** PageRef boundingPoly */
                            boundingPoly?: (google.cloud.documentai.v1.IBoundingPoly|null);

                            /** PageRef confidence */
                            confidence?: (number|null);
                        }

                        /** Represents a PageRef. */
                        class PageRef implements IPageRef {

                            /**
                             * Constructs a new PageRef.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.PageAnchor.IPageRef);

                            /** PageRef page. */
                            public page: (number|Long|string);

                            /** PageRef layoutType. */
                            public layoutType: (google.cloud.documentai.v1.Document.PageAnchor.PageRef.LayoutType|keyof typeof google.cloud.documentai.v1.Document.PageAnchor.PageRef.LayoutType);

                            /** PageRef layoutId. */
                            public layoutId: string;

                            /** PageRef boundingPoly. */
                            public boundingPoly?: (google.cloud.documentai.v1.IBoundingPoly|null);

                            /** PageRef confidence. */
                            public confidence: number;

                            /**
                             * Creates a new PageRef instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns PageRef instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.PageAnchor.IPageRef): google.cloud.documentai.v1.Document.PageAnchor.PageRef;

                            /**
                             * Encodes the specified PageRef message. Does not implicitly {@link google.cloud.documentai.v1.Document.PageAnchor.PageRef.verify|verify} messages.
                             * @param message PageRef message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.PageAnchor.IPageRef, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified PageRef message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.PageAnchor.PageRef.verify|verify} messages.
                             * @param message PageRef message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.PageAnchor.IPageRef, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a PageRef message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns PageRef
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.PageAnchor.PageRef;

                            /**
                             * Decodes a PageRef message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns PageRef
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.PageAnchor.PageRef;

                            /**
                             * Verifies a PageRef message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a PageRef message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns PageRef
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.PageAnchor.PageRef;

                            /**
                             * Creates a plain object from a PageRef message. Also converts values to other types if specified.
                             * @param message PageRef
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.PageAnchor.PageRef, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this PageRef to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for PageRef
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace PageRef {

                            /** LayoutType enum. */
                            enum LayoutType {
                                LAYOUT_TYPE_UNSPECIFIED = 0,
                                BLOCK = 1,
                                PARAGRAPH = 2,
                                LINE = 3,
                                TOKEN = 4,
                                VISUAL_ELEMENT = 5,
                                TABLE = 6,
                                FORM_FIELD = 7
                            }
                        }
                    }

                    /** Properties of a Provenance. */
                    interface IProvenance {

                        /** Provenance revision */
                        revision?: (number|null);

                        /** Provenance id */
                        id?: (number|null);

                        /** Provenance parents */
                        parents?: (google.cloud.documentai.v1.Document.Provenance.IParent[]|null);

                        /** Provenance type */
                        type?: (google.cloud.documentai.v1.Document.Provenance.OperationType|keyof typeof google.cloud.documentai.v1.Document.Provenance.OperationType|null);
                    }

                    /** Represents a Provenance. */
                    class Provenance implements IProvenance {

                        /**
                         * Constructs a new Provenance.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IProvenance);

                        /** Provenance revision. */
                        public revision: number;

                        /** Provenance id. */
                        public id: number;

                        /** Provenance parents. */
                        public parents: google.cloud.documentai.v1.Document.Provenance.IParent[];

                        /** Provenance type. */
                        public type: (google.cloud.documentai.v1.Document.Provenance.OperationType|keyof typeof google.cloud.documentai.v1.Document.Provenance.OperationType);

                        /**
                         * Creates a new Provenance instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Provenance instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IProvenance): google.cloud.documentai.v1.Document.Provenance;

                        /**
                         * Encodes the specified Provenance message. Does not implicitly {@link google.cloud.documentai.v1.Document.Provenance.verify|verify} messages.
                         * @param message Provenance message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IProvenance, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Provenance message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Provenance.verify|verify} messages.
                         * @param message Provenance message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IProvenance, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Provenance message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Provenance
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Provenance;

                        /**
                         * Decodes a Provenance message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Provenance
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Provenance;

                        /**
                         * Verifies a Provenance message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Provenance message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Provenance
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Provenance;

                        /**
                         * Creates a plain object from a Provenance message. Also converts values to other types if specified.
                         * @param message Provenance
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.Provenance, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Provenance to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Provenance
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Provenance {

                        /** Properties of a Parent. */
                        interface IParent {

                            /** Parent revision */
                            revision?: (number|null);

                            /** Parent index */
                            index?: (number|null);

                            /** Parent id */
                            id?: (number|null);
                        }

                        /** Represents a Parent. */
                        class Parent implements IParent {

                            /**
                             * Constructs a new Parent.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Provenance.IParent);

                            /** Parent revision. */
                            public revision: number;

                            /** Parent index. */
                            public index: number;

                            /** Parent id. */
                            public id: number;

                            /**
                             * Creates a new Parent instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Parent instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Provenance.IParent): google.cloud.documentai.v1.Document.Provenance.Parent;

                            /**
                             * Encodes the specified Parent message. Does not implicitly {@link google.cloud.documentai.v1.Document.Provenance.Parent.verify|verify} messages.
                             * @param message Parent message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Provenance.IParent, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Parent message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Provenance.Parent.verify|verify} messages.
                             * @param message Parent message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Provenance.IParent, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Parent message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Parent
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Provenance.Parent;

                            /**
                             * Decodes a Parent message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Parent
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Provenance.Parent;

                            /**
                             * Verifies a Parent message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Parent message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Parent
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Provenance.Parent;

                            /**
                             * Creates a plain object from a Parent message. Also converts values to other types if specified.
                             * @param message Parent
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Provenance.Parent, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Parent to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Parent
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** OperationType enum. */
                        enum OperationType {
                            OPERATION_TYPE_UNSPECIFIED = 0,
                            ADD = 1,
                            REMOVE = 2,
                            UPDATE = 7,
                            REPLACE = 3,
                            EVAL_REQUESTED = 4,
                            EVAL_APPROVED = 5,
                            EVAL_SKIPPED = 6
                        }
                    }

                    /** Properties of a Revision. */
                    interface IRevision {

                        /** Revision agent */
                        agent?: (string|null);

                        /** Revision processor */
                        processor?: (string|null);

                        /** Revision id */
                        id?: (string|null);

                        /** Revision parent */
                        parent?: (number[]|null);

                        /** Revision parentIds */
                        parentIds?: (string[]|null);

                        /** Revision createTime */
                        createTime?: (google.protobuf.ITimestamp|null);

                        /** Revision humanReview */
                        humanReview?: (google.cloud.documentai.v1.Document.Revision.IHumanReview|null);
                    }

                    /** Represents a Revision. */
                    class Revision implements IRevision {

                        /**
                         * Constructs a new Revision.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IRevision);

                        /** Revision agent. */
                        public agent?: (string|null);

                        /** Revision processor. */
                        public processor?: (string|null);

                        /** Revision id. */
                        public id: string;

                        /** Revision parent. */
                        public parent: number[];

                        /** Revision parentIds. */
                        public parentIds: string[];

                        /** Revision createTime. */
                        public createTime?: (google.protobuf.ITimestamp|null);

                        /** Revision humanReview. */
                        public humanReview?: (google.cloud.documentai.v1.Document.Revision.IHumanReview|null);

                        /** Revision source. */
                        public source?: ("agent"|"processor");

                        /**
                         * Creates a new Revision instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Revision instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IRevision): google.cloud.documentai.v1.Document.Revision;

                        /**
                         * Encodes the specified Revision message. Does not implicitly {@link google.cloud.documentai.v1.Document.Revision.verify|verify} messages.
                         * @param message Revision message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IRevision, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Revision message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Revision.verify|verify} messages.
                         * @param message Revision message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IRevision, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Revision message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Revision
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Revision;

                        /**
                         * Decodes a Revision message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Revision
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Revision;

                        /**
                         * Verifies a Revision message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Revision message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Revision
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Revision;

                        /**
                         * Creates a plain object from a Revision message. Also converts values to other types if specified.
                         * @param message Revision
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.Revision, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Revision to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Revision
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Revision {

                        /** Properties of a HumanReview. */
                        interface IHumanReview {

                            /** HumanReview state */
                            state?: (string|null);

                            /** HumanReview stateMessage */
                            stateMessage?: (string|null);
                        }

                        /** Represents a HumanReview. */
                        class HumanReview implements IHumanReview {

                            /**
                             * Constructs a new HumanReview.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.Revision.IHumanReview);

                            /** HumanReview state. */
                            public state: string;

                            /** HumanReview stateMessage. */
                            public stateMessage: string;

                            /**
                             * Creates a new HumanReview instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns HumanReview instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.Revision.IHumanReview): google.cloud.documentai.v1.Document.Revision.HumanReview;

                            /**
                             * Encodes the specified HumanReview message. Does not implicitly {@link google.cloud.documentai.v1.Document.Revision.HumanReview.verify|verify} messages.
                             * @param message HumanReview message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.Revision.IHumanReview, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified HumanReview message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.Revision.HumanReview.verify|verify} messages.
                             * @param message HumanReview message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.Revision.IHumanReview, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a HumanReview message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns HumanReview
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.Revision.HumanReview;

                            /**
                             * Decodes a HumanReview message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns HumanReview
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.Revision.HumanReview;

                            /**
                             * Verifies a HumanReview message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a HumanReview message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns HumanReview
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.Revision.HumanReview;

                            /**
                             * Creates a plain object from a HumanReview message. Also converts values to other types if specified.
                             * @param message HumanReview
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.Revision.HumanReview, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this HumanReview to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for HumanReview
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a TextChange. */
                    interface ITextChange {

                        /** TextChange textAnchor */
                        textAnchor?: (google.cloud.documentai.v1.Document.ITextAnchor|null);

                        /** TextChange changedText */
                        changedText?: (string|null);

                        /** TextChange provenance */
                        provenance?: (google.cloud.documentai.v1.Document.IProvenance[]|null);
                    }

                    /** Represents a TextChange. */
                    class TextChange implements ITextChange {

                        /**
                         * Constructs a new TextChange.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.ITextChange);

                        /** TextChange textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1.Document.ITextAnchor|null);

                        /** TextChange changedText. */
                        public changedText: string;

                        /** TextChange provenance. */
                        public provenance: google.cloud.documentai.v1.Document.IProvenance[];

                        /**
                         * Creates a new TextChange instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns TextChange instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.ITextChange): google.cloud.documentai.v1.Document.TextChange;

                        /**
                         * Encodes the specified TextChange message. Does not implicitly {@link google.cloud.documentai.v1.Document.TextChange.verify|verify} messages.
                         * @param message TextChange message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.ITextChange, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified TextChange message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.TextChange.verify|verify} messages.
                         * @param message TextChange message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.ITextChange, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a TextChange message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns TextChange
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.TextChange;

                        /**
                         * Decodes a TextChange message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns TextChange
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.TextChange;

                        /**
                         * Verifies a TextChange message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a TextChange message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns TextChange
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.TextChange;

                        /**
                         * Creates a plain object from a TextChange message. Also converts values to other types if specified.
                         * @param message TextChange
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.TextChange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this TextChange to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for TextChange
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a DocumentLayout. */
                    interface IDocumentLayout {

                        /** DocumentLayout blocks */
                        blocks?: (google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock[]|null);
                    }

                    /** Represents a DocumentLayout. */
                    class DocumentLayout implements IDocumentLayout {

                        /**
                         * Constructs a new DocumentLayout.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IDocumentLayout);

                        /** DocumentLayout blocks. */
                        public blocks: google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock[];

                        /**
                         * Creates a new DocumentLayout instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns DocumentLayout instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IDocumentLayout): google.cloud.documentai.v1.Document.DocumentLayout;

                        /**
                         * Encodes the specified DocumentLayout message. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.verify|verify} messages.
                         * @param message DocumentLayout message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IDocumentLayout, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified DocumentLayout message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.verify|verify} messages.
                         * @param message DocumentLayout message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IDocumentLayout, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a DocumentLayout message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns DocumentLayout
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.DocumentLayout;

                        /**
                         * Decodes a DocumentLayout message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns DocumentLayout
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.DocumentLayout;

                        /**
                         * Verifies a DocumentLayout message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a DocumentLayout message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns DocumentLayout
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.DocumentLayout;

                        /**
                         * Creates a plain object from a DocumentLayout message. Also converts values to other types if specified.
                         * @param message DocumentLayout
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.DocumentLayout, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this DocumentLayout to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for DocumentLayout
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace DocumentLayout {

                        /** Properties of a DocumentLayoutBlock. */
                        interface IDocumentLayoutBlock {

                            /** DocumentLayoutBlock textBlock */
                            textBlock?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock|null);

                            /** DocumentLayoutBlock tableBlock */
                            tableBlock?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock|null);

                            /** DocumentLayoutBlock listBlock */
                            listBlock?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock|null);

                            /** DocumentLayoutBlock blockId */
                            blockId?: (string|null);

                            /** DocumentLayoutBlock pageSpan */
                            pageSpan?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan|null);
                        }

                        /** Represents a DocumentLayoutBlock. */
                        class DocumentLayoutBlock implements IDocumentLayoutBlock {

                            /**
                             * Constructs a new DocumentLayoutBlock.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock);

                            /** DocumentLayoutBlock textBlock. */
                            public textBlock?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock|null);

                            /** DocumentLayoutBlock tableBlock. */
                            public tableBlock?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock|null);

                            /** DocumentLayoutBlock listBlock. */
                            public listBlock?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock|null);

                            /** DocumentLayoutBlock blockId. */
                            public blockId: string;

                            /** DocumentLayoutBlock pageSpan. */
                            public pageSpan?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan|null);

                            /** DocumentLayoutBlock block. */
                            public block?: ("textBlock"|"tableBlock"|"listBlock");

                            /**
                             * Creates a new DocumentLayoutBlock instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns DocumentLayoutBlock instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock;

                            /**
                             * Encodes the specified DocumentLayoutBlock message. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.verify|verify} messages.
                             * @param message DocumentLayoutBlock message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified DocumentLayoutBlock message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.verify|verify} messages.
                             * @param message DocumentLayoutBlock message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a DocumentLayoutBlock message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns DocumentLayoutBlock
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock;

                            /**
                             * Decodes a DocumentLayoutBlock message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns DocumentLayoutBlock
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock;

                            /**
                             * Verifies a DocumentLayoutBlock message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a DocumentLayoutBlock message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns DocumentLayoutBlock
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock;

                            /**
                             * Creates a plain object from a DocumentLayoutBlock message. Also converts values to other types if specified.
                             * @param message DocumentLayoutBlock
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this DocumentLayoutBlock to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for DocumentLayoutBlock
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace DocumentLayoutBlock {

                            /** Properties of a LayoutPageSpan. */
                            interface ILayoutPageSpan {

                                /** LayoutPageSpan pageStart */
                                pageStart?: (number|null);

                                /** LayoutPageSpan pageEnd */
                                pageEnd?: (number|null);
                            }

                            /** Represents a LayoutPageSpan. */
                            class LayoutPageSpan implements ILayoutPageSpan {

                                /**
                                 * Constructs a new LayoutPageSpan.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan);

                                /** LayoutPageSpan pageStart. */
                                public pageStart: number;

                                /** LayoutPageSpan pageEnd. */
                                public pageEnd: number;

                                /**
                                 * Creates a new LayoutPageSpan instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutPageSpan instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan;

                                /**
                                 * Encodes the specified LayoutPageSpan message. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan.verify|verify} messages.
                                 * @param message LayoutPageSpan message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutPageSpan message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan.verify|verify} messages.
                                 * @param message LayoutPageSpan message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutPageSpan message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutPageSpan
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan;

                                /**
                                 * Decodes a LayoutPageSpan message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutPageSpan
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan;

                                /**
                                 * Verifies a LayoutPageSpan message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutPageSpan message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutPageSpan
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan;

                                /**
                                 * Creates a plain object from a LayoutPageSpan message. Also converts values to other types if specified.
                                 * @param message LayoutPageSpan
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutPageSpan to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutPageSpan
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutTextBlock. */
                            interface ILayoutTextBlock {

                                /** LayoutTextBlock text */
                                text?: (string|null);

                                /** LayoutTextBlock type */
                                type?: (string|null);

                                /** LayoutTextBlock blocks */
                                blocks?: (google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock[]|null);
                            }

                            /** Represents a LayoutTextBlock. */
                            class LayoutTextBlock implements ILayoutTextBlock {

                                /**
                                 * Constructs a new LayoutTextBlock.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock);

                                /** LayoutTextBlock text. */
                                public text: string;

                                /** LayoutTextBlock type. */
                                public type: string;

                                /** LayoutTextBlock blocks. */
                                public blocks: google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock[];

                                /**
                                 * Creates a new LayoutTextBlock instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutTextBlock instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock;

                                /**
                                 * Encodes the specified LayoutTextBlock message. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock.verify|verify} messages.
                                 * @param message LayoutTextBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutTextBlock message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock.verify|verify} messages.
                                 * @param message LayoutTextBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutTextBlock message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutTextBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock;

                                /**
                                 * Decodes a LayoutTextBlock message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutTextBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock;

                                /**
                                 * Verifies a LayoutTextBlock message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutTextBlock message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutTextBlock
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock;

                                /**
                                 * Creates a plain object from a LayoutTextBlock message. Also converts values to other types if specified.
                                 * @param message LayoutTextBlock
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutTextBlock to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutTextBlock
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutTableBlock. */
                            interface ILayoutTableBlock {

                                /** LayoutTableBlock headerRows */
                                headerRows?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow[]|null);

                                /** LayoutTableBlock bodyRows */
                                bodyRows?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow[]|null);

                                /** LayoutTableBlock caption */
                                caption?: (string|null);
                            }

                            /** Represents a LayoutTableBlock. */
                            class LayoutTableBlock implements ILayoutTableBlock {

                                /**
                                 * Constructs a new LayoutTableBlock.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock);

                                /** LayoutTableBlock headerRows. */
                                public headerRows: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow[];

                                /** LayoutTableBlock bodyRows. */
                                public bodyRows: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow[];

                                /** LayoutTableBlock caption. */
                                public caption: string;

                                /**
                                 * Creates a new LayoutTableBlock instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutTableBlock instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock;

                                /**
                                 * Encodes the specified LayoutTableBlock message. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock.verify|verify} messages.
                                 * @param message LayoutTableBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutTableBlock message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock.verify|verify} messages.
                                 * @param message LayoutTableBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutTableBlock message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutTableBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock;

                                /**
                                 * Decodes a LayoutTableBlock message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutTableBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock;

                                /**
                                 * Verifies a LayoutTableBlock message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutTableBlock message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutTableBlock
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock;

                                /**
                                 * Creates a plain object from a LayoutTableBlock message. Also converts values to other types if specified.
                                 * @param message LayoutTableBlock
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutTableBlock to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutTableBlock
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutTableRow. */
                            interface ILayoutTableRow {

                                /** LayoutTableRow cells */
                                cells?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell[]|null);
                            }

                            /** Represents a LayoutTableRow. */
                            class LayoutTableRow implements ILayoutTableRow {

                                /**
                                 * Constructs a new LayoutTableRow.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow);

                                /** LayoutTableRow cells. */
                                public cells: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell[];

                                /**
                                 * Creates a new LayoutTableRow instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutTableRow instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow;

                                /**
                                 * Encodes the specified LayoutTableRow message. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow.verify|verify} messages.
                                 * @param message LayoutTableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutTableRow message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow.verify|verify} messages.
                                 * @param message LayoutTableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutTableRow message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutTableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow;

                                /**
                                 * Decodes a LayoutTableRow message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutTableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow;

                                /**
                                 * Verifies a LayoutTableRow message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutTableRow message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutTableRow
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow;

                                /**
                                 * Creates a plain object from a LayoutTableRow message. Also converts values to other types if specified.
                                 * @param message LayoutTableRow
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutTableRow to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutTableRow
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutTableCell. */
                            interface ILayoutTableCell {

                                /** LayoutTableCell blocks */
                                blocks?: (google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock[]|null);

                                /** LayoutTableCell rowSpan */
                                rowSpan?: (number|null);

                                /** LayoutTableCell colSpan */
                                colSpan?: (number|null);
                            }

                            /** Represents a LayoutTableCell. */
                            class LayoutTableCell implements ILayoutTableCell {

                                /**
                                 * Constructs a new LayoutTableCell.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell);

                                /** LayoutTableCell blocks. */
                                public blocks: google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock[];

                                /** LayoutTableCell rowSpan. */
                                public rowSpan: number;

                                /** LayoutTableCell colSpan. */
                                public colSpan: number;

                                /**
                                 * Creates a new LayoutTableCell instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutTableCell instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell;

                                /**
                                 * Encodes the specified LayoutTableCell message. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell.verify|verify} messages.
                                 * @param message LayoutTableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutTableCell message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell.verify|verify} messages.
                                 * @param message LayoutTableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutTableCell message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutTableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell;

                                /**
                                 * Decodes a LayoutTableCell message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutTableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell;

                                /**
                                 * Verifies a LayoutTableCell message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutTableCell message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutTableCell
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell;

                                /**
                                 * Creates a plain object from a LayoutTableCell message. Also converts values to other types if specified.
                                 * @param message LayoutTableCell
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutTableCell to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutTableCell
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutListBlock. */
                            interface ILayoutListBlock {

                                /** LayoutListBlock listEntries */
                                listEntries?: (google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry[]|null);

                                /** LayoutListBlock type */
                                type?: (string|null);
                            }

                            /** Represents a LayoutListBlock. */
                            class LayoutListBlock implements ILayoutListBlock {

                                /**
                                 * Constructs a new LayoutListBlock.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock);

                                /** LayoutListBlock listEntries. */
                                public listEntries: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry[];

                                /** LayoutListBlock type. */
                                public type: string;

                                /**
                                 * Creates a new LayoutListBlock instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutListBlock instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock;

                                /**
                                 * Encodes the specified LayoutListBlock message. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock.verify|verify} messages.
                                 * @param message LayoutListBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutListBlock message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock.verify|verify} messages.
                                 * @param message LayoutListBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutListBlock message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutListBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock;

                                /**
                                 * Decodes a LayoutListBlock message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutListBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock;

                                /**
                                 * Verifies a LayoutListBlock message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutListBlock message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutListBlock
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock;

                                /**
                                 * Creates a plain object from a LayoutListBlock message. Also converts values to other types if specified.
                                 * @param message LayoutListBlock
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutListBlock to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutListBlock
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutListEntry. */
                            interface ILayoutListEntry {

                                /** LayoutListEntry blocks */
                                blocks?: (google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock[]|null);
                            }

                            /** Represents a LayoutListEntry. */
                            class LayoutListEntry implements ILayoutListEntry {

                                /**
                                 * Constructs a new LayoutListEntry.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry);

                                /** LayoutListEntry blocks. */
                                public blocks: google.cloud.documentai.v1.Document.DocumentLayout.IDocumentLayoutBlock[];

                                /**
                                 * Creates a new LayoutListEntry instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutListEntry instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry;

                                /**
                                 * Encodes the specified LayoutListEntry message. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry.verify|verify} messages.
                                 * @param message LayoutListEntry message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutListEntry message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry.verify|verify} messages.
                                 * @param message LayoutListEntry message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutListEntry message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutListEntry
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry;

                                /**
                                 * Decodes a LayoutListEntry message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutListEntry
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry;

                                /**
                                 * Verifies a LayoutListEntry message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutListEntry message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutListEntry
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry;

                                /**
                                 * Creates a plain object from a LayoutListEntry message. Also converts values to other types if specified.
                                 * @param message LayoutListEntry
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutListEntry to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutListEntry
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }
                    }

                    /** Properties of a ChunkedDocument. */
                    interface IChunkedDocument {

                        /** ChunkedDocument chunks */
                        chunks?: (google.cloud.documentai.v1.Document.ChunkedDocument.IChunk[]|null);
                    }

                    /** Represents a ChunkedDocument. */
                    class ChunkedDocument implements IChunkedDocument {

                        /**
                         * Constructs a new ChunkedDocument.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Document.IChunkedDocument);

                        /** ChunkedDocument chunks. */
                        public chunks: google.cloud.documentai.v1.Document.ChunkedDocument.IChunk[];

                        /**
                         * Creates a new ChunkedDocument instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ChunkedDocument instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Document.IChunkedDocument): google.cloud.documentai.v1.Document.ChunkedDocument;

                        /**
                         * Encodes the specified ChunkedDocument message. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.verify|verify} messages.
                         * @param message ChunkedDocument message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Document.IChunkedDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ChunkedDocument message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.verify|verify} messages.
                         * @param message ChunkedDocument message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Document.IChunkedDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a ChunkedDocument message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ChunkedDocument
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.ChunkedDocument;

                        /**
                         * Decodes a ChunkedDocument message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ChunkedDocument
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.ChunkedDocument;

                        /**
                         * Verifies a ChunkedDocument message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a ChunkedDocument message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ChunkedDocument
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.ChunkedDocument;

                        /**
                         * Creates a plain object from a ChunkedDocument message. Also converts values to other types if specified.
                         * @param message ChunkedDocument
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Document.ChunkedDocument, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ChunkedDocument to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ChunkedDocument
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace ChunkedDocument {

                        /** Properties of a Chunk. */
                        interface IChunk {

                            /** Chunk chunkId */
                            chunkId?: (string|null);

                            /** Chunk sourceBlockIds */
                            sourceBlockIds?: (string[]|null);

                            /** Chunk content */
                            content?: (string|null);

                            /** Chunk pageSpan */
                            pageSpan?: (google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);

                            /** Chunk pageHeaders */
                            pageHeaders?: (google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageHeader[]|null);

                            /** Chunk pageFooters */
                            pageFooters?: (google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageFooter[]|null);
                        }

                        /** Represents a Chunk. */
                        class Chunk implements IChunk {

                            /**
                             * Constructs a new Chunk.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.Document.ChunkedDocument.IChunk);

                            /** Chunk chunkId. */
                            public chunkId: string;

                            /** Chunk sourceBlockIds. */
                            public sourceBlockIds: string[];

                            /** Chunk content. */
                            public content: string;

                            /** Chunk pageSpan. */
                            public pageSpan?: (google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);

                            /** Chunk pageHeaders. */
                            public pageHeaders: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageHeader[];

                            /** Chunk pageFooters. */
                            public pageFooters: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageFooter[];

                            /**
                             * Creates a new Chunk instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Chunk instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.Document.ChunkedDocument.IChunk): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk;

                            /**
                             * Encodes the specified Chunk message. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.verify|verify} messages.
                             * @param message Chunk message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.Document.ChunkedDocument.IChunk, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Chunk message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.verify|verify} messages.
                             * @param message Chunk message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.Document.ChunkedDocument.IChunk, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Chunk message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Chunk
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk;

                            /**
                             * Decodes a Chunk message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Chunk
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk;

                            /**
                             * Verifies a Chunk message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Chunk message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Chunk
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk;

                            /**
                             * Creates a plain object from a Chunk message. Also converts values to other types if specified.
                             * @param message Chunk
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Chunk to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Chunk
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Chunk {

                            /** Properties of a ChunkPageSpan. */
                            interface IChunkPageSpan {

                                /** ChunkPageSpan pageStart */
                                pageStart?: (number|null);

                                /** ChunkPageSpan pageEnd */
                                pageEnd?: (number|null);
                            }

                            /** Represents a ChunkPageSpan. */
                            class ChunkPageSpan implements IChunkPageSpan {

                                /**
                                 * Constructs a new ChunkPageSpan.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan);

                                /** ChunkPageSpan pageStart. */
                                public pageStart: number;

                                /** ChunkPageSpan pageEnd. */
                                public pageEnd: number;

                                /**
                                 * Creates a new ChunkPageSpan instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns ChunkPageSpan instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageSpan;

                                /**
                                 * Encodes the specified ChunkPageSpan message. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageSpan.verify|verify} messages.
                                 * @param message ChunkPageSpan message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified ChunkPageSpan message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageSpan.verify|verify} messages.
                                 * @param message ChunkPageSpan message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a ChunkPageSpan message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns ChunkPageSpan
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageSpan;

                                /**
                                 * Decodes a ChunkPageSpan message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns ChunkPageSpan
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageSpan;

                                /**
                                 * Verifies a ChunkPageSpan message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a ChunkPageSpan message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns ChunkPageSpan
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageSpan;

                                /**
                                 * Creates a plain object from a ChunkPageSpan message. Also converts values to other types if specified.
                                 * @param message ChunkPageSpan
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageSpan, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this ChunkPageSpan to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for ChunkPageSpan
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a ChunkPageHeader. */
                            interface IChunkPageHeader {

                                /** ChunkPageHeader text */
                                text?: (string|null);

                                /** ChunkPageHeader pageSpan */
                                pageSpan?: (google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);
                            }

                            /** Represents a ChunkPageHeader. */
                            class ChunkPageHeader implements IChunkPageHeader {

                                /**
                                 * Constructs a new ChunkPageHeader.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageHeader);

                                /** ChunkPageHeader text. */
                                public text: string;

                                /** ChunkPageHeader pageSpan. */
                                public pageSpan?: (google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);

                                /**
                                 * Creates a new ChunkPageHeader instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns ChunkPageHeader instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageHeader): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageHeader;

                                /**
                                 * Encodes the specified ChunkPageHeader message. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageHeader.verify|verify} messages.
                                 * @param message ChunkPageHeader message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified ChunkPageHeader message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageHeader.verify|verify} messages.
                                 * @param message ChunkPageHeader message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a ChunkPageHeader message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns ChunkPageHeader
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageHeader;

                                /**
                                 * Decodes a ChunkPageHeader message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns ChunkPageHeader
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageHeader;

                                /**
                                 * Verifies a ChunkPageHeader message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a ChunkPageHeader message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns ChunkPageHeader
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageHeader;

                                /**
                                 * Creates a plain object from a ChunkPageHeader message. Also converts values to other types if specified.
                                 * @param message ChunkPageHeader
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageHeader, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this ChunkPageHeader to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for ChunkPageHeader
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a ChunkPageFooter. */
                            interface IChunkPageFooter {

                                /** ChunkPageFooter text */
                                text?: (string|null);

                                /** ChunkPageFooter pageSpan */
                                pageSpan?: (google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);
                            }

                            /** Represents a ChunkPageFooter. */
                            class ChunkPageFooter implements IChunkPageFooter {

                                /**
                                 * Constructs a new ChunkPageFooter.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageFooter);

                                /** ChunkPageFooter text. */
                                public text: string;

                                /** ChunkPageFooter pageSpan. */
                                public pageSpan?: (google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);

                                /**
                                 * Creates a new ChunkPageFooter instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns ChunkPageFooter instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageFooter): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageFooter;

                                /**
                                 * Encodes the specified ChunkPageFooter message. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageFooter.verify|verify} messages.
                                 * @param message ChunkPageFooter message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageFooter, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified ChunkPageFooter message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageFooter.verify|verify} messages.
                                 * @param message ChunkPageFooter message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.IChunkPageFooter, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a ChunkPageFooter message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns ChunkPageFooter
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageFooter;

                                /**
                                 * Decodes a ChunkPageFooter message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns ChunkPageFooter
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageFooter;

                                /**
                                 * Verifies a ChunkPageFooter message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a ChunkPageFooter message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns ChunkPageFooter
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageFooter;

                                /**
                                 * Creates a plain object from a ChunkPageFooter message. Also converts values to other types if specified.
                                 * @param message ChunkPageFooter
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1.Document.ChunkedDocument.Chunk.ChunkPageFooter, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this ChunkPageFooter to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for ChunkPageFooter
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }
                    }
                }

                /** Properties of a Vertex. */
                interface IVertex {

                    /** Vertex x */
                    x?: (number|null);

                    /** Vertex y */
                    y?: (number|null);
                }

                /** Represents a Vertex. */
                class Vertex implements IVertex {

                    /**
                     * Constructs a new Vertex.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IVertex);

                    /** Vertex x. */
                    public x: number;

                    /** Vertex y. */
                    public y: number;

                    /**
                     * Creates a new Vertex instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Vertex instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IVertex): google.cloud.documentai.v1.Vertex;

                    /**
                     * Encodes the specified Vertex message. Does not implicitly {@link google.cloud.documentai.v1.Vertex.verify|verify} messages.
                     * @param message Vertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Vertex message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Vertex.verify|verify} messages.
                     * @param message Vertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Vertex message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Vertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Vertex;

                    /**
                     * Decodes a Vertex message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Vertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Vertex;

                    /**
                     * Verifies a Vertex message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Vertex message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Vertex
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Vertex;

                    /**
                     * Creates a plain object from a Vertex message. Also converts values to other types if specified.
                     * @param message Vertex
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.Vertex, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Vertex to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Vertex
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NormalizedVertex. */
                interface INormalizedVertex {

                    /** NormalizedVertex x */
                    x?: (number|null);

                    /** NormalizedVertex y */
                    y?: (number|null);
                }

                /** Represents a NormalizedVertex. */
                class NormalizedVertex implements INormalizedVertex {

                    /**
                     * Constructs a new NormalizedVertex.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.INormalizedVertex);

                    /** NormalizedVertex x. */
                    public x: number;

                    /** NormalizedVertex y. */
                    public y: number;

                    /**
                     * Creates a new NormalizedVertex instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NormalizedVertex instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.INormalizedVertex): google.cloud.documentai.v1.NormalizedVertex;

                    /**
                     * Encodes the specified NormalizedVertex message. Does not implicitly {@link google.cloud.documentai.v1.NormalizedVertex.verify|verify} messages.
                     * @param message NormalizedVertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.INormalizedVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NormalizedVertex message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.NormalizedVertex.verify|verify} messages.
                     * @param message NormalizedVertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.INormalizedVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NormalizedVertex message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NormalizedVertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.NormalizedVertex;

                    /**
                     * Decodes a NormalizedVertex message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NormalizedVertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.NormalizedVertex;

                    /**
                     * Verifies a NormalizedVertex message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NormalizedVertex message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NormalizedVertex
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.NormalizedVertex;

                    /**
                     * Creates a plain object from a NormalizedVertex message. Also converts values to other types if specified.
                     * @param message NormalizedVertex
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.NormalizedVertex, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NormalizedVertex to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NormalizedVertex
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BoundingPoly. */
                interface IBoundingPoly {

                    /** BoundingPoly vertices */
                    vertices?: (google.cloud.documentai.v1.IVertex[]|null);

                    /** BoundingPoly normalizedVertices */
                    normalizedVertices?: (google.cloud.documentai.v1.INormalizedVertex[]|null);
                }

                /** Represents a BoundingPoly. */
                class BoundingPoly implements IBoundingPoly {

                    /**
                     * Constructs a new BoundingPoly.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IBoundingPoly);

                    /** BoundingPoly vertices. */
                    public vertices: google.cloud.documentai.v1.IVertex[];

                    /** BoundingPoly normalizedVertices. */
                    public normalizedVertices: google.cloud.documentai.v1.INormalizedVertex[];

                    /**
                     * Creates a new BoundingPoly instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BoundingPoly instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IBoundingPoly): google.cloud.documentai.v1.BoundingPoly;

                    /**
                     * Encodes the specified BoundingPoly message. Does not implicitly {@link google.cloud.documentai.v1.BoundingPoly.verify|verify} messages.
                     * @param message BoundingPoly message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IBoundingPoly, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BoundingPoly message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.BoundingPoly.verify|verify} messages.
                     * @param message BoundingPoly message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IBoundingPoly, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BoundingPoly message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BoundingPoly
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.BoundingPoly;

                    /**
                     * Decodes a BoundingPoly message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BoundingPoly
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.BoundingPoly;

                    /**
                     * Verifies a BoundingPoly message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BoundingPoly message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BoundingPoly
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.BoundingPoly;

                    /**
                     * Creates a plain object from a BoundingPoly message. Also converts values to other types if specified.
                     * @param message BoundingPoly
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.BoundingPoly, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BoundingPoly to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BoundingPoly
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RawDocument. */
                interface IRawDocument {

                    /** RawDocument content */
                    content?: (Uint8Array|string|null);

                    /** RawDocument mimeType */
                    mimeType?: (string|null);

                    /** RawDocument displayName */
                    displayName?: (string|null);
                }

                /** Represents a RawDocument. */
                class RawDocument implements IRawDocument {

                    /**
                     * Constructs a new RawDocument.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IRawDocument);

                    /** RawDocument content. */
                    public content: (Uint8Array|string);

                    /** RawDocument mimeType. */
                    public mimeType: string;

                    /** RawDocument displayName. */
                    public displayName: string;

                    /**
                     * Creates a new RawDocument instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RawDocument instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IRawDocument): google.cloud.documentai.v1.RawDocument;

                    /**
                     * Encodes the specified RawDocument message. Does not implicitly {@link google.cloud.documentai.v1.RawDocument.verify|verify} messages.
                     * @param message RawDocument message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IRawDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RawDocument message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.RawDocument.verify|verify} messages.
                     * @param message RawDocument message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IRawDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RawDocument message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RawDocument
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.RawDocument;

                    /**
                     * Decodes a RawDocument message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RawDocument
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.RawDocument;

                    /**
                     * Verifies a RawDocument message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RawDocument message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RawDocument
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.RawDocument;

                    /**
                     * Creates a plain object from a RawDocument message. Also converts values to other types if specified.
                     * @param message RawDocument
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.RawDocument, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RawDocument to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RawDocument
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsDocument. */
                interface IGcsDocument {

                    /** GcsDocument gcsUri */
                    gcsUri?: (string|null);

                    /** GcsDocument mimeType */
                    mimeType?: (string|null);
                }

                /** Represents a GcsDocument. */
                class GcsDocument implements IGcsDocument {

                    /**
                     * Constructs a new GcsDocument.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IGcsDocument);

                    /** GcsDocument gcsUri. */
                    public gcsUri: string;

                    /** GcsDocument mimeType. */
                    public mimeType: string;

                    /**
                     * Creates a new GcsDocument instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsDocument instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IGcsDocument): google.cloud.documentai.v1.GcsDocument;

                    /**
                     * Encodes the specified GcsDocument message. Does not implicitly {@link google.cloud.documentai.v1.GcsDocument.verify|verify} messages.
                     * @param message GcsDocument message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IGcsDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsDocument message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.GcsDocument.verify|verify} messages.
                     * @param message GcsDocument message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IGcsDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsDocument message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsDocument
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.GcsDocument;

                    /**
                     * Decodes a GcsDocument message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsDocument
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.GcsDocument;

                    /**
                     * Verifies a GcsDocument message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsDocument message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsDocument
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.GcsDocument;

                    /**
                     * Creates a plain object from a GcsDocument message. Also converts values to other types if specified.
                     * @param message GcsDocument
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.GcsDocument, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsDocument to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsDocument
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsDocuments. */
                interface IGcsDocuments {

                    /** GcsDocuments documents */
                    documents?: (google.cloud.documentai.v1.IGcsDocument[]|null);
                }

                /** Represents a GcsDocuments. */
                class GcsDocuments implements IGcsDocuments {

                    /**
                     * Constructs a new GcsDocuments.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IGcsDocuments);

                    /** GcsDocuments documents. */
                    public documents: google.cloud.documentai.v1.IGcsDocument[];

                    /**
                     * Creates a new GcsDocuments instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsDocuments instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IGcsDocuments): google.cloud.documentai.v1.GcsDocuments;

                    /**
                     * Encodes the specified GcsDocuments message. Does not implicitly {@link google.cloud.documentai.v1.GcsDocuments.verify|verify} messages.
                     * @param message GcsDocuments message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IGcsDocuments, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsDocuments message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.GcsDocuments.verify|verify} messages.
                     * @param message GcsDocuments message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IGcsDocuments, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsDocuments message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsDocuments
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.GcsDocuments;

                    /**
                     * Decodes a GcsDocuments message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsDocuments
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.GcsDocuments;

                    /**
                     * Verifies a GcsDocuments message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsDocuments message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsDocuments
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.GcsDocuments;

                    /**
                     * Creates a plain object from a GcsDocuments message. Also converts values to other types if specified.
                     * @param message GcsDocuments
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.GcsDocuments, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsDocuments to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsDocuments
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsPrefix. */
                interface IGcsPrefix {

                    /** GcsPrefix gcsUriPrefix */
                    gcsUriPrefix?: (string|null);
                }

                /** Represents a GcsPrefix. */
                class GcsPrefix implements IGcsPrefix {

                    /**
                     * Constructs a new GcsPrefix.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IGcsPrefix);

                    /** GcsPrefix gcsUriPrefix. */
                    public gcsUriPrefix: string;

                    /**
                     * Creates a new GcsPrefix instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsPrefix instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IGcsPrefix): google.cloud.documentai.v1.GcsPrefix;

                    /**
                     * Encodes the specified GcsPrefix message. Does not implicitly {@link google.cloud.documentai.v1.GcsPrefix.verify|verify} messages.
                     * @param message GcsPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IGcsPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsPrefix message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.GcsPrefix.verify|verify} messages.
                     * @param message GcsPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IGcsPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsPrefix message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.GcsPrefix;

                    /**
                     * Decodes a GcsPrefix message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.GcsPrefix;

                    /**
                     * Verifies a GcsPrefix message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsPrefix message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsPrefix
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.GcsPrefix;

                    /**
                     * Creates a plain object from a GcsPrefix message. Also converts values to other types if specified.
                     * @param message GcsPrefix
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.GcsPrefix, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsPrefix to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsPrefix
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchDocumentsInputConfig. */
                interface IBatchDocumentsInputConfig {

                    /** BatchDocumentsInputConfig gcsPrefix */
                    gcsPrefix?: (google.cloud.documentai.v1.IGcsPrefix|null);

                    /** BatchDocumentsInputConfig gcsDocuments */
                    gcsDocuments?: (google.cloud.documentai.v1.IGcsDocuments|null);
                }

                /** Represents a BatchDocumentsInputConfig. */
                class BatchDocumentsInputConfig implements IBatchDocumentsInputConfig {

                    /**
                     * Constructs a new BatchDocumentsInputConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IBatchDocumentsInputConfig);

                    /** BatchDocumentsInputConfig gcsPrefix. */
                    public gcsPrefix?: (google.cloud.documentai.v1.IGcsPrefix|null);

                    /** BatchDocumentsInputConfig gcsDocuments. */
                    public gcsDocuments?: (google.cloud.documentai.v1.IGcsDocuments|null);

                    /** BatchDocumentsInputConfig source. */
                    public source?: ("gcsPrefix"|"gcsDocuments");

                    /**
                     * Creates a new BatchDocumentsInputConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchDocumentsInputConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IBatchDocumentsInputConfig): google.cloud.documentai.v1.BatchDocumentsInputConfig;

                    /**
                     * Encodes the specified BatchDocumentsInputConfig message. Does not implicitly {@link google.cloud.documentai.v1.BatchDocumentsInputConfig.verify|verify} messages.
                     * @param message BatchDocumentsInputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IBatchDocumentsInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchDocumentsInputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.BatchDocumentsInputConfig.verify|verify} messages.
                     * @param message BatchDocumentsInputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IBatchDocumentsInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchDocumentsInputConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchDocumentsInputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.BatchDocumentsInputConfig;

                    /**
                     * Decodes a BatchDocumentsInputConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchDocumentsInputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.BatchDocumentsInputConfig;

                    /**
                     * Verifies a BatchDocumentsInputConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchDocumentsInputConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchDocumentsInputConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.BatchDocumentsInputConfig;

                    /**
                     * Creates a plain object from a BatchDocumentsInputConfig message. Also converts values to other types if specified.
                     * @param message BatchDocumentsInputConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.BatchDocumentsInputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchDocumentsInputConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchDocumentsInputConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DocumentOutputConfig. */
                interface IDocumentOutputConfig {

                    /** DocumentOutputConfig gcsOutputConfig */
                    gcsOutputConfig?: (google.cloud.documentai.v1.DocumentOutputConfig.IGcsOutputConfig|null);
                }

                /** Represents a DocumentOutputConfig. */
                class DocumentOutputConfig implements IDocumentOutputConfig {

                    /**
                     * Constructs a new DocumentOutputConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDocumentOutputConfig);

                    /** DocumentOutputConfig gcsOutputConfig. */
                    public gcsOutputConfig?: (google.cloud.documentai.v1.DocumentOutputConfig.IGcsOutputConfig|null);

                    /** DocumentOutputConfig destination. */
                    public destination?: "gcsOutputConfig";

                    /**
                     * Creates a new DocumentOutputConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DocumentOutputConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDocumentOutputConfig): google.cloud.documentai.v1.DocumentOutputConfig;

                    /**
                     * Encodes the specified DocumentOutputConfig message. Does not implicitly {@link google.cloud.documentai.v1.DocumentOutputConfig.verify|verify} messages.
                     * @param message DocumentOutputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDocumentOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DocumentOutputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DocumentOutputConfig.verify|verify} messages.
                     * @param message DocumentOutputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDocumentOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DocumentOutputConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DocumentOutputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DocumentOutputConfig;

                    /**
                     * Decodes a DocumentOutputConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DocumentOutputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DocumentOutputConfig;

                    /**
                     * Verifies a DocumentOutputConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DocumentOutputConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DocumentOutputConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DocumentOutputConfig;

                    /**
                     * Creates a plain object from a DocumentOutputConfig message. Also converts values to other types if specified.
                     * @param message DocumentOutputConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DocumentOutputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DocumentOutputConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DocumentOutputConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace DocumentOutputConfig {

                    /** Properties of a GcsOutputConfig. */
                    interface IGcsOutputConfig {

                        /** GcsOutputConfig gcsUri */
                        gcsUri?: (string|null);

                        /** GcsOutputConfig fieldMask */
                        fieldMask?: (google.protobuf.IFieldMask|null);

                        /** GcsOutputConfig shardingConfig */
                        shardingConfig?: (google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.IShardingConfig|null);
                    }

                    /** Represents a GcsOutputConfig. */
                    class GcsOutputConfig implements IGcsOutputConfig {

                        /**
                         * Constructs a new GcsOutputConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.DocumentOutputConfig.IGcsOutputConfig);

                        /** GcsOutputConfig gcsUri. */
                        public gcsUri: string;

                        /** GcsOutputConfig fieldMask. */
                        public fieldMask?: (google.protobuf.IFieldMask|null);

                        /** GcsOutputConfig shardingConfig. */
                        public shardingConfig?: (google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.IShardingConfig|null);

                        /**
                         * Creates a new GcsOutputConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns GcsOutputConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.DocumentOutputConfig.IGcsOutputConfig): google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig;

                        /**
                         * Encodes the specified GcsOutputConfig message. Does not implicitly {@link google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.verify|verify} messages.
                         * @param message GcsOutputConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.DocumentOutputConfig.IGcsOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified GcsOutputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.verify|verify} messages.
                         * @param message GcsOutputConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.DocumentOutputConfig.IGcsOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a GcsOutputConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns GcsOutputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig;

                        /**
                         * Decodes a GcsOutputConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns GcsOutputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig;

                        /**
                         * Verifies a GcsOutputConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a GcsOutputConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns GcsOutputConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig;

                        /**
                         * Creates a plain object from a GcsOutputConfig message. Also converts values to other types if specified.
                         * @param message GcsOutputConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this GcsOutputConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for GcsOutputConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace GcsOutputConfig {

                        /** Properties of a ShardingConfig. */
                        interface IShardingConfig {

                            /** ShardingConfig pagesPerShard */
                            pagesPerShard?: (number|null);

                            /** ShardingConfig pagesOverlap */
                            pagesOverlap?: (number|null);
                        }

                        /** Represents a ShardingConfig. */
                        class ShardingConfig implements IShardingConfig {

                            /**
                             * Constructs a new ShardingConfig.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.IShardingConfig);

                            /** ShardingConfig pagesPerShard. */
                            public pagesPerShard: number;

                            /** ShardingConfig pagesOverlap. */
                            public pagesOverlap: number;

                            /**
                             * Creates a new ShardingConfig instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns ShardingConfig instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.IShardingConfig): google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.ShardingConfig;

                            /**
                             * Encodes the specified ShardingConfig message. Does not implicitly {@link google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.ShardingConfig.verify|verify} messages.
                             * @param message ShardingConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.IShardingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified ShardingConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.ShardingConfig.verify|verify} messages.
                             * @param message ShardingConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.IShardingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a ShardingConfig message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns ShardingConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.ShardingConfig;

                            /**
                             * Decodes a ShardingConfig message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns ShardingConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.ShardingConfig;

                            /**
                             * Verifies a ShardingConfig message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a ShardingConfig message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns ShardingConfig
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.ShardingConfig;

                            /**
                             * Creates a plain object from a ShardingConfig message. Also converts values to other types if specified.
                             * @param message ShardingConfig
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.DocumentOutputConfig.GcsOutputConfig.ShardingConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this ShardingConfig to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for ShardingConfig
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }
                }

                /** Properties of an OcrConfig. */
                interface IOcrConfig {

                    /** OcrConfig hints */
                    hints?: (google.cloud.documentai.v1.OcrConfig.IHints|null);

                    /** OcrConfig enableNativePdfParsing */
                    enableNativePdfParsing?: (boolean|null);

                    /** OcrConfig enableImageQualityScores */
                    enableImageQualityScores?: (boolean|null);

                    /** OcrConfig advancedOcrOptions */
                    advancedOcrOptions?: (string[]|null);

                    /** OcrConfig enableSymbol */
                    enableSymbol?: (boolean|null);

                    /** OcrConfig computeStyleInfo */
                    computeStyleInfo?: (boolean|null);

                    /** OcrConfig disableCharacterBoxesDetection */
                    disableCharacterBoxesDetection?: (boolean|null);

                    /** OcrConfig premiumFeatures */
                    premiumFeatures?: (google.cloud.documentai.v1.OcrConfig.IPremiumFeatures|null);
                }

                /** Represents an OcrConfig. */
                class OcrConfig implements IOcrConfig {

                    /**
                     * Constructs a new OcrConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IOcrConfig);

                    /** OcrConfig hints. */
                    public hints?: (google.cloud.documentai.v1.OcrConfig.IHints|null);

                    /** OcrConfig enableNativePdfParsing. */
                    public enableNativePdfParsing: boolean;

                    /** OcrConfig enableImageQualityScores. */
                    public enableImageQualityScores: boolean;

                    /** OcrConfig advancedOcrOptions. */
                    public advancedOcrOptions: string[];

                    /** OcrConfig enableSymbol. */
                    public enableSymbol: boolean;

                    /** OcrConfig computeStyleInfo. */
                    public computeStyleInfo: boolean;

                    /** OcrConfig disableCharacterBoxesDetection. */
                    public disableCharacterBoxesDetection: boolean;

                    /** OcrConfig premiumFeatures. */
                    public premiumFeatures?: (google.cloud.documentai.v1.OcrConfig.IPremiumFeatures|null);

                    /**
                     * Creates a new OcrConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OcrConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IOcrConfig): google.cloud.documentai.v1.OcrConfig;

                    /**
                     * Encodes the specified OcrConfig message. Does not implicitly {@link google.cloud.documentai.v1.OcrConfig.verify|verify} messages.
                     * @param message OcrConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IOcrConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OcrConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.OcrConfig.verify|verify} messages.
                     * @param message OcrConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IOcrConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OcrConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OcrConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.OcrConfig;

                    /**
                     * Decodes an OcrConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OcrConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.OcrConfig;

                    /**
                     * Verifies an OcrConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OcrConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OcrConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.OcrConfig;

                    /**
                     * Creates a plain object from an OcrConfig message. Also converts values to other types if specified.
                     * @param message OcrConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.OcrConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OcrConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OcrConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace OcrConfig {

                    /** Properties of a Hints. */
                    interface IHints {

                        /** Hints languageHints */
                        languageHints?: (string[]|null);
                    }

                    /** Represents a Hints. */
                    class Hints implements IHints {

                        /**
                         * Constructs a new Hints.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.OcrConfig.IHints);

                        /** Hints languageHints. */
                        public languageHints: string[];

                        /**
                         * Creates a new Hints instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Hints instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.OcrConfig.IHints): google.cloud.documentai.v1.OcrConfig.Hints;

                        /**
                         * Encodes the specified Hints message. Does not implicitly {@link google.cloud.documentai.v1.OcrConfig.Hints.verify|verify} messages.
                         * @param message Hints message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.OcrConfig.IHints, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Hints message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.OcrConfig.Hints.verify|verify} messages.
                         * @param message Hints message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.OcrConfig.IHints, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Hints message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Hints
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.OcrConfig.Hints;

                        /**
                         * Decodes a Hints message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Hints
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.OcrConfig.Hints;

                        /**
                         * Verifies a Hints message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Hints message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Hints
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.OcrConfig.Hints;

                        /**
                         * Creates a plain object from a Hints message. Also converts values to other types if specified.
                         * @param message Hints
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.OcrConfig.Hints, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Hints to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Hints
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a PremiumFeatures. */
                    interface IPremiumFeatures {

                        /** PremiumFeatures enableSelectionMarkDetection */
                        enableSelectionMarkDetection?: (boolean|null);

                        /** PremiumFeatures computeStyleInfo */
                        computeStyleInfo?: (boolean|null);

                        /** PremiumFeatures enableMathOcr */
                        enableMathOcr?: (boolean|null);
                    }

                    /** Represents a PremiumFeatures. */
                    class PremiumFeatures implements IPremiumFeatures {

                        /**
                         * Constructs a new PremiumFeatures.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.OcrConfig.IPremiumFeatures);

                        /** PremiumFeatures enableSelectionMarkDetection. */
                        public enableSelectionMarkDetection: boolean;

                        /** PremiumFeatures computeStyleInfo. */
                        public computeStyleInfo: boolean;

                        /** PremiumFeatures enableMathOcr. */
                        public enableMathOcr: boolean;

                        /**
                         * Creates a new PremiumFeatures instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns PremiumFeatures instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.OcrConfig.IPremiumFeatures): google.cloud.documentai.v1.OcrConfig.PremiumFeatures;

                        /**
                         * Encodes the specified PremiumFeatures message. Does not implicitly {@link google.cloud.documentai.v1.OcrConfig.PremiumFeatures.verify|verify} messages.
                         * @param message PremiumFeatures message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.OcrConfig.IPremiumFeatures, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified PremiumFeatures message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.OcrConfig.PremiumFeatures.verify|verify} messages.
                         * @param message PremiumFeatures message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.OcrConfig.IPremiumFeatures, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a PremiumFeatures message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns PremiumFeatures
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.OcrConfig.PremiumFeatures;

                        /**
                         * Decodes a PremiumFeatures message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns PremiumFeatures
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.OcrConfig.PremiumFeatures;

                        /**
                         * Verifies a PremiumFeatures message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a PremiumFeatures message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns PremiumFeatures
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.OcrConfig.PremiumFeatures;

                        /**
                         * Creates a plain object from a PremiumFeatures message. Also converts values to other types if specified.
                         * @param message PremiumFeatures
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.OcrConfig.PremiumFeatures, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this PremiumFeatures to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for PremiumFeatures
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Represents a DocumentProcessorService */
                class DocumentProcessorService extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new DocumentProcessorService service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new DocumentProcessorService service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): DocumentProcessorService;

                    /**
                     * Calls ProcessDocument.
                     * @param request ProcessRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ProcessResponse
                     */
                    public processDocument(request: google.cloud.documentai.v1.IProcessRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.ProcessDocumentCallback): void;

                    /**
                     * Calls ProcessDocument.
                     * @param request ProcessRequest message or plain object
                     * @returns Promise
                     */
                    public processDocument(request: google.cloud.documentai.v1.IProcessRequest): Promise<google.cloud.documentai.v1.ProcessResponse>;

                    /**
                     * Calls BatchProcessDocuments.
                     * @param request BatchProcessRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public batchProcessDocuments(request: google.cloud.documentai.v1.IBatchProcessRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.BatchProcessDocumentsCallback): void;

                    /**
                     * Calls BatchProcessDocuments.
                     * @param request BatchProcessRequest message or plain object
                     * @returns Promise
                     */
                    public batchProcessDocuments(request: google.cloud.documentai.v1.IBatchProcessRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls FetchProcessorTypes.
                     * @param request FetchProcessorTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FetchProcessorTypesResponse
                     */
                    public fetchProcessorTypes(request: google.cloud.documentai.v1.IFetchProcessorTypesRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.FetchProcessorTypesCallback): void;

                    /**
                     * Calls FetchProcessorTypes.
                     * @param request FetchProcessorTypesRequest message or plain object
                     * @returns Promise
                     */
                    public fetchProcessorTypes(request: google.cloud.documentai.v1.IFetchProcessorTypesRequest): Promise<google.cloud.documentai.v1.FetchProcessorTypesResponse>;

                    /**
                     * Calls ListProcessorTypes.
                     * @param request ListProcessorTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ListProcessorTypesResponse
                     */
                    public listProcessorTypes(request: google.cloud.documentai.v1.IListProcessorTypesRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.ListProcessorTypesCallback): void;

                    /**
                     * Calls ListProcessorTypes.
                     * @param request ListProcessorTypesRequest message or plain object
                     * @returns Promise
                     */
                    public listProcessorTypes(request: google.cloud.documentai.v1.IListProcessorTypesRequest): Promise<google.cloud.documentai.v1.ListProcessorTypesResponse>;

                    /**
                     * Calls GetProcessorType.
                     * @param request GetProcessorTypeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ProcessorType
                     */
                    public getProcessorType(request: google.cloud.documentai.v1.IGetProcessorTypeRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.GetProcessorTypeCallback): void;

                    /**
                     * Calls GetProcessorType.
                     * @param request GetProcessorTypeRequest message or plain object
                     * @returns Promise
                     */
                    public getProcessorType(request: google.cloud.documentai.v1.IGetProcessorTypeRequest): Promise<google.cloud.documentai.v1.ProcessorType>;

                    /**
                     * Calls ListProcessors.
                     * @param request ListProcessorsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ListProcessorsResponse
                     */
                    public listProcessors(request: google.cloud.documentai.v1.IListProcessorsRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.ListProcessorsCallback): void;

                    /**
                     * Calls ListProcessors.
                     * @param request ListProcessorsRequest message or plain object
                     * @returns Promise
                     */
                    public listProcessors(request: google.cloud.documentai.v1.IListProcessorsRequest): Promise<google.cloud.documentai.v1.ListProcessorsResponse>;

                    /**
                     * Calls GetProcessor.
                     * @param request GetProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Processor
                     */
                    public getProcessor(request: google.cloud.documentai.v1.IGetProcessorRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.GetProcessorCallback): void;

                    /**
                     * Calls GetProcessor.
                     * @param request GetProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public getProcessor(request: google.cloud.documentai.v1.IGetProcessorRequest): Promise<google.cloud.documentai.v1.Processor>;

                    /**
                     * Calls TrainProcessorVersion.
                     * @param request TrainProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public trainProcessorVersion(request: google.cloud.documentai.v1.ITrainProcessorVersionRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.TrainProcessorVersionCallback): void;

                    /**
                     * Calls TrainProcessorVersion.
                     * @param request TrainProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public trainProcessorVersion(request: google.cloud.documentai.v1.ITrainProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls GetProcessorVersion.
                     * @param request GetProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ProcessorVersion
                     */
                    public getProcessorVersion(request: google.cloud.documentai.v1.IGetProcessorVersionRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.GetProcessorVersionCallback): void;

                    /**
                     * Calls GetProcessorVersion.
                     * @param request GetProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public getProcessorVersion(request: google.cloud.documentai.v1.IGetProcessorVersionRequest): Promise<google.cloud.documentai.v1.ProcessorVersion>;

                    /**
                     * Calls ListProcessorVersions.
                     * @param request ListProcessorVersionsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ListProcessorVersionsResponse
                     */
                    public listProcessorVersions(request: google.cloud.documentai.v1.IListProcessorVersionsRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.ListProcessorVersionsCallback): void;

                    /**
                     * Calls ListProcessorVersions.
                     * @param request ListProcessorVersionsRequest message or plain object
                     * @returns Promise
                     */
                    public listProcessorVersions(request: google.cloud.documentai.v1.IListProcessorVersionsRequest): Promise<google.cloud.documentai.v1.ListProcessorVersionsResponse>;

                    /**
                     * Calls DeleteProcessorVersion.
                     * @param request DeleteProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteProcessorVersion(request: google.cloud.documentai.v1.IDeleteProcessorVersionRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.DeleteProcessorVersionCallback): void;

                    /**
                     * Calls DeleteProcessorVersion.
                     * @param request DeleteProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public deleteProcessorVersion(request: google.cloud.documentai.v1.IDeleteProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls DeployProcessorVersion.
                     * @param request DeployProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deployProcessorVersion(request: google.cloud.documentai.v1.IDeployProcessorVersionRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.DeployProcessorVersionCallback): void;

                    /**
                     * Calls DeployProcessorVersion.
                     * @param request DeployProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public deployProcessorVersion(request: google.cloud.documentai.v1.IDeployProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls UndeployProcessorVersion.
                     * @param request UndeployProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public undeployProcessorVersion(request: google.cloud.documentai.v1.IUndeployProcessorVersionRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.UndeployProcessorVersionCallback): void;

                    /**
                     * Calls UndeployProcessorVersion.
                     * @param request UndeployProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public undeployProcessorVersion(request: google.cloud.documentai.v1.IUndeployProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls CreateProcessor.
                     * @param request CreateProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Processor
                     */
                    public createProcessor(request: google.cloud.documentai.v1.ICreateProcessorRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.CreateProcessorCallback): void;

                    /**
                     * Calls CreateProcessor.
                     * @param request CreateProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public createProcessor(request: google.cloud.documentai.v1.ICreateProcessorRequest): Promise<google.cloud.documentai.v1.Processor>;

                    /**
                     * Calls DeleteProcessor.
                     * @param request DeleteProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteProcessor(request: google.cloud.documentai.v1.IDeleteProcessorRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.DeleteProcessorCallback): void;

                    /**
                     * Calls DeleteProcessor.
                     * @param request DeleteProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public deleteProcessor(request: google.cloud.documentai.v1.IDeleteProcessorRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls EnableProcessor.
                     * @param request EnableProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public enableProcessor(request: google.cloud.documentai.v1.IEnableProcessorRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.EnableProcessorCallback): void;

                    /**
                     * Calls EnableProcessor.
                     * @param request EnableProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public enableProcessor(request: google.cloud.documentai.v1.IEnableProcessorRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls DisableProcessor.
                     * @param request DisableProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public disableProcessor(request: google.cloud.documentai.v1.IDisableProcessorRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.DisableProcessorCallback): void;

                    /**
                     * Calls DisableProcessor.
                     * @param request DisableProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public disableProcessor(request: google.cloud.documentai.v1.IDisableProcessorRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls SetDefaultProcessorVersion.
                     * @param request SetDefaultProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setDefaultProcessorVersion(request: google.cloud.documentai.v1.ISetDefaultProcessorVersionRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.SetDefaultProcessorVersionCallback): void;

                    /**
                     * Calls SetDefaultProcessorVersion.
                     * @param request SetDefaultProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public setDefaultProcessorVersion(request: google.cloud.documentai.v1.ISetDefaultProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls ReviewDocument.
                     * @param request ReviewDocumentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public reviewDocument(request: google.cloud.documentai.v1.IReviewDocumentRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.ReviewDocumentCallback): void;

                    /**
                     * Calls ReviewDocument.
                     * @param request ReviewDocumentRequest message or plain object
                     * @returns Promise
                     */
                    public reviewDocument(request: google.cloud.documentai.v1.IReviewDocumentRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls EvaluateProcessorVersion.
                     * @param request EvaluateProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public evaluateProcessorVersion(request: google.cloud.documentai.v1.IEvaluateProcessorVersionRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.EvaluateProcessorVersionCallback): void;

                    /**
                     * Calls EvaluateProcessorVersion.
                     * @param request EvaluateProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public evaluateProcessorVersion(request: google.cloud.documentai.v1.IEvaluateProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls GetEvaluation.
                     * @param request GetEvaluationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Evaluation
                     */
                    public getEvaluation(request: google.cloud.documentai.v1.IGetEvaluationRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.GetEvaluationCallback): void;

                    /**
                     * Calls GetEvaluation.
                     * @param request GetEvaluationRequest message or plain object
                     * @returns Promise
                     */
                    public getEvaluation(request: google.cloud.documentai.v1.IGetEvaluationRequest): Promise<google.cloud.documentai.v1.Evaluation>;

                    /**
                     * Calls ListEvaluations.
                     * @param request ListEvaluationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ListEvaluationsResponse
                     */
                    public listEvaluations(request: google.cloud.documentai.v1.IListEvaluationsRequest, callback: google.cloud.documentai.v1.DocumentProcessorService.ListEvaluationsCallback): void;

                    /**
                     * Calls ListEvaluations.
                     * @param request ListEvaluationsRequest message or plain object
                     * @returns Promise
                     */
                    public listEvaluations(request: google.cloud.documentai.v1.IListEvaluationsRequest): Promise<google.cloud.documentai.v1.ListEvaluationsResponse>;
                }

                namespace DocumentProcessorService {

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|processDocument}.
                     * @param error Error, if any
                     * @param [response] ProcessResponse
                     */
                    type ProcessDocumentCallback = (error: (Error|null), response?: google.cloud.documentai.v1.ProcessResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|batchProcessDocuments}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type BatchProcessDocumentsCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|fetchProcessorTypes}.
                     * @param error Error, if any
                     * @param [response] FetchProcessorTypesResponse
                     */
                    type FetchProcessorTypesCallback = (error: (Error|null), response?: google.cloud.documentai.v1.FetchProcessorTypesResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|listProcessorTypes}.
                     * @param error Error, if any
                     * @param [response] ListProcessorTypesResponse
                     */
                    type ListProcessorTypesCallback = (error: (Error|null), response?: google.cloud.documentai.v1.ListProcessorTypesResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|getProcessorType}.
                     * @param error Error, if any
                     * @param [response] ProcessorType
                     */
                    type GetProcessorTypeCallback = (error: (Error|null), response?: google.cloud.documentai.v1.ProcessorType) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|listProcessors}.
                     * @param error Error, if any
                     * @param [response] ListProcessorsResponse
                     */
                    type ListProcessorsCallback = (error: (Error|null), response?: google.cloud.documentai.v1.ListProcessorsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|getProcessor}.
                     * @param error Error, if any
                     * @param [response] Processor
                     */
                    type GetProcessorCallback = (error: (Error|null), response?: google.cloud.documentai.v1.Processor) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|trainProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type TrainProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|getProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] ProcessorVersion
                     */
                    type GetProcessorVersionCallback = (error: (Error|null), response?: google.cloud.documentai.v1.ProcessorVersion) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|listProcessorVersions}.
                     * @param error Error, if any
                     * @param [response] ListProcessorVersionsResponse
                     */
                    type ListProcessorVersionsCallback = (error: (Error|null), response?: google.cloud.documentai.v1.ListProcessorVersionsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|deleteProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|deployProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeployProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|undeployProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UndeployProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|createProcessor}.
                     * @param error Error, if any
                     * @param [response] Processor
                     */
                    type CreateProcessorCallback = (error: (Error|null), response?: google.cloud.documentai.v1.Processor) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|deleteProcessor}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteProcessorCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|enableProcessor}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type EnableProcessorCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|disableProcessor}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DisableProcessorCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|setDefaultProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetDefaultProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|reviewDocument}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ReviewDocumentCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|evaluateProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type EvaluateProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|getEvaluation}.
                     * @param error Error, if any
                     * @param [response] Evaluation
                     */
                    type GetEvaluationCallback = (error: (Error|null), response?: google.cloud.documentai.v1.Evaluation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1.DocumentProcessorService|listEvaluations}.
                     * @param error Error, if any
                     * @param [response] ListEvaluationsResponse
                     */
                    type ListEvaluationsCallback = (error: (Error|null), response?: google.cloud.documentai.v1.ListEvaluationsResponse) => void;
                }

                /** Properties of a ProcessOptions. */
                interface IProcessOptions {

                    /** ProcessOptions individualPageSelector */
                    individualPageSelector?: (google.cloud.documentai.v1.ProcessOptions.IIndividualPageSelector|null);

                    /** ProcessOptions fromStart */
                    fromStart?: (number|null);

                    /** ProcessOptions fromEnd */
                    fromEnd?: (number|null);

                    /** ProcessOptions ocrConfig */
                    ocrConfig?: (google.cloud.documentai.v1.IOcrConfig|null);

                    /** ProcessOptions layoutConfig */
                    layoutConfig?: (google.cloud.documentai.v1.ProcessOptions.ILayoutConfig|null);

                    /** ProcessOptions schemaOverride */
                    schemaOverride?: (google.cloud.documentai.v1.IDocumentSchema|null);
                }

                /** Represents a ProcessOptions. */
                class ProcessOptions implements IProcessOptions {

                    /**
                     * Constructs a new ProcessOptions.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IProcessOptions);

                    /** ProcessOptions individualPageSelector. */
                    public individualPageSelector?: (google.cloud.documentai.v1.ProcessOptions.IIndividualPageSelector|null);

                    /** ProcessOptions fromStart. */
                    public fromStart?: (number|null);

                    /** ProcessOptions fromEnd. */
                    public fromEnd?: (number|null);

                    /** ProcessOptions ocrConfig. */
                    public ocrConfig?: (google.cloud.documentai.v1.IOcrConfig|null);

                    /** ProcessOptions layoutConfig. */
                    public layoutConfig?: (google.cloud.documentai.v1.ProcessOptions.ILayoutConfig|null);

                    /** ProcessOptions schemaOverride. */
                    public schemaOverride?: (google.cloud.documentai.v1.IDocumentSchema|null);

                    /** ProcessOptions pageRange. */
                    public pageRange?: ("individualPageSelector"|"fromStart"|"fromEnd");

                    /**
                     * Creates a new ProcessOptions instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessOptions instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IProcessOptions): google.cloud.documentai.v1.ProcessOptions;

                    /**
                     * Encodes the specified ProcessOptions message. Does not implicitly {@link google.cloud.documentai.v1.ProcessOptions.verify|verify} messages.
                     * @param message ProcessOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IProcessOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessOptions message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessOptions.verify|verify} messages.
                     * @param message ProcessOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IProcessOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessOptions message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessOptions;

                    /**
                     * Decodes a ProcessOptions message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessOptions;

                    /**
                     * Verifies a ProcessOptions message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessOptions message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessOptions
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessOptions;

                    /**
                     * Creates a plain object from a ProcessOptions message. Also converts values to other types if specified.
                     * @param message ProcessOptions
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ProcessOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessOptions to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessOptions
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ProcessOptions {

                    /** Properties of a LayoutConfig. */
                    interface ILayoutConfig {

                        /** LayoutConfig chunkingConfig */
                        chunkingConfig?: (google.cloud.documentai.v1.ProcessOptions.LayoutConfig.IChunkingConfig|null);
                    }

                    /** Represents a LayoutConfig. */
                    class LayoutConfig implements ILayoutConfig {

                        /**
                         * Constructs a new LayoutConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.ProcessOptions.ILayoutConfig);

                        /** LayoutConfig chunkingConfig. */
                        public chunkingConfig?: (google.cloud.documentai.v1.ProcessOptions.LayoutConfig.IChunkingConfig|null);

                        /**
                         * Creates a new LayoutConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns LayoutConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.ProcessOptions.ILayoutConfig): google.cloud.documentai.v1.ProcessOptions.LayoutConfig;

                        /**
                         * Encodes the specified LayoutConfig message. Does not implicitly {@link google.cloud.documentai.v1.ProcessOptions.LayoutConfig.verify|verify} messages.
                         * @param message LayoutConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.ProcessOptions.ILayoutConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified LayoutConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessOptions.LayoutConfig.verify|verify} messages.
                         * @param message LayoutConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.ProcessOptions.ILayoutConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a LayoutConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns LayoutConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessOptions.LayoutConfig;

                        /**
                         * Decodes a LayoutConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns LayoutConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessOptions.LayoutConfig;

                        /**
                         * Verifies a LayoutConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a LayoutConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns LayoutConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessOptions.LayoutConfig;

                        /**
                         * Creates a plain object from a LayoutConfig message. Also converts values to other types if specified.
                         * @param message LayoutConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.ProcessOptions.LayoutConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this LayoutConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for LayoutConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace LayoutConfig {

                        /** Properties of a ChunkingConfig. */
                        interface IChunkingConfig {

                            /** ChunkingConfig chunkSize */
                            chunkSize?: (number|null);

                            /** ChunkingConfig includeAncestorHeadings */
                            includeAncestorHeadings?: (boolean|null);
                        }

                        /** Represents a ChunkingConfig. */
                        class ChunkingConfig implements IChunkingConfig {

                            /**
                             * Constructs a new ChunkingConfig.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.ProcessOptions.LayoutConfig.IChunkingConfig);

                            /** ChunkingConfig chunkSize. */
                            public chunkSize: number;

                            /** ChunkingConfig includeAncestorHeadings. */
                            public includeAncestorHeadings: boolean;

                            /**
                             * Creates a new ChunkingConfig instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns ChunkingConfig instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.ProcessOptions.LayoutConfig.IChunkingConfig): google.cloud.documentai.v1.ProcessOptions.LayoutConfig.ChunkingConfig;

                            /**
                             * Encodes the specified ChunkingConfig message. Does not implicitly {@link google.cloud.documentai.v1.ProcessOptions.LayoutConfig.ChunkingConfig.verify|verify} messages.
                             * @param message ChunkingConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.ProcessOptions.LayoutConfig.IChunkingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified ChunkingConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessOptions.LayoutConfig.ChunkingConfig.verify|verify} messages.
                             * @param message ChunkingConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.ProcessOptions.LayoutConfig.IChunkingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a ChunkingConfig message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns ChunkingConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessOptions.LayoutConfig.ChunkingConfig;

                            /**
                             * Decodes a ChunkingConfig message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns ChunkingConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessOptions.LayoutConfig.ChunkingConfig;

                            /**
                             * Verifies a ChunkingConfig message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a ChunkingConfig message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns ChunkingConfig
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessOptions.LayoutConfig.ChunkingConfig;

                            /**
                             * Creates a plain object from a ChunkingConfig message. Also converts values to other types if specified.
                             * @param message ChunkingConfig
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.ProcessOptions.LayoutConfig.ChunkingConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this ChunkingConfig to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for ChunkingConfig
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of an IndividualPageSelector. */
                    interface IIndividualPageSelector {

                        /** IndividualPageSelector pages */
                        pages?: (number[]|null);
                    }

                    /** Represents an IndividualPageSelector. */
                    class IndividualPageSelector implements IIndividualPageSelector {

                        /**
                         * Constructs a new IndividualPageSelector.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.ProcessOptions.IIndividualPageSelector);

                        /** IndividualPageSelector pages. */
                        public pages: number[];

                        /**
                         * Creates a new IndividualPageSelector instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns IndividualPageSelector instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.ProcessOptions.IIndividualPageSelector): google.cloud.documentai.v1.ProcessOptions.IndividualPageSelector;

                        /**
                         * Encodes the specified IndividualPageSelector message. Does not implicitly {@link google.cloud.documentai.v1.ProcessOptions.IndividualPageSelector.verify|verify} messages.
                         * @param message IndividualPageSelector message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.ProcessOptions.IIndividualPageSelector, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified IndividualPageSelector message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessOptions.IndividualPageSelector.verify|verify} messages.
                         * @param message IndividualPageSelector message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.ProcessOptions.IIndividualPageSelector, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an IndividualPageSelector message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns IndividualPageSelector
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessOptions.IndividualPageSelector;

                        /**
                         * Decodes an IndividualPageSelector message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns IndividualPageSelector
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessOptions.IndividualPageSelector;

                        /**
                         * Verifies an IndividualPageSelector message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an IndividualPageSelector message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns IndividualPageSelector
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessOptions.IndividualPageSelector;

                        /**
                         * Creates a plain object from an IndividualPageSelector message. Also converts values to other types if specified.
                         * @param message IndividualPageSelector
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.ProcessOptions.IndividualPageSelector, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this IndividualPageSelector to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for IndividualPageSelector
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a ProcessRequest. */
                interface IProcessRequest {

                    /** ProcessRequest inlineDocument */
                    inlineDocument?: (google.cloud.documentai.v1.IDocument|null);

                    /** ProcessRequest rawDocument */
                    rawDocument?: (google.cloud.documentai.v1.IRawDocument|null);

                    /** ProcessRequest gcsDocument */
                    gcsDocument?: (google.cloud.documentai.v1.IGcsDocument|null);

                    /** ProcessRequest name */
                    name?: (string|null);

                    /** ProcessRequest skipHumanReview */
                    skipHumanReview?: (boolean|null);

                    /** ProcessRequest fieldMask */
                    fieldMask?: (google.protobuf.IFieldMask|null);

                    /** ProcessRequest processOptions */
                    processOptions?: (google.cloud.documentai.v1.IProcessOptions|null);

                    /** ProcessRequest labels */
                    labels?: ({ [k: string]: string }|null);

                    /** ProcessRequest imagelessMode */
                    imagelessMode?: (boolean|null);
                }

                /** Represents a ProcessRequest. */
                class ProcessRequest implements IProcessRequest {

                    /**
                     * Constructs a new ProcessRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IProcessRequest);

                    /** ProcessRequest inlineDocument. */
                    public inlineDocument?: (google.cloud.documentai.v1.IDocument|null);

                    /** ProcessRequest rawDocument. */
                    public rawDocument?: (google.cloud.documentai.v1.IRawDocument|null);

                    /** ProcessRequest gcsDocument. */
                    public gcsDocument?: (google.cloud.documentai.v1.IGcsDocument|null);

                    /** ProcessRequest name. */
                    public name: string;

                    /** ProcessRequest skipHumanReview. */
                    public skipHumanReview: boolean;

                    /** ProcessRequest fieldMask. */
                    public fieldMask?: (google.protobuf.IFieldMask|null);

                    /** ProcessRequest processOptions. */
                    public processOptions?: (google.cloud.documentai.v1.IProcessOptions|null);

                    /** ProcessRequest labels. */
                    public labels: { [k: string]: string };

                    /** ProcessRequest imagelessMode. */
                    public imagelessMode: boolean;

                    /** ProcessRequest source. */
                    public source?: ("inlineDocument"|"rawDocument"|"gcsDocument");

                    /**
                     * Creates a new ProcessRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IProcessRequest): google.cloud.documentai.v1.ProcessRequest;

                    /**
                     * Encodes the specified ProcessRequest message. Does not implicitly {@link google.cloud.documentai.v1.ProcessRequest.verify|verify} messages.
                     * @param message ProcessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IProcessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessRequest.verify|verify} messages.
                     * @param message ProcessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IProcessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessRequest;

                    /**
                     * Decodes a ProcessRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessRequest;

                    /**
                     * Verifies a ProcessRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessRequest;

                    /**
                     * Creates a plain object from a ProcessRequest message. Also converts values to other types if specified.
                     * @param message ProcessRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ProcessRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HumanReviewStatus. */
                interface IHumanReviewStatus {

                    /** HumanReviewStatus state */
                    state?: (google.cloud.documentai.v1.HumanReviewStatus.State|keyof typeof google.cloud.documentai.v1.HumanReviewStatus.State|null);

                    /** HumanReviewStatus stateMessage */
                    stateMessage?: (string|null);

                    /** HumanReviewStatus humanReviewOperation */
                    humanReviewOperation?: (string|null);
                }

                /** Represents a HumanReviewStatus. */
                class HumanReviewStatus implements IHumanReviewStatus {

                    /**
                     * Constructs a new HumanReviewStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IHumanReviewStatus);

                    /** HumanReviewStatus state. */
                    public state: (google.cloud.documentai.v1.HumanReviewStatus.State|keyof typeof google.cloud.documentai.v1.HumanReviewStatus.State);

                    /** HumanReviewStatus stateMessage. */
                    public stateMessage: string;

                    /** HumanReviewStatus humanReviewOperation. */
                    public humanReviewOperation: string;

                    /**
                     * Creates a new HumanReviewStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HumanReviewStatus instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IHumanReviewStatus): google.cloud.documentai.v1.HumanReviewStatus;

                    /**
                     * Encodes the specified HumanReviewStatus message. Does not implicitly {@link google.cloud.documentai.v1.HumanReviewStatus.verify|verify} messages.
                     * @param message HumanReviewStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IHumanReviewStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HumanReviewStatus message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.HumanReviewStatus.verify|verify} messages.
                     * @param message HumanReviewStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IHumanReviewStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HumanReviewStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HumanReviewStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.HumanReviewStatus;

                    /**
                     * Decodes a HumanReviewStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HumanReviewStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.HumanReviewStatus;

                    /**
                     * Verifies a HumanReviewStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HumanReviewStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HumanReviewStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.HumanReviewStatus;

                    /**
                     * Creates a plain object from a HumanReviewStatus message. Also converts values to other types if specified.
                     * @param message HumanReviewStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.HumanReviewStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HumanReviewStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HumanReviewStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HumanReviewStatus {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        SKIPPED = 1,
                        VALIDATION_PASSED = 2,
                        IN_PROGRESS = 3,
                        ERROR = 4
                    }
                }

                /** Properties of a ProcessResponse. */
                interface IProcessResponse {

                    /** ProcessResponse document */
                    document?: (google.cloud.documentai.v1.IDocument|null);

                    /** ProcessResponse humanReviewStatus */
                    humanReviewStatus?: (google.cloud.documentai.v1.IHumanReviewStatus|null);
                }

                /** Represents a ProcessResponse. */
                class ProcessResponse implements IProcessResponse {

                    /**
                     * Constructs a new ProcessResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IProcessResponse);

                    /** ProcessResponse document. */
                    public document?: (google.cloud.documentai.v1.IDocument|null);

                    /** ProcessResponse humanReviewStatus. */
                    public humanReviewStatus?: (google.cloud.documentai.v1.IHumanReviewStatus|null);

                    /**
                     * Creates a new ProcessResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IProcessResponse): google.cloud.documentai.v1.ProcessResponse;

                    /**
                     * Encodes the specified ProcessResponse message. Does not implicitly {@link google.cloud.documentai.v1.ProcessResponse.verify|verify} messages.
                     * @param message ProcessResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IProcessResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessResponse.verify|verify} messages.
                     * @param message ProcessResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IProcessResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessResponse;

                    /**
                     * Decodes a ProcessResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessResponse;

                    /**
                     * Verifies a ProcessResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessResponse;

                    /**
                     * Creates a plain object from a ProcessResponse message. Also converts values to other types if specified.
                     * @param message ProcessResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ProcessResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchProcessRequest. */
                interface IBatchProcessRequest {

                    /** BatchProcessRequest name */
                    name?: (string|null);

                    /** BatchProcessRequest inputDocuments */
                    inputDocuments?: (google.cloud.documentai.v1.IBatchDocumentsInputConfig|null);

                    /** BatchProcessRequest documentOutputConfig */
                    documentOutputConfig?: (google.cloud.documentai.v1.IDocumentOutputConfig|null);

                    /** BatchProcessRequest skipHumanReview */
                    skipHumanReview?: (boolean|null);

                    /** BatchProcessRequest processOptions */
                    processOptions?: (google.cloud.documentai.v1.IProcessOptions|null);

                    /** BatchProcessRequest labels */
                    labels?: ({ [k: string]: string }|null);
                }

                /** Represents a BatchProcessRequest. */
                class BatchProcessRequest implements IBatchProcessRequest {

                    /**
                     * Constructs a new BatchProcessRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IBatchProcessRequest);

                    /** BatchProcessRequest name. */
                    public name: string;

                    /** BatchProcessRequest inputDocuments. */
                    public inputDocuments?: (google.cloud.documentai.v1.IBatchDocumentsInputConfig|null);

                    /** BatchProcessRequest documentOutputConfig. */
                    public documentOutputConfig?: (google.cloud.documentai.v1.IDocumentOutputConfig|null);

                    /** BatchProcessRequest skipHumanReview. */
                    public skipHumanReview: boolean;

                    /** BatchProcessRequest processOptions. */
                    public processOptions?: (google.cloud.documentai.v1.IProcessOptions|null);

                    /** BatchProcessRequest labels. */
                    public labels: { [k: string]: string };

                    /**
                     * Creates a new BatchProcessRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IBatchProcessRequest): google.cloud.documentai.v1.BatchProcessRequest;

                    /**
                     * Encodes the specified BatchProcessRequest message. Does not implicitly {@link google.cloud.documentai.v1.BatchProcessRequest.verify|verify} messages.
                     * @param message BatchProcessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IBatchProcessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.BatchProcessRequest.verify|verify} messages.
                     * @param message BatchProcessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IBatchProcessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.BatchProcessRequest;

                    /**
                     * Decodes a BatchProcessRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.BatchProcessRequest;

                    /**
                     * Verifies a BatchProcessRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.BatchProcessRequest;

                    /**
                     * Creates a plain object from a BatchProcessRequest message. Also converts values to other types if specified.
                     * @param message BatchProcessRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.BatchProcessRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchProcessResponse. */
                interface IBatchProcessResponse {
                }

                /** Represents a BatchProcessResponse. */
                class BatchProcessResponse implements IBatchProcessResponse {

                    /**
                     * Constructs a new BatchProcessResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IBatchProcessResponse);

                    /**
                     * Creates a new BatchProcessResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IBatchProcessResponse): google.cloud.documentai.v1.BatchProcessResponse;

                    /**
                     * Encodes the specified BatchProcessResponse message. Does not implicitly {@link google.cloud.documentai.v1.BatchProcessResponse.verify|verify} messages.
                     * @param message BatchProcessResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IBatchProcessResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.BatchProcessResponse.verify|verify} messages.
                     * @param message BatchProcessResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IBatchProcessResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.BatchProcessResponse;

                    /**
                     * Decodes a BatchProcessResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.BatchProcessResponse;

                    /**
                     * Verifies a BatchProcessResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.BatchProcessResponse;

                    /**
                     * Creates a plain object from a BatchProcessResponse message. Also converts values to other types if specified.
                     * @param message BatchProcessResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.BatchProcessResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchProcessMetadata. */
                interface IBatchProcessMetadata {

                    /** BatchProcessMetadata state */
                    state?: (google.cloud.documentai.v1.BatchProcessMetadata.State|keyof typeof google.cloud.documentai.v1.BatchProcessMetadata.State|null);

                    /** BatchProcessMetadata stateMessage */
                    stateMessage?: (string|null);

                    /** BatchProcessMetadata createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** BatchProcessMetadata updateTime */
                    updateTime?: (google.protobuf.ITimestamp|null);

                    /** BatchProcessMetadata individualProcessStatuses */
                    individualProcessStatuses?: (google.cloud.documentai.v1.BatchProcessMetadata.IIndividualProcessStatus[]|null);
                }

                /** Represents a BatchProcessMetadata. */
                class BatchProcessMetadata implements IBatchProcessMetadata {

                    /**
                     * Constructs a new BatchProcessMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IBatchProcessMetadata);

                    /** BatchProcessMetadata state. */
                    public state: (google.cloud.documentai.v1.BatchProcessMetadata.State|keyof typeof google.cloud.documentai.v1.BatchProcessMetadata.State);

                    /** BatchProcessMetadata stateMessage. */
                    public stateMessage: string;

                    /** BatchProcessMetadata createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** BatchProcessMetadata updateTime. */
                    public updateTime?: (google.protobuf.ITimestamp|null);

                    /** BatchProcessMetadata individualProcessStatuses. */
                    public individualProcessStatuses: google.cloud.documentai.v1.BatchProcessMetadata.IIndividualProcessStatus[];

                    /**
                     * Creates a new BatchProcessMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IBatchProcessMetadata): google.cloud.documentai.v1.BatchProcessMetadata;

                    /**
                     * Encodes the specified BatchProcessMetadata message. Does not implicitly {@link google.cloud.documentai.v1.BatchProcessMetadata.verify|verify} messages.
                     * @param message BatchProcessMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IBatchProcessMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.BatchProcessMetadata.verify|verify} messages.
                     * @param message BatchProcessMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IBatchProcessMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.BatchProcessMetadata;

                    /**
                     * Decodes a BatchProcessMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.BatchProcessMetadata;

                    /**
                     * Verifies a BatchProcessMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.BatchProcessMetadata;

                    /**
                     * Creates a plain object from a BatchProcessMetadata message. Also converts values to other types if specified.
                     * @param message BatchProcessMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.BatchProcessMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BatchProcessMetadata {

                    /** Properties of an IndividualProcessStatus. */
                    interface IIndividualProcessStatus {

                        /** IndividualProcessStatus inputGcsSource */
                        inputGcsSource?: (string|null);

                        /** IndividualProcessStatus status */
                        status?: (google.rpc.IStatus|null);

                        /** IndividualProcessStatus outputGcsDestination */
                        outputGcsDestination?: (string|null);

                        /** IndividualProcessStatus humanReviewStatus */
                        humanReviewStatus?: (google.cloud.documentai.v1.IHumanReviewStatus|null);
                    }

                    /** Represents an IndividualProcessStatus. */
                    class IndividualProcessStatus implements IIndividualProcessStatus {

                        /**
                         * Constructs a new IndividualProcessStatus.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.BatchProcessMetadata.IIndividualProcessStatus);

                        /** IndividualProcessStatus inputGcsSource. */
                        public inputGcsSource: string;

                        /** IndividualProcessStatus status. */
                        public status?: (google.rpc.IStatus|null);

                        /** IndividualProcessStatus outputGcsDestination. */
                        public outputGcsDestination: string;

                        /** IndividualProcessStatus humanReviewStatus. */
                        public humanReviewStatus?: (google.cloud.documentai.v1.IHumanReviewStatus|null);

                        /**
                         * Creates a new IndividualProcessStatus instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns IndividualProcessStatus instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.BatchProcessMetadata.IIndividualProcessStatus): google.cloud.documentai.v1.BatchProcessMetadata.IndividualProcessStatus;

                        /**
                         * Encodes the specified IndividualProcessStatus message. Does not implicitly {@link google.cloud.documentai.v1.BatchProcessMetadata.IndividualProcessStatus.verify|verify} messages.
                         * @param message IndividualProcessStatus message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.BatchProcessMetadata.IIndividualProcessStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified IndividualProcessStatus message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.BatchProcessMetadata.IndividualProcessStatus.verify|verify} messages.
                         * @param message IndividualProcessStatus message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.BatchProcessMetadata.IIndividualProcessStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an IndividualProcessStatus message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns IndividualProcessStatus
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.BatchProcessMetadata.IndividualProcessStatus;

                        /**
                         * Decodes an IndividualProcessStatus message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns IndividualProcessStatus
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.BatchProcessMetadata.IndividualProcessStatus;

                        /**
                         * Verifies an IndividualProcessStatus message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an IndividualProcessStatus message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns IndividualProcessStatus
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.BatchProcessMetadata.IndividualProcessStatus;

                        /**
                         * Creates a plain object from an IndividualProcessStatus message. Also converts values to other types if specified.
                         * @param message IndividualProcessStatus
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.BatchProcessMetadata.IndividualProcessStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this IndividualProcessStatus to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for IndividualProcessStatus
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        WAITING = 1,
                        RUNNING = 2,
                        SUCCEEDED = 3,
                        CANCELLING = 4,
                        CANCELLED = 5,
                        FAILED = 6
                    }
                }

                /** Properties of a FetchProcessorTypesRequest. */
                interface IFetchProcessorTypesRequest {

                    /** FetchProcessorTypesRequest parent */
                    parent?: (string|null);
                }

                /** Represents a FetchProcessorTypesRequest. */
                class FetchProcessorTypesRequest implements IFetchProcessorTypesRequest {

                    /**
                     * Constructs a new FetchProcessorTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IFetchProcessorTypesRequest);

                    /** FetchProcessorTypesRequest parent. */
                    public parent: string;

                    /**
                     * Creates a new FetchProcessorTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FetchProcessorTypesRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IFetchProcessorTypesRequest): google.cloud.documentai.v1.FetchProcessorTypesRequest;

                    /**
                     * Encodes the specified FetchProcessorTypesRequest message. Does not implicitly {@link google.cloud.documentai.v1.FetchProcessorTypesRequest.verify|verify} messages.
                     * @param message FetchProcessorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IFetchProcessorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FetchProcessorTypesRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.FetchProcessorTypesRequest.verify|verify} messages.
                     * @param message FetchProcessorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IFetchProcessorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FetchProcessorTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FetchProcessorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.FetchProcessorTypesRequest;

                    /**
                     * Decodes a FetchProcessorTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FetchProcessorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.FetchProcessorTypesRequest;

                    /**
                     * Verifies a FetchProcessorTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FetchProcessorTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FetchProcessorTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.FetchProcessorTypesRequest;

                    /**
                     * Creates a plain object from a FetchProcessorTypesRequest message. Also converts values to other types if specified.
                     * @param message FetchProcessorTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.FetchProcessorTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FetchProcessorTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FetchProcessorTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FetchProcessorTypesResponse. */
                interface IFetchProcessorTypesResponse {

                    /** FetchProcessorTypesResponse processorTypes */
                    processorTypes?: (google.cloud.documentai.v1.IProcessorType[]|null);
                }

                /** Represents a FetchProcessorTypesResponse. */
                class FetchProcessorTypesResponse implements IFetchProcessorTypesResponse {

                    /**
                     * Constructs a new FetchProcessorTypesResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IFetchProcessorTypesResponse);

                    /** FetchProcessorTypesResponse processorTypes. */
                    public processorTypes: google.cloud.documentai.v1.IProcessorType[];

                    /**
                     * Creates a new FetchProcessorTypesResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FetchProcessorTypesResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IFetchProcessorTypesResponse): google.cloud.documentai.v1.FetchProcessorTypesResponse;

                    /**
                     * Encodes the specified FetchProcessorTypesResponse message. Does not implicitly {@link google.cloud.documentai.v1.FetchProcessorTypesResponse.verify|verify} messages.
                     * @param message FetchProcessorTypesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IFetchProcessorTypesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FetchProcessorTypesResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.FetchProcessorTypesResponse.verify|verify} messages.
                     * @param message FetchProcessorTypesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IFetchProcessorTypesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FetchProcessorTypesResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FetchProcessorTypesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.FetchProcessorTypesResponse;

                    /**
                     * Decodes a FetchProcessorTypesResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FetchProcessorTypesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.FetchProcessorTypesResponse;

                    /**
                     * Verifies a FetchProcessorTypesResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FetchProcessorTypesResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FetchProcessorTypesResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.FetchProcessorTypesResponse;

                    /**
                     * Creates a plain object from a FetchProcessorTypesResponse message. Also converts values to other types if specified.
                     * @param message FetchProcessorTypesResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.FetchProcessorTypesResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FetchProcessorTypesResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FetchProcessorTypesResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorTypesRequest. */
                interface IListProcessorTypesRequest {

                    /** ListProcessorTypesRequest parent */
                    parent?: (string|null);

                    /** ListProcessorTypesRequest pageSize */
                    pageSize?: (number|null);

                    /** ListProcessorTypesRequest pageToken */
                    pageToken?: (string|null);
                }

                /** Represents a ListProcessorTypesRequest. */
                class ListProcessorTypesRequest implements IListProcessorTypesRequest {

                    /**
                     * Constructs a new ListProcessorTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IListProcessorTypesRequest);

                    /** ListProcessorTypesRequest parent. */
                    public parent: string;

                    /** ListProcessorTypesRequest pageSize. */
                    public pageSize: number;

                    /** ListProcessorTypesRequest pageToken. */
                    public pageToken: string;

                    /**
                     * Creates a new ListProcessorTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorTypesRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IListProcessorTypesRequest): google.cloud.documentai.v1.ListProcessorTypesRequest;

                    /**
                     * Encodes the specified ListProcessorTypesRequest message. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorTypesRequest.verify|verify} messages.
                     * @param message ListProcessorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IListProcessorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorTypesRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorTypesRequest.verify|verify} messages.
                     * @param message ListProcessorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IListProcessorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ListProcessorTypesRequest;

                    /**
                     * Decodes a ListProcessorTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ListProcessorTypesRequest;

                    /**
                     * Verifies a ListProcessorTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ListProcessorTypesRequest;

                    /**
                     * Creates a plain object from a ListProcessorTypesRequest message. Also converts values to other types if specified.
                     * @param message ListProcessorTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ListProcessorTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorTypesResponse. */
                interface IListProcessorTypesResponse {

                    /** ListProcessorTypesResponse processorTypes */
                    processorTypes?: (google.cloud.documentai.v1.IProcessorType[]|null);

                    /** ListProcessorTypesResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a ListProcessorTypesResponse. */
                class ListProcessorTypesResponse implements IListProcessorTypesResponse {

                    /**
                     * Constructs a new ListProcessorTypesResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IListProcessorTypesResponse);

                    /** ListProcessorTypesResponse processorTypes. */
                    public processorTypes: google.cloud.documentai.v1.IProcessorType[];

                    /** ListProcessorTypesResponse nextPageToken. */
                    public nextPageToken: string;

                    /**
                     * Creates a new ListProcessorTypesResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorTypesResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IListProcessorTypesResponse): google.cloud.documentai.v1.ListProcessorTypesResponse;

                    /**
                     * Encodes the specified ListProcessorTypesResponse message. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorTypesResponse.verify|verify} messages.
                     * @param message ListProcessorTypesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IListProcessorTypesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorTypesResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorTypesResponse.verify|verify} messages.
                     * @param message ListProcessorTypesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IListProcessorTypesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorTypesResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorTypesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ListProcessorTypesResponse;

                    /**
                     * Decodes a ListProcessorTypesResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorTypesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ListProcessorTypesResponse;

                    /**
                     * Verifies a ListProcessorTypesResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorTypesResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorTypesResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ListProcessorTypesResponse;

                    /**
                     * Creates a plain object from a ListProcessorTypesResponse message. Also converts values to other types if specified.
                     * @param message ListProcessorTypesResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ListProcessorTypesResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorTypesResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorTypesResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorsRequest. */
                interface IListProcessorsRequest {

                    /** ListProcessorsRequest parent */
                    parent?: (string|null);

                    /** ListProcessorsRequest pageSize */
                    pageSize?: (number|null);

                    /** ListProcessorsRequest pageToken */
                    pageToken?: (string|null);
                }

                /** Represents a ListProcessorsRequest. */
                class ListProcessorsRequest implements IListProcessorsRequest {

                    /**
                     * Constructs a new ListProcessorsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IListProcessorsRequest);

                    /** ListProcessorsRequest parent. */
                    public parent: string;

                    /** ListProcessorsRequest pageSize. */
                    public pageSize: number;

                    /** ListProcessorsRequest pageToken. */
                    public pageToken: string;

                    /**
                     * Creates a new ListProcessorsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IListProcessorsRequest): google.cloud.documentai.v1.ListProcessorsRequest;

                    /**
                     * Encodes the specified ListProcessorsRequest message. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorsRequest.verify|verify} messages.
                     * @param message ListProcessorsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IListProcessorsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorsRequest.verify|verify} messages.
                     * @param message ListProcessorsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IListProcessorsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ListProcessorsRequest;

                    /**
                     * Decodes a ListProcessorsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ListProcessorsRequest;

                    /**
                     * Verifies a ListProcessorsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ListProcessorsRequest;

                    /**
                     * Creates a plain object from a ListProcessorsRequest message. Also converts values to other types if specified.
                     * @param message ListProcessorsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ListProcessorsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorsResponse. */
                interface IListProcessorsResponse {

                    /** ListProcessorsResponse processors */
                    processors?: (google.cloud.documentai.v1.IProcessor[]|null);

                    /** ListProcessorsResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a ListProcessorsResponse. */
                class ListProcessorsResponse implements IListProcessorsResponse {

                    /**
                     * Constructs a new ListProcessorsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IListProcessorsResponse);

                    /** ListProcessorsResponse processors. */
                    public processors: google.cloud.documentai.v1.IProcessor[];

                    /** ListProcessorsResponse nextPageToken. */
                    public nextPageToken: string;

                    /**
                     * Creates a new ListProcessorsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IListProcessorsResponse): google.cloud.documentai.v1.ListProcessorsResponse;

                    /**
                     * Encodes the specified ListProcessorsResponse message. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorsResponse.verify|verify} messages.
                     * @param message ListProcessorsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IListProcessorsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorsResponse.verify|verify} messages.
                     * @param message ListProcessorsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IListProcessorsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ListProcessorsResponse;

                    /**
                     * Decodes a ListProcessorsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ListProcessorsResponse;

                    /**
                     * Verifies a ListProcessorsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ListProcessorsResponse;

                    /**
                     * Creates a plain object from a ListProcessorsResponse message. Also converts values to other types if specified.
                     * @param message ListProcessorsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ListProcessorsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetProcessorTypeRequest. */
                interface IGetProcessorTypeRequest {

                    /** GetProcessorTypeRequest name */
                    name?: (string|null);
                }

                /** Represents a GetProcessorTypeRequest. */
                class GetProcessorTypeRequest implements IGetProcessorTypeRequest {

                    /**
                     * Constructs a new GetProcessorTypeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IGetProcessorTypeRequest);

                    /** GetProcessorTypeRequest name. */
                    public name: string;

                    /**
                     * Creates a new GetProcessorTypeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetProcessorTypeRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IGetProcessorTypeRequest): google.cloud.documentai.v1.GetProcessorTypeRequest;

                    /**
                     * Encodes the specified GetProcessorTypeRequest message. Does not implicitly {@link google.cloud.documentai.v1.GetProcessorTypeRequest.verify|verify} messages.
                     * @param message GetProcessorTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IGetProcessorTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetProcessorTypeRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.GetProcessorTypeRequest.verify|verify} messages.
                     * @param message GetProcessorTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IGetProcessorTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetProcessorTypeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetProcessorTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.GetProcessorTypeRequest;

                    /**
                     * Decodes a GetProcessorTypeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetProcessorTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.GetProcessorTypeRequest;

                    /**
                     * Verifies a GetProcessorTypeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetProcessorTypeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetProcessorTypeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.GetProcessorTypeRequest;

                    /**
                     * Creates a plain object from a GetProcessorTypeRequest message. Also converts values to other types if specified.
                     * @param message GetProcessorTypeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.GetProcessorTypeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetProcessorTypeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetProcessorTypeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetProcessorRequest. */
                interface IGetProcessorRequest {

                    /** GetProcessorRequest name */
                    name?: (string|null);
                }

                /** Represents a GetProcessorRequest. */
                class GetProcessorRequest implements IGetProcessorRequest {

                    /**
                     * Constructs a new GetProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IGetProcessorRequest);

                    /** GetProcessorRequest name. */
                    public name: string;

                    /**
                     * Creates a new GetProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IGetProcessorRequest): google.cloud.documentai.v1.GetProcessorRequest;

                    /**
                     * Encodes the specified GetProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1.GetProcessorRequest.verify|verify} messages.
                     * @param message GetProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IGetProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.GetProcessorRequest.verify|verify} messages.
                     * @param message GetProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IGetProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.GetProcessorRequest;

                    /**
                     * Decodes a GetProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.GetProcessorRequest;

                    /**
                     * Verifies a GetProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.GetProcessorRequest;

                    /**
                     * Creates a plain object from a GetProcessorRequest message. Also converts values to other types if specified.
                     * @param message GetProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.GetProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetProcessorVersionRequest. */
                interface IGetProcessorVersionRequest {

                    /** GetProcessorVersionRequest name */
                    name?: (string|null);
                }

                /** Represents a GetProcessorVersionRequest. */
                class GetProcessorVersionRequest implements IGetProcessorVersionRequest {

                    /**
                     * Constructs a new GetProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IGetProcessorVersionRequest);

                    /** GetProcessorVersionRequest name. */
                    public name: string;

                    /**
                     * Creates a new GetProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IGetProcessorVersionRequest): google.cloud.documentai.v1.GetProcessorVersionRequest;

                    /**
                     * Encodes the specified GetProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1.GetProcessorVersionRequest.verify|verify} messages.
                     * @param message GetProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IGetProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.GetProcessorVersionRequest.verify|verify} messages.
                     * @param message GetProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IGetProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.GetProcessorVersionRequest;

                    /**
                     * Decodes a GetProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.GetProcessorVersionRequest;

                    /**
                     * Verifies a GetProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.GetProcessorVersionRequest;

                    /**
                     * Creates a plain object from a GetProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message GetProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.GetProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorVersionsRequest. */
                interface IListProcessorVersionsRequest {

                    /** ListProcessorVersionsRequest parent */
                    parent?: (string|null);

                    /** ListProcessorVersionsRequest pageSize */
                    pageSize?: (number|null);

                    /** ListProcessorVersionsRequest pageToken */
                    pageToken?: (string|null);
                }

                /** Represents a ListProcessorVersionsRequest. */
                class ListProcessorVersionsRequest implements IListProcessorVersionsRequest {

                    /**
                     * Constructs a new ListProcessorVersionsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IListProcessorVersionsRequest);

                    /** ListProcessorVersionsRequest parent. */
                    public parent: string;

                    /** ListProcessorVersionsRequest pageSize. */
                    public pageSize: number;

                    /** ListProcessorVersionsRequest pageToken. */
                    public pageToken: string;

                    /**
                     * Creates a new ListProcessorVersionsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorVersionsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IListProcessorVersionsRequest): google.cloud.documentai.v1.ListProcessorVersionsRequest;

                    /**
                     * Encodes the specified ListProcessorVersionsRequest message. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorVersionsRequest.verify|verify} messages.
                     * @param message ListProcessorVersionsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IListProcessorVersionsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorVersionsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorVersionsRequest.verify|verify} messages.
                     * @param message ListProcessorVersionsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IListProcessorVersionsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorVersionsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorVersionsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ListProcessorVersionsRequest;

                    /**
                     * Decodes a ListProcessorVersionsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorVersionsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ListProcessorVersionsRequest;

                    /**
                     * Verifies a ListProcessorVersionsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorVersionsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorVersionsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ListProcessorVersionsRequest;

                    /**
                     * Creates a plain object from a ListProcessorVersionsRequest message. Also converts values to other types if specified.
                     * @param message ListProcessorVersionsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ListProcessorVersionsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorVersionsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorVersionsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorVersionsResponse. */
                interface IListProcessorVersionsResponse {

                    /** ListProcessorVersionsResponse processorVersions */
                    processorVersions?: (google.cloud.documentai.v1.IProcessorVersion[]|null);

                    /** ListProcessorVersionsResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a ListProcessorVersionsResponse. */
                class ListProcessorVersionsResponse implements IListProcessorVersionsResponse {

                    /**
                     * Constructs a new ListProcessorVersionsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IListProcessorVersionsResponse);

                    /** ListProcessorVersionsResponse processorVersions. */
                    public processorVersions: google.cloud.documentai.v1.IProcessorVersion[];

                    /** ListProcessorVersionsResponse nextPageToken. */
                    public nextPageToken: string;

                    /**
                     * Creates a new ListProcessorVersionsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorVersionsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IListProcessorVersionsResponse): google.cloud.documentai.v1.ListProcessorVersionsResponse;

                    /**
                     * Encodes the specified ListProcessorVersionsResponse message. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorVersionsResponse.verify|verify} messages.
                     * @param message ListProcessorVersionsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IListProcessorVersionsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorVersionsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ListProcessorVersionsResponse.verify|verify} messages.
                     * @param message ListProcessorVersionsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IListProcessorVersionsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorVersionsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorVersionsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ListProcessorVersionsResponse;

                    /**
                     * Decodes a ListProcessorVersionsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorVersionsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ListProcessorVersionsResponse;

                    /**
                     * Verifies a ListProcessorVersionsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorVersionsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorVersionsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ListProcessorVersionsResponse;

                    /**
                     * Creates a plain object from a ListProcessorVersionsResponse message. Also converts values to other types if specified.
                     * @param message ListProcessorVersionsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ListProcessorVersionsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorVersionsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorVersionsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteProcessorVersionRequest. */
                interface IDeleteProcessorVersionRequest {

                    /** DeleteProcessorVersionRequest name */
                    name?: (string|null);
                }

                /** Represents a DeleteProcessorVersionRequest. */
                class DeleteProcessorVersionRequest implements IDeleteProcessorVersionRequest {

                    /**
                     * Constructs a new DeleteProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDeleteProcessorVersionRequest);

                    /** DeleteProcessorVersionRequest name. */
                    public name: string;

                    /**
                     * Creates a new DeleteProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDeleteProcessorVersionRequest): google.cloud.documentai.v1.DeleteProcessorVersionRequest;

                    /**
                     * Encodes the specified DeleteProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1.DeleteProcessorVersionRequest.verify|verify} messages.
                     * @param message DeleteProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDeleteProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DeleteProcessorVersionRequest.verify|verify} messages.
                     * @param message DeleteProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDeleteProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DeleteProcessorVersionRequest;

                    /**
                     * Decodes a DeleteProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DeleteProcessorVersionRequest;

                    /**
                     * Verifies a DeleteProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DeleteProcessorVersionRequest;

                    /**
                     * Creates a plain object from a DeleteProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message DeleteProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DeleteProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteProcessorVersionMetadata. */
                interface IDeleteProcessorVersionMetadata {

                    /** DeleteProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);
                }

                /** Represents a DeleteProcessorVersionMetadata. */
                class DeleteProcessorVersionMetadata implements IDeleteProcessorVersionMetadata {

                    /**
                     * Constructs a new DeleteProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDeleteProcessorVersionMetadata);

                    /** DeleteProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /**
                     * Creates a new DeleteProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDeleteProcessorVersionMetadata): google.cloud.documentai.v1.DeleteProcessorVersionMetadata;

                    /**
                     * Encodes the specified DeleteProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1.DeleteProcessorVersionMetadata.verify|verify} messages.
                     * @param message DeleteProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDeleteProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DeleteProcessorVersionMetadata.verify|verify} messages.
                     * @param message DeleteProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDeleteProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DeleteProcessorVersionMetadata;

                    /**
                     * Decodes a DeleteProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DeleteProcessorVersionMetadata;

                    /**
                     * Verifies a DeleteProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DeleteProcessorVersionMetadata;

                    /**
                     * Creates a plain object from a DeleteProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message DeleteProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DeleteProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeployProcessorVersionRequest. */
                interface IDeployProcessorVersionRequest {

                    /** DeployProcessorVersionRequest name */
                    name?: (string|null);
                }

                /** Represents a DeployProcessorVersionRequest. */
                class DeployProcessorVersionRequest implements IDeployProcessorVersionRequest {

                    /**
                     * Constructs a new DeployProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDeployProcessorVersionRequest);

                    /** DeployProcessorVersionRequest name. */
                    public name: string;

                    /**
                     * Creates a new DeployProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeployProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDeployProcessorVersionRequest): google.cloud.documentai.v1.DeployProcessorVersionRequest;

                    /**
                     * Encodes the specified DeployProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1.DeployProcessorVersionRequest.verify|verify} messages.
                     * @param message DeployProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDeployProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeployProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DeployProcessorVersionRequest.verify|verify} messages.
                     * @param message DeployProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDeployProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeployProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeployProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DeployProcessorVersionRequest;

                    /**
                     * Decodes a DeployProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeployProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DeployProcessorVersionRequest;

                    /**
                     * Verifies a DeployProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeployProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeployProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DeployProcessorVersionRequest;

                    /**
                     * Creates a plain object from a DeployProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message DeployProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DeployProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeployProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeployProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeployProcessorVersionResponse. */
                interface IDeployProcessorVersionResponse {
                }

                /** Represents a DeployProcessorVersionResponse. */
                class DeployProcessorVersionResponse implements IDeployProcessorVersionResponse {

                    /**
                     * Constructs a new DeployProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDeployProcessorVersionResponse);

                    /**
                     * Creates a new DeployProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeployProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDeployProcessorVersionResponse): google.cloud.documentai.v1.DeployProcessorVersionResponse;

                    /**
                     * Encodes the specified DeployProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1.DeployProcessorVersionResponse.verify|verify} messages.
                     * @param message DeployProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDeployProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeployProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DeployProcessorVersionResponse.verify|verify} messages.
                     * @param message DeployProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDeployProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeployProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeployProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DeployProcessorVersionResponse;

                    /**
                     * Decodes a DeployProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeployProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DeployProcessorVersionResponse;

                    /**
                     * Verifies a DeployProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeployProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeployProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DeployProcessorVersionResponse;

                    /**
                     * Creates a plain object from a DeployProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message DeployProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DeployProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeployProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeployProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeployProcessorVersionMetadata. */
                interface IDeployProcessorVersionMetadata {

                    /** DeployProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);
                }

                /** Represents a DeployProcessorVersionMetadata. */
                class DeployProcessorVersionMetadata implements IDeployProcessorVersionMetadata {

                    /**
                     * Constructs a new DeployProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDeployProcessorVersionMetadata);

                    /** DeployProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /**
                     * Creates a new DeployProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeployProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDeployProcessorVersionMetadata): google.cloud.documentai.v1.DeployProcessorVersionMetadata;

                    /**
                     * Encodes the specified DeployProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1.DeployProcessorVersionMetadata.verify|verify} messages.
                     * @param message DeployProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDeployProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeployProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DeployProcessorVersionMetadata.verify|verify} messages.
                     * @param message DeployProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDeployProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeployProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeployProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DeployProcessorVersionMetadata;

                    /**
                     * Decodes a DeployProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeployProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DeployProcessorVersionMetadata;

                    /**
                     * Verifies a DeployProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeployProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeployProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DeployProcessorVersionMetadata;

                    /**
                     * Creates a plain object from a DeployProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message DeployProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DeployProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeployProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeployProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UndeployProcessorVersionRequest. */
                interface IUndeployProcessorVersionRequest {

                    /** UndeployProcessorVersionRequest name */
                    name?: (string|null);
                }

                /** Represents an UndeployProcessorVersionRequest. */
                class UndeployProcessorVersionRequest implements IUndeployProcessorVersionRequest {

                    /**
                     * Constructs a new UndeployProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IUndeployProcessorVersionRequest);

                    /** UndeployProcessorVersionRequest name. */
                    public name: string;

                    /**
                     * Creates a new UndeployProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UndeployProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IUndeployProcessorVersionRequest): google.cloud.documentai.v1.UndeployProcessorVersionRequest;

                    /**
                     * Encodes the specified UndeployProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1.UndeployProcessorVersionRequest.verify|verify} messages.
                     * @param message UndeployProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IUndeployProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UndeployProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.UndeployProcessorVersionRequest.verify|verify} messages.
                     * @param message UndeployProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IUndeployProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UndeployProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UndeployProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.UndeployProcessorVersionRequest;

                    /**
                     * Decodes an UndeployProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UndeployProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.UndeployProcessorVersionRequest;

                    /**
                     * Verifies an UndeployProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UndeployProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UndeployProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.UndeployProcessorVersionRequest;

                    /**
                     * Creates a plain object from an UndeployProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message UndeployProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.UndeployProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UndeployProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UndeployProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UndeployProcessorVersionResponse. */
                interface IUndeployProcessorVersionResponse {
                }

                /** Represents an UndeployProcessorVersionResponse. */
                class UndeployProcessorVersionResponse implements IUndeployProcessorVersionResponse {

                    /**
                     * Constructs a new UndeployProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IUndeployProcessorVersionResponse);

                    /**
                     * Creates a new UndeployProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UndeployProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IUndeployProcessorVersionResponse): google.cloud.documentai.v1.UndeployProcessorVersionResponse;

                    /**
                     * Encodes the specified UndeployProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1.UndeployProcessorVersionResponse.verify|verify} messages.
                     * @param message UndeployProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IUndeployProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UndeployProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.UndeployProcessorVersionResponse.verify|verify} messages.
                     * @param message UndeployProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IUndeployProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UndeployProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UndeployProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.UndeployProcessorVersionResponse;

                    /**
                     * Decodes an UndeployProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UndeployProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.UndeployProcessorVersionResponse;

                    /**
                     * Verifies an UndeployProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UndeployProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UndeployProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.UndeployProcessorVersionResponse;

                    /**
                     * Creates a plain object from an UndeployProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message UndeployProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.UndeployProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UndeployProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UndeployProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UndeployProcessorVersionMetadata. */
                interface IUndeployProcessorVersionMetadata {

                    /** UndeployProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);
                }

                /** Represents an UndeployProcessorVersionMetadata. */
                class UndeployProcessorVersionMetadata implements IUndeployProcessorVersionMetadata {

                    /**
                     * Constructs a new UndeployProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IUndeployProcessorVersionMetadata);

                    /** UndeployProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /**
                     * Creates a new UndeployProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UndeployProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IUndeployProcessorVersionMetadata): google.cloud.documentai.v1.UndeployProcessorVersionMetadata;

                    /**
                     * Encodes the specified UndeployProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1.UndeployProcessorVersionMetadata.verify|verify} messages.
                     * @param message UndeployProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IUndeployProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UndeployProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.UndeployProcessorVersionMetadata.verify|verify} messages.
                     * @param message UndeployProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IUndeployProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UndeployProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UndeployProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.UndeployProcessorVersionMetadata;

                    /**
                     * Decodes an UndeployProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UndeployProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.UndeployProcessorVersionMetadata;

                    /**
                     * Verifies an UndeployProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UndeployProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UndeployProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.UndeployProcessorVersionMetadata;

                    /**
                     * Creates a plain object from an UndeployProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message UndeployProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.UndeployProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UndeployProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UndeployProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CreateProcessorRequest. */
                interface ICreateProcessorRequest {

                    /** CreateProcessorRequest parent */
                    parent?: (string|null);

                    /** CreateProcessorRequest processor */
                    processor?: (google.cloud.documentai.v1.IProcessor|null);
                }

                /** Represents a CreateProcessorRequest. */
                class CreateProcessorRequest implements ICreateProcessorRequest {

                    /**
                     * Constructs a new CreateProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.ICreateProcessorRequest);

                    /** CreateProcessorRequest parent. */
                    public parent: string;

                    /** CreateProcessorRequest processor. */
                    public processor?: (google.cloud.documentai.v1.IProcessor|null);

                    /**
                     * Creates a new CreateProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CreateProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.ICreateProcessorRequest): google.cloud.documentai.v1.CreateProcessorRequest;

                    /**
                     * Encodes the specified CreateProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1.CreateProcessorRequest.verify|verify} messages.
                     * @param message CreateProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.ICreateProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CreateProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.CreateProcessorRequest.verify|verify} messages.
                     * @param message CreateProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.ICreateProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CreateProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CreateProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.CreateProcessorRequest;

                    /**
                     * Decodes a CreateProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CreateProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.CreateProcessorRequest;

                    /**
                     * Verifies a CreateProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CreateProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CreateProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.CreateProcessorRequest;

                    /**
                     * Creates a plain object from a CreateProcessorRequest message. Also converts values to other types if specified.
                     * @param message CreateProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.CreateProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CreateProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CreateProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteProcessorRequest. */
                interface IDeleteProcessorRequest {

                    /** DeleteProcessorRequest name */
                    name?: (string|null);
                }

                /** Represents a DeleteProcessorRequest. */
                class DeleteProcessorRequest implements IDeleteProcessorRequest {

                    /**
                     * Constructs a new DeleteProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDeleteProcessorRequest);

                    /** DeleteProcessorRequest name. */
                    public name: string;

                    /**
                     * Creates a new DeleteProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDeleteProcessorRequest): google.cloud.documentai.v1.DeleteProcessorRequest;

                    /**
                     * Encodes the specified DeleteProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1.DeleteProcessorRequest.verify|verify} messages.
                     * @param message DeleteProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDeleteProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DeleteProcessorRequest.verify|verify} messages.
                     * @param message DeleteProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDeleteProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DeleteProcessorRequest;

                    /**
                     * Decodes a DeleteProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DeleteProcessorRequest;

                    /**
                     * Verifies a DeleteProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DeleteProcessorRequest;

                    /**
                     * Creates a plain object from a DeleteProcessorRequest message. Also converts values to other types if specified.
                     * @param message DeleteProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DeleteProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteProcessorMetadata. */
                interface IDeleteProcessorMetadata {

                    /** DeleteProcessorMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);
                }

                /** Represents a DeleteProcessorMetadata. */
                class DeleteProcessorMetadata implements IDeleteProcessorMetadata {

                    /**
                     * Constructs a new DeleteProcessorMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDeleteProcessorMetadata);

                    /** DeleteProcessorMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /**
                     * Creates a new DeleteProcessorMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteProcessorMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDeleteProcessorMetadata): google.cloud.documentai.v1.DeleteProcessorMetadata;

                    /**
                     * Encodes the specified DeleteProcessorMetadata message. Does not implicitly {@link google.cloud.documentai.v1.DeleteProcessorMetadata.verify|verify} messages.
                     * @param message DeleteProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDeleteProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteProcessorMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DeleteProcessorMetadata.verify|verify} messages.
                     * @param message DeleteProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDeleteProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteProcessorMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DeleteProcessorMetadata;

                    /**
                     * Decodes a DeleteProcessorMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DeleteProcessorMetadata;

                    /**
                     * Verifies a DeleteProcessorMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteProcessorMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteProcessorMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DeleteProcessorMetadata;

                    /**
                     * Creates a plain object from a DeleteProcessorMetadata message. Also converts values to other types if specified.
                     * @param message DeleteProcessorMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DeleteProcessorMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteProcessorMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteProcessorMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EnableProcessorRequest. */
                interface IEnableProcessorRequest {

                    /** EnableProcessorRequest name */
                    name?: (string|null);
                }

                /** Represents an EnableProcessorRequest. */
                class EnableProcessorRequest implements IEnableProcessorRequest {

                    /**
                     * Constructs a new EnableProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IEnableProcessorRequest);

                    /** EnableProcessorRequest name. */
                    public name: string;

                    /**
                     * Creates a new EnableProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EnableProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IEnableProcessorRequest): google.cloud.documentai.v1.EnableProcessorRequest;

                    /**
                     * Encodes the specified EnableProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1.EnableProcessorRequest.verify|verify} messages.
                     * @param message EnableProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IEnableProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EnableProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.EnableProcessorRequest.verify|verify} messages.
                     * @param message EnableProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IEnableProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EnableProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EnableProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.EnableProcessorRequest;

                    /**
                     * Decodes an EnableProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EnableProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.EnableProcessorRequest;

                    /**
                     * Verifies an EnableProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EnableProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EnableProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.EnableProcessorRequest;

                    /**
                     * Creates a plain object from an EnableProcessorRequest message. Also converts values to other types if specified.
                     * @param message EnableProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.EnableProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EnableProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EnableProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EnableProcessorResponse. */
                interface IEnableProcessorResponse {
                }

                /** Represents an EnableProcessorResponse. */
                class EnableProcessorResponse implements IEnableProcessorResponse {

                    /**
                     * Constructs a new EnableProcessorResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IEnableProcessorResponse);

                    /**
                     * Creates a new EnableProcessorResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EnableProcessorResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IEnableProcessorResponse): google.cloud.documentai.v1.EnableProcessorResponse;

                    /**
                     * Encodes the specified EnableProcessorResponse message. Does not implicitly {@link google.cloud.documentai.v1.EnableProcessorResponse.verify|verify} messages.
                     * @param message EnableProcessorResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IEnableProcessorResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EnableProcessorResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.EnableProcessorResponse.verify|verify} messages.
                     * @param message EnableProcessorResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IEnableProcessorResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EnableProcessorResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EnableProcessorResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.EnableProcessorResponse;

                    /**
                     * Decodes an EnableProcessorResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EnableProcessorResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.EnableProcessorResponse;

                    /**
                     * Verifies an EnableProcessorResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EnableProcessorResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EnableProcessorResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.EnableProcessorResponse;

                    /**
                     * Creates a plain object from an EnableProcessorResponse message. Also converts values to other types if specified.
                     * @param message EnableProcessorResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.EnableProcessorResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EnableProcessorResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EnableProcessorResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EnableProcessorMetadata. */
                interface IEnableProcessorMetadata {

                    /** EnableProcessorMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);
                }

                /** Represents an EnableProcessorMetadata. */
                class EnableProcessorMetadata implements IEnableProcessorMetadata {

                    /**
                     * Constructs a new EnableProcessorMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IEnableProcessorMetadata);

                    /** EnableProcessorMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /**
                     * Creates a new EnableProcessorMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EnableProcessorMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IEnableProcessorMetadata): google.cloud.documentai.v1.EnableProcessorMetadata;

                    /**
                     * Encodes the specified EnableProcessorMetadata message. Does not implicitly {@link google.cloud.documentai.v1.EnableProcessorMetadata.verify|verify} messages.
                     * @param message EnableProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IEnableProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EnableProcessorMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.EnableProcessorMetadata.verify|verify} messages.
                     * @param message EnableProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IEnableProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EnableProcessorMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EnableProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.EnableProcessorMetadata;

                    /**
                     * Decodes an EnableProcessorMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EnableProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.EnableProcessorMetadata;

                    /**
                     * Verifies an EnableProcessorMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EnableProcessorMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EnableProcessorMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.EnableProcessorMetadata;

                    /**
                     * Creates a plain object from an EnableProcessorMetadata message. Also converts values to other types if specified.
                     * @param message EnableProcessorMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.EnableProcessorMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EnableProcessorMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EnableProcessorMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisableProcessorRequest. */
                interface IDisableProcessorRequest {

                    /** DisableProcessorRequest name */
                    name?: (string|null);
                }

                /** Represents a DisableProcessorRequest. */
                class DisableProcessorRequest implements IDisableProcessorRequest {

                    /**
                     * Constructs a new DisableProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDisableProcessorRequest);

                    /** DisableProcessorRequest name. */
                    public name: string;

                    /**
                     * Creates a new DisableProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisableProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDisableProcessorRequest): google.cloud.documentai.v1.DisableProcessorRequest;

                    /**
                     * Encodes the specified DisableProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1.DisableProcessorRequest.verify|verify} messages.
                     * @param message DisableProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDisableProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisableProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DisableProcessorRequest.verify|verify} messages.
                     * @param message DisableProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDisableProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisableProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisableProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DisableProcessorRequest;

                    /**
                     * Decodes a DisableProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisableProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DisableProcessorRequest;

                    /**
                     * Verifies a DisableProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisableProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisableProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DisableProcessorRequest;

                    /**
                     * Creates a plain object from a DisableProcessorRequest message. Also converts values to other types if specified.
                     * @param message DisableProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DisableProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisableProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisableProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisableProcessorResponse. */
                interface IDisableProcessorResponse {
                }

                /** Represents a DisableProcessorResponse. */
                class DisableProcessorResponse implements IDisableProcessorResponse {

                    /**
                     * Constructs a new DisableProcessorResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDisableProcessorResponse);

                    /**
                     * Creates a new DisableProcessorResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisableProcessorResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDisableProcessorResponse): google.cloud.documentai.v1.DisableProcessorResponse;

                    /**
                     * Encodes the specified DisableProcessorResponse message. Does not implicitly {@link google.cloud.documentai.v1.DisableProcessorResponse.verify|verify} messages.
                     * @param message DisableProcessorResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDisableProcessorResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisableProcessorResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DisableProcessorResponse.verify|verify} messages.
                     * @param message DisableProcessorResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDisableProcessorResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisableProcessorResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisableProcessorResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DisableProcessorResponse;

                    /**
                     * Decodes a DisableProcessorResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisableProcessorResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DisableProcessorResponse;

                    /**
                     * Verifies a DisableProcessorResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisableProcessorResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisableProcessorResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DisableProcessorResponse;

                    /**
                     * Creates a plain object from a DisableProcessorResponse message. Also converts values to other types if specified.
                     * @param message DisableProcessorResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DisableProcessorResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisableProcessorResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisableProcessorResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisableProcessorMetadata. */
                interface IDisableProcessorMetadata {

                    /** DisableProcessorMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);
                }

                /** Represents a DisableProcessorMetadata. */
                class DisableProcessorMetadata implements IDisableProcessorMetadata {

                    /**
                     * Constructs a new DisableProcessorMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDisableProcessorMetadata);

                    /** DisableProcessorMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /**
                     * Creates a new DisableProcessorMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisableProcessorMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDisableProcessorMetadata): google.cloud.documentai.v1.DisableProcessorMetadata;

                    /**
                     * Encodes the specified DisableProcessorMetadata message. Does not implicitly {@link google.cloud.documentai.v1.DisableProcessorMetadata.verify|verify} messages.
                     * @param message DisableProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDisableProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisableProcessorMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DisableProcessorMetadata.verify|verify} messages.
                     * @param message DisableProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDisableProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisableProcessorMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisableProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DisableProcessorMetadata;

                    /**
                     * Decodes a DisableProcessorMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisableProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DisableProcessorMetadata;

                    /**
                     * Verifies a DisableProcessorMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisableProcessorMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisableProcessorMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DisableProcessorMetadata;

                    /**
                     * Creates a plain object from a DisableProcessorMetadata message. Also converts values to other types if specified.
                     * @param message DisableProcessorMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DisableProcessorMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisableProcessorMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisableProcessorMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetDefaultProcessorVersionRequest. */
                interface ISetDefaultProcessorVersionRequest {

                    /** SetDefaultProcessorVersionRequest processor */
                    processor?: (string|null);

                    /** SetDefaultProcessorVersionRequest defaultProcessorVersion */
                    defaultProcessorVersion?: (string|null);
                }

                /** Represents a SetDefaultProcessorVersionRequest. */
                class SetDefaultProcessorVersionRequest implements ISetDefaultProcessorVersionRequest {

                    /**
                     * Constructs a new SetDefaultProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.ISetDefaultProcessorVersionRequest);

                    /** SetDefaultProcessorVersionRequest processor. */
                    public processor: string;

                    /** SetDefaultProcessorVersionRequest defaultProcessorVersion. */
                    public defaultProcessorVersion: string;

                    /**
                     * Creates a new SetDefaultProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetDefaultProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.ISetDefaultProcessorVersionRequest): google.cloud.documentai.v1.SetDefaultProcessorVersionRequest;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1.SetDefaultProcessorVersionRequest.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.ISetDefaultProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.SetDefaultProcessorVersionRequest.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.ISetDefaultProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetDefaultProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetDefaultProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.SetDefaultProcessorVersionRequest;

                    /**
                     * Decodes a SetDefaultProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetDefaultProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.SetDefaultProcessorVersionRequest;

                    /**
                     * Verifies a SetDefaultProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetDefaultProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetDefaultProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.SetDefaultProcessorVersionRequest;

                    /**
                     * Creates a plain object from a SetDefaultProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message SetDefaultProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.SetDefaultProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetDefaultProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetDefaultProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetDefaultProcessorVersionResponse. */
                interface ISetDefaultProcessorVersionResponse {
                }

                /** Represents a SetDefaultProcessorVersionResponse. */
                class SetDefaultProcessorVersionResponse implements ISetDefaultProcessorVersionResponse {

                    /**
                     * Constructs a new SetDefaultProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.ISetDefaultProcessorVersionResponse);

                    /**
                     * Creates a new SetDefaultProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetDefaultProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.ISetDefaultProcessorVersionResponse): google.cloud.documentai.v1.SetDefaultProcessorVersionResponse;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1.SetDefaultProcessorVersionResponse.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.ISetDefaultProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.SetDefaultProcessorVersionResponse.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.ISetDefaultProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetDefaultProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetDefaultProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.SetDefaultProcessorVersionResponse;

                    /**
                     * Decodes a SetDefaultProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetDefaultProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.SetDefaultProcessorVersionResponse;

                    /**
                     * Verifies a SetDefaultProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetDefaultProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetDefaultProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.SetDefaultProcessorVersionResponse;

                    /**
                     * Creates a plain object from a SetDefaultProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message SetDefaultProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.SetDefaultProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetDefaultProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetDefaultProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetDefaultProcessorVersionMetadata. */
                interface ISetDefaultProcessorVersionMetadata {

                    /** SetDefaultProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);
                }

                /** Represents a SetDefaultProcessorVersionMetadata. */
                class SetDefaultProcessorVersionMetadata implements ISetDefaultProcessorVersionMetadata {

                    /**
                     * Constructs a new SetDefaultProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.ISetDefaultProcessorVersionMetadata);

                    /** SetDefaultProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /**
                     * Creates a new SetDefaultProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetDefaultProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.ISetDefaultProcessorVersionMetadata): google.cloud.documentai.v1.SetDefaultProcessorVersionMetadata;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1.SetDefaultProcessorVersionMetadata.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.ISetDefaultProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.SetDefaultProcessorVersionMetadata.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.ISetDefaultProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetDefaultProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetDefaultProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.SetDefaultProcessorVersionMetadata;

                    /**
                     * Decodes a SetDefaultProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetDefaultProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.SetDefaultProcessorVersionMetadata;

                    /**
                     * Verifies a SetDefaultProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetDefaultProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetDefaultProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.SetDefaultProcessorVersionMetadata;

                    /**
                     * Creates a plain object from a SetDefaultProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message SetDefaultProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.SetDefaultProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetDefaultProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetDefaultProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TrainProcessorVersionRequest. */
                interface ITrainProcessorVersionRequest {

                    /** TrainProcessorVersionRequest customDocumentExtractionOptions */
                    customDocumentExtractionOptions?: (google.cloud.documentai.v1.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions|null);

                    /** TrainProcessorVersionRequest foundationModelTuningOptions */
                    foundationModelTuningOptions?: (google.cloud.documentai.v1.TrainProcessorVersionRequest.IFoundationModelTuningOptions|null);

                    /** TrainProcessorVersionRequest parent */
                    parent?: (string|null);

                    /** TrainProcessorVersionRequest processorVersion */
                    processorVersion?: (google.cloud.documentai.v1.IProcessorVersion|null);

                    /** TrainProcessorVersionRequest documentSchema */
                    documentSchema?: (google.cloud.documentai.v1.IDocumentSchema|null);

                    /** TrainProcessorVersionRequest inputData */
                    inputData?: (google.cloud.documentai.v1.TrainProcessorVersionRequest.IInputData|null);

                    /** TrainProcessorVersionRequest baseProcessorVersion */
                    baseProcessorVersion?: (string|null);
                }

                /** Represents a TrainProcessorVersionRequest. */
                class TrainProcessorVersionRequest implements ITrainProcessorVersionRequest {

                    /**
                     * Constructs a new TrainProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.ITrainProcessorVersionRequest);

                    /** TrainProcessorVersionRequest customDocumentExtractionOptions. */
                    public customDocumentExtractionOptions?: (google.cloud.documentai.v1.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions|null);

                    /** TrainProcessorVersionRequest foundationModelTuningOptions. */
                    public foundationModelTuningOptions?: (google.cloud.documentai.v1.TrainProcessorVersionRequest.IFoundationModelTuningOptions|null);

                    /** TrainProcessorVersionRequest parent. */
                    public parent: string;

                    /** TrainProcessorVersionRequest processorVersion. */
                    public processorVersion?: (google.cloud.documentai.v1.IProcessorVersion|null);

                    /** TrainProcessorVersionRequest documentSchema. */
                    public documentSchema?: (google.cloud.documentai.v1.IDocumentSchema|null);

                    /** TrainProcessorVersionRequest inputData. */
                    public inputData?: (google.cloud.documentai.v1.TrainProcessorVersionRequest.IInputData|null);

                    /** TrainProcessorVersionRequest baseProcessorVersion. */
                    public baseProcessorVersion: string;

                    /** TrainProcessorVersionRequest processorFlags. */
                    public processorFlags?: ("customDocumentExtractionOptions"|"foundationModelTuningOptions");

                    /**
                     * Creates a new TrainProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TrainProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.ITrainProcessorVersionRequest): google.cloud.documentai.v1.TrainProcessorVersionRequest;

                    /**
                     * Encodes the specified TrainProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionRequest.verify|verify} messages.
                     * @param message TrainProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.ITrainProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TrainProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionRequest.verify|verify} messages.
                     * @param message TrainProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.ITrainProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TrainProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TrainProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.TrainProcessorVersionRequest;

                    /**
                     * Decodes a TrainProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TrainProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.TrainProcessorVersionRequest;

                    /**
                     * Verifies a TrainProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TrainProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TrainProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.TrainProcessorVersionRequest;

                    /**
                     * Creates a plain object from a TrainProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message TrainProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.TrainProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TrainProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TrainProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TrainProcessorVersionRequest {

                    /** Properties of an InputData. */
                    interface IInputData {

                        /** InputData trainingDocuments */
                        trainingDocuments?: (google.cloud.documentai.v1.IBatchDocumentsInputConfig|null);

                        /** InputData testDocuments */
                        testDocuments?: (google.cloud.documentai.v1.IBatchDocumentsInputConfig|null);
                    }

                    /** Represents an InputData. */
                    class InputData implements IInputData {

                        /**
                         * Constructs a new InputData.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.TrainProcessorVersionRequest.IInputData);

                        /** InputData trainingDocuments. */
                        public trainingDocuments?: (google.cloud.documentai.v1.IBatchDocumentsInputConfig|null);

                        /** InputData testDocuments. */
                        public testDocuments?: (google.cloud.documentai.v1.IBatchDocumentsInputConfig|null);

                        /**
                         * Creates a new InputData instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns InputData instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.TrainProcessorVersionRequest.IInputData): google.cloud.documentai.v1.TrainProcessorVersionRequest.InputData;

                        /**
                         * Encodes the specified InputData message. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionRequest.InputData.verify|verify} messages.
                         * @param message InputData message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.TrainProcessorVersionRequest.IInputData, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified InputData message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionRequest.InputData.verify|verify} messages.
                         * @param message InputData message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.TrainProcessorVersionRequest.IInputData, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an InputData message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns InputData
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.TrainProcessorVersionRequest.InputData;

                        /**
                         * Decodes an InputData message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns InputData
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.TrainProcessorVersionRequest.InputData;

                        /**
                         * Verifies an InputData message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an InputData message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns InputData
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.TrainProcessorVersionRequest.InputData;

                        /**
                         * Creates a plain object from an InputData message. Also converts values to other types if specified.
                         * @param message InputData
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.TrainProcessorVersionRequest.InputData, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this InputData to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for InputData
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a CustomDocumentExtractionOptions. */
                    interface ICustomDocumentExtractionOptions {

                        /** CustomDocumentExtractionOptions trainingMethod */
                        trainingMethod?: (google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.TrainingMethod|keyof typeof google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.TrainingMethod|null);
                    }

                    /** Represents a CustomDocumentExtractionOptions. */
                    class CustomDocumentExtractionOptions implements ICustomDocumentExtractionOptions {

                        /**
                         * Constructs a new CustomDocumentExtractionOptions.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions);

                        /** CustomDocumentExtractionOptions trainingMethod. */
                        public trainingMethod: (google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.TrainingMethod|keyof typeof google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.TrainingMethod);

                        /**
                         * Creates a new CustomDocumentExtractionOptions instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns CustomDocumentExtractionOptions instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions): google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions;

                        /**
                         * Encodes the specified CustomDocumentExtractionOptions message. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.verify|verify} messages.
                         * @param message CustomDocumentExtractionOptions message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified CustomDocumentExtractionOptions message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.verify|verify} messages.
                         * @param message CustomDocumentExtractionOptions message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a CustomDocumentExtractionOptions message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns CustomDocumentExtractionOptions
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions;

                        /**
                         * Decodes a CustomDocumentExtractionOptions message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns CustomDocumentExtractionOptions
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions;

                        /**
                         * Verifies a CustomDocumentExtractionOptions message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a CustomDocumentExtractionOptions message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns CustomDocumentExtractionOptions
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions;

                        /**
                         * Creates a plain object from a CustomDocumentExtractionOptions message. Also converts values to other types if specified.
                         * @param message CustomDocumentExtractionOptions
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.TrainProcessorVersionRequest.CustomDocumentExtractionOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this CustomDocumentExtractionOptions to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for CustomDocumentExtractionOptions
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace CustomDocumentExtractionOptions {

                        /** TrainingMethod enum. */
                        enum TrainingMethod {
                            TRAINING_METHOD_UNSPECIFIED = 0,
                            MODEL_BASED = 1,
                            TEMPLATE_BASED = 2
                        }
                    }

                    /** Properties of a FoundationModelTuningOptions. */
                    interface IFoundationModelTuningOptions {

                        /** FoundationModelTuningOptions trainSteps */
                        trainSteps?: (number|null);

                        /** FoundationModelTuningOptions learningRateMultiplier */
                        learningRateMultiplier?: (number|null);
                    }

                    /** Represents a FoundationModelTuningOptions. */
                    class FoundationModelTuningOptions implements IFoundationModelTuningOptions {

                        /**
                         * Constructs a new FoundationModelTuningOptions.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.TrainProcessorVersionRequest.IFoundationModelTuningOptions);

                        /** FoundationModelTuningOptions trainSteps. */
                        public trainSteps: number;

                        /** FoundationModelTuningOptions learningRateMultiplier. */
                        public learningRateMultiplier: number;

                        /**
                         * Creates a new FoundationModelTuningOptions instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns FoundationModelTuningOptions instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.TrainProcessorVersionRequest.IFoundationModelTuningOptions): google.cloud.documentai.v1.TrainProcessorVersionRequest.FoundationModelTuningOptions;

                        /**
                         * Encodes the specified FoundationModelTuningOptions message. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionRequest.FoundationModelTuningOptions.verify|verify} messages.
                         * @param message FoundationModelTuningOptions message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.TrainProcessorVersionRequest.IFoundationModelTuningOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified FoundationModelTuningOptions message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionRequest.FoundationModelTuningOptions.verify|verify} messages.
                         * @param message FoundationModelTuningOptions message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.TrainProcessorVersionRequest.IFoundationModelTuningOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a FoundationModelTuningOptions message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns FoundationModelTuningOptions
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.TrainProcessorVersionRequest.FoundationModelTuningOptions;

                        /**
                         * Decodes a FoundationModelTuningOptions message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns FoundationModelTuningOptions
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.TrainProcessorVersionRequest.FoundationModelTuningOptions;

                        /**
                         * Verifies a FoundationModelTuningOptions message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a FoundationModelTuningOptions message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns FoundationModelTuningOptions
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.TrainProcessorVersionRequest.FoundationModelTuningOptions;

                        /**
                         * Creates a plain object from a FoundationModelTuningOptions message. Also converts values to other types if specified.
                         * @param message FoundationModelTuningOptions
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.TrainProcessorVersionRequest.FoundationModelTuningOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this FoundationModelTuningOptions to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for FoundationModelTuningOptions
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a TrainProcessorVersionResponse. */
                interface ITrainProcessorVersionResponse {

                    /** TrainProcessorVersionResponse processorVersion */
                    processorVersion?: (string|null);
                }

                /** Represents a TrainProcessorVersionResponse. */
                class TrainProcessorVersionResponse implements ITrainProcessorVersionResponse {

                    /**
                     * Constructs a new TrainProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.ITrainProcessorVersionResponse);

                    /** TrainProcessorVersionResponse processorVersion. */
                    public processorVersion: string;

                    /**
                     * Creates a new TrainProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TrainProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.ITrainProcessorVersionResponse): google.cloud.documentai.v1.TrainProcessorVersionResponse;

                    /**
                     * Encodes the specified TrainProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionResponse.verify|verify} messages.
                     * @param message TrainProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.ITrainProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TrainProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionResponse.verify|verify} messages.
                     * @param message TrainProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.ITrainProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TrainProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TrainProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.TrainProcessorVersionResponse;

                    /**
                     * Decodes a TrainProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TrainProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.TrainProcessorVersionResponse;

                    /**
                     * Verifies a TrainProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TrainProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TrainProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.TrainProcessorVersionResponse;

                    /**
                     * Creates a plain object from a TrainProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message TrainProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.TrainProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TrainProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TrainProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TrainProcessorVersionMetadata. */
                interface ITrainProcessorVersionMetadata {

                    /** TrainProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /** TrainProcessorVersionMetadata trainingDatasetValidation */
                    trainingDatasetValidation?: (google.cloud.documentai.v1.TrainProcessorVersionMetadata.IDatasetValidation|null);

                    /** TrainProcessorVersionMetadata testDatasetValidation */
                    testDatasetValidation?: (google.cloud.documentai.v1.TrainProcessorVersionMetadata.IDatasetValidation|null);
                }

                /** Represents a TrainProcessorVersionMetadata. */
                class TrainProcessorVersionMetadata implements ITrainProcessorVersionMetadata {

                    /**
                     * Constructs a new TrainProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.ITrainProcessorVersionMetadata);

                    /** TrainProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /** TrainProcessorVersionMetadata trainingDatasetValidation. */
                    public trainingDatasetValidation?: (google.cloud.documentai.v1.TrainProcessorVersionMetadata.IDatasetValidation|null);

                    /** TrainProcessorVersionMetadata testDatasetValidation. */
                    public testDatasetValidation?: (google.cloud.documentai.v1.TrainProcessorVersionMetadata.IDatasetValidation|null);

                    /**
                     * Creates a new TrainProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TrainProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.ITrainProcessorVersionMetadata): google.cloud.documentai.v1.TrainProcessorVersionMetadata;

                    /**
                     * Encodes the specified TrainProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionMetadata.verify|verify} messages.
                     * @param message TrainProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.ITrainProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TrainProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionMetadata.verify|verify} messages.
                     * @param message TrainProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.ITrainProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TrainProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TrainProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.TrainProcessorVersionMetadata;

                    /**
                     * Decodes a TrainProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TrainProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.TrainProcessorVersionMetadata;

                    /**
                     * Verifies a TrainProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TrainProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TrainProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.TrainProcessorVersionMetadata;

                    /**
                     * Creates a plain object from a TrainProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message TrainProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.TrainProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TrainProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TrainProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TrainProcessorVersionMetadata {

                    /** Properties of a DatasetValidation. */
                    interface IDatasetValidation {

                        /** DatasetValidation documentErrorCount */
                        documentErrorCount?: (number|null);

                        /** DatasetValidation datasetErrorCount */
                        datasetErrorCount?: (number|null);

                        /** DatasetValidation documentErrors */
                        documentErrors?: (google.rpc.IStatus[]|null);

                        /** DatasetValidation datasetErrors */
                        datasetErrors?: (google.rpc.IStatus[]|null);
                    }

                    /** Represents a DatasetValidation. */
                    class DatasetValidation implements IDatasetValidation {

                        /**
                         * Constructs a new DatasetValidation.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.TrainProcessorVersionMetadata.IDatasetValidation);

                        /** DatasetValidation documentErrorCount. */
                        public documentErrorCount: number;

                        /** DatasetValidation datasetErrorCount. */
                        public datasetErrorCount: number;

                        /** DatasetValidation documentErrors. */
                        public documentErrors: google.rpc.IStatus[];

                        /** DatasetValidation datasetErrors. */
                        public datasetErrors: google.rpc.IStatus[];

                        /**
                         * Creates a new DatasetValidation instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns DatasetValidation instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.TrainProcessorVersionMetadata.IDatasetValidation): google.cloud.documentai.v1.TrainProcessorVersionMetadata.DatasetValidation;

                        /**
                         * Encodes the specified DatasetValidation message. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionMetadata.DatasetValidation.verify|verify} messages.
                         * @param message DatasetValidation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.TrainProcessorVersionMetadata.IDatasetValidation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified DatasetValidation message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.TrainProcessorVersionMetadata.DatasetValidation.verify|verify} messages.
                         * @param message DatasetValidation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.TrainProcessorVersionMetadata.IDatasetValidation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a DatasetValidation message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns DatasetValidation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.TrainProcessorVersionMetadata.DatasetValidation;

                        /**
                         * Decodes a DatasetValidation message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns DatasetValidation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.TrainProcessorVersionMetadata.DatasetValidation;

                        /**
                         * Verifies a DatasetValidation message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a DatasetValidation message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns DatasetValidation
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.TrainProcessorVersionMetadata.DatasetValidation;

                        /**
                         * Creates a plain object from a DatasetValidation message. Also converts values to other types if specified.
                         * @param message DatasetValidation
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.TrainProcessorVersionMetadata.DatasetValidation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this DatasetValidation to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for DatasetValidation
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a ReviewDocumentRequest. */
                interface IReviewDocumentRequest {

                    /** ReviewDocumentRequest inlineDocument */
                    inlineDocument?: (google.cloud.documentai.v1.IDocument|null);

                    /** ReviewDocumentRequest humanReviewConfig */
                    humanReviewConfig?: (string|null);

                    /** ReviewDocumentRequest enableSchemaValidation */
                    enableSchemaValidation?: (boolean|null);

                    /** ReviewDocumentRequest priority */
                    priority?: (google.cloud.documentai.v1.ReviewDocumentRequest.Priority|keyof typeof google.cloud.documentai.v1.ReviewDocumentRequest.Priority|null);

                    /** ReviewDocumentRequest documentSchema */
                    documentSchema?: (google.cloud.documentai.v1.IDocumentSchema|null);
                }

                /** Represents a ReviewDocumentRequest. */
                class ReviewDocumentRequest implements IReviewDocumentRequest {

                    /**
                     * Constructs a new ReviewDocumentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IReviewDocumentRequest);

                    /** ReviewDocumentRequest inlineDocument. */
                    public inlineDocument?: (google.cloud.documentai.v1.IDocument|null);

                    /** ReviewDocumentRequest humanReviewConfig. */
                    public humanReviewConfig: string;

                    /** ReviewDocumentRequest enableSchemaValidation. */
                    public enableSchemaValidation: boolean;

                    /** ReviewDocumentRequest priority. */
                    public priority: (google.cloud.documentai.v1.ReviewDocumentRequest.Priority|keyof typeof google.cloud.documentai.v1.ReviewDocumentRequest.Priority);

                    /** ReviewDocumentRequest documentSchema. */
                    public documentSchema?: (google.cloud.documentai.v1.IDocumentSchema|null);

                    /** ReviewDocumentRequest source. */
                    public source?: "inlineDocument";

                    /**
                     * Creates a new ReviewDocumentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReviewDocumentRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IReviewDocumentRequest): google.cloud.documentai.v1.ReviewDocumentRequest;

                    /**
                     * Encodes the specified ReviewDocumentRequest message. Does not implicitly {@link google.cloud.documentai.v1.ReviewDocumentRequest.verify|verify} messages.
                     * @param message ReviewDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IReviewDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReviewDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ReviewDocumentRequest.verify|verify} messages.
                     * @param message ReviewDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IReviewDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReviewDocumentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReviewDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ReviewDocumentRequest;

                    /**
                     * Decodes a ReviewDocumentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReviewDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ReviewDocumentRequest;

                    /**
                     * Verifies a ReviewDocumentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReviewDocumentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReviewDocumentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ReviewDocumentRequest;

                    /**
                     * Creates a plain object from a ReviewDocumentRequest message. Also converts values to other types if specified.
                     * @param message ReviewDocumentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ReviewDocumentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReviewDocumentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReviewDocumentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ReviewDocumentRequest {

                    /** Priority enum. */
                    enum Priority {
                        DEFAULT = 0,
                        URGENT = 1
                    }
                }

                /** Properties of a ReviewDocumentResponse. */
                interface IReviewDocumentResponse {

                    /** ReviewDocumentResponse gcsDestination */
                    gcsDestination?: (string|null);

                    /** ReviewDocumentResponse state */
                    state?: (google.cloud.documentai.v1.ReviewDocumentResponse.State|keyof typeof google.cloud.documentai.v1.ReviewDocumentResponse.State|null);

                    /** ReviewDocumentResponse rejectionReason */
                    rejectionReason?: (string|null);
                }

                /** Represents a ReviewDocumentResponse. */
                class ReviewDocumentResponse implements IReviewDocumentResponse {

                    /**
                     * Constructs a new ReviewDocumentResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IReviewDocumentResponse);

                    /** ReviewDocumentResponse gcsDestination. */
                    public gcsDestination: string;

                    /** ReviewDocumentResponse state. */
                    public state: (google.cloud.documentai.v1.ReviewDocumentResponse.State|keyof typeof google.cloud.documentai.v1.ReviewDocumentResponse.State);

                    /** ReviewDocumentResponse rejectionReason. */
                    public rejectionReason: string;

                    /**
                     * Creates a new ReviewDocumentResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReviewDocumentResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IReviewDocumentResponse): google.cloud.documentai.v1.ReviewDocumentResponse;

                    /**
                     * Encodes the specified ReviewDocumentResponse message. Does not implicitly {@link google.cloud.documentai.v1.ReviewDocumentResponse.verify|verify} messages.
                     * @param message ReviewDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IReviewDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReviewDocumentResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ReviewDocumentResponse.verify|verify} messages.
                     * @param message ReviewDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IReviewDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReviewDocumentResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReviewDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ReviewDocumentResponse;

                    /**
                     * Decodes a ReviewDocumentResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReviewDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ReviewDocumentResponse;

                    /**
                     * Verifies a ReviewDocumentResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReviewDocumentResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReviewDocumentResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ReviewDocumentResponse;

                    /**
                     * Creates a plain object from a ReviewDocumentResponse message. Also converts values to other types if specified.
                     * @param message ReviewDocumentResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ReviewDocumentResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReviewDocumentResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReviewDocumentResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ReviewDocumentResponse {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        REJECTED = 1,
                        SUCCEEDED = 2
                    }
                }

                /** Properties of a ReviewDocumentOperationMetadata. */
                interface IReviewDocumentOperationMetadata {

                    /** ReviewDocumentOperationMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /** ReviewDocumentOperationMetadata questionId */
                    questionId?: (string|null);
                }

                /** Represents a ReviewDocumentOperationMetadata. */
                class ReviewDocumentOperationMetadata implements IReviewDocumentOperationMetadata {

                    /**
                     * Constructs a new ReviewDocumentOperationMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IReviewDocumentOperationMetadata);

                    /** ReviewDocumentOperationMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /** ReviewDocumentOperationMetadata questionId. */
                    public questionId: string;

                    /**
                     * Creates a new ReviewDocumentOperationMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReviewDocumentOperationMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IReviewDocumentOperationMetadata): google.cloud.documentai.v1.ReviewDocumentOperationMetadata;

                    /**
                     * Encodes the specified ReviewDocumentOperationMetadata message. Does not implicitly {@link google.cloud.documentai.v1.ReviewDocumentOperationMetadata.verify|verify} messages.
                     * @param message ReviewDocumentOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IReviewDocumentOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReviewDocumentOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ReviewDocumentOperationMetadata.verify|verify} messages.
                     * @param message ReviewDocumentOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IReviewDocumentOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReviewDocumentOperationMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReviewDocumentOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ReviewDocumentOperationMetadata;

                    /**
                     * Decodes a ReviewDocumentOperationMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReviewDocumentOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ReviewDocumentOperationMetadata;

                    /**
                     * Verifies a ReviewDocumentOperationMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReviewDocumentOperationMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReviewDocumentOperationMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ReviewDocumentOperationMetadata;

                    /**
                     * Creates a plain object from a ReviewDocumentOperationMetadata message. Also converts values to other types if specified.
                     * @param message ReviewDocumentOperationMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ReviewDocumentOperationMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReviewDocumentOperationMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReviewDocumentOperationMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EvaluateProcessorVersionRequest. */
                interface IEvaluateProcessorVersionRequest {

                    /** EvaluateProcessorVersionRequest processorVersion */
                    processorVersion?: (string|null);

                    /** EvaluateProcessorVersionRequest evaluationDocuments */
                    evaluationDocuments?: (google.cloud.documentai.v1.IBatchDocumentsInputConfig|null);
                }

                /** Represents an EvaluateProcessorVersionRequest. */
                class EvaluateProcessorVersionRequest implements IEvaluateProcessorVersionRequest {

                    /**
                     * Constructs a new EvaluateProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IEvaluateProcessorVersionRequest);

                    /** EvaluateProcessorVersionRequest processorVersion. */
                    public processorVersion: string;

                    /** EvaluateProcessorVersionRequest evaluationDocuments. */
                    public evaluationDocuments?: (google.cloud.documentai.v1.IBatchDocumentsInputConfig|null);

                    /**
                     * Creates a new EvaluateProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EvaluateProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IEvaluateProcessorVersionRequest): google.cloud.documentai.v1.EvaluateProcessorVersionRequest;

                    /**
                     * Encodes the specified EvaluateProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1.EvaluateProcessorVersionRequest.verify|verify} messages.
                     * @param message EvaluateProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IEvaluateProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EvaluateProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.EvaluateProcessorVersionRequest.verify|verify} messages.
                     * @param message EvaluateProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IEvaluateProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EvaluateProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EvaluateProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.EvaluateProcessorVersionRequest;

                    /**
                     * Decodes an EvaluateProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EvaluateProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.EvaluateProcessorVersionRequest;

                    /**
                     * Verifies an EvaluateProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EvaluateProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EvaluateProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.EvaluateProcessorVersionRequest;

                    /**
                     * Creates a plain object from an EvaluateProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message EvaluateProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.EvaluateProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EvaluateProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EvaluateProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EvaluateProcessorVersionMetadata. */
                interface IEvaluateProcessorVersionMetadata {

                    /** EvaluateProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);
                }

                /** Represents an EvaluateProcessorVersionMetadata. */
                class EvaluateProcessorVersionMetadata implements IEvaluateProcessorVersionMetadata {

                    /**
                     * Constructs a new EvaluateProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IEvaluateProcessorVersionMetadata);

                    /** EvaluateProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1.ICommonOperationMetadata|null);

                    /**
                     * Creates a new EvaluateProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EvaluateProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IEvaluateProcessorVersionMetadata): google.cloud.documentai.v1.EvaluateProcessorVersionMetadata;

                    /**
                     * Encodes the specified EvaluateProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1.EvaluateProcessorVersionMetadata.verify|verify} messages.
                     * @param message EvaluateProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IEvaluateProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EvaluateProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.EvaluateProcessorVersionMetadata.verify|verify} messages.
                     * @param message EvaluateProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IEvaluateProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EvaluateProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EvaluateProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.EvaluateProcessorVersionMetadata;

                    /**
                     * Decodes an EvaluateProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EvaluateProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.EvaluateProcessorVersionMetadata;

                    /**
                     * Verifies an EvaluateProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EvaluateProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EvaluateProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.EvaluateProcessorVersionMetadata;

                    /**
                     * Creates a plain object from an EvaluateProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message EvaluateProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.EvaluateProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EvaluateProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EvaluateProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EvaluateProcessorVersionResponse. */
                interface IEvaluateProcessorVersionResponse {

                    /** EvaluateProcessorVersionResponse evaluation */
                    evaluation?: (string|null);
                }

                /** Represents an EvaluateProcessorVersionResponse. */
                class EvaluateProcessorVersionResponse implements IEvaluateProcessorVersionResponse {

                    /**
                     * Constructs a new EvaluateProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IEvaluateProcessorVersionResponse);

                    /** EvaluateProcessorVersionResponse evaluation. */
                    public evaluation: string;

                    /**
                     * Creates a new EvaluateProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EvaluateProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IEvaluateProcessorVersionResponse): google.cloud.documentai.v1.EvaluateProcessorVersionResponse;

                    /**
                     * Encodes the specified EvaluateProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1.EvaluateProcessorVersionResponse.verify|verify} messages.
                     * @param message EvaluateProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IEvaluateProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EvaluateProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.EvaluateProcessorVersionResponse.verify|verify} messages.
                     * @param message EvaluateProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IEvaluateProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EvaluateProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EvaluateProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.EvaluateProcessorVersionResponse;

                    /**
                     * Decodes an EvaluateProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EvaluateProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.EvaluateProcessorVersionResponse;

                    /**
                     * Verifies an EvaluateProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EvaluateProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EvaluateProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.EvaluateProcessorVersionResponse;

                    /**
                     * Creates a plain object from an EvaluateProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message EvaluateProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.EvaluateProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EvaluateProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EvaluateProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetEvaluationRequest. */
                interface IGetEvaluationRequest {

                    /** GetEvaluationRequest name */
                    name?: (string|null);
                }

                /** Represents a GetEvaluationRequest. */
                class GetEvaluationRequest implements IGetEvaluationRequest {

                    /**
                     * Constructs a new GetEvaluationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IGetEvaluationRequest);

                    /** GetEvaluationRequest name. */
                    public name: string;

                    /**
                     * Creates a new GetEvaluationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetEvaluationRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IGetEvaluationRequest): google.cloud.documentai.v1.GetEvaluationRequest;

                    /**
                     * Encodes the specified GetEvaluationRequest message. Does not implicitly {@link google.cloud.documentai.v1.GetEvaluationRequest.verify|verify} messages.
                     * @param message GetEvaluationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IGetEvaluationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetEvaluationRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.GetEvaluationRequest.verify|verify} messages.
                     * @param message GetEvaluationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IGetEvaluationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetEvaluationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetEvaluationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.GetEvaluationRequest;

                    /**
                     * Decodes a GetEvaluationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetEvaluationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.GetEvaluationRequest;

                    /**
                     * Verifies a GetEvaluationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetEvaluationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetEvaluationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.GetEvaluationRequest;

                    /**
                     * Creates a plain object from a GetEvaluationRequest message. Also converts values to other types if specified.
                     * @param message GetEvaluationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.GetEvaluationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetEvaluationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetEvaluationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListEvaluationsRequest. */
                interface IListEvaluationsRequest {

                    /** ListEvaluationsRequest parent */
                    parent?: (string|null);

                    /** ListEvaluationsRequest pageSize */
                    pageSize?: (number|null);

                    /** ListEvaluationsRequest pageToken */
                    pageToken?: (string|null);
                }

                /** Represents a ListEvaluationsRequest. */
                class ListEvaluationsRequest implements IListEvaluationsRequest {

                    /**
                     * Constructs a new ListEvaluationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IListEvaluationsRequest);

                    /** ListEvaluationsRequest parent. */
                    public parent: string;

                    /** ListEvaluationsRequest pageSize. */
                    public pageSize: number;

                    /** ListEvaluationsRequest pageToken. */
                    public pageToken: string;

                    /**
                     * Creates a new ListEvaluationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListEvaluationsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IListEvaluationsRequest): google.cloud.documentai.v1.ListEvaluationsRequest;

                    /**
                     * Encodes the specified ListEvaluationsRequest message. Does not implicitly {@link google.cloud.documentai.v1.ListEvaluationsRequest.verify|verify} messages.
                     * @param message ListEvaluationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IListEvaluationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListEvaluationsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ListEvaluationsRequest.verify|verify} messages.
                     * @param message ListEvaluationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IListEvaluationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListEvaluationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListEvaluationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ListEvaluationsRequest;

                    /**
                     * Decodes a ListEvaluationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListEvaluationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ListEvaluationsRequest;

                    /**
                     * Verifies a ListEvaluationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListEvaluationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListEvaluationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ListEvaluationsRequest;

                    /**
                     * Creates a plain object from a ListEvaluationsRequest message. Also converts values to other types if specified.
                     * @param message ListEvaluationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ListEvaluationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListEvaluationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListEvaluationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListEvaluationsResponse. */
                interface IListEvaluationsResponse {

                    /** ListEvaluationsResponse evaluations */
                    evaluations?: (google.cloud.documentai.v1.IEvaluation[]|null);

                    /** ListEvaluationsResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a ListEvaluationsResponse. */
                class ListEvaluationsResponse implements IListEvaluationsResponse {

                    /**
                     * Constructs a new ListEvaluationsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IListEvaluationsResponse);

                    /** ListEvaluationsResponse evaluations. */
                    public evaluations: google.cloud.documentai.v1.IEvaluation[];

                    /** ListEvaluationsResponse nextPageToken. */
                    public nextPageToken: string;

                    /**
                     * Creates a new ListEvaluationsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListEvaluationsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IListEvaluationsResponse): google.cloud.documentai.v1.ListEvaluationsResponse;

                    /**
                     * Encodes the specified ListEvaluationsResponse message. Does not implicitly {@link google.cloud.documentai.v1.ListEvaluationsResponse.verify|verify} messages.
                     * @param message ListEvaluationsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IListEvaluationsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListEvaluationsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ListEvaluationsResponse.verify|verify} messages.
                     * @param message ListEvaluationsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IListEvaluationsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListEvaluationsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListEvaluationsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ListEvaluationsResponse;

                    /**
                     * Decodes a ListEvaluationsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListEvaluationsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ListEvaluationsResponse;

                    /**
                     * Verifies a ListEvaluationsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListEvaluationsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListEvaluationsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ListEvaluationsResponse;

                    /**
                     * Creates a plain object from a ListEvaluationsResponse message. Also converts values to other types if specified.
                     * @param message ListEvaluationsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ListEvaluationsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListEvaluationsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListEvaluationsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DocumentSchema. */
                interface IDocumentSchema {

                    /** DocumentSchema displayName */
                    displayName?: (string|null);

                    /** DocumentSchema description */
                    description?: (string|null);

                    /** DocumentSchema entityTypes */
                    entityTypes?: (google.cloud.documentai.v1.DocumentSchema.IEntityType[]|null);

                    /** DocumentSchema metadata */
                    metadata?: (google.cloud.documentai.v1.DocumentSchema.IMetadata|null);
                }

                /** Represents a DocumentSchema. */
                class DocumentSchema implements IDocumentSchema {

                    /**
                     * Constructs a new DocumentSchema.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IDocumentSchema);

                    /** DocumentSchema displayName. */
                    public displayName: string;

                    /** DocumentSchema description. */
                    public description: string;

                    /** DocumentSchema entityTypes. */
                    public entityTypes: google.cloud.documentai.v1.DocumentSchema.IEntityType[];

                    /** DocumentSchema metadata. */
                    public metadata?: (google.cloud.documentai.v1.DocumentSchema.IMetadata|null);

                    /**
                     * Creates a new DocumentSchema instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DocumentSchema instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IDocumentSchema): google.cloud.documentai.v1.DocumentSchema;

                    /**
                     * Encodes the specified DocumentSchema message. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.verify|verify} messages.
                     * @param message DocumentSchema message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IDocumentSchema, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DocumentSchema message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.verify|verify} messages.
                     * @param message DocumentSchema message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IDocumentSchema, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DocumentSchema message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DocumentSchema
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DocumentSchema;

                    /**
                     * Decodes a DocumentSchema message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DocumentSchema
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DocumentSchema;

                    /**
                     * Verifies a DocumentSchema message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DocumentSchema message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DocumentSchema
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DocumentSchema;

                    /**
                     * Creates a plain object from a DocumentSchema message. Also converts values to other types if specified.
                     * @param message DocumentSchema
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.DocumentSchema, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DocumentSchema to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DocumentSchema
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace DocumentSchema {

                    /** Properties of an EntityType. */
                    interface IEntityType {

                        /** EntityType enumValues */
                        enumValues?: (google.cloud.documentai.v1.DocumentSchema.EntityType.IEnumValues|null);

                        /** EntityType displayName */
                        displayName?: (string|null);

                        /** EntityType name */
                        name?: (string|null);

                        /** EntityType baseTypes */
                        baseTypes?: (string[]|null);

                        /** EntityType properties */
                        properties?: (google.cloud.documentai.v1.DocumentSchema.EntityType.IProperty[]|null);
                    }

                    /** Represents an EntityType. */
                    class EntityType implements IEntityType {

                        /**
                         * Constructs a new EntityType.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.DocumentSchema.IEntityType);

                        /** EntityType enumValues. */
                        public enumValues?: (google.cloud.documentai.v1.DocumentSchema.EntityType.IEnumValues|null);

                        /** EntityType displayName. */
                        public displayName: string;

                        /** EntityType name. */
                        public name: string;

                        /** EntityType baseTypes. */
                        public baseTypes: string[];

                        /** EntityType properties. */
                        public properties: google.cloud.documentai.v1.DocumentSchema.EntityType.IProperty[];

                        /** EntityType valueSource. */
                        public valueSource?: "enumValues";

                        /**
                         * Creates a new EntityType instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns EntityType instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.DocumentSchema.IEntityType): google.cloud.documentai.v1.DocumentSchema.EntityType;

                        /**
                         * Encodes the specified EntityType message. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.EntityType.verify|verify} messages.
                         * @param message EntityType message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.DocumentSchema.IEntityType, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified EntityType message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.EntityType.verify|verify} messages.
                         * @param message EntityType message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.DocumentSchema.IEntityType, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an EntityType message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns EntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DocumentSchema.EntityType;

                        /**
                         * Decodes an EntityType message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns EntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DocumentSchema.EntityType;

                        /**
                         * Verifies an EntityType message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an EntityType message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns EntityType
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DocumentSchema.EntityType;

                        /**
                         * Creates a plain object from an EntityType message. Also converts values to other types if specified.
                         * @param message EntityType
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.DocumentSchema.EntityType, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this EntityType to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for EntityType
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace EntityType {

                        /** Properties of an EnumValues. */
                        interface IEnumValues {

                            /** EnumValues values */
                            values?: (string[]|null);
                        }

                        /** Represents an EnumValues. */
                        class EnumValues implements IEnumValues {

                            /**
                             * Constructs a new EnumValues.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.DocumentSchema.EntityType.IEnumValues);

                            /** EnumValues values. */
                            public values: string[];

                            /**
                             * Creates a new EnumValues instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns EnumValues instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.DocumentSchema.EntityType.IEnumValues): google.cloud.documentai.v1.DocumentSchema.EntityType.EnumValues;

                            /**
                             * Encodes the specified EnumValues message. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.EntityType.EnumValues.verify|verify} messages.
                             * @param message EnumValues message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.DocumentSchema.EntityType.IEnumValues, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified EnumValues message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.EntityType.EnumValues.verify|verify} messages.
                             * @param message EnumValues message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.DocumentSchema.EntityType.IEnumValues, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes an EnumValues message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns EnumValues
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DocumentSchema.EntityType.EnumValues;

                            /**
                             * Decodes an EnumValues message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns EnumValues
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DocumentSchema.EntityType.EnumValues;

                            /**
                             * Verifies an EnumValues message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates an EnumValues message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns EnumValues
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DocumentSchema.EntityType.EnumValues;

                            /**
                             * Creates a plain object from an EnumValues message. Also converts values to other types if specified.
                             * @param message EnumValues
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.DocumentSchema.EntityType.EnumValues, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this EnumValues to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for EnumValues
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Property. */
                        interface IProperty {

                            /** Property name */
                            name?: (string|null);

                            /** Property displayName */
                            displayName?: (string|null);

                            /** Property valueType */
                            valueType?: (string|null);

                            /** Property occurrenceType */
                            occurrenceType?: (google.cloud.documentai.v1.DocumentSchema.EntityType.Property.OccurrenceType|keyof typeof google.cloud.documentai.v1.DocumentSchema.EntityType.Property.OccurrenceType|null);
                        }

                        /** Represents a Property. */
                        class Property implements IProperty {

                            /**
                             * Constructs a new Property.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.DocumentSchema.EntityType.IProperty);

                            /** Property name. */
                            public name: string;

                            /** Property displayName. */
                            public displayName: string;

                            /** Property valueType. */
                            public valueType: string;

                            /** Property occurrenceType. */
                            public occurrenceType: (google.cloud.documentai.v1.DocumentSchema.EntityType.Property.OccurrenceType|keyof typeof google.cloud.documentai.v1.DocumentSchema.EntityType.Property.OccurrenceType);

                            /**
                             * Creates a new Property instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Property instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.DocumentSchema.EntityType.IProperty): google.cloud.documentai.v1.DocumentSchema.EntityType.Property;

                            /**
                             * Encodes the specified Property message. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.EntityType.Property.verify|verify} messages.
                             * @param message Property message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.DocumentSchema.EntityType.IProperty, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Property message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.EntityType.Property.verify|verify} messages.
                             * @param message Property message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.DocumentSchema.EntityType.IProperty, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Property message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Property
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DocumentSchema.EntityType.Property;

                            /**
                             * Decodes a Property message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Property
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DocumentSchema.EntityType.Property;

                            /**
                             * Verifies a Property message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Property message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Property
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DocumentSchema.EntityType.Property;

                            /**
                             * Creates a plain object from a Property message. Also converts values to other types if specified.
                             * @param message Property
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.DocumentSchema.EntityType.Property, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Property to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Property
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Property {

                            /** OccurrenceType enum. */
                            enum OccurrenceType {
                                OCCURRENCE_TYPE_UNSPECIFIED = 0,
                                OPTIONAL_ONCE = 1,
                                OPTIONAL_MULTIPLE = 2,
                                REQUIRED_ONCE = 3,
                                REQUIRED_MULTIPLE = 4
                            }
                        }
                    }

                    /** Properties of a Metadata. */
                    interface IMetadata {

                        /** Metadata documentSplitter */
                        documentSplitter?: (boolean|null);

                        /** Metadata documentAllowMultipleLabels */
                        documentAllowMultipleLabels?: (boolean|null);

                        /** Metadata prefixedNamingOnProperties */
                        prefixedNamingOnProperties?: (boolean|null);

                        /** Metadata skipNamingValidation */
                        skipNamingValidation?: (boolean|null);
                    }

                    /** Represents a Metadata. */
                    class Metadata implements IMetadata {

                        /**
                         * Constructs a new Metadata.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.DocumentSchema.IMetadata);

                        /** Metadata documentSplitter. */
                        public documentSplitter: boolean;

                        /** Metadata documentAllowMultipleLabels. */
                        public documentAllowMultipleLabels: boolean;

                        /** Metadata prefixedNamingOnProperties. */
                        public prefixedNamingOnProperties: boolean;

                        /** Metadata skipNamingValidation. */
                        public skipNamingValidation: boolean;

                        /**
                         * Creates a new Metadata instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Metadata instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.DocumentSchema.IMetadata): google.cloud.documentai.v1.DocumentSchema.Metadata;

                        /**
                         * Encodes the specified Metadata message. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.Metadata.verify|verify} messages.
                         * @param message Metadata message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.DocumentSchema.IMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Metadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.DocumentSchema.Metadata.verify|verify} messages.
                         * @param message Metadata message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.DocumentSchema.IMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Metadata message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Metadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.DocumentSchema.Metadata;

                        /**
                         * Decodes a Metadata message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Metadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.DocumentSchema.Metadata;

                        /**
                         * Verifies a Metadata message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Metadata message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Metadata
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.DocumentSchema.Metadata;

                        /**
                         * Creates a plain object from a Metadata message. Also converts values to other types if specified.
                         * @param message Metadata
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.DocumentSchema.Metadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Metadata to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Metadata
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of an EvaluationReference. */
                interface IEvaluationReference {

                    /** EvaluationReference operation */
                    operation?: (string|null);

                    /** EvaluationReference evaluation */
                    evaluation?: (string|null);

                    /** EvaluationReference aggregateMetrics */
                    aggregateMetrics?: (google.cloud.documentai.v1.Evaluation.IMetrics|null);

                    /** EvaluationReference aggregateMetricsExact */
                    aggregateMetricsExact?: (google.cloud.documentai.v1.Evaluation.IMetrics|null);
                }

                /** Represents an EvaluationReference. */
                class EvaluationReference implements IEvaluationReference {

                    /**
                     * Constructs a new EvaluationReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IEvaluationReference);

                    /** EvaluationReference operation. */
                    public operation: string;

                    /** EvaluationReference evaluation. */
                    public evaluation: string;

                    /** EvaluationReference aggregateMetrics. */
                    public aggregateMetrics?: (google.cloud.documentai.v1.Evaluation.IMetrics|null);

                    /** EvaluationReference aggregateMetricsExact. */
                    public aggregateMetricsExact?: (google.cloud.documentai.v1.Evaluation.IMetrics|null);

                    /**
                     * Creates a new EvaluationReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EvaluationReference instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IEvaluationReference): google.cloud.documentai.v1.EvaluationReference;

                    /**
                     * Encodes the specified EvaluationReference message. Does not implicitly {@link google.cloud.documentai.v1.EvaluationReference.verify|verify} messages.
                     * @param message EvaluationReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IEvaluationReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EvaluationReference message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.EvaluationReference.verify|verify} messages.
                     * @param message EvaluationReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IEvaluationReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EvaluationReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EvaluationReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.EvaluationReference;

                    /**
                     * Decodes an EvaluationReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EvaluationReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.EvaluationReference;

                    /**
                     * Verifies an EvaluationReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EvaluationReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EvaluationReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.EvaluationReference;

                    /**
                     * Creates a plain object from an EvaluationReference message. Also converts values to other types if specified.
                     * @param message EvaluationReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.EvaluationReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EvaluationReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EvaluationReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Evaluation. */
                interface IEvaluation {

                    /** Evaluation name */
                    name?: (string|null);

                    /** Evaluation createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** Evaluation documentCounters */
                    documentCounters?: (google.cloud.documentai.v1.Evaluation.ICounters|null);

                    /** Evaluation allEntitiesMetrics */
                    allEntitiesMetrics?: (google.cloud.documentai.v1.Evaluation.IMultiConfidenceMetrics|null);

                    /** Evaluation entityMetrics */
                    entityMetrics?: ({ [k: string]: google.cloud.documentai.v1.Evaluation.IMultiConfidenceMetrics }|null);

                    /** Evaluation kmsKeyName */
                    kmsKeyName?: (string|null);

                    /** Evaluation kmsKeyVersionName */
                    kmsKeyVersionName?: (string|null);
                }

                /** Represents an Evaluation. */
                class Evaluation implements IEvaluation {

                    /**
                     * Constructs a new Evaluation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IEvaluation);

                    /** Evaluation name. */
                    public name: string;

                    /** Evaluation createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** Evaluation documentCounters. */
                    public documentCounters?: (google.cloud.documentai.v1.Evaluation.ICounters|null);

                    /** Evaluation allEntitiesMetrics. */
                    public allEntitiesMetrics?: (google.cloud.documentai.v1.Evaluation.IMultiConfidenceMetrics|null);

                    /** Evaluation entityMetrics. */
                    public entityMetrics: { [k: string]: google.cloud.documentai.v1.Evaluation.IMultiConfidenceMetrics };

                    /** Evaluation kmsKeyName. */
                    public kmsKeyName: string;

                    /** Evaluation kmsKeyVersionName. */
                    public kmsKeyVersionName: string;

                    /**
                     * Creates a new Evaluation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Evaluation instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IEvaluation): google.cloud.documentai.v1.Evaluation;

                    /**
                     * Encodes the specified Evaluation message. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.verify|verify} messages.
                     * @param message Evaluation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IEvaluation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Evaluation message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.verify|verify} messages.
                     * @param message Evaluation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IEvaluation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Evaluation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Evaluation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Evaluation;

                    /**
                     * Decodes an Evaluation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Evaluation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Evaluation;

                    /**
                     * Verifies an Evaluation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Evaluation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Evaluation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Evaluation;

                    /**
                     * Creates a plain object from an Evaluation message. Also converts values to other types if specified.
                     * @param message Evaluation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.Evaluation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Evaluation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Evaluation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Evaluation {

                    /** Properties of a Counters. */
                    interface ICounters {

                        /** Counters inputDocumentsCount */
                        inputDocumentsCount?: (number|null);

                        /** Counters invalidDocumentsCount */
                        invalidDocumentsCount?: (number|null);

                        /** Counters failedDocumentsCount */
                        failedDocumentsCount?: (number|null);

                        /** Counters evaluatedDocumentsCount */
                        evaluatedDocumentsCount?: (number|null);
                    }

                    /** Represents a Counters. */
                    class Counters implements ICounters {

                        /**
                         * Constructs a new Counters.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Evaluation.ICounters);

                        /** Counters inputDocumentsCount. */
                        public inputDocumentsCount: number;

                        /** Counters invalidDocumentsCount. */
                        public invalidDocumentsCount: number;

                        /** Counters failedDocumentsCount. */
                        public failedDocumentsCount: number;

                        /** Counters evaluatedDocumentsCount. */
                        public evaluatedDocumentsCount: number;

                        /**
                         * Creates a new Counters instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Counters instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Evaluation.ICounters): google.cloud.documentai.v1.Evaluation.Counters;

                        /**
                         * Encodes the specified Counters message. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.Counters.verify|verify} messages.
                         * @param message Counters message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Evaluation.ICounters, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Counters message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.Counters.verify|verify} messages.
                         * @param message Counters message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Evaluation.ICounters, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Counters message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Counters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Evaluation.Counters;

                        /**
                         * Decodes a Counters message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Counters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Evaluation.Counters;

                        /**
                         * Verifies a Counters message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Counters message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Counters
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Evaluation.Counters;

                        /**
                         * Creates a plain object from a Counters message. Also converts values to other types if specified.
                         * @param message Counters
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Evaluation.Counters, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Counters to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Counters
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a Metrics. */
                    interface IMetrics {

                        /** Metrics precision */
                        precision?: (number|null);

                        /** Metrics recall */
                        recall?: (number|null);

                        /** Metrics f1Score */
                        f1Score?: (number|null);

                        /** Metrics predictedOccurrencesCount */
                        predictedOccurrencesCount?: (number|null);

                        /** Metrics groundTruthOccurrencesCount */
                        groundTruthOccurrencesCount?: (number|null);

                        /** Metrics predictedDocumentCount */
                        predictedDocumentCount?: (number|null);

                        /** Metrics groundTruthDocumentCount */
                        groundTruthDocumentCount?: (number|null);

                        /** Metrics truePositivesCount */
                        truePositivesCount?: (number|null);

                        /** Metrics falsePositivesCount */
                        falsePositivesCount?: (number|null);

                        /** Metrics falseNegativesCount */
                        falseNegativesCount?: (number|null);

                        /** Metrics totalDocumentsCount */
                        totalDocumentsCount?: (number|null);
                    }

                    /** Represents a Metrics. */
                    class Metrics implements IMetrics {

                        /**
                         * Constructs a new Metrics.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Evaluation.IMetrics);

                        /** Metrics precision. */
                        public precision: number;

                        /** Metrics recall. */
                        public recall: number;

                        /** Metrics f1Score. */
                        public f1Score: number;

                        /** Metrics predictedOccurrencesCount. */
                        public predictedOccurrencesCount: number;

                        /** Metrics groundTruthOccurrencesCount. */
                        public groundTruthOccurrencesCount: number;

                        /** Metrics predictedDocumentCount. */
                        public predictedDocumentCount: number;

                        /** Metrics groundTruthDocumentCount. */
                        public groundTruthDocumentCount: number;

                        /** Metrics truePositivesCount. */
                        public truePositivesCount: number;

                        /** Metrics falsePositivesCount. */
                        public falsePositivesCount: number;

                        /** Metrics falseNegativesCount. */
                        public falseNegativesCount: number;

                        /** Metrics totalDocumentsCount. */
                        public totalDocumentsCount: number;

                        /**
                         * Creates a new Metrics instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Metrics instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Evaluation.IMetrics): google.cloud.documentai.v1.Evaluation.Metrics;

                        /**
                         * Encodes the specified Metrics message. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.Metrics.verify|verify} messages.
                         * @param message Metrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Evaluation.IMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Metrics message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.Metrics.verify|verify} messages.
                         * @param message Metrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Evaluation.IMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Metrics message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Metrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Evaluation.Metrics;

                        /**
                         * Decodes a Metrics message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Metrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Evaluation.Metrics;

                        /**
                         * Verifies a Metrics message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Metrics message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Metrics
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Evaluation.Metrics;

                        /**
                         * Creates a plain object from a Metrics message. Also converts values to other types if specified.
                         * @param message Metrics
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Evaluation.Metrics, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Metrics to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Metrics
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a ConfidenceLevelMetrics. */
                    interface IConfidenceLevelMetrics {

                        /** ConfidenceLevelMetrics confidenceLevel */
                        confidenceLevel?: (number|null);

                        /** ConfidenceLevelMetrics metrics */
                        metrics?: (google.cloud.documentai.v1.Evaluation.IMetrics|null);
                    }

                    /** Represents a ConfidenceLevelMetrics. */
                    class ConfidenceLevelMetrics implements IConfidenceLevelMetrics {

                        /**
                         * Constructs a new ConfidenceLevelMetrics.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Evaluation.IConfidenceLevelMetrics);

                        /** ConfidenceLevelMetrics confidenceLevel. */
                        public confidenceLevel: number;

                        /** ConfidenceLevelMetrics metrics. */
                        public metrics?: (google.cloud.documentai.v1.Evaluation.IMetrics|null);

                        /**
                         * Creates a new ConfidenceLevelMetrics instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ConfidenceLevelMetrics instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Evaluation.IConfidenceLevelMetrics): google.cloud.documentai.v1.Evaluation.ConfidenceLevelMetrics;

                        /**
                         * Encodes the specified ConfidenceLevelMetrics message. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.ConfidenceLevelMetrics.verify|verify} messages.
                         * @param message ConfidenceLevelMetrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Evaluation.IConfidenceLevelMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ConfidenceLevelMetrics message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.ConfidenceLevelMetrics.verify|verify} messages.
                         * @param message ConfidenceLevelMetrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Evaluation.IConfidenceLevelMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a ConfidenceLevelMetrics message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ConfidenceLevelMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Evaluation.ConfidenceLevelMetrics;

                        /**
                         * Decodes a ConfidenceLevelMetrics message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ConfidenceLevelMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Evaluation.ConfidenceLevelMetrics;

                        /**
                         * Verifies a ConfidenceLevelMetrics message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a ConfidenceLevelMetrics message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ConfidenceLevelMetrics
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Evaluation.ConfidenceLevelMetrics;

                        /**
                         * Creates a plain object from a ConfidenceLevelMetrics message. Also converts values to other types if specified.
                         * @param message ConfidenceLevelMetrics
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Evaluation.ConfidenceLevelMetrics, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ConfidenceLevelMetrics to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ConfidenceLevelMetrics
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a MultiConfidenceMetrics. */
                    interface IMultiConfidenceMetrics {

                        /** MultiConfidenceMetrics confidenceLevelMetrics */
                        confidenceLevelMetrics?: (google.cloud.documentai.v1.Evaluation.IConfidenceLevelMetrics[]|null);

                        /** MultiConfidenceMetrics confidenceLevelMetricsExact */
                        confidenceLevelMetricsExact?: (google.cloud.documentai.v1.Evaluation.IConfidenceLevelMetrics[]|null);

                        /** MultiConfidenceMetrics auprc */
                        auprc?: (number|null);

                        /** MultiConfidenceMetrics estimatedCalibrationError */
                        estimatedCalibrationError?: (number|null);

                        /** MultiConfidenceMetrics auprcExact */
                        auprcExact?: (number|null);

                        /** MultiConfidenceMetrics estimatedCalibrationErrorExact */
                        estimatedCalibrationErrorExact?: (number|null);

                        /** MultiConfidenceMetrics metricsType */
                        metricsType?: (google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics.MetricsType|keyof typeof google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics.MetricsType|null);
                    }

                    /** Represents a MultiConfidenceMetrics. */
                    class MultiConfidenceMetrics implements IMultiConfidenceMetrics {

                        /**
                         * Constructs a new MultiConfidenceMetrics.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.Evaluation.IMultiConfidenceMetrics);

                        /** MultiConfidenceMetrics confidenceLevelMetrics. */
                        public confidenceLevelMetrics: google.cloud.documentai.v1.Evaluation.IConfidenceLevelMetrics[];

                        /** MultiConfidenceMetrics confidenceLevelMetricsExact. */
                        public confidenceLevelMetricsExact: google.cloud.documentai.v1.Evaluation.IConfidenceLevelMetrics[];

                        /** MultiConfidenceMetrics auprc. */
                        public auprc: number;

                        /** MultiConfidenceMetrics estimatedCalibrationError. */
                        public estimatedCalibrationError: number;

                        /** MultiConfidenceMetrics auprcExact. */
                        public auprcExact: number;

                        /** MultiConfidenceMetrics estimatedCalibrationErrorExact. */
                        public estimatedCalibrationErrorExact: number;

                        /** MultiConfidenceMetrics metricsType. */
                        public metricsType: (google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics.MetricsType|keyof typeof google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics.MetricsType);

                        /**
                         * Creates a new MultiConfidenceMetrics instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns MultiConfidenceMetrics instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.Evaluation.IMultiConfidenceMetrics): google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics;

                        /**
                         * Encodes the specified MultiConfidenceMetrics message. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics.verify|verify} messages.
                         * @param message MultiConfidenceMetrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.Evaluation.IMultiConfidenceMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified MultiConfidenceMetrics message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics.verify|verify} messages.
                         * @param message MultiConfidenceMetrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.Evaluation.IMultiConfidenceMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a MultiConfidenceMetrics message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns MultiConfidenceMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics;

                        /**
                         * Decodes a MultiConfidenceMetrics message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns MultiConfidenceMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics;

                        /**
                         * Verifies a MultiConfidenceMetrics message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a MultiConfidenceMetrics message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns MultiConfidenceMetrics
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics;

                        /**
                         * Creates a plain object from a MultiConfidenceMetrics message. Also converts values to other types if specified.
                         * @param message MultiConfidenceMetrics
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.Evaluation.MultiConfidenceMetrics, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this MultiConfidenceMetrics to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for MultiConfidenceMetrics
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace MultiConfidenceMetrics {

                        /** MetricsType enum. */
                        enum MetricsType {
                            METRICS_TYPE_UNSPECIFIED = 0,
                            AGGREGATE = 1
                        }
                    }
                }

                /** Properties of a CommonOperationMetadata. */
                interface ICommonOperationMetadata {

                    /** CommonOperationMetadata state */
                    state?: (google.cloud.documentai.v1.CommonOperationMetadata.State|keyof typeof google.cloud.documentai.v1.CommonOperationMetadata.State|null);

                    /** CommonOperationMetadata stateMessage */
                    stateMessage?: (string|null);

                    /** CommonOperationMetadata resource */
                    resource?: (string|null);

                    /** CommonOperationMetadata createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** CommonOperationMetadata updateTime */
                    updateTime?: (google.protobuf.ITimestamp|null);
                }

                /** Represents a CommonOperationMetadata. */
                class CommonOperationMetadata implements ICommonOperationMetadata {

                    /**
                     * Constructs a new CommonOperationMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.ICommonOperationMetadata);

                    /** CommonOperationMetadata state. */
                    public state: (google.cloud.documentai.v1.CommonOperationMetadata.State|keyof typeof google.cloud.documentai.v1.CommonOperationMetadata.State);

                    /** CommonOperationMetadata stateMessage. */
                    public stateMessage: string;

                    /** CommonOperationMetadata resource. */
                    public resource: string;

                    /** CommonOperationMetadata createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** CommonOperationMetadata updateTime. */
                    public updateTime?: (google.protobuf.ITimestamp|null);

                    /**
                     * Creates a new CommonOperationMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CommonOperationMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.ICommonOperationMetadata): google.cloud.documentai.v1.CommonOperationMetadata;

                    /**
                     * Encodes the specified CommonOperationMetadata message. Does not implicitly {@link google.cloud.documentai.v1.CommonOperationMetadata.verify|verify} messages.
                     * @param message CommonOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.ICommonOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CommonOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.CommonOperationMetadata.verify|verify} messages.
                     * @param message CommonOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.ICommonOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CommonOperationMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CommonOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.CommonOperationMetadata;

                    /**
                     * Decodes a CommonOperationMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CommonOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.CommonOperationMetadata;

                    /**
                     * Verifies a CommonOperationMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CommonOperationMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CommonOperationMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.CommonOperationMetadata;

                    /**
                     * Creates a plain object from a CommonOperationMetadata message. Also converts values to other types if specified.
                     * @param message CommonOperationMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.CommonOperationMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CommonOperationMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CommonOperationMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace CommonOperationMetadata {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        RUNNING = 1,
                        CANCELLING = 2,
                        SUCCEEDED = 3,
                        FAILED = 4,
                        CANCELLED = 5
                    }
                }

                /** Properties of a ProcessorVersion. */
                interface IProcessorVersion {

                    /** ProcessorVersion name */
                    name?: (string|null);

                    /** ProcessorVersion displayName */
                    displayName?: (string|null);

                    /** ProcessorVersion documentSchema */
                    documentSchema?: (google.cloud.documentai.v1.IDocumentSchema|null);

                    /** ProcessorVersion state */
                    state?: (google.cloud.documentai.v1.ProcessorVersion.State|keyof typeof google.cloud.documentai.v1.ProcessorVersion.State|null);

                    /** ProcessorVersion createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** ProcessorVersion latestEvaluation */
                    latestEvaluation?: (google.cloud.documentai.v1.IEvaluationReference|null);

                    /** ProcessorVersion kmsKeyName */
                    kmsKeyName?: (string|null);

                    /** ProcessorVersion kmsKeyVersionName */
                    kmsKeyVersionName?: (string|null);

                    /** ProcessorVersion googleManaged */
                    googleManaged?: (boolean|null);

                    /** ProcessorVersion deprecationInfo */
                    deprecationInfo?: (google.cloud.documentai.v1.ProcessorVersion.IDeprecationInfo|null);

                    /** ProcessorVersion modelType */
                    modelType?: (google.cloud.documentai.v1.ProcessorVersion.ModelType|keyof typeof google.cloud.documentai.v1.ProcessorVersion.ModelType|null);

                    /** ProcessorVersion satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** ProcessorVersion satisfiesPzi */
                    satisfiesPzi?: (boolean|null);

                    /** ProcessorVersion genAiModelInfo */
                    genAiModelInfo?: (google.cloud.documentai.v1.ProcessorVersion.IGenAiModelInfo|null);
                }

                /** Represents a ProcessorVersion. */
                class ProcessorVersion implements IProcessorVersion {

                    /**
                     * Constructs a new ProcessorVersion.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IProcessorVersion);

                    /** ProcessorVersion name. */
                    public name: string;

                    /** ProcessorVersion displayName. */
                    public displayName: string;

                    /** ProcessorVersion documentSchema. */
                    public documentSchema?: (google.cloud.documentai.v1.IDocumentSchema|null);

                    /** ProcessorVersion state. */
                    public state: (google.cloud.documentai.v1.ProcessorVersion.State|keyof typeof google.cloud.documentai.v1.ProcessorVersion.State);

                    /** ProcessorVersion createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** ProcessorVersion latestEvaluation. */
                    public latestEvaluation?: (google.cloud.documentai.v1.IEvaluationReference|null);

                    /** ProcessorVersion kmsKeyName. */
                    public kmsKeyName: string;

                    /** ProcessorVersion kmsKeyVersionName. */
                    public kmsKeyVersionName: string;

                    /** ProcessorVersion googleManaged. */
                    public googleManaged: boolean;

                    /** ProcessorVersion deprecationInfo. */
                    public deprecationInfo?: (google.cloud.documentai.v1.ProcessorVersion.IDeprecationInfo|null);

                    /** ProcessorVersion modelType. */
                    public modelType: (google.cloud.documentai.v1.ProcessorVersion.ModelType|keyof typeof google.cloud.documentai.v1.ProcessorVersion.ModelType);

                    /** ProcessorVersion satisfiesPzs. */
                    public satisfiesPzs: boolean;

                    /** ProcessorVersion satisfiesPzi. */
                    public satisfiesPzi: boolean;

                    /** ProcessorVersion genAiModelInfo. */
                    public genAiModelInfo?: (google.cloud.documentai.v1.ProcessorVersion.IGenAiModelInfo|null);

                    /**
                     * Creates a new ProcessorVersion instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessorVersion instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IProcessorVersion): google.cloud.documentai.v1.ProcessorVersion;

                    /**
                     * Encodes the specified ProcessorVersion message. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.verify|verify} messages.
                     * @param message ProcessorVersion message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IProcessorVersion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessorVersion message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.verify|verify} messages.
                     * @param message ProcessorVersion message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IProcessorVersion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessorVersion message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessorVersion
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessorVersion;

                    /**
                     * Decodes a ProcessorVersion message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessorVersion
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessorVersion;

                    /**
                     * Verifies a ProcessorVersion message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessorVersion message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessorVersion
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessorVersion;

                    /**
                     * Creates a plain object from a ProcessorVersion message. Also converts values to other types if specified.
                     * @param message ProcessorVersion
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ProcessorVersion, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessorVersion to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessorVersion
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ProcessorVersion {

                    /** Properties of a DeprecationInfo. */
                    interface IDeprecationInfo {

                        /** DeprecationInfo deprecationTime */
                        deprecationTime?: (google.protobuf.ITimestamp|null);

                        /** DeprecationInfo replacementProcessorVersion */
                        replacementProcessorVersion?: (string|null);
                    }

                    /** Represents a DeprecationInfo. */
                    class DeprecationInfo implements IDeprecationInfo {

                        /**
                         * Constructs a new DeprecationInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.ProcessorVersion.IDeprecationInfo);

                        /** DeprecationInfo deprecationTime. */
                        public deprecationTime?: (google.protobuf.ITimestamp|null);

                        /** DeprecationInfo replacementProcessorVersion. */
                        public replacementProcessorVersion: string;

                        /**
                         * Creates a new DeprecationInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns DeprecationInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.ProcessorVersion.IDeprecationInfo): google.cloud.documentai.v1.ProcessorVersion.DeprecationInfo;

                        /**
                         * Encodes the specified DeprecationInfo message. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.DeprecationInfo.verify|verify} messages.
                         * @param message DeprecationInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.ProcessorVersion.IDeprecationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified DeprecationInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.DeprecationInfo.verify|verify} messages.
                         * @param message DeprecationInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.ProcessorVersion.IDeprecationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a DeprecationInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns DeprecationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessorVersion.DeprecationInfo;

                        /**
                         * Decodes a DeprecationInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns DeprecationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessorVersion.DeprecationInfo;

                        /**
                         * Verifies a DeprecationInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a DeprecationInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns DeprecationInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessorVersion.DeprecationInfo;

                        /**
                         * Creates a plain object from a DeprecationInfo message. Also converts values to other types if specified.
                         * @param message DeprecationInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.ProcessorVersion.DeprecationInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this DeprecationInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for DeprecationInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a GenAiModelInfo. */
                    interface IGenAiModelInfo {

                        /** GenAiModelInfo foundationGenAiModelInfo */
                        foundationGenAiModelInfo?: (google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo|null);

                        /** GenAiModelInfo customGenAiModelInfo */
                        customGenAiModelInfo?: (google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo|null);
                    }

                    /** Represents a GenAiModelInfo. */
                    class GenAiModelInfo implements IGenAiModelInfo {

                        /**
                         * Constructs a new GenAiModelInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.ProcessorVersion.IGenAiModelInfo);

                        /** GenAiModelInfo foundationGenAiModelInfo. */
                        public foundationGenAiModelInfo?: (google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo|null);

                        /** GenAiModelInfo customGenAiModelInfo. */
                        public customGenAiModelInfo?: (google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo|null);

                        /** GenAiModelInfo modelInfo. */
                        public modelInfo?: ("foundationGenAiModelInfo"|"customGenAiModelInfo");

                        /**
                         * Creates a new GenAiModelInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns GenAiModelInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.ProcessorVersion.IGenAiModelInfo): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo;

                        /**
                         * Encodes the specified GenAiModelInfo message. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.verify|verify} messages.
                         * @param message GenAiModelInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.ProcessorVersion.IGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified GenAiModelInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.verify|verify} messages.
                         * @param message GenAiModelInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.ProcessorVersion.IGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a GenAiModelInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns GenAiModelInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo;

                        /**
                         * Decodes a GenAiModelInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns GenAiModelInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo;

                        /**
                         * Verifies a GenAiModelInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a GenAiModelInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns GenAiModelInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo;

                        /**
                         * Creates a plain object from a GenAiModelInfo message. Also converts values to other types if specified.
                         * @param message GenAiModelInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this GenAiModelInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for GenAiModelInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace GenAiModelInfo {

                        /** Properties of a FoundationGenAiModelInfo. */
                        interface IFoundationGenAiModelInfo {

                            /** FoundationGenAiModelInfo finetuningAllowed */
                            finetuningAllowed?: (boolean|null);

                            /** FoundationGenAiModelInfo minTrainLabeledDocuments */
                            minTrainLabeledDocuments?: (number|null);
                        }

                        /** Represents a FoundationGenAiModelInfo. */
                        class FoundationGenAiModelInfo implements IFoundationGenAiModelInfo {

                            /**
                             * Constructs a new FoundationGenAiModelInfo.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo);

                            /** FoundationGenAiModelInfo finetuningAllowed. */
                            public finetuningAllowed: boolean;

                            /** FoundationGenAiModelInfo minTrainLabeledDocuments. */
                            public minTrainLabeledDocuments: number;

                            /**
                             * Creates a new FoundationGenAiModelInfo instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FoundationGenAiModelInfo instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo;

                            /**
                             * Encodes the specified FoundationGenAiModelInfo message. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo.verify|verify} messages.
                             * @param message FoundationGenAiModelInfo message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FoundationGenAiModelInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo.verify|verify} messages.
                             * @param message FoundationGenAiModelInfo message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FoundationGenAiModelInfo message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FoundationGenAiModelInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo;

                            /**
                             * Decodes a FoundationGenAiModelInfo message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FoundationGenAiModelInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo;

                            /**
                             * Verifies a FoundationGenAiModelInfo message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FoundationGenAiModelInfo message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FoundationGenAiModelInfo
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo;

                            /**
                             * Creates a plain object from a FoundationGenAiModelInfo message. Also converts values to other types if specified.
                             * @param message FoundationGenAiModelInfo
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FoundationGenAiModelInfo to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FoundationGenAiModelInfo
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a CustomGenAiModelInfo. */
                        interface ICustomGenAiModelInfo {

                            /** CustomGenAiModelInfo customModelType */
                            customModelType?: (google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.CustomModelType|keyof typeof google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.CustomModelType|null);

                            /** CustomGenAiModelInfo baseProcessorVersionId */
                            baseProcessorVersionId?: (string|null);
                        }

                        /** Represents a CustomGenAiModelInfo. */
                        class CustomGenAiModelInfo implements ICustomGenAiModelInfo {

                            /**
                             * Constructs a new CustomGenAiModelInfo.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo);

                            /** CustomGenAiModelInfo customModelType. */
                            public customModelType: (google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.CustomModelType|keyof typeof google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.CustomModelType);

                            /** CustomGenAiModelInfo baseProcessorVersionId. */
                            public baseProcessorVersionId: string;

                            /**
                             * Creates a new CustomGenAiModelInfo instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns CustomGenAiModelInfo instance
                             */
                            public static create(properties?: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo;

                            /**
                             * Encodes the specified CustomGenAiModelInfo message. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.verify|verify} messages.
                             * @param message CustomGenAiModelInfo message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified CustomGenAiModelInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.verify|verify} messages.
                             * @param message CustomGenAiModelInfo message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a CustomGenAiModelInfo message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns CustomGenAiModelInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo;

                            /**
                             * Decodes a CustomGenAiModelInfo message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns CustomGenAiModelInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo;

                            /**
                             * Verifies a CustomGenAiModelInfo message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a CustomGenAiModelInfo message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns CustomGenAiModelInfo
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo;

                            /**
                             * Creates a plain object from a CustomGenAiModelInfo message. Also converts values to other types if specified.
                             * @param message CustomGenAiModelInfo
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this CustomGenAiModelInfo to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for CustomGenAiModelInfo
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace CustomGenAiModelInfo {

                            /** CustomModelType enum. */
                            enum CustomModelType {
                                CUSTOM_MODEL_TYPE_UNSPECIFIED = 0,
                                VERSIONED_FOUNDATION = 1,
                                FINE_TUNED = 2
                            }
                        }
                    }

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        DEPLOYED = 1,
                        DEPLOYING = 2,
                        UNDEPLOYED = 3,
                        UNDEPLOYING = 4,
                        CREATING = 5,
                        DELETING = 6,
                        FAILED = 7,
                        IMPORTING = 8
                    }

                    /** ModelType enum. */
                    enum ModelType {
                        MODEL_TYPE_UNSPECIFIED = 0,
                        MODEL_TYPE_GENERATIVE = 1,
                        MODEL_TYPE_CUSTOM = 2
                    }
                }

                /** Properties of a ProcessorVersionAlias. */
                interface IProcessorVersionAlias {

                    /** ProcessorVersionAlias alias */
                    alias?: (string|null);

                    /** ProcessorVersionAlias processorVersion */
                    processorVersion?: (string|null);
                }

                /** Represents a ProcessorVersionAlias. */
                class ProcessorVersionAlias implements IProcessorVersionAlias {

                    /**
                     * Constructs a new ProcessorVersionAlias.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IProcessorVersionAlias);

                    /** ProcessorVersionAlias alias. */
                    public alias: string;

                    /** ProcessorVersionAlias processorVersion. */
                    public processorVersion: string;

                    /**
                     * Creates a new ProcessorVersionAlias instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessorVersionAlias instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IProcessorVersionAlias): google.cloud.documentai.v1.ProcessorVersionAlias;

                    /**
                     * Encodes the specified ProcessorVersionAlias message. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersionAlias.verify|verify} messages.
                     * @param message ProcessorVersionAlias message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IProcessorVersionAlias, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessorVersionAlias message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessorVersionAlias.verify|verify} messages.
                     * @param message ProcessorVersionAlias message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IProcessorVersionAlias, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessorVersionAlias message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessorVersionAlias
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessorVersionAlias;

                    /**
                     * Decodes a ProcessorVersionAlias message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessorVersionAlias
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessorVersionAlias;

                    /**
                     * Verifies a ProcessorVersionAlias message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessorVersionAlias message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessorVersionAlias
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessorVersionAlias;

                    /**
                     * Creates a plain object from a ProcessorVersionAlias message. Also converts values to other types if specified.
                     * @param message ProcessorVersionAlias
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ProcessorVersionAlias, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessorVersionAlias to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessorVersionAlias
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Processor. */
                interface IProcessor {

                    /** Processor name */
                    name?: (string|null);

                    /** Processor type */
                    type?: (string|null);

                    /** Processor displayName */
                    displayName?: (string|null);

                    /** Processor state */
                    state?: (google.cloud.documentai.v1.Processor.State|keyof typeof google.cloud.documentai.v1.Processor.State|null);

                    /** Processor defaultProcessorVersion */
                    defaultProcessorVersion?: (string|null);

                    /** Processor processorVersionAliases */
                    processorVersionAliases?: (google.cloud.documentai.v1.IProcessorVersionAlias[]|null);

                    /** Processor processEndpoint */
                    processEndpoint?: (string|null);

                    /** Processor createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** Processor kmsKeyName */
                    kmsKeyName?: (string|null);

                    /** Processor satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** Processor satisfiesPzi */
                    satisfiesPzi?: (boolean|null);
                }

                /** Represents a Processor. */
                class Processor implements IProcessor {

                    /**
                     * Constructs a new Processor.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IProcessor);

                    /** Processor name. */
                    public name: string;

                    /** Processor type. */
                    public type: string;

                    /** Processor displayName. */
                    public displayName: string;

                    /** Processor state. */
                    public state: (google.cloud.documentai.v1.Processor.State|keyof typeof google.cloud.documentai.v1.Processor.State);

                    /** Processor defaultProcessorVersion. */
                    public defaultProcessorVersion: string;

                    /** Processor processorVersionAliases. */
                    public processorVersionAliases: google.cloud.documentai.v1.IProcessorVersionAlias[];

                    /** Processor processEndpoint. */
                    public processEndpoint: string;

                    /** Processor createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** Processor kmsKeyName. */
                    public kmsKeyName: string;

                    /** Processor satisfiesPzs. */
                    public satisfiesPzs: boolean;

                    /** Processor satisfiesPzi. */
                    public satisfiesPzi: boolean;

                    /**
                     * Creates a new Processor instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Processor instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IProcessor): google.cloud.documentai.v1.Processor;

                    /**
                     * Encodes the specified Processor message. Does not implicitly {@link google.cloud.documentai.v1.Processor.verify|verify} messages.
                     * @param message Processor message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IProcessor, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Processor message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.Processor.verify|verify} messages.
                     * @param message Processor message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IProcessor, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Processor message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Processor
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.Processor;

                    /**
                     * Decodes a Processor message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Processor
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.Processor;

                    /**
                     * Verifies a Processor message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Processor message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Processor
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.Processor;

                    /**
                     * Creates a plain object from a Processor message. Also converts values to other types if specified.
                     * @param message Processor
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.Processor, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Processor to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Processor
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Processor {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        ENABLED = 1,
                        DISABLED = 2,
                        ENABLING = 3,
                        DISABLING = 4,
                        CREATING = 5,
                        FAILED = 6,
                        DELETING = 7
                    }
                }

                /** Properties of a ProcessorType. */
                interface IProcessorType {

                    /** ProcessorType name */
                    name?: (string|null);

                    /** ProcessorType type */
                    type?: (string|null);

                    /** ProcessorType category */
                    category?: (string|null);

                    /** ProcessorType availableLocations */
                    availableLocations?: (google.cloud.documentai.v1.ProcessorType.ILocationInfo[]|null);

                    /** ProcessorType allowCreation */
                    allowCreation?: (boolean|null);

                    /** ProcessorType launchStage */
                    launchStage?: (google.api.LaunchStage|keyof typeof google.api.LaunchStage|null);

                    /** ProcessorType sampleDocumentUris */
                    sampleDocumentUris?: (string[]|null);
                }

                /** Represents a ProcessorType. */
                class ProcessorType implements IProcessorType {

                    /**
                     * Constructs a new ProcessorType.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1.IProcessorType);

                    /** ProcessorType name. */
                    public name: string;

                    /** ProcessorType type. */
                    public type: string;

                    /** ProcessorType category. */
                    public category: string;

                    /** ProcessorType availableLocations. */
                    public availableLocations: google.cloud.documentai.v1.ProcessorType.ILocationInfo[];

                    /** ProcessorType allowCreation. */
                    public allowCreation: boolean;

                    /** ProcessorType launchStage. */
                    public launchStage: (google.api.LaunchStage|keyof typeof google.api.LaunchStage);

                    /** ProcessorType sampleDocumentUris. */
                    public sampleDocumentUris: string[];

                    /**
                     * Creates a new ProcessorType instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessorType instance
                     */
                    public static create(properties?: google.cloud.documentai.v1.IProcessorType): google.cloud.documentai.v1.ProcessorType;

                    /**
                     * Encodes the specified ProcessorType message. Does not implicitly {@link google.cloud.documentai.v1.ProcessorType.verify|verify} messages.
                     * @param message ProcessorType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1.IProcessorType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessorType message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessorType.verify|verify} messages.
                     * @param message ProcessorType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1.IProcessorType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessorType message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessorType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessorType;

                    /**
                     * Decodes a ProcessorType message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessorType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessorType;

                    /**
                     * Verifies a ProcessorType message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessorType message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessorType
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessorType;

                    /**
                     * Creates a plain object from a ProcessorType message. Also converts values to other types if specified.
                     * @param message ProcessorType
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1.ProcessorType, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessorType to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessorType
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ProcessorType {

                    /** Properties of a LocationInfo. */
                    interface ILocationInfo {

                        /** LocationInfo locationId */
                        locationId?: (string|null);
                    }

                    /** Represents a LocationInfo. */
                    class LocationInfo implements ILocationInfo {

                        /**
                         * Constructs a new LocationInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1.ProcessorType.ILocationInfo);

                        /** LocationInfo locationId. */
                        public locationId: string;

                        /**
                         * Creates a new LocationInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns LocationInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1.ProcessorType.ILocationInfo): google.cloud.documentai.v1.ProcessorType.LocationInfo;

                        /**
                         * Encodes the specified LocationInfo message. Does not implicitly {@link google.cloud.documentai.v1.ProcessorType.LocationInfo.verify|verify} messages.
                         * @param message LocationInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1.ProcessorType.ILocationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified LocationInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1.ProcessorType.LocationInfo.verify|verify} messages.
                         * @param message LocationInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1.ProcessorType.ILocationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a LocationInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns LocationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1.ProcessorType.LocationInfo;

                        /**
                         * Decodes a LocationInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns LocationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1.ProcessorType.LocationInfo;

                        /**
                         * Verifies a LocationInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a LocationInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns LocationInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1.ProcessorType.LocationInfo;

                        /**
                         * Creates a plain object from a LocationInfo message. Also converts values to other types if specified.
                         * @param message LocationInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1.ProcessorType.LocationInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this LocationInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for LocationInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }
            }

            /** Namespace v1beta1. */
            namespace v1beta1 {

                /** Properties of a Document. */
                interface IDocument {

                    /** Document uri */
                    uri?: (string|null);

                    /** Document content */
                    content?: (Uint8Array|string|null);

                    /** Document mimeType */
                    mimeType?: (string|null);

                    /** Document text */
                    text?: (string|null);

                    /** Document textStyles */
                    textStyles?: (google.cloud.documentai.v1beta1.Document.IStyle[]|null);

                    /** Document pages */
                    pages?: (google.cloud.documentai.v1beta1.Document.IPage[]|null);

                    /** Document entities */
                    entities?: (google.cloud.documentai.v1beta1.Document.IEntity[]|null);

                    /** Document entityRelations */
                    entityRelations?: (google.cloud.documentai.v1beta1.Document.IEntityRelation[]|null);

                    /** Document shardInfo */
                    shardInfo?: (google.cloud.documentai.v1beta1.Document.IShardInfo|null);

                    /** Document error */
                    error?: (google.rpc.IStatus|null);
                }

                /** Represents a Document. */
                class Document implements IDocument {

                    /**
                     * Constructs a new Document.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IDocument);

                    /** Document uri. */
                    public uri?: (string|null);

                    /** Document content. */
                    public content?: (Uint8Array|string|null);

                    /** Document mimeType. */
                    public mimeType: string;

                    /** Document text. */
                    public text: string;

                    /** Document textStyles. */
                    public textStyles: google.cloud.documentai.v1beta1.Document.IStyle[];

                    /** Document pages. */
                    public pages: google.cloud.documentai.v1beta1.Document.IPage[];

                    /** Document entities. */
                    public entities: google.cloud.documentai.v1beta1.Document.IEntity[];

                    /** Document entityRelations. */
                    public entityRelations: google.cloud.documentai.v1beta1.Document.IEntityRelation[];

                    /** Document shardInfo. */
                    public shardInfo?: (google.cloud.documentai.v1beta1.Document.IShardInfo|null);

                    /** Document error. */
                    public error?: (google.rpc.IStatus|null);

                    /** Document source. */
                    public source?: ("uri"|"content");

                    /**
                     * Creates a new Document instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Document instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IDocument): google.cloud.documentai.v1beta1.Document;

                    /**
                     * Encodes the specified Document message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.verify|verify} messages.
                     * @param message Document message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Document message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.verify|verify} messages.
                     * @param message Document message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Document message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Document
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document;

                    /**
                     * Decodes a Document message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Document
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document;

                    /**
                     * Verifies a Document message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Document message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Document
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document;

                    /**
                     * Creates a plain object from a Document message. Also converts values to other types if specified.
                     * @param message Document
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.Document, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Document to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Document
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Document {

                    /** Properties of a ShardInfo. */
                    interface IShardInfo {

                        /** ShardInfo shardIndex */
                        shardIndex?: (number|Long|string|null);

                        /** ShardInfo shardCount */
                        shardCount?: (number|Long|string|null);

                        /** ShardInfo textOffset */
                        textOffset?: (number|Long|string|null);
                    }

                    /** Represents a ShardInfo. */
                    class ShardInfo implements IShardInfo {

                        /**
                         * Constructs a new ShardInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta1.Document.IShardInfo);

                        /** ShardInfo shardIndex. */
                        public shardIndex: (number|Long|string);

                        /** ShardInfo shardCount. */
                        public shardCount: (number|Long|string);

                        /** ShardInfo textOffset. */
                        public textOffset: (number|Long|string);

                        /**
                         * Creates a new ShardInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ShardInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta1.Document.IShardInfo): google.cloud.documentai.v1beta1.Document.ShardInfo;

                        /**
                         * Encodes the specified ShardInfo message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.ShardInfo.verify|verify} messages.
                         * @param message ShardInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta1.Document.IShardInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ShardInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.ShardInfo.verify|verify} messages.
                         * @param message ShardInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.IShardInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a ShardInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ShardInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.ShardInfo;

                        /**
                         * Decodes a ShardInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ShardInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.ShardInfo;

                        /**
                         * Verifies a ShardInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a ShardInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ShardInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.ShardInfo;

                        /**
                         * Creates a plain object from a ShardInfo message. Also converts values to other types if specified.
                         * @param message ShardInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta1.Document.ShardInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ShardInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ShardInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a Style. */
                    interface IStyle {

                        /** Style textAnchor */
                        textAnchor?: (google.cloud.documentai.v1beta1.Document.ITextAnchor|null);

                        /** Style color */
                        color?: (google.type.IColor|null);

                        /** Style backgroundColor */
                        backgroundColor?: (google.type.IColor|null);

                        /** Style fontWeight */
                        fontWeight?: (string|null);

                        /** Style textStyle */
                        textStyle?: (string|null);

                        /** Style textDecoration */
                        textDecoration?: (string|null);

                        /** Style fontSize */
                        fontSize?: (google.cloud.documentai.v1beta1.Document.Style.IFontSize|null);
                    }

                    /** Represents a Style. */
                    class Style implements IStyle {

                        /**
                         * Constructs a new Style.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta1.Document.IStyle);

                        /** Style textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1beta1.Document.ITextAnchor|null);

                        /** Style color. */
                        public color?: (google.type.IColor|null);

                        /** Style backgroundColor. */
                        public backgroundColor?: (google.type.IColor|null);

                        /** Style fontWeight. */
                        public fontWeight: string;

                        /** Style textStyle. */
                        public textStyle: string;

                        /** Style textDecoration. */
                        public textDecoration: string;

                        /** Style fontSize. */
                        public fontSize?: (google.cloud.documentai.v1beta1.Document.Style.IFontSize|null);

                        /**
                         * Creates a new Style instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Style instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta1.Document.IStyle): google.cloud.documentai.v1beta1.Document.Style;

                        /**
                         * Encodes the specified Style message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Style.verify|verify} messages.
                         * @param message Style message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta1.Document.IStyle, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Style message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Style.verify|verify} messages.
                         * @param message Style message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.IStyle, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Style message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Style
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Style;

                        /**
                         * Decodes a Style message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Style
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Style;

                        /**
                         * Verifies a Style message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Style message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Style
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Style;

                        /**
                         * Creates a plain object from a Style message. Also converts values to other types if specified.
                         * @param message Style
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta1.Document.Style, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Style to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Style
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Style {

                        /** Properties of a FontSize. */
                        interface IFontSize {

                            /** FontSize size */
                            size?: (number|null);

                            /** FontSize unit */
                            unit?: (string|null);
                        }

                        /** Represents a FontSize. */
                        class FontSize implements IFontSize {

                            /**
                             * Constructs a new FontSize.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Style.IFontSize);

                            /** FontSize size. */
                            public size: number;

                            /** FontSize unit. */
                            public unit: string;

                            /**
                             * Creates a new FontSize instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FontSize instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Style.IFontSize): google.cloud.documentai.v1beta1.Document.Style.FontSize;

                            /**
                             * Encodes the specified FontSize message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Style.FontSize.verify|verify} messages.
                             * @param message FontSize message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Style.IFontSize, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FontSize message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Style.FontSize.verify|verify} messages.
                             * @param message FontSize message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Style.IFontSize, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FontSize message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FontSize
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Style.FontSize;

                            /**
                             * Decodes a FontSize message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FontSize
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Style.FontSize;

                            /**
                             * Verifies a FontSize message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FontSize message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FontSize
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Style.FontSize;

                            /**
                             * Creates a plain object from a FontSize message. Also converts values to other types if specified.
                             * @param message FontSize
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Style.FontSize, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FontSize to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FontSize
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a Page. */
                    interface IPage {

                        /** Page pageNumber */
                        pageNumber?: (number|null);

                        /** Page dimension */
                        dimension?: (google.cloud.documentai.v1beta1.Document.Page.IDimension|null);

                        /** Page layout */
                        layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                        /** Page detectedLanguages */
                        detectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);

                        /** Page blocks */
                        blocks?: (google.cloud.documentai.v1beta1.Document.Page.IBlock[]|null);

                        /** Page paragraphs */
                        paragraphs?: (google.cloud.documentai.v1beta1.Document.Page.IParagraph[]|null);

                        /** Page lines */
                        lines?: (google.cloud.documentai.v1beta1.Document.Page.ILine[]|null);

                        /** Page tokens */
                        tokens?: (google.cloud.documentai.v1beta1.Document.Page.IToken[]|null);

                        /** Page visualElements */
                        visualElements?: (google.cloud.documentai.v1beta1.Document.Page.IVisualElement[]|null);

                        /** Page tables */
                        tables?: (google.cloud.documentai.v1beta1.Document.Page.ITable[]|null);

                        /** Page formFields */
                        formFields?: (google.cloud.documentai.v1beta1.Document.Page.IFormField[]|null);
                    }

                    /** Represents a Page. */
                    class Page implements IPage {

                        /**
                         * Constructs a new Page.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta1.Document.IPage);

                        /** Page pageNumber. */
                        public pageNumber: number;

                        /** Page dimension. */
                        public dimension?: (google.cloud.documentai.v1beta1.Document.Page.IDimension|null);

                        /** Page layout. */
                        public layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                        /** Page detectedLanguages. */
                        public detectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                        /** Page blocks. */
                        public blocks: google.cloud.documentai.v1beta1.Document.Page.IBlock[];

                        /** Page paragraphs. */
                        public paragraphs: google.cloud.documentai.v1beta1.Document.Page.IParagraph[];

                        /** Page lines. */
                        public lines: google.cloud.documentai.v1beta1.Document.Page.ILine[];

                        /** Page tokens. */
                        public tokens: google.cloud.documentai.v1beta1.Document.Page.IToken[];

                        /** Page visualElements. */
                        public visualElements: google.cloud.documentai.v1beta1.Document.Page.IVisualElement[];

                        /** Page tables. */
                        public tables: google.cloud.documentai.v1beta1.Document.Page.ITable[];

                        /** Page formFields. */
                        public formFields: google.cloud.documentai.v1beta1.Document.Page.IFormField[];

                        /**
                         * Creates a new Page instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Page instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta1.Document.IPage): google.cloud.documentai.v1beta1.Document.Page;

                        /**
                         * Encodes the specified Page message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.verify|verify} messages.
                         * @param message Page message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta1.Document.IPage, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Page message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.verify|verify} messages.
                         * @param message Page message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.IPage, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Page message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Page
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page;

                        /**
                         * Decodes a Page message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Page
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page;

                        /**
                         * Verifies a Page message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Page message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Page
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page;

                        /**
                         * Creates a plain object from a Page message. Also converts values to other types if specified.
                         * @param message Page
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta1.Document.Page, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Page to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Page
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Page {

                        /** Properties of a Dimension. */
                        interface IDimension {

                            /** Dimension width */
                            width?: (number|null);

                            /** Dimension height */
                            height?: (number|null);

                            /** Dimension unit */
                            unit?: (string|null);
                        }

                        /** Represents a Dimension. */
                        class Dimension implements IDimension {

                            /**
                             * Constructs a new Dimension.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.IDimension);

                            /** Dimension width. */
                            public width: number;

                            /** Dimension height. */
                            public height: number;

                            /** Dimension unit. */
                            public unit: string;

                            /**
                             * Creates a new Dimension instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Dimension instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.IDimension): google.cloud.documentai.v1beta1.Document.Page.Dimension;

                            /**
                             * Encodes the specified Dimension message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Dimension.verify|verify} messages.
                             * @param message Dimension message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.IDimension, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Dimension message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Dimension.verify|verify} messages.
                             * @param message Dimension message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.IDimension, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Dimension message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Dimension
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Dimension;

                            /**
                             * Decodes a Dimension message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Dimension
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Dimension;

                            /**
                             * Verifies a Dimension message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Dimension message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Dimension
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Dimension;

                            /**
                             * Creates a plain object from a Dimension message. Also converts values to other types if specified.
                             * @param message Dimension
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Dimension, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Dimension to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Dimension
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Layout. */
                        interface ILayout {

                            /** Layout textAnchor */
                            textAnchor?: (google.cloud.documentai.v1beta1.Document.ITextAnchor|null);

                            /** Layout confidence */
                            confidence?: (number|null);

                            /** Layout boundingPoly */
                            boundingPoly?: (google.cloud.documentai.v1beta1.IBoundingPoly|null);

                            /** Layout orientation */
                            orientation?: (google.cloud.documentai.v1beta1.Document.Page.Layout.Orientation|keyof typeof google.cloud.documentai.v1beta1.Document.Page.Layout.Orientation|null);
                        }

                        /** Represents a Layout. */
                        class Layout implements ILayout {

                            /**
                             * Constructs a new Layout.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.ILayout);

                            /** Layout textAnchor. */
                            public textAnchor?: (google.cloud.documentai.v1beta1.Document.ITextAnchor|null);

                            /** Layout confidence. */
                            public confidence: number;

                            /** Layout boundingPoly. */
                            public boundingPoly?: (google.cloud.documentai.v1beta1.IBoundingPoly|null);

                            /** Layout orientation. */
                            public orientation: (google.cloud.documentai.v1beta1.Document.Page.Layout.Orientation|keyof typeof google.cloud.documentai.v1beta1.Document.Page.Layout.Orientation);

                            /**
                             * Creates a new Layout instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Layout instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.ILayout): google.cloud.documentai.v1beta1.Document.Page.Layout;

                            /**
                             * Encodes the specified Layout message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Layout.verify|verify} messages.
                             * @param message Layout message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.ILayout, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Layout message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Layout.verify|verify} messages.
                             * @param message Layout message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.ILayout, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Layout message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Layout
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Layout;

                            /**
                             * Decodes a Layout message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Layout
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Layout;

                            /**
                             * Verifies a Layout message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Layout message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Layout
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Layout;

                            /**
                             * Creates a plain object from a Layout message. Also converts values to other types if specified.
                             * @param message Layout
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Layout, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Layout to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Layout
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Layout {

                            /** Orientation enum. */
                            enum Orientation {
                                ORIENTATION_UNSPECIFIED = 0,
                                PAGE_UP = 1,
                                PAGE_RIGHT = 2,
                                PAGE_DOWN = 3,
                                PAGE_LEFT = 4
                            }
                        }

                        /** Properties of a Block. */
                        interface IBlock {

                            /** Block layout */
                            layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Block detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a Block. */
                        class Block implements IBlock {

                            /**
                             * Constructs a new Block.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.IBlock);

                            /** Block layout. */
                            public layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Block detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new Block instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Block instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.IBlock): google.cloud.documentai.v1beta1.Document.Page.Block;

                            /**
                             * Encodes the specified Block message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Block.verify|verify} messages.
                             * @param message Block message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.IBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Block message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Block.verify|verify} messages.
                             * @param message Block message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.IBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Block message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Block
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Block;

                            /**
                             * Decodes a Block message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Block
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Block;

                            /**
                             * Verifies a Block message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Block message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Block
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Block;

                            /**
                             * Creates a plain object from a Block message. Also converts values to other types if specified.
                             * @param message Block
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Block, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Block to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Block
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Paragraph. */
                        interface IParagraph {

                            /** Paragraph layout */
                            layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Paragraph detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a Paragraph. */
                        class Paragraph implements IParagraph {

                            /**
                             * Constructs a new Paragraph.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.IParagraph);

                            /** Paragraph layout. */
                            public layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Paragraph detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new Paragraph instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Paragraph instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.IParagraph): google.cloud.documentai.v1beta1.Document.Page.Paragraph;

                            /**
                             * Encodes the specified Paragraph message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Paragraph.verify|verify} messages.
                             * @param message Paragraph message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.IParagraph, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Paragraph message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Paragraph.verify|verify} messages.
                             * @param message Paragraph message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.IParagraph, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Paragraph message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Paragraph
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Paragraph;

                            /**
                             * Decodes a Paragraph message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Paragraph
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Paragraph;

                            /**
                             * Verifies a Paragraph message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Paragraph message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Paragraph
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Paragraph;

                            /**
                             * Creates a plain object from a Paragraph message. Also converts values to other types if specified.
                             * @param message Paragraph
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Paragraph, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Paragraph to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Paragraph
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Line. */
                        interface ILine {

                            /** Line layout */
                            layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Line detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a Line. */
                        class Line implements ILine {

                            /**
                             * Constructs a new Line.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.ILine);

                            /** Line layout. */
                            public layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Line detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new Line instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Line instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.ILine): google.cloud.documentai.v1beta1.Document.Page.Line;

                            /**
                             * Encodes the specified Line message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Line.verify|verify} messages.
                             * @param message Line message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.ILine, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Line message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Line.verify|verify} messages.
                             * @param message Line message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.ILine, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Line message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Line
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Line;

                            /**
                             * Decodes a Line message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Line
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Line;

                            /**
                             * Verifies a Line message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Line message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Line
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Line;

                            /**
                             * Creates a plain object from a Line message. Also converts values to other types if specified.
                             * @param message Line
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Line, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Line to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Line
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Token. */
                        interface IToken {

                            /** Token layout */
                            layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Token detectedBreak */
                            detectedBreak?: (google.cloud.documentai.v1beta1.Document.Page.Token.IDetectedBreak|null);

                            /** Token detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a Token. */
                        class Token implements IToken {

                            /**
                             * Constructs a new Token.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.IToken);

                            /** Token layout. */
                            public layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Token detectedBreak. */
                            public detectedBreak?: (google.cloud.documentai.v1beta1.Document.Page.Token.IDetectedBreak|null);

                            /** Token detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new Token instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Token instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.IToken): google.cloud.documentai.v1beta1.Document.Page.Token;

                            /**
                             * Encodes the specified Token message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Token.verify|verify} messages.
                             * @param message Token message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.IToken, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Token message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Token.verify|verify} messages.
                             * @param message Token message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.IToken, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Token message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Token
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Token;

                            /**
                             * Decodes a Token message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Token
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Token;

                            /**
                             * Verifies a Token message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Token message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Token
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Token;

                            /**
                             * Creates a plain object from a Token message. Also converts values to other types if specified.
                             * @param message Token
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Token, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Token to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Token
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Token {

                            /** Properties of a DetectedBreak. */
                            interface IDetectedBreak {

                                /** DetectedBreak type */
                                type?: (google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak.Type|keyof typeof google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak.Type|null);
                            }

                            /** Represents a DetectedBreak. */
                            class DetectedBreak implements IDetectedBreak {

                                /**
                                 * Constructs a new DetectedBreak.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.Token.IDetectedBreak);

                                /** DetectedBreak type. */
                                public type: (google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak.Type|keyof typeof google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak.Type);

                                /**
                                 * Creates a new DetectedBreak instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns DetectedBreak instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.Token.IDetectedBreak): google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak;

                                /**
                                 * Encodes the specified DetectedBreak message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak.verify|verify} messages.
                                 * @param message DetectedBreak message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta1.Document.Page.Token.IDetectedBreak, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified DetectedBreak message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak.verify|verify} messages.
                                 * @param message DetectedBreak message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.Token.IDetectedBreak, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a DetectedBreak message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns DetectedBreak
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak;

                                /**
                                 * Decodes a DetectedBreak message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns DetectedBreak
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak;

                                /**
                                 * Verifies a DetectedBreak message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a DetectedBreak message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns DetectedBreak
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak;

                                /**
                                 * Creates a plain object from a DetectedBreak message. Also converts values to other types if specified.
                                 * @param message DetectedBreak
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Token.DetectedBreak, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this DetectedBreak to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for DetectedBreak
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            namespace DetectedBreak {

                                /** Type enum. */
                                enum Type {
                                    TYPE_UNSPECIFIED = 0,
                                    SPACE = 1,
                                    WIDE_SPACE = 2,
                                    HYPHEN = 3
                                }
                            }
                        }

                        /** Properties of a VisualElement. */
                        interface IVisualElement {

                            /** VisualElement layout */
                            layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** VisualElement type */
                            type?: (string|null);

                            /** VisualElement detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a VisualElement. */
                        class VisualElement implements IVisualElement {

                            /**
                             * Constructs a new VisualElement.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.IVisualElement);

                            /** VisualElement layout. */
                            public layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** VisualElement type. */
                            public type: string;

                            /** VisualElement detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new VisualElement instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns VisualElement instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.IVisualElement): google.cloud.documentai.v1beta1.Document.Page.VisualElement;

                            /**
                             * Encodes the specified VisualElement message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.VisualElement.verify|verify} messages.
                             * @param message VisualElement message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.IVisualElement, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified VisualElement message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.VisualElement.verify|verify} messages.
                             * @param message VisualElement message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.IVisualElement, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a VisualElement message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns VisualElement
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.VisualElement;

                            /**
                             * Decodes a VisualElement message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns VisualElement
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.VisualElement;

                            /**
                             * Verifies a VisualElement message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a VisualElement message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns VisualElement
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.VisualElement;

                            /**
                             * Creates a plain object from a VisualElement message. Also converts values to other types if specified.
                             * @param message VisualElement
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.VisualElement, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this VisualElement to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for VisualElement
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Table. */
                        interface ITable {

                            /** Table layout */
                            layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Table headerRows */
                            headerRows?: (google.cloud.documentai.v1beta1.Document.Page.Table.ITableRow[]|null);

                            /** Table bodyRows */
                            bodyRows?: (google.cloud.documentai.v1beta1.Document.Page.Table.ITableRow[]|null);

                            /** Table detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a Table. */
                        class Table implements ITable {

                            /**
                             * Constructs a new Table.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.ITable);

                            /** Table layout. */
                            public layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** Table headerRows. */
                            public headerRows: google.cloud.documentai.v1beta1.Document.Page.Table.ITableRow[];

                            /** Table bodyRows. */
                            public bodyRows: google.cloud.documentai.v1beta1.Document.Page.Table.ITableRow[];

                            /** Table detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new Table instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Table instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.ITable): google.cloud.documentai.v1beta1.Document.Page.Table;

                            /**
                             * Encodes the specified Table message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Table.verify|verify} messages.
                             * @param message Table message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.ITable, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Table message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Table.verify|verify} messages.
                             * @param message Table message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.ITable, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Table message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Table
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Table;

                            /**
                             * Decodes a Table message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Table
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Table;

                            /**
                             * Verifies a Table message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Table message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Table
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Table;

                            /**
                             * Creates a plain object from a Table message. Also converts values to other types if specified.
                             * @param message Table
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Table, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Table to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Table
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Table {

                            /** Properties of a TableRow. */
                            interface ITableRow {

                                /** TableRow cells */
                                cells?: (google.cloud.documentai.v1beta1.Document.Page.Table.ITableCell[]|null);
                            }

                            /** Represents a TableRow. */
                            class TableRow implements ITableRow {

                                /**
                                 * Constructs a new TableRow.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.Table.ITableRow);

                                /** TableRow cells. */
                                public cells: google.cloud.documentai.v1beta1.Document.Page.Table.ITableCell[];

                                /**
                                 * Creates a new TableRow instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns TableRow instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.Table.ITableRow): google.cloud.documentai.v1beta1.Document.Page.Table.TableRow;

                                /**
                                 * Encodes the specified TableRow message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Table.TableRow.verify|verify} messages.
                                 * @param message TableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta1.Document.Page.Table.ITableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified TableRow message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Table.TableRow.verify|verify} messages.
                                 * @param message TableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.Table.ITableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a TableRow message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns TableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Table.TableRow;

                                /**
                                 * Decodes a TableRow message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns TableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Table.TableRow;

                                /**
                                 * Verifies a TableRow message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a TableRow message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns TableRow
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Table.TableRow;

                                /**
                                 * Creates a plain object from a TableRow message. Also converts values to other types if specified.
                                 * @param message TableRow
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Table.TableRow, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this TableRow to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for TableRow
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a TableCell. */
                            interface ITableCell {

                                /** TableCell layout */
                                layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                                /** TableCell rowSpan */
                                rowSpan?: (number|null);

                                /** TableCell colSpan */
                                colSpan?: (number|null);

                                /** TableCell detectedLanguages */
                                detectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);
                            }

                            /** Represents a TableCell. */
                            class TableCell implements ITableCell {

                                /**
                                 * Constructs a new TableCell.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.Table.ITableCell);

                                /** TableCell layout. */
                                public layout?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                                /** TableCell rowSpan. */
                                public rowSpan: number;

                                /** TableCell colSpan. */
                                public colSpan: number;

                                /** TableCell detectedLanguages. */
                                public detectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                                /**
                                 * Creates a new TableCell instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns TableCell instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.Table.ITableCell): google.cloud.documentai.v1beta1.Document.Page.Table.TableCell;

                                /**
                                 * Encodes the specified TableCell message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Table.TableCell.verify|verify} messages.
                                 * @param message TableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta1.Document.Page.Table.ITableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified TableCell message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.Table.TableCell.verify|verify} messages.
                                 * @param message TableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.Table.ITableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a TableCell message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns TableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.Table.TableCell;

                                /**
                                 * Decodes a TableCell message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns TableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.Table.TableCell;

                                /**
                                 * Verifies a TableCell message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a TableCell message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns TableCell
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.Table.TableCell;

                                /**
                                 * Creates a plain object from a TableCell message. Also converts values to other types if specified.
                                 * @param message TableCell
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.Table.TableCell, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this TableCell to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for TableCell
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }

                        /** Properties of a FormField. */
                        interface IFormField {

                            /** FormField fieldName */
                            fieldName?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** FormField fieldValue */
                            fieldValue?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** FormField nameDetectedLanguages */
                            nameDetectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);

                            /** FormField valueDetectedLanguages */
                            valueDetectedLanguages?: (google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a FormField. */
                        class FormField implements IFormField {

                            /**
                             * Constructs a new FormField.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.IFormField);

                            /** FormField fieldName. */
                            public fieldName?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** FormField fieldValue. */
                            public fieldValue?: (google.cloud.documentai.v1beta1.Document.Page.ILayout|null);

                            /** FormField nameDetectedLanguages. */
                            public nameDetectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                            /** FormField valueDetectedLanguages. */
                            public valueDetectedLanguages: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new FormField instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FormField instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.IFormField): google.cloud.documentai.v1beta1.Document.Page.FormField;

                            /**
                             * Encodes the specified FormField message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.FormField.verify|verify} messages.
                             * @param message FormField message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.IFormField, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FormField message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.FormField.verify|verify} messages.
                             * @param message FormField message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.IFormField, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FormField message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FormField
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.FormField;

                            /**
                             * Decodes a FormField message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FormField
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.FormField;

                            /**
                             * Verifies a FormField message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FormField message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FormField
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.FormField;

                            /**
                             * Creates a plain object from a FormField message. Also converts values to other types if specified.
                             * @param message FormField
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.FormField, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FormField to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FormField
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a DetectedLanguage. */
                        interface IDetectedLanguage {

                            /** DetectedLanguage languageCode */
                            languageCode?: (string|null);

                            /** DetectedLanguage confidence */
                            confidence?: (number|null);
                        }

                        /** Represents a DetectedLanguage. */
                        class DetectedLanguage implements IDetectedLanguage {

                            /**
                             * Constructs a new DetectedLanguage.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage);

                            /** DetectedLanguage languageCode. */
                            public languageCode: string;

                            /** DetectedLanguage confidence. */
                            public confidence: number;

                            /**
                             * Creates a new DetectedLanguage instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns DetectedLanguage instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage): google.cloud.documentai.v1beta1.Document.Page.DetectedLanguage;

                            /**
                             * Encodes the specified DetectedLanguage message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.DetectedLanguage.verify|verify} messages.
                             * @param message DetectedLanguage message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified DetectedLanguage message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Page.DetectedLanguage.verify|verify} messages.
                             * @param message DetectedLanguage message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.Page.IDetectedLanguage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a DetectedLanguage message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns DetectedLanguage
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Page.DetectedLanguage;

                            /**
                             * Decodes a DetectedLanguage message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns DetectedLanguage
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Page.DetectedLanguage;

                            /**
                             * Verifies a DetectedLanguage message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a DetectedLanguage message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns DetectedLanguage
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Page.DetectedLanguage;

                            /**
                             * Creates a plain object from a DetectedLanguage message. Also converts values to other types if specified.
                             * @param message DetectedLanguage
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.Page.DetectedLanguage, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this DetectedLanguage to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for DetectedLanguage
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of an Entity. */
                    interface IEntity {

                        /** Entity textAnchor */
                        textAnchor?: (google.cloud.documentai.v1beta1.Document.ITextAnchor|null);

                        /** Entity type */
                        type?: (string|null);

                        /** Entity mentionText */
                        mentionText?: (string|null);

                        /** Entity mentionId */
                        mentionId?: (string|null);
                    }

                    /** Represents an Entity. */
                    class Entity implements IEntity {

                        /**
                         * Constructs a new Entity.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta1.Document.IEntity);

                        /** Entity textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1beta1.Document.ITextAnchor|null);

                        /** Entity type. */
                        public type: string;

                        /** Entity mentionText. */
                        public mentionText: string;

                        /** Entity mentionId. */
                        public mentionId: string;

                        /**
                         * Creates a new Entity instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Entity instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta1.Document.IEntity): google.cloud.documentai.v1beta1.Document.Entity;

                        /**
                         * Encodes the specified Entity message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Entity.verify|verify} messages.
                         * @param message Entity message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta1.Document.IEntity, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Entity message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.Entity.verify|verify} messages.
                         * @param message Entity message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.IEntity, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an Entity message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Entity
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.Entity;

                        /**
                         * Decodes an Entity message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Entity
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.Entity;

                        /**
                         * Verifies an Entity message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an Entity message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Entity
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.Entity;

                        /**
                         * Creates a plain object from an Entity message. Also converts values to other types if specified.
                         * @param message Entity
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta1.Document.Entity, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Entity to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Entity
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of an EntityRelation. */
                    interface IEntityRelation {

                        /** EntityRelation subjectId */
                        subjectId?: (string|null);

                        /** EntityRelation objectId */
                        objectId?: (string|null);

                        /** EntityRelation relation */
                        relation?: (string|null);
                    }

                    /** Represents an EntityRelation. */
                    class EntityRelation implements IEntityRelation {

                        /**
                         * Constructs a new EntityRelation.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta1.Document.IEntityRelation);

                        /** EntityRelation subjectId. */
                        public subjectId: string;

                        /** EntityRelation objectId. */
                        public objectId: string;

                        /** EntityRelation relation. */
                        public relation: string;

                        /**
                         * Creates a new EntityRelation instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns EntityRelation instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta1.Document.IEntityRelation): google.cloud.documentai.v1beta1.Document.EntityRelation;

                        /**
                         * Encodes the specified EntityRelation message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.EntityRelation.verify|verify} messages.
                         * @param message EntityRelation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta1.Document.IEntityRelation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified EntityRelation message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.EntityRelation.verify|verify} messages.
                         * @param message EntityRelation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.IEntityRelation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an EntityRelation message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns EntityRelation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.EntityRelation;

                        /**
                         * Decodes an EntityRelation message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns EntityRelation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.EntityRelation;

                        /**
                         * Verifies an EntityRelation message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an EntityRelation message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns EntityRelation
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.EntityRelation;

                        /**
                         * Creates a plain object from an EntityRelation message. Also converts values to other types if specified.
                         * @param message EntityRelation
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta1.Document.EntityRelation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this EntityRelation to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for EntityRelation
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a TextAnchor. */
                    interface ITextAnchor {

                        /** TextAnchor textSegments */
                        textSegments?: (google.cloud.documentai.v1beta1.Document.TextAnchor.ITextSegment[]|null);
                    }

                    /** Represents a TextAnchor. */
                    class TextAnchor implements ITextAnchor {

                        /**
                         * Constructs a new TextAnchor.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta1.Document.ITextAnchor);

                        /** TextAnchor textSegments. */
                        public textSegments: google.cloud.documentai.v1beta1.Document.TextAnchor.ITextSegment[];

                        /**
                         * Creates a new TextAnchor instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns TextAnchor instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta1.Document.ITextAnchor): google.cloud.documentai.v1beta1.Document.TextAnchor;

                        /**
                         * Encodes the specified TextAnchor message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.TextAnchor.verify|verify} messages.
                         * @param message TextAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta1.Document.ITextAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified TextAnchor message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.TextAnchor.verify|verify} messages.
                         * @param message TextAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.ITextAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a TextAnchor message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns TextAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.TextAnchor;

                        /**
                         * Decodes a TextAnchor message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns TextAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.TextAnchor;

                        /**
                         * Verifies a TextAnchor message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a TextAnchor message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns TextAnchor
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.TextAnchor;

                        /**
                         * Creates a plain object from a TextAnchor message. Also converts values to other types if specified.
                         * @param message TextAnchor
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta1.Document.TextAnchor, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this TextAnchor to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for TextAnchor
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace TextAnchor {

                        /** Properties of a TextSegment. */
                        interface ITextSegment {

                            /** TextSegment startIndex */
                            startIndex?: (number|Long|string|null);

                            /** TextSegment endIndex */
                            endIndex?: (number|Long|string|null);
                        }

                        /** Represents a TextSegment. */
                        class TextSegment implements ITextSegment {

                            /**
                             * Constructs a new TextSegment.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta1.Document.TextAnchor.ITextSegment);

                            /** TextSegment startIndex. */
                            public startIndex: (number|Long|string);

                            /** TextSegment endIndex. */
                            public endIndex: (number|Long|string);

                            /**
                             * Creates a new TextSegment instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns TextSegment instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta1.Document.TextAnchor.ITextSegment): google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment;

                            /**
                             * Encodes the specified TextSegment message. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment.verify|verify} messages.
                             * @param message TextSegment message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta1.Document.TextAnchor.ITextSegment, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified TextSegment message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment.verify|verify} messages.
                             * @param message TextSegment message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta1.Document.TextAnchor.ITextSegment, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a TextSegment message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns TextSegment
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment;

                            /**
                             * Decodes a TextSegment message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns TextSegment
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment;

                            /**
                             * Verifies a TextSegment message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a TextSegment message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns TextSegment
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment;

                            /**
                             * Creates a plain object from a TextSegment message. Also converts values to other types if specified.
                             * @param message TextSegment
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta1.Document.TextAnchor.TextSegment, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this TextSegment to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for TextSegment
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }
                }

                /** Properties of a Vertex. */
                interface IVertex {

                    /** Vertex x */
                    x?: (number|null);

                    /** Vertex y */
                    y?: (number|null);
                }

                /** Represents a Vertex. */
                class Vertex implements IVertex {

                    /**
                     * Constructs a new Vertex.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IVertex);

                    /** Vertex x. */
                    public x: number;

                    /** Vertex y. */
                    public y: number;

                    /**
                     * Creates a new Vertex instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Vertex instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IVertex): google.cloud.documentai.v1beta1.Vertex;

                    /**
                     * Encodes the specified Vertex message. Does not implicitly {@link google.cloud.documentai.v1beta1.Vertex.verify|verify} messages.
                     * @param message Vertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Vertex message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.Vertex.verify|verify} messages.
                     * @param message Vertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Vertex message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Vertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.Vertex;

                    /**
                     * Decodes a Vertex message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Vertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.Vertex;

                    /**
                     * Verifies a Vertex message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Vertex message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Vertex
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.Vertex;

                    /**
                     * Creates a plain object from a Vertex message. Also converts values to other types if specified.
                     * @param message Vertex
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.Vertex, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Vertex to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Vertex
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NormalizedVertex. */
                interface INormalizedVertex {

                    /** NormalizedVertex x */
                    x?: (number|null);

                    /** NormalizedVertex y */
                    y?: (number|null);
                }

                /** Represents a NormalizedVertex. */
                class NormalizedVertex implements INormalizedVertex {

                    /**
                     * Constructs a new NormalizedVertex.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.INormalizedVertex);

                    /** NormalizedVertex x. */
                    public x: number;

                    /** NormalizedVertex y. */
                    public y: number;

                    /**
                     * Creates a new NormalizedVertex instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NormalizedVertex instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.INormalizedVertex): google.cloud.documentai.v1beta1.NormalizedVertex;

                    /**
                     * Encodes the specified NormalizedVertex message. Does not implicitly {@link google.cloud.documentai.v1beta1.NormalizedVertex.verify|verify} messages.
                     * @param message NormalizedVertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.INormalizedVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NormalizedVertex message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.NormalizedVertex.verify|verify} messages.
                     * @param message NormalizedVertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.INormalizedVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NormalizedVertex message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NormalizedVertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.NormalizedVertex;

                    /**
                     * Decodes a NormalizedVertex message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NormalizedVertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.NormalizedVertex;

                    /**
                     * Verifies a NormalizedVertex message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NormalizedVertex message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NormalizedVertex
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.NormalizedVertex;

                    /**
                     * Creates a plain object from a NormalizedVertex message. Also converts values to other types if specified.
                     * @param message NormalizedVertex
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.NormalizedVertex, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NormalizedVertex to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NormalizedVertex
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BoundingPoly. */
                interface IBoundingPoly {

                    /** BoundingPoly vertices */
                    vertices?: (google.cloud.documentai.v1beta1.IVertex[]|null);

                    /** BoundingPoly normalizedVertices */
                    normalizedVertices?: (google.cloud.documentai.v1beta1.INormalizedVertex[]|null);
                }

                /** Represents a BoundingPoly. */
                class BoundingPoly implements IBoundingPoly {

                    /**
                     * Constructs a new BoundingPoly.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IBoundingPoly);

                    /** BoundingPoly vertices. */
                    public vertices: google.cloud.documentai.v1beta1.IVertex[];

                    /** BoundingPoly normalizedVertices. */
                    public normalizedVertices: google.cloud.documentai.v1beta1.INormalizedVertex[];

                    /**
                     * Creates a new BoundingPoly instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BoundingPoly instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IBoundingPoly): google.cloud.documentai.v1beta1.BoundingPoly;

                    /**
                     * Encodes the specified BoundingPoly message. Does not implicitly {@link google.cloud.documentai.v1beta1.BoundingPoly.verify|verify} messages.
                     * @param message BoundingPoly message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IBoundingPoly, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BoundingPoly message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.BoundingPoly.verify|verify} messages.
                     * @param message BoundingPoly message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IBoundingPoly, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BoundingPoly message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BoundingPoly
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.BoundingPoly;

                    /**
                     * Decodes a BoundingPoly message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BoundingPoly
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.BoundingPoly;

                    /**
                     * Verifies a BoundingPoly message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BoundingPoly message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BoundingPoly
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.BoundingPoly;

                    /**
                     * Creates a plain object from a BoundingPoly message. Also converts values to other types if specified.
                     * @param message BoundingPoly
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.BoundingPoly, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BoundingPoly to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BoundingPoly
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Represents a DocumentUnderstandingService */
                class DocumentUnderstandingService extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new DocumentUnderstandingService service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new DocumentUnderstandingService service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): DocumentUnderstandingService;

                    /**
                     * Calls BatchProcessDocuments.
                     * @param request BatchProcessDocumentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public batchProcessDocuments(request: google.cloud.documentai.v1beta1.IBatchProcessDocumentsRequest, callback: google.cloud.documentai.v1beta1.DocumentUnderstandingService.BatchProcessDocumentsCallback): void;

                    /**
                     * Calls BatchProcessDocuments.
                     * @param request BatchProcessDocumentsRequest message or plain object
                     * @returns Promise
                     */
                    public batchProcessDocuments(request: google.cloud.documentai.v1beta1.IBatchProcessDocumentsRequest): Promise<google.longrunning.Operation>;
                }

                namespace DocumentUnderstandingService {

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta1.DocumentUnderstandingService|batchProcessDocuments}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type BatchProcessDocumentsCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;
                }

                /** Properties of a BatchProcessDocumentsRequest. */
                interface IBatchProcessDocumentsRequest {

                    /** BatchProcessDocumentsRequest requests */
                    requests?: (google.cloud.documentai.v1beta1.IProcessDocumentRequest[]|null);

                    /** BatchProcessDocumentsRequest parent */
                    parent?: (string|null);
                }

                /** Represents a BatchProcessDocumentsRequest. */
                class BatchProcessDocumentsRequest implements IBatchProcessDocumentsRequest {

                    /**
                     * Constructs a new BatchProcessDocumentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IBatchProcessDocumentsRequest);

                    /** BatchProcessDocumentsRequest requests. */
                    public requests: google.cloud.documentai.v1beta1.IProcessDocumentRequest[];

                    /** BatchProcessDocumentsRequest parent. */
                    public parent: string;

                    /**
                     * Creates a new BatchProcessDocumentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessDocumentsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IBatchProcessDocumentsRequest): google.cloud.documentai.v1beta1.BatchProcessDocumentsRequest;

                    /**
                     * Encodes the specified BatchProcessDocumentsRequest message. Does not implicitly {@link google.cloud.documentai.v1beta1.BatchProcessDocumentsRequest.verify|verify} messages.
                     * @param message BatchProcessDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IBatchProcessDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessDocumentsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.BatchProcessDocumentsRequest.verify|verify} messages.
                     * @param message BatchProcessDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IBatchProcessDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessDocumentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.BatchProcessDocumentsRequest;

                    /**
                     * Decodes a BatchProcessDocumentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.BatchProcessDocumentsRequest;

                    /**
                     * Verifies a BatchProcessDocumentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessDocumentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessDocumentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.BatchProcessDocumentsRequest;

                    /**
                     * Creates a plain object from a BatchProcessDocumentsRequest message. Also converts values to other types if specified.
                     * @param message BatchProcessDocumentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.BatchProcessDocumentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessDocumentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessDocumentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ProcessDocumentRequest. */
                interface IProcessDocumentRequest {

                    /** ProcessDocumentRequest inputConfig */
                    inputConfig?: (google.cloud.documentai.v1beta1.IInputConfig|null);

                    /** ProcessDocumentRequest outputConfig */
                    outputConfig?: (google.cloud.documentai.v1beta1.IOutputConfig|null);

                    /** ProcessDocumentRequest documentType */
                    documentType?: (string|null);

                    /** ProcessDocumentRequest tableExtractionParams */
                    tableExtractionParams?: (google.cloud.documentai.v1beta1.ITableExtractionParams|null);

                    /** ProcessDocumentRequest formExtractionParams */
                    formExtractionParams?: (google.cloud.documentai.v1beta1.IFormExtractionParams|null);

                    /** ProcessDocumentRequest entityExtractionParams */
                    entityExtractionParams?: (google.cloud.documentai.v1beta1.IEntityExtractionParams|null);

                    /** ProcessDocumentRequest ocrParams */
                    ocrParams?: (google.cloud.documentai.v1beta1.IOcrParams|null);
                }

                /** Represents a ProcessDocumentRequest. */
                class ProcessDocumentRequest implements IProcessDocumentRequest {

                    /**
                     * Constructs a new ProcessDocumentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IProcessDocumentRequest);

                    /** ProcessDocumentRequest inputConfig. */
                    public inputConfig?: (google.cloud.documentai.v1beta1.IInputConfig|null);

                    /** ProcessDocumentRequest outputConfig. */
                    public outputConfig?: (google.cloud.documentai.v1beta1.IOutputConfig|null);

                    /** ProcessDocumentRequest documentType. */
                    public documentType: string;

                    /** ProcessDocumentRequest tableExtractionParams. */
                    public tableExtractionParams?: (google.cloud.documentai.v1beta1.ITableExtractionParams|null);

                    /** ProcessDocumentRequest formExtractionParams. */
                    public formExtractionParams?: (google.cloud.documentai.v1beta1.IFormExtractionParams|null);

                    /** ProcessDocumentRequest entityExtractionParams. */
                    public entityExtractionParams?: (google.cloud.documentai.v1beta1.IEntityExtractionParams|null);

                    /** ProcessDocumentRequest ocrParams. */
                    public ocrParams?: (google.cloud.documentai.v1beta1.IOcrParams|null);

                    /**
                     * Creates a new ProcessDocumentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessDocumentRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IProcessDocumentRequest): google.cloud.documentai.v1beta1.ProcessDocumentRequest;

                    /**
                     * Encodes the specified ProcessDocumentRequest message. Does not implicitly {@link google.cloud.documentai.v1beta1.ProcessDocumentRequest.verify|verify} messages.
                     * @param message ProcessDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IProcessDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.ProcessDocumentRequest.verify|verify} messages.
                     * @param message ProcessDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IProcessDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessDocumentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.ProcessDocumentRequest;

                    /**
                     * Decodes a ProcessDocumentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.ProcessDocumentRequest;

                    /**
                     * Verifies a ProcessDocumentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessDocumentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessDocumentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.ProcessDocumentRequest;

                    /**
                     * Creates a plain object from a ProcessDocumentRequest message. Also converts values to other types if specified.
                     * @param message ProcessDocumentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.ProcessDocumentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessDocumentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessDocumentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchProcessDocumentsResponse. */
                interface IBatchProcessDocumentsResponse {

                    /** BatchProcessDocumentsResponse responses */
                    responses?: (google.cloud.documentai.v1beta1.IProcessDocumentResponse[]|null);
                }

                /** Represents a BatchProcessDocumentsResponse. */
                class BatchProcessDocumentsResponse implements IBatchProcessDocumentsResponse {

                    /**
                     * Constructs a new BatchProcessDocumentsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IBatchProcessDocumentsResponse);

                    /** BatchProcessDocumentsResponse responses. */
                    public responses: google.cloud.documentai.v1beta1.IProcessDocumentResponse[];

                    /**
                     * Creates a new BatchProcessDocumentsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessDocumentsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IBatchProcessDocumentsResponse): google.cloud.documentai.v1beta1.BatchProcessDocumentsResponse;

                    /**
                     * Encodes the specified BatchProcessDocumentsResponse message. Does not implicitly {@link google.cloud.documentai.v1beta1.BatchProcessDocumentsResponse.verify|verify} messages.
                     * @param message BatchProcessDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IBatchProcessDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessDocumentsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.BatchProcessDocumentsResponse.verify|verify} messages.
                     * @param message BatchProcessDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IBatchProcessDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessDocumentsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.BatchProcessDocumentsResponse;

                    /**
                     * Decodes a BatchProcessDocumentsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.BatchProcessDocumentsResponse;

                    /**
                     * Verifies a BatchProcessDocumentsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessDocumentsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessDocumentsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.BatchProcessDocumentsResponse;

                    /**
                     * Creates a plain object from a BatchProcessDocumentsResponse message. Also converts values to other types if specified.
                     * @param message BatchProcessDocumentsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.BatchProcessDocumentsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessDocumentsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessDocumentsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ProcessDocumentResponse. */
                interface IProcessDocumentResponse {

                    /** ProcessDocumentResponse inputConfig */
                    inputConfig?: (google.cloud.documentai.v1beta1.IInputConfig|null);

                    /** ProcessDocumentResponse outputConfig */
                    outputConfig?: (google.cloud.documentai.v1beta1.IOutputConfig|null);
                }

                /** Represents a ProcessDocumentResponse. */
                class ProcessDocumentResponse implements IProcessDocumentResponse {

                    /**
                     * Constructs a new ProcessDocumentResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IProcessDocumentResponse);

                    /** ProcessDocumentResponse inputConfig. */
                    public inputConfig?: (google.cloud.documentai.v1beta1.IInputConfig|null);

                    /** ProcessDocumentResponse outputConfig. */
                    public outputConfig?: (google.cloud.documentai.v1beta1.IOutputConfig|null);

                    /**
                     * Creates a new ProcessDocumentResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessDocumentResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IProcessDocumentResponse): google.cloud.documentai.v1beta1.ProcessDocumentResponse;

                    /**
                     * Encodes the specified ProcessDocumentResponse message. Does not implicitly {@link google.cloud.documentai.v1beta1.ProcessDocumentResponse.verify|verify} messages.
                     * @param message ProcessDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IProcessDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessDocumentResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.ProcessDocumentResponse.verify|verify} messages.
                     * @param message ProcessDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IProcessDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessDocumentResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.ProcessDocumentResponse;

                    /**
                     * Decodes a ProcessDocumentResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.ProcessDocumentResponse;

                    /**
                     * Verifies a ProcessDocumentResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessDocumentResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessDocumentResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.ProcessDocumentResponse;

                    /**
                     * Creates a plain object from a ProcessDocumentResponse message. Also converts values to other types if specified.
                     * @param message ProcessDocumentResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.ProcessDocumentResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessDocumentResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessDocumentResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an OcrParams. */
                interface IOcrParams {

                    /** OcrParams languageHints */
                    languageHints?: (string[]|null);
                }

                /** Represents an OcrParams. */
                class OcrParams implements IOcrParams {

                    /**
                     * Constructs a new OcrParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IOcrParams);

                    /** OcrParams languageHints. */
                    public languageHints: string[];

                    /**
                     * Creates a new OcrParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OcrParams instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IOcrParams): google.cloud.documentai.v1beta1.OcrParams;

                    /**
                     * Encodes the specified OcrParams message. Does not implicitly {@link google.cloud.documentai.v1beta1.OcrParams.verify|verify} messages.
                     * @param message OcrParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IOcrParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OcrParams message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.OcrParams.verify|verify} messages.
                     * @param message OcrParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IOcrParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OcrParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OcrParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.OcrParams;

                    /**
                     * Decodes an OcrParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OcrParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.OcrParams;

                    /**
                     * Verifies an OcrParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OcrParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OcrParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.OcrParams;

                    /**
                     * Creates a plain object from an OcrParams message. Also converts values to other types if specified.
                     * @param message OcrParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.OcrParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OcrParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OcrParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TableExtractionParams. */
                interface ITableExtractionParams {

                    /** TableExtractionParams enabled */
                    enabled?: (boolean|null);

                    /** TableExtractionParams tableBoundHints */
                    tableBoundHints?: (google.cloud.documentai.v1beta1.ITableBoundHint[]|null);

                    /** TableExtractionParams headerHints */
                    headerHints?: (string[]|null);

                    /** TableExtractionParams modelVersion */
                    modelVersion?: (string|null);
                }

                /** Represents a TableExtractionParams. */
                class TableExtractionParams implements ITableExtractionParams {

                    /**
                     * Constructs a new TableExtractionParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.ITableExtractionParams);

                    /** TableExtractionParams enabled. */
                    public enabled: boolean;

                    /** TableExtractionParams tableBoundHints. */
                    public tableBoundHints: google.cloud.documentai.v1beta1.ITableBoundHint[];

                    /** TableExtractionParams headerHints. */
                    public headerHints: string[];

                    /** TableExtractionParams modelVersion. */
                    public modelVersion: string;

                    /**
                     * Creates a new TableExtractionParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TableExtractionParams instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.ITableExtractionParams): google.cloud.documentai.v1beta1.TableExtractionParams;

                    /**
                     * Encodes the specified TableExtractionParams message. Does not implicitly {@link google.cloud.documentai.v1beta1.TableExtractionParams.verify|verify} messages.
                     * @param message TableExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.ITableExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TableExtractionParams message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.TableExtractionParams.verify|verify} messages.
                     * @param message TableExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.ITableExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TableExtractionParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TableExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.TableExtractionParams;

                    /**
                     * Decodes a TableExtractionParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TableExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.TableExtractionParams;

                    /**
                     * Verifies a TableExtractionParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TableExtractionParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TableExtractionParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.TableExtractionParams;

                    /**
                     * Creates a plain object from a TableExtractionParams message. Also converts values to other types if specified.
                     * @param message TableExtractionParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.TableExtractionParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TableExtractionParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TableExtractionParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TableBoundHint. */
                interface ITableBoundHint {

                    /** TableBoundHint pageNumber */
                    pageNumber?: (number|null);

                    /** TableBoundHint boundingBox */
                    boundingBox?: (google.cloud.documentai.v1beta1.IBoundingPoly|null);
                }

                /** Represents a TableBoundHint. */
                class TableBoundHint implements ITableBoundHint {

                    /**
                     * Constructs a new TableBoundHint.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.ITableBoundHint);

                    /** TableBoundHint pageNumber. */
                    public pageNumber: number;

                    /** TableBoundHint boundingBox. */
                    public boundingBox?: (google.cloud.documentai.v1beta1.IBoundingPoly|null);

                    /**
                     * Creates a new TableBoundHint instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TableBoundHint instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.ITableBoundHint): google.cloud.documentai.v1beta1.TableBoundHint;

                    /**
                     * Encodes the specified TableBoundHint message. Does not implicitly {@link google.cloud.documentai.v1beta1.TableBoundHint.verify|verify} messages.
                     * @param message TableBoundHint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.ITableBoundHint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TableBoundHint message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.TableBoundHint.verify|verify} messages.
                     * @param message TableBoundHint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.ITableBoundHint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TableBoundHint message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TableBoundHint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.TableBoundHint;

                    /**
                     * Decodes a TableBoundHint message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TableBoundHint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.TableBoundHint;

                    /**
                     * Verifies a TableBoundHint message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TableBoundHint message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TableBoundHint
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.TableBoundHint;

                    /**
                     * Creates a plain object from a TableBoundHint message. Also converts values to other types if specified.
                     * @param message TableBoundHint
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.TableBoundHint, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TableBoundHint to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TableBoundHint
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FormExtractionParams. */
                interface IFormExtractionParams {

                    /** FormExtractionParams enabled */
                    enabled?: (boolean|null);

                    /** FormExtractionParams keyValuePairHints */
                    keyValuePairHints?: (google.cloud.documentai.v1beta1.IKeyValuePairHint[]|null);

                    /** FormExtractionParams modelVersion */
                    modelVersion?: (string|null);
                }

                /** Represents a FormExtractionParams. */
                class FormExtractionParams implements IFormExtractionParams {

                    /**
                     * Constructs a new FormExtractionParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IFormExtractionParams);

                    /** FormExtractionParams enabled. */
                    public enabled: boolean;

                    /** FormExtractionParams keyValuePairHints. */
                    public keyValuePairHints: google.cloud.documentai.v1beta1.IKeyValuePairHint[];

                    /** FormExtractionParams modelVersion. */
                    public modelVersion: string;

                    /**
                     * Creates a new FormExtractionParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FormExtractionParams instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IFormExtractionParams): google.cloud.documentai.v1beta1.FormExtractionParams;

                    /**
                     * Encodes the specified FormExtractionParams message. Does not implicitly {@link google.cloud.documentai.v1beta1.FormExtractionParams.verify|verify} messages.
                     * @param message FormExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IFormExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FormExtractionParams message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.FormExtractionParams.verify|verify} messages.
                     * @param message FormExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IFormExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FormExtractionParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FormExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.FormExtractionParams;

                    /**
                     * Decodes a FormExtractionParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FormExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.FormExtractionParams;

                    /**
                     * Verifies a FormExtractionParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FormExtractionParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FormExtractionParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.FormExtractionParams;

                    /**
                     * Creates a plain object from a FormExtractionParams message. Also converts values to other types if specified.
                     * @param message FormExtractionParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.FormExtractionParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FormExtractionParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FormExtractionParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a KeyValuePairHint. */
                interface IKeyValuePairHint {

                    /** KeyValuePairHint key */
                    key?: (string|null);

                    /** KeyValuePairHint valueTypes */
                    valueTypes?: (string[]|null);
                }

                /** Represents a KeyValuePairHint. */
                class KeyValuePairHint implements IKeyValuePairHint {

                    /**
                     * Constructs a new KeyValuePairHint.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IKeyValuePairHint);

                    /** KeyValuePairHint key. */
                    public key: string;

                    /** KeyValuePairHint valueTypes. */
                    public valueTypes: string[];

                    /**
                     * Creates a new KeyValuePairHint instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns KeyValuePairHint instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IKeyValuePairHint): google.cloud.documentai.v1beta1.KeyValuePairHint;

                    /**
                     * Encodes the specified KeyValuePairHint message. Does not implicitly {@link google.cloud.documentai.v1beta1.KeyValuePairHint.verify|verify} messages.
                     * @param message KeyValuePairHint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IKeyValuePairHint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified KeyValuePairHint message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.KeyValuePairHint.verify|verify} messages.
                     * @param message KeyValuePairHint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IKeyValuePairHint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a KeyValuePairHint message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns KeyValuePairHint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.KeyValuePairHint;

                    /**
                     * Decodes a KeyValuePairHint message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns KeyValuePairHint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.KeyValuePairHint;

                    /**
                     * Verifies a KeyValuePairHint message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a KeyValuePairHint message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns KeyValuePairHint
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.KeyValuePairHint;

                    /**
                     * Creates a plain object from a KeyValuePairHint message. Also converts values to other types if specified.
                     * @param message KeyValuePairHint
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.KeyValuePairHint, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this KeyValuePairHint to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for KeyValuePairHint
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EntityExtractionParams. */
                interface IEntityExtractionParams {

                    /** EntityExtractionParams enabled */
                    enabled?: (boolean|null);

                    /** EntityExtractionParams modelVersion */
                    modelVersion?: (string|null);
                }

                /** Represents an EntityExtractionParams. */
                class EntityExtractionParams implements IEntityExtractionParams {

                    /**
                     * Constructs a new EntityExtractionParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IEntityExtractionParams);

                    /** EntityExtractionParams enabled. */
                    public enabled: boolean;

                    /** EntityExtractionParams modelVersion. */
                    public modelVersion: string;

                    /**
                     * Creates a new EntityExtractionParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EntityExtractionParams instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IEntityExtractionParams): google.cloud.documentai.v1beta1.EntityExtractionParams;

                    /**
                     * Encodes the specified EntityExtractionParams message. Does not implicitly {@link google.cloud.documentai.v1beta1.EntityExtractionParams.verify|verify} messages.
                     * @param message EntityExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IEntityExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EntityExtractionParams message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.EntityExtractionParams.verify|verify} messages.
                     * @param message EntityExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IEntityExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EntityExtractionParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EntityExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.EntityExtractionParams;

                    /**
                     * Decodes an EntityExtractionParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EntityExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.EntityExtractionParams;

                    /**
                     * Verifies an EntityExtractionParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EntityExtractionParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EntityExtractionParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.EntityExtractionParams;

                    /**
                     * Creates a plain object from an EntityExtractionParams message. Also converts values to other types if specified.
                     * @param message EntityExtractionParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.EntityExtractionParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EntityExtractionParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EntityExtractionParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InputConfig. */
                interface IInputConfig {

                    /** InputConfig gcsSource */
                    gcsSource?: (google.cloud.documentai.v1beta1.IGcsSource|null);

                    /** InputConfig mimeType */
                    mimeType?: (string|null);
                }

                /** Represents an InputConfig. */
                class InputConfig implements IInputConfig {

                    /**
                     * Constructs a new InputConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IInputConfig);

                    /** InputConfig gcsSource. */
                    public gcsSource?: (google.cloud.documentai.v1beta1.IGcsSource|null);

                    /** InputConfig mimeType. */
                    public mimeType: string;

                    /** InputConfig source. */
                    public source?: "gcsSource";

                    /**
                     * Creates a new InputConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InputConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IInputConfig): google.cloud.documentai.v1beta1.InputConfig;

                    /**
                     * Encodes the specified InputConfig message. Does not implicitly {@link google.cloud.documentai.v1beta1.InputConfig.verify|verify} messages.
                     * @param message InputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.InputConfig.verify|verify} messages.
                     * @param message InputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InputConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.InputConfig;

                    /**
                     * Decodes an InputConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.InputConfig;

                    /**
                     * Verifies an InputConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InputConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InputConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.InputConfig;

                    /**
                     * Creates a plain object from an InputConfig message. Also converts values to other types if specified.
                     * @param message InputConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.InputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InputConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InputConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an OutputConfig. */
                interface IOutputConfig {

                    /** OutputConfig gcsDestination */
                    gcsDestination?: (google.cloud.documentai.v1beta1.IGcsDestination|null);

                    /** OutputConfig pagesPerShard */
                    pagesPerShard?: (number|null);
                }

                /** Represents an OutputConfig. */
                class OutputConfig implements IOutputConfig {

                    /**
                     * Constructs a new OutputConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IOutputConfig);

                    /** OutputConfig gcsDestination. */
                    public gcsDestination?: (google.cloud.documentai.v1beta1.IGcsDestination|null);

                    /** OutputConfig pagesPerShard. */
                    public pagesPerShard: number;

                    /** OutputConfig destination. */
                    public destination?: "gcsDestination";

                    /**
                     * Creates a new OutputConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OutputConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IOutputConfig): google.cloud.documentai.v1beta1.OutputConfig;

                    /**
                     * Encodes the specified OutputConfig message. Does not implicitly {@link google.cloud.documentai.v1beta1.OutputConfig.verify|verify} messages.
                     * @param message OutputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OutputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.OutputConfig.verify|verify} messages.
                     * @param message OutputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OutputConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OutputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.OutputConfig;

                    /**
                     * Decodes an OutputConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OutputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.OutputConfig;

                    /**
                     * Verifies an OutputConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OutputConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OutputConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.OutputConfig;

                    /**
                     * Creates a plain object from an OutputConfig message. Also converts values to other types if specified.
                     * @param message OutputConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.OutputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OutputConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OutputConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsSource. */
                interface IGcsSource {

                    /** GcsSource uri */
                    uri?: (string|null);
                }

                /** Represents a GcsSource. */
                class GcsSource implements IGcsSource {

                    /**
                     * Constructs a new GcsSource.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IGcsSource);

                    /** GcsSource uri. */
                    public uri: string;

                    /**
                     * Creates a new GcsSource instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsSource instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IGcsSource): google.cloud.documentai.v1beta1.GcsSource;

                    /**
                     * Encodes the specified GcsSource message. Does not implicitly {@link google.cloud.documentai.v1beta1.GcsSource.verify|verify} messages.
                     * @param message GcsSource message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IGcsSource, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsSource message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.GcsSource.verify|verify} messages.
                     * @param message GcsSource message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IGcsSource, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsSource message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsSource
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.GcsSource;

                    /**
                     * Decodes a GcsSource message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsSource
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.GcsSource;

                    /**
                     * Verifies a GcsSource message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsSource message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsSource
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.GcsSource;

                    /**
                     * Creates a plain object from a GcsSource message. Also converts values to other types if specified.
                     * @param message GcsSource
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.GcsSource, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsSource to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsSource
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsDestination. */
                interface IGcsDestination {

                    /** GcsDestination uri */
                    uri?: (string|null);
                }

                /** Represents a GcsDestination. */
                class GcsDestination implements IGcsDestination {

                    /**
                     * Constructs a new GcsDestination.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IGcsDestination);

                    /** GcsDestination uri. */
                    public uri: string;

                    /**
                     * Creates a new GcsDestination instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsDestination instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IGcsDestination): google.cloud.documentai.v1beta1.GcsDestination;

                    /**
                     * Encodes the specified GcsDestination message. Does not implicitly {@link google.cloud.documentai.v1beta1.GcsDestination.verify|verify} messages.
                     * @param message GcsDestination message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IGcsDestination, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsDestination message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.GcsDestination.verify|verify} messages.
                     * @param message GcsDestination message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IGcsDestination, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsDestination message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsDestination
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.GcsDestination;

                    /**
                     * Decodes a GcsDestination message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsDestination
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.GcsDestination;

                    /**
                     * Verifies a GcsDestination message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsDestination message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsDestination
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.GcsDestination;

                    /**
                     * Creates a plain object from a GcsDestination message. Also converts values to other types if specified.
                     * @param message GcsDestination
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.GcsDestination, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsDestination to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsDestination
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an OperationMetadata. */
                interface IOperationMetadata {

                    /** OperationMetadata state */
                    state?: (google.cloud.documentai.v1beta1.OperationMetadata.State|keyof typeof google.cloud.documentai.v1beta1.OperationMetadata.State|null);

                    /** OperationMetadata stateMessage */
                    stateMessage?: (string|null);

                    /** OperationMetadata createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** OperationMetadata updateTime */
                    updateTime?: (google.protobuf.ITimestamp|null);
                }

                /** Represents an OperationMetadata. */
                class OperationMetadata implements IOperationMetadata {

                    /**
                     * Constructs a new OperationMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta1.IOperationMetadata);

                    /** OperationMetadata state. */
                    public state: (google.cloud.documentai.v1beta1.OperationMetadata.State|keyof typeof google.cloud.documentai.v1beta1.OperationMetadata.State);

                    /** OperationMetadata stateMessage. */
                    public stateMessage: string;

                    /** OperationMetadata createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** OperationMetadata updateTime. */
                    public updateTime?: (google.protobuf.ITimestamp|null);

                    /**
                     * Creates a new OperationMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OperationMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta1.IOperationMetadata): google.cloud.documentai.v1beta1.OperationMetadata;

                    /**
                     * Encodes the specified OperationMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta1.OperationMetadata.verify|verify} messages.
                     * @param message OperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta1.IOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OperationMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta1.OperationMetadata.verify|verify} messages.
                     * @param message OperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta1.IOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OperationMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta1.OperationMetadata;

                    /**
                     * Decodes an OperationMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta1.OperationMetadata;

                    /**
                     * Verifies an OperationMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OperationMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OperationMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta1.OperationMetadata;

                    /**
                     * Creates a plain object from an OperationMetadata message. Also converts values to other types if specified.
                     * @param message OperationMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta1.OperationMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OperationMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OperationMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace OperationMetadata {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        ACCEPTED = 1,
                        WAITING = 2,
                        RUNNING = 3,
                        SUCCEEDED = 4,
                        CANCELLED = 5,
                        FAILED = 6
                    }
                }
            }

            /** Namespace v1beta2. */
            namespace v1beta2 {

                /** Properties of a Barcode. */
                interface IBarcode {

                    /** Barcode format */
                    format?: (string|null);

                    /** Barcode valueFormat */
                    valueFormat?: (string|null);

                    /** Barcode rawValue */
                    rawValue?: (string|null);
                }

                /** Represents a Barcode. */
                class Barcode implements IBarcode {

                    /**
                     * Constructs a new Barcode.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IBarcode);

                    /** Barcode format. */
                    public format: string;

                    /** Barcode valueFormat. */
                    public valueFormat: string;

                    /** Barcode rawValue. */
                    public rawValue: string;

                    /**
                     * Creates a new Barcode instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Barcode instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IBarcode): google.cloud.documentai.v1beta2.Barcode;

                    /**
                     * Encodes the specified Barcode message. Does not implicitly {@link google.cloud.documentai.v1beta2.Barcode.verify|verify} messages.
                     * @param message Barcode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Barcode message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Barcode.verify|verify} messages.
                     * @param message Barcode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Barcode message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Barcode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Barcode;

                    /**
                     * Decodes a Barcode message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Barcode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Barcode;

                    /**
                     * Verifies a Barcode message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Barcode message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Barcode
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Barcode;

                    /**
                     * Creates a plain object from a Barcode message. Also converts values to other types if specified.
                     * @param message Barcode
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.Barcode, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Barcode to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Barcode
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Document. */
                interface IDocument {

                    /** Document uri */
                    uri?: (string|null);

                    /** Document content */
                    content?: (Uint8Array|string|null);

                    /** Document mimeType */
                    mimeType?: (string|null);

                    /** Document text */
                    text?: (string|null);

                    /** Document textStyles */
                    textStyles?: (google.cloud.documentai.v1beta2.Document.IStyle[]|null);

                    /** Document pages */
                    pages?: (google.cloud.documentai.v1beta2.Document.IPage[]|null);

                    /** Document entities */
                    entities?: (google.cloud.documentai.v1beta2.Document.IEntity[]|null);

                    /** Document entityRelations */
                    entityRelations?: (google.cloud.documentai.v1beta2.Document.IEntityRelation[]|null);

                    /** Document textChanges */
                    textChanges?: (google.cloud.documentai.v1beta2.Document.ITextChange[]|null);

                    /** Document shardInfo */
                    shardInfo?: (google.cloud.documentai.v1beta2.Document.IShardInfo|null);

                    /** Document labels */
                    labels?: (google.cloud.documentai.v1beta2.Document.ILabel[]|null);

                    /** Document error */
                    error?: (google.rpc.IStatus|null);

                    /** Document revisions */
                    revisions?: (google.cloud.documentai.v1beta2.Document.IRevision[]|null);
                }

                /** Represents a Document. */
                class Document implements IDocument {

                    /**
                     * Constructs a new Document.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IDocument);

                    /** Document uri. */
                    public uri?: (string|null);

                    /** Document content. */
                    public content?: (Uint8Array|string|null);

                    /** Document mimeType. */
                    public mimeType: string;

                    /** Document text. */
                    public text: string;

                    /** Document textStyles. */
                    public textStyles: google.cloud.documentai.v1beta2.Document.IStyle[];

                    /** Document pages. */
                    public pages: google.cloud.documentai.v1beta2.Document.IPage[];

                    /** Document entities. */
                    public entities: google.cloud.documentai.v1beta2.Document.IEntity[];

                    /** Document entityRelations. */
                    public entityRelations: google.cloud.documentai.v1beta2.Document.IEntityRelation[];

                    /** Document textChanges. */
                    public textChanges: google.cloud.documentai.v1beta2.Document.ITextChange[];

                    /** Document shardInfo. */
                    public shardInfo?: (google.cloud.documentai.v1beta2.Document.IShardInfo|null);

                    /** Document labels. */
                    public labels: google.cloud.documentai.v1beta2.Document.ILabel[];

                    /** Document error. */
                    public error?: (google.rpc.IStatus|null);

                    /** Document revisions. */
                    public revisions: google.cloud.documentai.v1beta2.Document.IRevision[];

                    /** Document source. */
                    public source?: ("uri"|"content");

                    /**
                     * Creates a new Document instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Document instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IDocument): google.cloud.documentai.v1beta2.Document;

                    /**
                     * Encodes the specified Document message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.verify|verify} messages.
                     * @param message Document message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Document message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.verify|verify} messages.
                     * @param message Document message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Document message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Document
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document;

                    /**
                     * Decodes a Document message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Document
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document;

                    /**
                     * Verifies a Document message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Document message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Document
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document;

                    /**
                     * Creates a plain object from a Document message. Also converts values to other types if specified.
                     * @param message Document
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.Document, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Document to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Document
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Document {

                    /** Properties of a ShardInfo. */
                    interface IShardInfo {

                        /** ShardInfo shardIndex */
                        shardIndex?: (number|Long|string|null);

                        /** ShardInfo shardCount */
                        shardCount?: (number|Long|string|null);

                        /** ShardInfo textOffset */
                        textOffset?: (number|Long|string|null);
                    }

                    /** Represents a ShardInfo. */
                    class ShardInfo implements IShardInfo {

                        /**
                         * Constructs a new ShardInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.IShardInfo);

                        /** ShardInfo shardIndex. */
                        public shardIndex: (number|Long|string);

                        /** ShardInfo shardCount. */
                        public shardCount: (number|Long|string);

                        /** ShardInfo textOffset. */
                        public textOffset: (number|Long|string);

                        /**
                         * Creates a new ShardInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ShardInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.IShardInfo): google.cloud.documentai.v1beta2.Document.ShardInfo;

                        /**
                         * Encodes the specified ShardInfo message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.ShardInfo.verify|verify} messages.
                         * @param message ShardInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.IShardInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ShardInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.ShardInfo.verify|verify} messages.
                         * @param message ShardInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.IShardInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a ShardInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ShardInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.ShardInfo;

                        /**
                         * Decodes a ShardInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ShardInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.ShardInfo;

                        /**
                         * Verifies a ShardInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a ShardInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ShardInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.ShardInfo;

                        /**
                         * Creates a plain object from a ShardInfo message. Also converts values to other types if specified.
                         * @param message ShardInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.ShardInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ShardInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ShardInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a Label. */
                    interface ILabel {

                        /** Label automlModel */
                        automlModel?: (string|null);

                        /** Label name */
                        name?: (string|null);

                        /** Label confidence */
                        confidence?: (number|null);
                    }

                    /** Represents a Label. */
                    class Label implements ILabel {

                        /**
                         * Constructs a new Label.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.ILabel);

                        /** Label automlModel. */
                        public automlModel?: (string|null);

                        /** Label name. */
                        public name: string;

                        /** Label confidence. */
                        public confidence: number;

                        /** Label source. */
                        public source?: "automlModel";

                        /**
                         * Creates a new Label instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Label instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.ILabel): google.cloud.documentai.v1beta2.Document.Label;

                        /**
                         * Encodes the specified Label message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Label.verify|verify} messages.
                         * @param message Label message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.ILabel, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Label message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Label.verify|verify} messages.
                         * @param message Label message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.ILabel, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Label message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Label
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Label;

                        /**
                         * Decodes a Label message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Label
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Label;

                        /**
                         * Verifies a Label message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Label message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Label
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Label;

                        /**
                         * Creates a plain object from a Label message. Also converts values to other types if specified.
                         * @param message Label
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.Label, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Label to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Label
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a Style. */
                    interface IStyle {

                        /** Style textAnchor */
                        textAnchor?: (google.cloud.documentai.v1beta2.Document.ITextAnchor|null);

                        /** Style color */
                        color?: (google.type.IColor|null);

                        /** Style backgroundColor */
                        backgroundColor?: (google.type.IColor|null);

                        /** Style fontWeight */
                        fontWeight?: (string|null);

                        /** Style textStyle */
                        textStyle?: (string|null);

                        /** Style textDecoration */
                        textDecoration?: (string|null);

                        /** Style fontSize */
                        fontSize?: (google.cloud.documentai.v1beta2.Document.Style.IFontSize|null);

                        /** Style fontFamily */
                        fontFamily?: (string|null);
                    }

                    /** Represents a Style. */
                    class Style implements IStyle {

                        /**
                         * Constructs a new Style.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.IStyle);

                        /** Style textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1beta2.Document.ITextAnchor|null);

                        /** Style color. */
                        public color?: (google.type.IColor|null);

                        /** Style backgroundColor. */
                        public backgroundColor?: (google.type.IColor|null);

                        /** Style fontWeight. */
                        public fontWeight: string;

                        /** Style textStyle. */
                        public textStyle: string;

                        /** Style textDecoration. */
                        public textDecoration: string;

                        /** Style fontSize. */
                        public fontSize?: (google.cloud.documentai.v1beta2.Document.Style.IFontSize|null);

                        /** Style fontFamily. */
                        public fontFamily: string;

                        /**
                         * Creates a new Style instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Style instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.IStyle): google.cloud.documentai.v1beta2.Document.Style;

                        /**
                         * Encodes the specified Style message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Style.verify|verify} messages.
                         * @param message Style message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.IStyle, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Style message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Style.verify|verify} messages.
                         * @param message Style message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.IStyle, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Style message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Style
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Style;

                        /**
                         * Decodes a Style message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Style
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Style;

                        /**
                         * Verifies a Style message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Style message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Style
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Style;

                        /**
                         * Creates a plain object from a Style message. Also converts values to other types if specified.
                         * @param message Style
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.Style, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Style to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Style
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Style {

                        /** Properties of a FontSize. */
                        interface IFontSize {

                            /** FontSize size */
                            size?: (number|null);

                            /** FontSize unit */
                            unit?: (string|null);
                        }

                        /** Represents a FontSize. */
                        class FontSize implements IFontSize {

                            /**
                             * Constructs a new FontSize.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Style.IFontSize);

                            /** FontSize size. */
                            public size: number;

                            /** FontSize unit. */
                            public unit: string;

                            /**
                             * Creates a new FontSize instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FontSize instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Style.IFontSize): google.cloud.documentai.v1beta2.Document.Style.FontSize;

                            /**
                             * Encodes the specified FontSize message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Style.FontSize.verify|verify} messages.
                             * @param message FontSize message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Style.IFontSize, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FontSize message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Style.FontSize.verify|verify} messages.
                             * @param message FontSize message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Style.IFontSize, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FontSize message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FontSize
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Style.FontSize;

                            /**
                             * Decodes a FontSize message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FontSize
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Style.FontSize;

                            /**
                             * Verifies a FontSize message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FontSize message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FontSize
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Style.FontSize;

                            /**
                             * Creates a plain object from a FontSize message. Also converts values to other types if specified.
                             * @param message FontSize
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Style.FontSize, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FontSize to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FontSize
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a Page. */
                    interface IPage {

                        /** Page pageNumber */
                        pageNumber?: (number|null);

                        /** Page image */
                        image?: (google.cloud.documentai.v1beta2.Document.Page.IImage|null);

                        /** Page transforms */
                        transforms?: (google.cloud.documentai.v1beta2.Document.Page.IMatrix[]|null);

                        /** Page dimension */
                        dimension?: (google.cloud.documentai.v1beta2.Document.Page.IDimension|null);

                        /** Page layout */
                        layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                        /** Page detectedLanguages */
                        detectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);

                        /** Page blocks */
                        blocks?: (google.cloud.documentai.v1beta2.Document.Page.IBlock[]|null);

                        /** Page paragraphs */
                        paragraphs?: (google.cloud.documentai.v1beta2.Document.Page.IParagraph[]|null);

                        /** Page lines */
                        lines?: (google.cloud.documentai.v1beta2.Document.Page.ILine[]|null);

                        /** Page tokens */
                        tokens?: (google.cloud.documentai.v1beta2.Document.Page.IToken[]|null);

                        /** Page visualElements */
                        visualElements?: (google.cloud.documentai.v1beta2.Document.Page.IVisualElement[]|null);

                        /** Page tables */
                        tables?: (google.cloud.documentai.v1beta2.Document.Page.ITable[]|null);

                        /** Page formFields */
                        formFields?: (google.cloud.documentai.v1beta2.Document.Page.IFormField[]|null);

                        /** Page symbols */
                        symbols?: (google.cloud.documentai.v1beta2.Document.Page.ISymbol[]|null);

                        /** Page detectedBarcodes */
                        detectedBarcodes?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedBarcode[]|null);

                        /** Page imageQualityScores */
                        imageQualityScores?: (google.cloud.documentai.v1beta2.Document.Page.IImageQualityScores|null);

                        /** Page provenance */
                        provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);
                    }

                    /** Represents a Page. */
                    class Page implements IPage {

                        /**
                         * Constructs a new Page.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.IPage);

                        /** Page pageNumber. */
                        public pageNumber: number;

                        /** Page image. */
                        public image?: (google.cloud.documentai.v1beta2.Document.Page.IImage|null);

                        /** Page transforms. */
                        public transforms: google.cloud.documentai.v1beta2.Document.Page.IMatrix[];

                        /** Page dimension. */
                        public dimension?: (google.cloud.documentai.v1beta2.Document.Page.IDimension|null);

                        /** Page layout. */
                        public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                        /** Page detectedLanguages. */
                        public detectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                        /** Page blocks. */
                        public blocks: google.cloud.documentai.v1beta2.Document.Page.IBlock[];

                        /** Page paragraphs. */
                        public paragraphs: google.cloud.documentai.v1beta2.Document.Page.IParagraph[];

                        /** Page lines. */
                        public lines: google.cloud.documentai.v1beta2.Document.Page.ILine[];

                        /** Page tokens. */
                        public tokens: google.cloud.documentai.v1beta2.Document.Page.IToken[];

                        /** Page visualElements. */
                        public visualElements: google.cloud.documentai.v1beta2.Document.Page.IVisualElement[];

                        /** Page tables. */
                        public tables: google.cloud.documentai.v1beta2.Document.Page.ITable[];

                        /** Page formFields. */
                        public formFields: google.cloud.documentai.v1beta2.Document.Page.IFormField[];

                        /** Page symbols. */
                        public symbols: google.cloud.documentai.v1beta2.Document.Page.ISymbol[];

                        /** Page detectedBarcodes. */
                        public detectedBarcodes: google.cloud.documentai.v1beta2.Document.Page.IDetectedBarcode[];

                        /** Page imageQualityScores. */
                        public imageQualityScores?: (google.cloud.documentai.v1beta2.Document.Page.IImageQualityScores|null);

                        /** Page provenance. */
                        public provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                        /**
                         * Creates a new Page instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Page instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.IPage): google.cloud.documentai.v1beta2.Document.Page;

                        /**
                         * Encodes the specified Page message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.verify|verify} messages.
                         * @param message Page message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.IPage, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Page message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.verify|verify} messages.
                         * @param message Page message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.IPage, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Page message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Page
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page;

                        /**
                         * Decodes a Page message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Page
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page;

                        /**
                         * Verifies a Page message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Page message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Page
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page;

                        /**
                         * Creates a plain object from a Page message. Also converts values to other types if specified.
                         * @param message Page
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.Page, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Page to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Page
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Page {

                        /** Properties of a Dimension. */
                        interface IDimension {

                            /** Dimension width */
                            width?: (number|null);

                            /** Dimension height */
                            height?: (number|null);

                            /** Dimension unit */
                            unit?: (string|null);
                        }

                        /** Represents a Dimension. */
                        class Dimension implements IDimension {

                            /**
                             * Constructs a new Dimension.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IDimension);

                            /** Dimension width. */
                            public width: number;

                            /** Dimension height. */
                            public height: number;

                            /** Dimension unit. */
                            public unit: string;

                            /**
                             * Creates a new Dimension instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Dimension instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IDimension): google.cloud.documentai.v1beta2.Document.Page.Dimension;

                            /**
                             * Encodes the specified Dimension message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Dimension.verify|verify} messages.
                             * @param message Dimension message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IDimension, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Dimension message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Dimension.verify|verify} messages.
                             * @param message Dimension message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IDimension, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Dimension message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Dimension
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Dimension;

                            /**
                             * Decodes a Dimension message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Dimension
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Dimension;

                            /**
                             * Verifies a Dimension message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Dimension message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Dimension
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Dimension;

                            /**
                             * Creates a plain object from a Dimension message. Also converts values to other types if specified.
                             * @param message Dimension
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Dimension, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Dimension to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Dimension
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of an Image. */
                        interface IImage {

                            /** Image content */
                            content?: (Uint8Array|string|null);

                            /** Image mimeType */
                            mimeType?: (string|null);

                            /** Image width */
                            width?: (number|null);

                            /** Image height */
                            height?: (number|null);
                        }

                        /** Represents an Image. */
                        class Image implements IImage {

                            /**
                             * Constructs a new Image.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IImage);

                            /** Image content. */
                            public content: (Uint8Array|string);

                            /** Image mimeType. */
                            public mimeType: string;

                            /** Image width. */
                            public width: number;

                            /** Image height. */
                            public height: number;

                            /**
                             * Creates a new Image instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Image instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IImage): google.cloud.documentai.v1beta2.Document.Page.Image;

                            /**
                             * Encodes the specified Image message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Image.verify|verify} messages.
                             * @param message Image message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IImage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Image message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Image.verify|verify} messages.
                             * @param message Image message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IImage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes an Image message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Image
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Image;

                            /**
                             * Decodes an Image message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Image
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Image;

                            /**
                             * Verifies an Image message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates an Image message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Image
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Image;

                            /**
                             * Creates a plain object from an Image message. Also converts values to other types if specified.
                             * @param message Image
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Image, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Image to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Image
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Matrix. */
                        interface IMatrix {

                            /** Matrix rows */
                            rows?: (number|null);

                            /** Matrix cols */
                            cols?: (number|null);

                            /** Matrix type */
                            type?: (number|null);

                            /** Matrix data */
                            data?: (Uint8Array|string|null);
                        }

                        /** Represents a Matrix. */
                        class Matrix implements IMatrix {

                            /**
                             * Constructs a new Matrix.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IMatrix);

                            /** Matrix rows. */
                            public rows: number;

                            /** Matrix cols. */
                            public cols: number;

                            /** Matrix type. */
                            public type: number;

                            /** Matrix data. */
                            public data: (Uint8Array|string);

                            /**
                             * Creates a new Matrix instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Matrix instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IMatrix): google.cloud.documentai.v1beta2.Document.Page.Matrix;

                            /**
                             * Encodes the specified Matrix message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Matrix.verify|verify} messages.
                             * @param message Matrix message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IMatrix, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Matrix message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Matrix.verify|verify} messages.
                             * @param message Matrix message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IMatrix, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Matrix message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Matrix
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Matrix;

                            /**
                             * Decodes a Matrix message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Matrix
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Matrix;

                            /**
                             * Verifies a Matrix message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Matrix message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Matrix
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Matrix;

                            /**
                             * Creates a plain object from a Matrix message. Also converts values to other types if specified.
                             * @param message Matrix
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Matrix, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Matrix to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Matrix
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Layout. */
                        interface ILayout {

                            /** Layout textAnchor */
                            textAnchor?: (google.cloud.documentai.v1beta2.Document.ITextAnchor|null);

                            /** Layout confidence */
                            confidence?: (number|null);

                            /** Layout boundingPoly */
                            boundingPoly?: (google.cloud.documentai.v1beta2.IBoundingPoly|null);

                            /** Layout orientation */
                            orientation?: (google.cloud.documentai.v1beta2.Document.Page.Layout.Orientation|keyof typeof google.cloud.documentai.v1beta2.Document.Page.Layout.Orientation|null);
                        }

                        /** Represents a Layout. */
                        class Layout implements ILayout {

                            /**
                             * Constructs a new Layout.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.ILayout);

                            /** Layout textAnchor. */
                            public textAnchor?: (google.cloud.documentai.v1beta2.Document.ITextAnchor|null);

                            /** Layout confidence. */
                            public confidence: number;

                            /** Layout boundingPoly. */
                            public boundingPoly?: (google.cloud.documentai.v1beta2.IBoundingPoly|null);

                            /** Layout orientation. */
                            public orientation: (google.cloud.documentai.v1beta2.Document.Page.Layout.Orientation|keyof typeof google.cloud.documentai.v1beta2.Document.Page.Layout.Orientation);

                            /**
                             * Creates a new Layout instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Layout instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.ILayout): google.cloud.documentai.v1beta2.Document.Page.Layout;

                            /**
                             * Encodes the specified Layout message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Layout.verify|verify} messages.
                             * @param message Layout message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.ILayout, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Layout message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Layout.verify|verify} messages.
                             * @param message Layout message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.ILayout, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Layout message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Layout
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Layout;

                            /**
                             * Decodes a Layout message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Layout
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Layout;

                            /**
                             * Verifies a Layout message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Layout message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Layout
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Layout;

                            /**
                             * Creates a plain object from a Layout message. Also converts values to other types if specified.
                             * @param message Layout
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Layout, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Layout to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Layout
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Layout {

                            /** Orientation enum. */
                            enum Orientation {
                                ORIENTATION_UNSPECIFIED = 0,
                                PAGE_UP = 1,
                                PAGE_RIGHT = 2,
                                PAGE_DOWN = 3,
                                PAGE_LEFT = 4
                            }
                        }

                        /** Properties of a Block. */
                        interface IBlock {

                            /** Block layout */
                            layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Block detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);

                            /** Block provenance */
                            provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);
                        }

                        /** Represents a Block. */
                        class Block implements IBlock {

                            /**
                             * Constructs a new Block.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IBlock);

                            /** Block layout. */
                            public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Block detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                            /** Block provenance. */
                            public provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                            /**
                             * Creates a new Block instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Block instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IBlock): google.cloud.documentai.v1beta2.Document.Page.Block;

                            /**
                             * Encodes the specified Block message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Block.verify|verify} messages.
                             * @param message Block message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Block message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Block.verify|verify} messages.
                             * @param message Block message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Block message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Block
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Block;

                            /**
                             * Decodes a Block message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Block
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Block;

                            /**
                             * Verifies a Block message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Block message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Block
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Block;

                            /**
                             * Creates a plain object from a Block message. Also converts values to other types if specified.
                             * @param message Block
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Block, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Block to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Block
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Paragraph. */
                        interface IParagraph {

                            /** Paragraph layout */
                            layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Paragraph detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);

                            /** Paragraph provenance */
                            provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);
                        }

                        /** Represents a Paragraph. */
                        class Paragraph implements IParagraph {

                            /**
                             * Constructs a new Paragraph.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IParagraph);

                            /** Paragraph layout. */
                            public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Paragraph detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                            /** Paragraph provenance. */
                            public provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                            /**
                             * Creates a new Paragraph instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Paragraph instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IParagraph): google.cloud.documentai.v1beta2.Document.Page.Paragraph;

                            /**
                             * Encodes the specified Paragraph message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Paragraph.verify|verify} messages.
                             * @param message Paragraph message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IParagraph, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Paragraph message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Paragraph.verify|verify} messages.
                             * @param message Paragraph message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IParagraph, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Paragraph message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Paragraph
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Paragraph;

                            /**
                             * Decodes a Paragraph message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Paragraph
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Paragraph;

                            /**
                             * Verifies a Paragraph message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Paragraph message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Paragraph
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Paragraph;

                            /**
                             * Creates a plain object from a Paragraph message. Also converts values to other types if specified.
                             * @param message Paragraph
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Paragraph, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Paragraph to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Paragraph
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Line. */
                        interface ILine {

                            /** Line layout */
                            layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Line detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);

                            /** Line provenance */
                            provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);
                        }

                        /** Represents a Line. */
                        class Line implements ILine {

                            /**
                             * Constructs a new Line.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.ILine);

                            /** Line layout. */
                            public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Line detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                            /** Line provenance. */
                            public provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                            /**
                             * Creates a new Line instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Line instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.ILine): google.cloud.documentai.v1beta2.Document.Page.Line;

                            /**
                             * Encodes the specified Line message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Line.verify|verify} messages.
                             * @param message Line message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.ILine, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Line message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Line.verify|verify} messages.
                             * @param message Line message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.ILine, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Line message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Line
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Line;

                            /**
                             * Decodes a Line message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Line
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Line;

                            /**
                             * Verifies a Line message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Line message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Line
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Line;

                            /**
                             * Creates a plain object from a Line message. Also converts values to other types if specified.
                             * @param message Line
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Line, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Line to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Line
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Token. */
                        interface IToken {

                            /** Token layout */
                            layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Token detectedBreak */
                            detectedBreak?: (google.cloud.documentai.v1beta2.Document.Page.Token.IDetectedBreak|null);

                            /** Token detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);

                            /** Token provenance */
                            provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                            /** Token styleInfo */
                            styleInfo?: (google.cloud.documentai.v1beta2.Document.Page.Token.IStyleInfo|null);
                        }

                        /** Represents a Token. */
                        class Token implements IToken {

                            /**
                             * Constructs a new Token.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IToken);

                            /** Token layout. */
                            public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Token detectedBreak. */
                            public detectedBreak?: (google.cloud.documentai.v1beta2.Document.Page.Token.IDetectedBreak|null);

                            /** Token detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                            /** Token provenance. */
                            public provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                            /** Token styleInfo. */
                            public styleInfo?: (google.cloud.documentai.v1beta2.Document.Page.Token.IStyleInfo|null);

                            /**
                             * Creates a new Token instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Token instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IToken): google.cloud.documentai.v1beta2.Document.Page.Token;

                            /**
                             * Encodes the specified Token message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Token.verify|verify} messages.
                             * @param message Token message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IToken, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Token message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Token.verify|verify} messages.
                             * @param message Token message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IToken, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Token message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Token
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Token;

                            /**
                             * Decodes a Token message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Token
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Token;

                            /**
                             * Verifies a Token message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Token message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Token
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Token;

                            /**
                             * Creates a plain object from a Token message. Also converts values to other types if specified.
                             * @param message Token
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Token, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Token to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Token
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Token {

                            /** Properties of a DetectedBreak. */
                            interface IDetectedBreak {

                                /** DetectedBreak type */
                                type?: (google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak.Type|keyof typeof google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak.Type|null);
                            }

                            /** Represents a DetectedBreak. */
                            class DetectedBreak implements IDetectedBreak {

                                /**
                                 * Constructs a new DetectedBreak.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.Token.IDetectedBreak);

                                /** DetectedBreak type. */
                                public type: (google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak.Type|keyof typeof google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak.Type);

                                /**
                                 * Creates a new DetectedBreak instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns DetectedBreak instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.Token.IDetectedBreak): google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak;

                                /**
                                 * Encodes the specified DetectedBreak message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak.verify|verify} messages.
                                 * @param message DetectedBreak message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta2.Document.Page.Token.IDetectedBreak, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified DetectedBreak message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak.verify|verify} messages.
                                 * @param message DetectedBreak message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.Token.IDetectedBreak, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a DetectedBreak message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns DetectedBreak
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak;

                                /**
                                 * Decodes a DetectedBreak message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns DetectedBreak
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak;

                                /**
                                 * Verifies a DetectedBreak message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a DetectedBreak message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns DetectedBreak
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak;

                                /**
                                 * Creates a plain object from a DetectedBreak message. Also converts values to other types if specified.
                                 * @param message DetectedBreak
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Token.DetectedBreak, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this DetectedBreak to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for DetectedBreak
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            namespace DetectedBreak {

                                /** Type enum. */
                                enum Type {
                                    TYPE_UNSPECIFIED = 0,
                                    SPACE = 1,
                                    WIDE_SPACE = 2,
                                    HYPHEN = 3
                                }
                            }

                            /** Properties of a StyleInfo. */
                            interface IStyleInfo {

                                /** StyleInfo fontSize */
                                fontSize?: (number|null);

                                /** StyleInfo pixelFontSize */
                                pixelFontSize?: (number|null);

                                /** StyleInfo letterSpacing */
                                letterSpacing?: (number|null);

                                /** StyleInfo fontType */
                                fontType?: (string|null);

                                /** StyleInfo bold */
                                bold?: (boolean|null);

                                /** StyleInfo italic */
                                italic?: (boolean|null);

                                /** StyleInfo underlined */
                                underlined?: (boolean|null);

                                /** StyleInfo strikeout */
                                strikeout?: (boolean|null);

                                /** StyleInfo subscript */
                                subscript?: (boolean|null);

                                /** StyleInfo superscript */
                                superscript?: (boolean|null);

                                /** StyleInfo smallcaps */
                                smallcaps?: (boolean|null);

                                /** StyleInfo fontWeight */
                                fontWeight?: (number|null);

                                /** StyleInfo handwritten */
                                handwritten?: (boolean|null);

                                /** StyleInfo textColor */
                                textColor?: (google.type.IColor|null);

                                /** StyleInfo backgroundColor */
                                backgroundColor?: (google.type.IColor|null);
                            }

                            /** Represents a StyleInfo. */
                            class StyleInfo implements IStyleInfo {

                                /**
                                 * Constructs a new StyleInfo.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.Token.IStyleInfo);

                                /** StyleInfo fontSize. */
                                public fontSize: number;

                                /** StyleInfo pixelFontSize. */
                                public pixelFontSize: number;

                                /** StyleInfo letterSpacing. */
                                public letterSpacing: number;

                                /** StyleInfo fontType. */
                                public fontType: string;

                                /** StyleInfo bold. */
                                public bold: boolean;

                                /** StyleInfo italic. */
                                public italic: boolean;

                                /** StyleInfo underlined. */
                                public underlined: boolean;

                                /** StyleInfo strikeout. */
                                public strikeout: boolean;

                                /** StyleInfo subscript. */
                                public subscript: boolean;

                                /** StyleInfo superscript. */
                                public superscript: boolean;

                                /** StyleInfo smallcaps. */
                                public smallcaps: boolean;

                                /** StyleInfo fontWeight. */
                                public fontWeight: number;

                                /** StyleInfo handwritten. */
                                public handwritten: boolean;

                                /** StyleInfo textColor. */
                                public textColor?: (google.type.IColor|null);

                                /** StyleInfo backgroundColor. */
                                public backgroundColor?: (google.type.IColor|null);

                                /**
                                 * Creates a new StyleInfo instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns StyleInfo instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.Token.IStyleInfo): google.cloud.documentai.v1beta2.Document.Page.Token.StyleInfo;

                                /**
                                 * Encodes the specified StyleInfo message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Token.StyleInfo.verify|verify} messages.
                                 * @param message StyleInfo message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta2.Document.Page.Token.IStyleInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified StyleInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Token.StyleInfo.verify|verify} messages.
                                 * @param message StyleInfo message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.Token.IStyleInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a StyleInfo message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns StyleInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Token.StyleInfo;

                                /**
                                 * Decodes a StyleInfo message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns StyleInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Token.StyleInfo;

                                /**
                                 * Verifies a StyleInfo message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a StyleInfo message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns StyleInfo
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Token.StyleInfo;

                                /**
                                 * Creates a plain object from a StyleInfo message. Also converts values to other types if specified.
                                 * @param message StyleInfo
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Token.StyleInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this StyleInfo to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for StyleInfo
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }

                        /** Properties of a Symbol. */
                        interface ISymbol {

                            /** Symbol layout */
                            layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Symbol detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a Symbol. */
                        class Symbol implements ISymbol {

                            /**
                             * Constructs a new Symbol.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.ISymbol);

                            /** Symbol layout. */
                            public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Symbol detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new Symbol instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Symbol instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.ISymbol): google.cloud.documentai.v1beta2.Document.Page.Symbol;

                            /**
                             * Encodes the specified Symbol message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Symbol.verify|verify} messages.
                             * @param message Symbol message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.ISymbol, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Symbol message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Symbol.verify|verify} messages.
                             * @param message Symbol message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.ISymbol, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Symbol message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Symbol
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Symbol;

                            /**
                             * Decodes a Symbol message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Symbol
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Symbol;

                            /**
                             * Verifies a Symbol message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Symbol message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Symbol
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Symbol;

                            /**
                             * Creates a plain object from a Symbol message. Also converts values to other types if specified.
                             * @param message Symbol
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Symbol, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Symbol to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Symbol
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a VisualElement. */
                        interface IVisualElement {

                            /** VisualElement layout */
                            layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** VisualElement type */
                            type?: (string|null);

                            /** VisualElement detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a VisualElement. */
                        class VisualElement implements IVisualElement {

                            /**
                             * Constructs a new VisualElement.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IVisualElement);

                            /** VisualElement layout. */
                            public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** VisualElement type. */
                            public type: string;

                            /** VisualElement detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new VisualElement instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns VisualElement instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IVisualElement): google.cloud.documentai.v1beta2.Document.Page.VisualElement;

                            /**
                             * Encodes the specified VisualElement message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.VisualElement.verify|verify} messages.
                             * @param message VisualElement message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IVisualElement, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified VisualElement message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.VisualElement.verify|verify} messages.
                             * @param message VisualElement message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IVisualElement, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a VisualElement message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns VisualElement
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.VisualElement;

                            /**
                             * Decodes a VisualElement message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns VisualElement
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.VisualElement;

                            /**
                             * Verifies a VisualElement message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a VisualElement message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns VisualElement
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.VisualElement;

                            /**
                             * Creates a plain object from a VisualElement message. Also converts values to other types if specified.
                             * @param message VisualElement
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.VisualElement, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this VisualElement to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for VisualElement
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Table. */
                        interface ITable {

                            /** Table layout */
                            layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Table headerRows */
                            headerRows?: (google.cloud.documentai.v1beta2.Document.Page.Table.ITableRow[]|null);

                            /** Table bodyRows */
                            bodyRows?: (google.cloud.documentai.v1beta2.Document.Page.Table.ITableRow[]|null);

                            /** Table detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);

                            /** Table provenance */
                            provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);
                        }

                        /** Represents a Table. */
                        class Table implements ITable {

                            /**
                             * Constructs a new Table.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.ITable);

                            /** Table layout. */
                            public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** Table headerRows. */
                            public headerRows: google.cloud.documentai.v1beta2.Document.Page.Table.ITableRow[];

                            /** Table bodyRows. */
                            public bodyRows: google.cloud.documentai.v1beta2.Document.Page.Table.ITableRow[];

                            /** Table detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                            /** Table provenance. */
                            public provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                            /**
                             * Creates a new Table instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Table instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.ITable): google.cloud.documentai.v1beta2.Document.Page.Table;

                            /**
                             * Encodes the specified Table message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Table.verify|verify} messages.
                             * @param message Table message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.ITable, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Table message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Table.verify|verify} messages.
                             * @param message Table message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.ITable, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Table message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Table
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Table;

                            /**
                             * Decodes a Table message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Table
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Table;

                            /**
                             * Verifies a Table message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Table message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Table
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Table;

                            /**
                             * Creates a plain object from a Table message. Also converts values to other types if specified.
                             * @param message Table
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Table, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Table to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Table
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Table {

                            /** Properties of a TableRow. */
                            interface ITableRow {

                                /** TableRow cells */
                                cells?: (google.cloud.documentai.v1beta2.Document.Page.Table.ITableCell[]|null);
                            }

                            /** Represents a TableRow. */
                            class TableRow implements ITableRow {

                                /**
                                 * Constructs a new TableRow.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.Table.ITableRow);

                                /** TableRow cells. */
                                public cells: google.cloud.documentai.v1beta2.Document.Page.Table.ITableCell[];

                                /**
                                 * Creates a new TableRow instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns TableRow instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.Table.ITableRow): google.cloud.documentai.v1beta2.Document.Page.Table.TableRow;

                                /**
                                 * Encodes the specified TableRow message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Table.TableRow.verify|verify} messages.
                                 * @param message TableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta2.Document.Page.Table.ITableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified TableRow message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Table.TableRow.verify|verify} messages.
                                 * @param message TableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.Table.ITableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a TableRow message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns TableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Table.TableRow;

                                /**
                                 * Decodes a TableRow message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns TableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Table.TableRow;

                                /**
                                 * Verifies a TableRow message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a TableRow message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns TableRow
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Table.TableRow;

                                /**
                                 * Creates a plain object from a TableRow message. Also converts values to other types if specified.
                                 * @param message TableRow
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Table.TableRow, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this TableRow to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for TableRow
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a TableCell. */
                            interface ITableCell {

                                /** TableCell layout */
                                layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                                /** TableCell rowSpan */
                                rowSpan?: (number|null);

                                /** TableCell colSpan */
                                colSpan?: (number|null);

                                /** TableCell detectedLanguages */
                                detectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);
                            }

                            /** Represents a TableCell. */
                            class TableCell implements ITableCell {

                                /**
                                 * Constructs a new TableCell.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.Table.ITableCell);

                                /** TableCell layout. */
                                public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                                /** TableCell rowSpan. */
                                public rowSpan: number;

                                /** TableCell colSpan. */
                                public colSpan: number;

                                /** TableCell detectedLanguages. */
                                public detectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                                /**
                                 * Creates a new TableCell instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns TableCell instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.Table.ITableCell): google.cloud.documentai.v1beta2.Document.Page.Table.TableCell;

                                /**
                                 * Encodes the specified TableCell message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Table.TableCell.verify|verify} messages.
                                 * @param message TableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta2.Document.Page.Table.ITableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified TableCell message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.Table.TableCell.verify|verify} messages.
                                 * @param message TableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.Table.ITableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a TableCell message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns TableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.Table.TableCell;

                                /**
                                 * Decodes a TableCell message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns TableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.Table.TableCell;

                                /**
                                 * Verifies a TableCell message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a TableCell message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns TableCell
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.Table.TableCell;

                                /**
                                 * Creates a plain object from a TableCell message. Also converts values to other types if specified.
                                 * @param message TableCell
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.Table.TableCell, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this TableCell to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for TableCell
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }

                        /** Properties of a FormField. */
                        interface IFormField {

                            /** FormField fieldName */
                            fieldName?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** FormField fieldValue */
                            fieldValue?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** FormField nameDetectedLanguages */
                            nameDetectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);

                            /** FormField valueDetectedLanguages */
                            valueDetectedLanguages?: (google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[]|null);

                            /** FormField valueType */
                            valueType?: (string|null);

                            /** FormField correctedKeyText */
                            correctedKeyText?: (string|null);

                            /** FormField correctedValueText */
                            correctedValueText?: (string|null);

                            /** FormField provenance */
                            provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);
                        }

                        /** Represents a FormField. */
                        class FormField implements IFormField {

                            /**
                             * Constructs a new FormField.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IFormField);

                            /** FormField fieldName. */
                            public fieldName?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** FormField fieldValue. */
                            public fieldValue?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** FormField nameDetectedLanguages. */
                            public nameDetectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                            /** FormField valueDetectedLanguages. */
                            public valueDetectedLanguages: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage[];

                            /** FormField valueType. */
                            public valueType: string;

                            /** FormField correctedKeyText. */
                            public correctedKeyText: string;

                            /** FormField correctedValueText. */
                            public correctedValueText: string;

                            /** FormField provenance. */
                            public provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                            /**
                             * Creates a new FormField instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FormField instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IFormField): google.cloud.documentai.v1beta2.Document.Page.FormField;

                            /**
                             * Encodes the specified FormField message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.FormField.verify|verify} messages.
                             * @param message FormField message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IFormField, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FormField message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.FormField.verify|verify} messages.
                             * @param message FormField message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IFormField, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FormField message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FormField
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.FormField;

                            /**
                             * Decodes a FormField message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FormField
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.FormField;

                            /**
                             * Verifies a FormField message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FormField message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FormField
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.FormField;

                            /**
                             * Creates a plain object from a FormField message. Also converts values to other types if specified.
                             * @param message FormField
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.FormField, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FormField to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FormField
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a DetectedBarcode. */
                        interface IDetectedBarcode {

                            /** DetectedBarcode layout */
                            layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** DetectedBarcode barcode */
                            barcode?: (google.cloud.documentai.v1beta2.IBarcode|null);
                        }

                        /** Represents a DetectedBarcode. */
                        class DetectedBarcode implements IDetectedBarcode {

                            /**
                             * Constructs a new DetectedBarcode.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IDetectedBarcode);

                            /** DetectedBarcode layout. */
                            public layout?: (google.cloud.documentai.v1beta2.Document.Page.ILayout|null);

                            /** DetectedBarcode barcode. */
                            public barcode?: (google.cloud.documentai.v1beta2.IBarcode|null);

                            /**
                             * Creates a new DetectedBarcode instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns DetectedBarcode instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IDetectedBarcode): google.cloud.documentai.v1beta2.Document.Page.DetectedBarcode;

                            /**
                             * Encodes the specified DetectedBarcode message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.DetectedBarcode.verify|verify} messages.
                             * @param message DetectedBarcode message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IDetectedBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified DetectedBarcode message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.DetectedBarcode.verify|verify} messages.
                             * @param message DetectedBarcode message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IDetectedBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a DetectedBarcode message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns DetectedBarcode
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.DetectedBarcode;

                            /**
                             * Decodes a DetectedBarcode message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns DetectedBarcode
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.DetectedBarcode;

                            /**
                             * Verifies a DetectedBarcode message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a DetectedBarcode message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns DetectedBarcode
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.DetectedBarcode;

                            /**
                             * Creates a plain object from a DetectedBarcode message. Also converts values to other types if specified.
                             * @param message DetectedBarcode
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.DetectedBarcode, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this DetectedBarcode to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for DetectedBarcode
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a DetectedLanguage. */
                        interface IDetectedLanguage {

                            /** DetectedLanguage languageCode */
                            languageCode?: (string|null);

                            /** DetectedLanguage confidence */
                            confidence?: (number|null);
                        }

                        /** Represents a DetectedLanguage. */
                        class DetectedLanguage implements IDetectedLanguage {

                            /**
                             * Constructs a new DetectedLanguage.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage);

                            /** DetectedLanguage languageCode. */
                            public languageCode: string;

                            /** DetectedLanguage confidence. */
                            public confidence: number;

                            /**
                             * Creates a new DetectedLanguage instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns DetectedLanguage instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage): google.cloud.documentai.v1beta2.Document.Page.DetectedLanguage;

                            /**
                             * Encodes the specified DetectedLanguage message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.DetectedLanguage.verify|verify} messages.
                             * @param message DetectedLanguage message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified DetectedLanguage message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.DetectedLanguage.verify|verify} messages.
                             * @param message DetectedLanguage message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IDetectedLanguage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a DetectedLanguage message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns DetectedLanguage
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.DetectedLanguage;

                            /**
                             * Decodes a DetectedLanguage message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns DetectedLanguage
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.DetectedLanguage;

                            /**
                             * Verifies a DetectedLanguage message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a DetectedLanguage message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns DetectedLanguage
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.DetectedLanguage;

                            /**
                             * Creates a plain object from a DetectedLanguage message. Also converts values to other types if specified.
                             * @param message DetectedLanguage
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.DetectedLanguage, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this DetectedLanguage to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for DetectedLanguage
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of an ImageQualityScores. */
                        interface IImageQualityScores {

                            /** ImageQualityScores qualityScore */
                            qualityScore?: (number|null);

                            /** ImageQualityScores detectedDefects */
                            detectedDefects?: (google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.IDetectedDefect[]|null);
                        }

                        /** Represents an ImageQualityScores. */
                        class ImageQualityScores implements IImageQualityScores {

                            /**
                             * Constructs a new ImageQualityScores.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.IImageQualityScores);

                            /** ImageQualityScores qualityScore. */
                            public qualityScore: number;

                            /** ImageQualityScores detectedDefects. */
                            public detectedDefects: google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.IDetectedDefect[];

                            /**
                             * Creates a new ImageQualityScores instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns ImageQualityScores instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.IImageQualityScores): google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores;

                            /**
                             * Encodes the specified ImageQualityScores message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.verify|verify} messages.
                             * @param message ImageQualityScores message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Page.IImageQualityScores, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified ImageQualityScores message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.verify|verify} messages.
                             * @param message ImageQualityScores message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.IImageQualityScores, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes an ImageQualityScores message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns ImageQualityScores
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores;

                            /**
                             * Decodes an ImageQualityScores message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns ImageQualityScores
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores;

                            /**
                             * Verifies an ImageQualityScores message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates an ImageQualityScores message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns ImageQualityScores
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores;

                            /**
                             * Creates a plain object from an ImageQualityScores message. Also converts values to other types if specified.
                             * @param message ImageQualityScores
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this ImageQualityScores to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for ImageQualityScores
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace ImageQualityScores {

                            /** Properties of a DetectedDefect. */
                            interface IDetectedDefect {

                                /** DetectedDefect type */
                                type?: (string|null);

                                /** DetectedDefect confidence */
                                confidence?: (number|null);
                            }

                            /** Represents a DetectedDefect. */
                            class DetectedDefect implements IDetectedDefect {

                                /**
                                 * Constructs a new DetectedDefect.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.IDetectedDefect);

                                /** DetectedDefect type. */
                                public type: string;

                                /** DetectedDefect confidence. */
                                public confidence: number;

                                /**
                                 * Creates a new DetectedDefect instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns DetectedDefect instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.IDetectedDefect): google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Encodes the specified DetectedDefect message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.DetectedDefect.verify|verify} messages.
                                 * @param message DetectedDefect message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.IDetectedDefect, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified DetectedDefect message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.DetectedDefect.verify|verify} messages.
                                 * @param message DetectedDefect message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.IDetectedDefect, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a DetectedDefect message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns DetectedDefect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Decodes a DetectedDefect message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns DetectedDefect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Verifies a DetectedDefect message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a DetectedDefect message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns DetectedDefect
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Creates a plain object from a DetectedDefect message. Also converts values to other types if specified.
                                 * @param message DetectedDefect
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta2.Document.Page.ImageQualityScores.DetectedDefect, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this DetectedDefect to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for DetectedDefect
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }
                    }

                    /** Properties of an Entity. */
                    interface IEntity {

                        /** Entity textAnchor */
                        textAnchor?: (google.cloud.documentai.v1beta2.Document.ITextAnchor|null);

                        /** Entity type */
                        type?: (string|null);

                        /** Entity mentionText */
                        mentionText?: (string|null);

                        /** Entity mentionId */
                        mentionId?: (string|null);

                        /** Entity confidence */
                        confidence?: (number|null);

                        /** Entity pageAnchor */
                        pageAnchor?: (google.cloud.documentai.v1beta2.Document.IPageAnchor|null);

                        /** Entity id */
                        id?: (string|null);

                        /** Entity normalizedValue */
                        normalizedValue?: (google.cloud.documentai.v1beta2.Document.Entity.INormalizedValue|null);

                        /** Entity properties */
                        properties?: (google.cloud.documentai.v1beta2.Document.IEntity[]|null);

                        /** Entity provenance */
                        provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                        /** Entity redacted */
                        redacted?: (boolean|null);
                    }

                    /** Represents an Entity. */
                    class Entity implements IEntity {

                        /**
                         * Constructs a new Entity.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.IEntity);

                        /** Entity textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1beta2.Document.ITextAnchor|null);

                        /** Entity type. */
                        public type: string;

                        /** Entity mentionText. */
                        public mentionText: string;

                        /** Entity mentionId. */
                        public mentionId: string;

                        /** Entity confidence. */
                        public confidence: number;

                        /** Entity pageAnchor. */
                        public pageAnchor?: (google.cloud.documentai.v1beta2.Document.IPageAnchor|null);

                        /** Entity id. */
                        public id: string;

                        /** Entity normalizedValue. */
                        public normalizedValue?: (google.cloud.documentai.v1beta2.Document.Entity.INormalizedValue|null);

                        /** Entity properties. */
                        public properties: google.cloud.documentai.v1beta2.Document.IEntity[];

                        /** Entity provenance. */
                        public provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance|null);

                        /** Entity redacted. */
                        public redacted: boolean;

                        /**
                         * Creates a new Entity instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Entity instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.IEntity): google.cloud.documentai.v1beta2.Document.Entity;

                        /**
                         * Encodes the specified Entity message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Entity.verify|verify} messages.
                         * @param message Entity message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.IEntity, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Entity message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Entity.verify|verify} messages.
                         * @param message Entity message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.IEntity, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an Entity message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Entity
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Entity;

                        /**
                         * Decodes an Entity message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Entity
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Entity;

                        /**
                         * Verifies an Entity message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an Entity message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Entity
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Entity;

                        /**
                         * Creates a plain object from an Entity message. Also converts values to other types if specified.
                         * @param message Entity
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.Entity, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Entity to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Entity
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Entity {

                        /** Properties of a NormalizedValue. */
                        interface INormalizedValue {

                            /** NormalizedValue moneyValue */
                            moneyValue?: (google.type.IMoney|null);

                            /** NormalizedValue dateValue */
                            dateValue?: (google.type.IDate|null);

                            /** NormalizedValue datetimeValue */
                            datetimeValue?: (google.type.IDateTime|null);

                            /** NormalizedValue addressValue */
                            addressValue?: (google.type.IPostalAddress|null);

                            /** NormalizedValue booleanValue */
                            booleanValue?: (boolean|null);

                            /** NormalizedValue integerValue */
                            integerValue?: (number|null);

                            /** NormalizedValue floatValue */
                            floatValue?: (number|null);

                            /** NormalizedValue text */
                            text?: (string|null);
                        }

                        /** Represents a NormalizedValue. */
                        class NormalizedValue implements INormalizedValue {

                            /**
                             * Constructs a new NormalizedValue.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Entity.INormalizedValue);

                            /** NormalizedValue moneyValue. */
                            public moneyValue?: (google.type.IMoney|null);

                            /** NormalizedValue dateValue. */
                            public dateValue?: (google.type.IDate|null);

                            /** NormalizedValue datetimeValue. */
                            public datetimeValue?: (google.type.IDateTime|null);

                            /** NormalizedValue addressValue. */
                            public addressValue?: (google.type.IPostalAddress|null);

                            /** NormalizedValue booleanValue. */
                            public booleanValue?: (boolean|null);

                            /** NormalizedValue integerValue. */
                            public integerValue?: (number|null);

                            /** NormalizedValue floatValue. */
                            public floatValue?: (number|null);

                            /** NormalizedValue text. */
                            public text: string;

                            /** NormalizedValue structuredValue. */
                            public structuredValue?: ("moneyValue"|"dateValue"|"datetimeValue"|"addressValue"|"booleanValue"|"integerValue"|"floatValue");

                            /**
                             * Creates a new NormalizedValue instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns NormalizedValue instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Entity.INormalizedValue): google.cloud.documentai.v1beta2.Document.Entity.NormalizedValue;

                            /**
                             * Encodes the specified NormalizedValue message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Entity.NormalizedValue.verify|verify} messages.
                             * @param message NormalizedValue message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Entity.INormalizedValue, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified NormalizedValue message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Entity.NormalizedValue.verify|verify} messages.
                             * @param message NormalizedValue message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Entity.INormalizedValue, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a NormalizedValue message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns NormalizedValue
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Entity.NormalizedValue;

                            /**
                             * Decodes a NormalizedValue message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns NormalizedValue
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Entity.NormalizedValue;

                            /**
                             * Verifies a NormalizedValue message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a NormalizedValue message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns NormalizedValue
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Entity.NormalizedValue;

                            /**
                             * Creates a plain object from a NormalizedValue message. Also converts values to other types if specified.
                             * @param message NormalizedValue
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Entity.NormalizedValue, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this NormalizedValue to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for NormalizedValue
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of an EntityRelation. */
                    interface IEntityRelation {

                        /** EntityRelation subjectId */
                        subjectId?: (string|null);

                        /** EntityRelation objectId */
                        objectId?: (string|null);

                        /** EntityRelation relation */
                        relation?: (string|null);
                    }

                    /** Represents an EntityRelation. */
                    class EntityRelation implements IEntityRelation {

                        /**
                         * Constructs a new EntityRelation.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.IEntityRelation);

                        /** EntityRelation subjectId. */
                        public subjectId: string;

                        /** EntityRelation objectId. */
                        public objectId: string;

                        /** EntityRelation relation. */
                        public relation: string;

                        /**
                         * Creates a new EntityRelation instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns EntityRelation instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.IEntityRelation): google.cloud.documentai.v1beta2.Document.EntityRelation;

                        /**
                         * Encodes the specified EntityRelation message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.EntityRelation.verify|verify} messages.
                         * @param message EntityRelation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.IEntityRelation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified EntityRelation message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.EntityRelation.verify|verify} messages.
                         * @param message EntityRelation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.IEntityRelation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an EntityRelation message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns EntityRelation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.EntityRelation;

                        /**
                         * Decodes an EntityRelation message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns EntityRelation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.EntityRelation;

                        /**
                         * Verifies an EntityRelation message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an EntityRelation message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns EntityRelation
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.EntityRelation;

                        /**
                         * Creates a plain object from an EntityRelation message. Also converts values to other types if specified.
                         * @param message EntityRelation
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.EntityRelation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this EntityRelation to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for EntityRelation
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a TextAnchor. */
                    interface ITextAnchor {

                        /** TextAnchor textSegments */
                        textSegments?: (google.cloud.documentai.v1beta2.Document.TextAnchor.ITextSegment[]|null);

                        /** TextAnchor content */
                        content?: (string|null);
                    }

                    /** Represents a TextAnchor. */
                    class TextAnchor implements ITextAnchor {

                        /**
                         * Constructs a new TextAnchor.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.ITextAnchor);

                        /** TextAnchor textSegments. */
                        public textSegments: google.cloud.documentai.v1beta2.Document.TextAnchor.ITextSegment[];

                        /** TextAnchor content. */
                        public content: string;

                        /**
                         * Creates a new TextAnchor instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns TextAnchor instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.ITextAnchor): google.cloud.documentai.v1beta2.Document.TextAnchor;

                        /**
                         * Encodes the specified TextAnchor message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.TextAnchor.verify|verify} messages.
                         * @param message TextAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.ITextAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified TextAnchor message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.TextAnchor.verify|verify} messages.
                         * @param message TextAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.ITextAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a TextAnchor message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns TextAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.TextAnchor;

                        /**
                         * Decodes a TextAnchor message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns TextAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.TextAnchor;

                        /**
                         * Verifies a TextAnchor message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a TextAnchor message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns TextAnchor
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.TextAnchor;

                        /**
                         * Creates a plain object from a TextAnchor message. Also converts values to other types if specified.
                         * @param message TextAnchor
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.TextAnchor, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this TextAnchor to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for TextAnchor
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace TextAnchor {

                        /** Properties of a TextSegment. */
                        interface ITextSegment {

                            /** TextSegment startIndex */
                            startIndex?: (number|Long|string|null);

                            /** TextSegment endIndex */
                            endIndex?: (number|Long|string|null);
                        }

                        /** Represents a TextSegment. */
                        class TextSegment implements ITextSegment {

                            /**
                             * Constructs a new TextSegment.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.TextAnchor.ITextSegment);

                            /** TextSegment startIndex. */
                            public startIndex: (number|Long|string);

                            /** TextSegment endIndex. */
                            public endIndex: (number|Long|string);

                            /**
                             * Creates a new TextSegment instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns TextSegment instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.TextAnchor.ITextSegment): google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment;

                            /**
                             * Encodes the specified TextSegment message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment.verify|verify} messages.
                             * @param message TextSegment message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.TextAnchor.ITextSegment, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified TextSegment message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment.verify|verify} messages.
                             * @param message TextSegment message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.TextAnchor.ITextSegment, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a TextSegment message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns TextSegment
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment;

                            /**
                             * Decodes a TextSegment message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns TextSegment
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment;

                            /**
                             * Verifies a TextSegment message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a TextSegment message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns TextSegment
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment;

                            /**
                             * Creates a plain object from a TextSegment message. Also converts values to other types if specified.
                             * @param message TextSegment
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.TextAnchor.TextSegment, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this TextSegment to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for TextSegment
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a PageAnchor. */
                    interface IPageAnchor {

                        /** PageAnchor pageRefs */
                        pageRefs?: (google.cloud.documentai.v1beta2.Document.PageAnchor.IPageRef[]|null);
                    }

                    /** Represents a PageAnchor. */
                    class PageAnchor implements IPageAnchor {

                        /**
                         * Constructs a new PageAnchor.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.IPageAnchor);

                        /** PageAnchor pageRefs. */
                        public pageRefs: google.cloud.documentai.v1beta2.Document.PageAnchor.IPageRef[];

                        /**
                         * Creates a new PageAnchor instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns PageAnchor instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.IPageAnchor): google.cloud.documentai.v1beta2.Document.PageAnchor;

                        /**
                         * Encodes the specified PageAnchor message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.PageAnchor.verify|verify} messages.
                         * @param message PageAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.IPageAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified PageAnchor message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.PageAnchor.verify|verify} messages.
                         * @param message PageAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.IPageAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a PageAnchor message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns PageAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.PageAnchor;

                        /**
                         * Decodes a PageAnchor message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns PageAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.PageAnchor;

                        /**
                         * Verifies a PageAnchor message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a PageAnchor message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns PageAnchor
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.PageAnchor;

                        /**
                         * Creates a plain object from a PageAnchor message. Also converts values to other types if specified.
                         * @param message PageAnchor
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.PageAnchor, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this PageAnchor to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for PageAnchor
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace PageAnchor {

                        /** Properties of a PageRef. */
                        interface IPageRef {

                            /** PageRef page */
                            page?: (number|Long|string|null);

                            /** PageRef layoutType */
                            layoutType?: (google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef.LayoutType|keyof typeof google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef.LayoutType|null);

                            /** PageRef layoutId */
                            layoutId?: (string|null);

                            /** PageRef boundingPoly */
                            boundingPoly?: (google.cloud.documentai.v1beta2.IBoundingPoly|null);

                            /** PageRef confidence */
                            confidence?: (number|null);
                        }

                        /** Represents a PageRef. */
                        class PageRef implements IPageRef {

                            /**
                             * Constructs a new PageRef.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.PageAnchor.IPageRef);

                            /** PageRef page. */
                            public page: (number|Long|string);

                            /** PageRef layoutType. */
                            public layoutType: (google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef.LayoutType|keyof typeof google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef.LayoutType);

                            /** PageRef layoutId. */
                            public layoutId: string;

                            /** PageRef boundingPoly. */
                            public boundingPoly?: (google.cloud.documentai.v1beta2.IBoundingPoly|null);

                            /** PageRef confidence. */
                            public confidence: number;

                            /**
                             * Creates a new PageRef instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns PageRef instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.PageAnchor.IPageRef): google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef;

                            /**
                             * Encodes the specified PageRef message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef.verify|verify} messages.
                             * @param message PageRef message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.PageAnchor.IPageRef, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified PageRef message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef.verify|verify} messages.
                             * @param message PageRef message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.PageAnchor.IPageRef, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a PageRef message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns PageRef
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef;

                            /**
                             * Decodes a PageRef message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns PageRef
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef;

                            /**
                             * Verifies a PageRef message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a PageRef message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns PageRef
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef;

                            /**
                             * Creates a plain object from a PageRef message. Also converts values to other types if specified.
                             * @param message PageRef
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.PageAnchor.PageRef, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this PageRef to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for PageRef
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace PageRef {

                            /** LayoutType enum. */
                            enum LayoutType {
                                LAYOUT_TYPE_UNSPECIFIED = 0,
                                BLOCK = 1,
                                PARAGRAPH = 2,
                                LINE = 3,
                                TOKEN = 4,
                                VISUAL_ELEMENT = 5,
                                TABLE = 6,
                                FORM_FIELD = 7
                            }
                        }
                    }

                    /** Properties of a Provenance. */
                    interface IProvenance {

                        /** Provenance revision */
                        revision?: (number|null);

                        /** Provenance id */
                        id?: (number|null);

                        /** Provenance parents */
                        parents?: (google.cloud.documentai.v1beta2.Document.Provenance.IParent[]|null);

                        /** Provenance type */
                        type?: (google.cloud.documentai.v1beta2.Document.Provenance.OperationType|keyof typeof google.cloud.documentai.v1beta2.Document.Provenance.OperationType|null);
                    }

                    /** Represents a Provenance. */
                    class Provenance implements IProvenance {

                        /**
                         * Constructs a new Provenance.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.IProvenance);

                        /** Provenance revision. */
                        public revision: number;

                        /** Provenance id. */
                        public id: number;

                        /** Provenance parents. */
                        public parents: google.cloud.documentai.v1beta2.Document.Provenance.IParent[];

                        /** Provenance type. */
                        public type: (google.cloud.documentai.v1beta2.Document.Provenance.OperationType|keyof typeof google.cloud.documentai.v1beta2.Document.Provenance.OperationType);

                        /**
                         * Creates a new Provenance instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Provenance instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.IProvenance): google.cloud.documentai.v1beta2.Document.Provenance;

                        /**
                         * Encodes the specified Provenance message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Provenance.verify|verify} messages.
                         * @param message Provenance message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.IProvenance, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Provenance message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Provenance.verify|verify} messages.
                         * @param message Provenance message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.IProvenance, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Provenance message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Provenance
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Provenance;

                        /**
                         * Decodes a Provenance message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Provenance
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Provenance;

                        /**
                         * Verifies a Provenance message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Provenance message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Provenance
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Provenance;

                        /**
                         * Creates a plain object from a Provenance message. Also converts values to other types if specified.
                         * @param message Provenance
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.Provenance, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Provenance to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Provenance
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Provenance {

                        /** Properties of a Parent. */
                        interface IParent {

                            /** Parent revision */
                            revision?: (number|null);

                            /** Parent index */
                            index?: (number|null);

                            /** Parent id */
                            id?: (number|null);
                        }

                        /** Represents a Parent. */
                        class Parent implements IParent {

                            /**
                             * Constructs a new Parent.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Provenance.IParent);

                            /** Parent revision. */
                            public revision: number;

                            /** Parent index. */
                            public index: number;

                            /** Parent id. */
                            public id: number;

                            /**
                             * Creates a new Parent instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Parent instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Provenance.IParent): google.cloud.documentai.v1beta2.Document.Provenance.Parent;

                            /**
                             * Encodes the specified Parent message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Provenance.Parent.verify|verify} messages.
                             * @param message Parent message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Provenance.IParent, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Parent message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Provenance.Parent.verify|verify} messages.
                             * @param message Parent message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Provenance.IParent, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Parent message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Parent
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Provenance.Parent;

                            /**
                             * Decodes a Parent message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Parent
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Provenance.Parent;

                            /**
                             * Verifies a Parent message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Parent message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Parent
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Provenance.Parent;

                            /**
                             * Creates a plain object from a Parent message. Also converts values to other types if specified.
                             * @param message Parent
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Provenance.Parent, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Parent to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Parent
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** OperationType enum. */
                        enum OperationType {
                            OPERATION_TYPE_UNSPECIFIED = 0,
                            ADD = 1,
                            REMOVE = 2,
                            UPDATE = 7,
                            REPLACE = 3,
                            EVAL_REQUESTED = 4,
                            EVAL_APPROVED = 5,
                            EVAL_SKIPPED = 6
                        }
                    }

                    /** Properties of a Revision. */
                    interface IRevision {

                        /** Revision agent */
                        agent?: (string|null);

                        /** Revision processor */
                        processor?: (string|null);

                        /** Revision id */
                        id?: (string|null);

                        /** Revision parent */
                        parent?: (number[]|null);

                        /** Revision parentIds */
                        parentIds?: (string[]|null);

                        /** Revision createTime */
                        createTime?: (google.protobuf.ITimestamp|null);

                        /** Revision humanReview */
                        humanReview?: (google.cloud.documentai.v1beta2.Document.Revision.IHumanReview|null);
                    }

                    /** Represents a Revision. */
                    class Revision implements IRevision {

                        /**
                         * Constructs a new Revision.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.IRevision);

                        /** Revision agent. */
                        public agent?: (string|null);

                        /** Revision processor. */
                        public processor?: (string|null);

                        /** Revision id. */
                        public id: string;

                        /** Revision parent. */
                        public parent: number[];

                        /** Revision parentIds. */
                        public parentIds: string[];

                        /** Revision createTime. */
                        public createTime?: (google.protobuf.ITimestamp|null);

                        /** Revision humanReview. */
                        public humanReview?: (google.cloud.documentai.v1beta2.Document.Revision.IHumanReview|null);

                        /** Revision source. */
                        public source?: ("agent"|"processor");

                        /**
                         * Creates a new Revision instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Revision instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.IRevision): google.cloud.documentai.v1beta2.Document.Revision;

                        /**
                         * Encodes the specified Revision message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Revision.verify|verify} messages.
                         * @param message Revision message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.IRevision, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Revision message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Revision.verify|verify} messages.
                         * @param message Revision message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.IRevision, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Revision message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Revision
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Revision;

                        /**
                         * Decodes a Revision message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Revision
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Revision;

                        /**
                         * Verifies a Revision message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Revision message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Revision
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Revision;

                        /**
                         * Creates a plain object from a Revision message. Also converts values to other types if specified.
                         * @param message Revision
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.Revision, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Revision to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Revision
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Revision {

                        /** Properties of a HumanReview. */
                        interface IHumanReview {

                            /** HumanReview state */
                            state?: (string|null);

                            /** HumanReview stateMessage */
                            stateMessage?: (string|null);
                        }

                        /** Represents a HumanReview. */
                        class HumanReview implements IHumanReview {

                            /**
                             * Constructs a new HumanReview.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta2.Document.Revision.IHumanReview);

                            /** HumanReview state. */
                            public state: string;

                            /** HumanReview stateMessage. */
                            public stateMessage: string;

                            /**
                             * Creates a new HumanReview instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns HumanReview instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta2.Document.Revision.IHumanReview): google.cloud.documentai.v1beta2.Document.Revision.HumanReview;

                            /**
                             * Encodes the specified HumanReview message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Revision.HumanReview.verify|verify} messages.
                             * @param message HumanReview message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta2.Document.Revision.IHumanReview, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified HumanReview message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.Revision.HumanReview.verify|verify} messages.
                             * @param message HumanReview message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.Revision.IHumanReview, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a HumanReview message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns HumanReview
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.Revision.HumanReview;

                            /**
                             * Decodes a HumanReview message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns HumanReview
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.Revision.HumanReview;

                            /**
                             * Verifies a HumanReview message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a HumanReview message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns HumanReview
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.Revision.HumanReview;

                            /**
                             * Creates a plain object from a HumanReview message. Also converts values to other types if specified.
                             * @param message HumanReview
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta2.Document.Revision.HumanReview, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this HumanReview to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for HumanReview
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a TextChange. */
                    interface ITextChange {

                        /** TextChange textAnchor */
                        textAnchor?: (google.cloud.documentai.v1beta2.Document.ITextAnchor|null);

                        /** TextChange changedText */
                        changedText?: (string|null);

                        /** TextChange provenance */
                        provenance?: (google.cloud.documentai.v1beta2.Document.IProvenance[]|null);
                    }

                    /** Represents a TextChange. */
                    class TextChange implements ITextChange {

                        /**
                         * Constructs a new TextChange.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta2.Document.ITextChange);

                        /** TextChange textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1beta2.Document.ITextAnchor|null);

                        /** TextChange changedText. */
                        public changedText: string;

                        /** TextChange provenance. */
                        public provenance: google.cloud.documentai.v1beta2.Document.IProvenance[];

                        /**
                         * Creates a new TextChange instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns TextChange instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta2.Document.ITextChange): google.cloud.documentai.v1beta2.Document.TextChange;

                        /**
                         * Encodes the specified TextChange message. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.TextChange.verify|verify} messages.
                         * @param message TextChange message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta2.Document.ITextChange, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified TextChange message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Document.TextChange.verify|verify} messages.
                         * @param message TextChange message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta2.Document.ITextChange, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a TextChange message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns TextChange
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Document.TextChange;

                        /**
                         * Decodes a TextChange message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns TextChange
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Document.TextChange;

                        /**
                         * Verifies a TextChange message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a TextChange message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns TextChange
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Document.TextChange;

                        /**
                         * Creates a plain object from a TextChange message. Also converts values to other types if specified.
                         * @param message TextChange
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta2.Document.TextChange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this TextChange to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for TextChange
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a Vertex. */
                interface IVertex {

                    /** Vertex x */
                    x?: (number|null);

                    /** Vertex y */
                    y?: (number|null);
                }

                /** Represents a Vertex. */
                class Vertex implements IVertex {

                    /**
                     * Constructs a new Vertex.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IVertex);

                    /** Vertex x. */
                    public x: number;

                    /** Vertex y. */
                    public y: number;

                    /**
                     * Creates a new Vertex instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Vertex instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IVertex): google.cloud.documentai.v1beta2.Vertex;

                    /**
                     * Encodes the specified Vertex message. Does not implicitly {@link google.cloud.documentai.v1beta2.Vertex.verify|verify} messages.
                     * @param message Vertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Vertex message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.Vertex.verify|verify} messages.
                     * @param message Vertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Vertex message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Vertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.Vertex;

                    /**
                     * Decodes a Vertex message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Vertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.Vertex;

                    /**
                     * Verifies a Vertex message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Vertex message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Vertex
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.Vertex;

                    /**
                     * Creates a plain object from a Vertex message. Also converts values to other types if specified.
                     * @param message Vertex
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.Vertex, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Vertex to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Vertex
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NormalizedVertex. */
                interface INormalizedVertex {

                    /** NormalizedVertex x */
                    x?: (number|null);

                    /** NormalizedVertex y */
                    y?: (number|null);
                }

                /** Represents a NormalizedVertex. */
                class NormalizedVertex implements INormalizedVertex {

                    /**
                     * Constructs a new NormalizedVertex.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.INormalizedVertex);

                    /** NormalizedVertex x. */
                    public x: number;

                    /** NormalizedVertex y. */
                    public y: number;

                    /**
                     * Creates a new NormalizedVertex instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NormalizedVertex instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.INormalizedVertex): google.cloud.documentai.v1beta2.NormalizedVertex;

                    /**
                     * Encodes the specified NormalizedVertex message. Does not implicitly {@link google.cloud.documentai.v1beta2.NormalizedVertex.verify|verify} messages.
                     * @param message NormalizedVertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.INormalizedVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NormalizedVertex message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.NormalizedVertex.verify|verify} messages.
                     * @param message NormalizedVertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.INormalizedVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NormalizedVertex message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NormalizedVertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.NormalizedVertex;

                    /**
                     * Decodes a NormalizedVertex message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NormalizedVertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.NormalizedVertex;

                    /**
                     * Verifies a NormalizedVertex message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NormalizedVertex message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NormalizedVertex
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.NormalizedVertex;

                    /**
                     * Creates a plain object from a NormalizedVertex message. Also converts values to other types if specified.
                     * @param message NormalizedVertex
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.NormalizedVertex, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NormalizedVertex to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NormalizedVertex
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BoundingPoly. */
                interface IBoundingPoly {

                    /** BoundingPoly vertices */
                    vertices?: (google.cloud.documentai.v1beta2.IVertex[]|null);

                    /** BoundingPoly normalizedVertices */
                    normalizedVertices?: (google.cloud.documentai.v1beta2.INormalizedVertex[]|null);
                }

                /** Represents a BoundingPoly. */
                class BoundingPoly implements IBoundingPoly {

                    /**
                     * Constructs a new BoundingPoly.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IBoundingPoly);

                    /** BoundingPoly vertices. */
                    public vertices: google.cloud.documentai.v1beta2.IVertex[];

                    /** BoundingPoly normalizedVertices. */
                    public normalizedVertices: google.cloud.documentai.v1beta2.INormalizedVertex[];

                    /**
                     * Creates a new BoundingPoly instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BoundingPoly instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IBoundingPoly): google.cloud.documentai.v1beta2.BoundingPoly;

                    /**
                     * Encodes the specified BoundingPoly message. Does not implicitly {@link google.cloud.documentai.v1beta2.BoundingPoly.verify|verify} messages.
                     * @param message BoundingPoly message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IBoundingPoly, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BoundingPoly message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.BoundingPoly.verify|verify} messages.
                     * @param message BoundingPoly message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IBoundingPoly, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BoundingPoly message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BoundingPoly
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.BoundingPoly;

                    /**
                     * Decodes a BoundingPoly message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BoundingPoly
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.BoundingPoly;

                    /**
                     * Verifies a BoundingPoly message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BoundingPoly message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BoundingPoly
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.BoundingPoly;

                    /**
                     * Creates a plain object from a BoundingPoly message. Also converts values to other types if specified.
                     * @param message BoundingPoly
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.BoundingPoly, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BoundingPoly to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BoundingPoly
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Represents a DocumentUnderstandingService */
                class DocumentUnderstandingService extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new DocumentUnderstandingService service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new DocumentUnderstandingService service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): DocumentUnderstandingService;

                    /**
                     * Calls BatchProcessDocuments.
                     * @param request BatchProcessDocumentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public batchProcessDocuments(request: google.cloud.documentai.v1beta2.IBatchProcessDocumentsRequest, callback: google.cloud.documentai.v1beta2.DocumentUnderstandingService.BatchProcessDocumentsCallback): void;

                    /**
                     * Calls BatchProcessDocuments.
                     * @param request BatchProcessDocumentsRequest message or plain object
                     * @returns Promise
                     */
                    public batchProcessDocuments(request: google.cloud.documentai.v1beta2.IBatchProcessDocumentsRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls ProcessDocument.
                     * @param request ProcessDocumentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Document
                     */
                    public processDocument(request: google.cloud.documentai.v1beta2.IProcessDocumentRequest, callback: google.cloud.documentai.v1beta2.DocumentUnderstandingService.ProcessDocumentCallback): void;

                    /**
                     * Calls ProcessDocument.
                     * @param request ProcessDocumentRequest message or plain object
                     * @returns Promise
                     */
                    public processDocument(request: google.cloud.documentai.v1beta2.IProcessDocumentRequest): Promise<google.cloud.documentai.v1beta2.Document>;
                }

                namespace DocumentUnderstandingService {

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta2.DocumentUnderstandingService|batchProcessDocuments}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type BatchProcessDocumentsCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta2.DocumentUnderstandingService|processDocument}.
                     * @param error Error, if any
                     * @param [response] Document
                     */
                    type ProcessDocumentCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta2.Document) => void;
                }

                /** Properties of a BatchProcessDocumentsRequest. */
                interface IBatchProcessDocumentsRequest {

                    /** BatchProcessDocumentsRequest requests */
                    requests?: (google.cloud.documentai.v1beta2.IProcessDocumentRequest[]|null);

                    /** BatchProcessDocumentsRequest parent */
                    parent?: (string|null);
                }

                /** Represents a BatchProcessDocumentsRequest. */
                class BatchProcessDocumentsRequest implements IBatchProcessDocumentsRequest {

                    /**
                     * Constructs a new BatchProcessDocumentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IBatchProcessDocumentsRequest);

                    /** BatchProcessDocumentsRequest requests. */
                    public requests: google.cloud.documentai.v1beta2.IProcessDocumentRequest[];

                    /** BatchProcessDocumentsRequest parent. */
                    public parent: string;

                    /**
                     * Creates a new BatchProcessDocumentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessDocumentsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IBatchProcessDocumentsRequest): google.cloud.documentai.v1beta2.BatchProcessDocumentsRequest;

                    /**
                     * Encodes the specified BatchProcessDocumentsRequest message. Does not implicitly {@link google.cloud.documentai.v1beta2.BatchProcessDocumentsRequest.verify|verify} messages.
                     * @param message BatchProcessDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IBatchProcessDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessDocumentsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.BatchProcessDocumentsRequest.verify|verify} messages.
                     * @param message BatchProcessDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IBatchProcessDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessDocumentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.BatchProcessDocumentsRequest;

                    /**
                     * Decodes a BatchProcessDocumentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.BatchProcessDocumentsRequest;

                    /**
                     * Verifies a BatchProcessDocumentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessDocumentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessDocumentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.BatchProcessDocumentsRequest;

                    /**
                     * Creates a plain object from a BatchProcessDocumentsRequest message. Also converts values to other types if specified.
                     * @param message BatchProcessDocumentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.BatchProcessDocumentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessDocumentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessDocumentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ProcessDocumentRequest. */
                interface IProcessDocumentRequest {

                    /** ProcessDocumentRequest parent */
                    parent?: (string|null);

                    /** ProcessDocumentRequest inputConfig */
                    inputConfig?: (google.cloud.documentai.v1beta2.IInputConfig|null);

                    /** ProcessDocumentRequest outputConfig */
                    outputConfig?: (google.cloud.documentai.v1beta2.IOutputConfig|null);

                    /** ProcessDocumentRequest documentType */
                    documentType?: (string|null);

                    /** ProcessDocumentRequest tableExtractionParams */
                    tableExtractionParams?: (google.cloud.documentai.v1beta2.ITableExtractionParams|null);

                    /** ProcessDocumentRequest formExtractionParams */
                    formExtractionParams?: (google.cloud.documentai.v1beta2.IFormExtractionParams|null);

                    /** ProcessDocumentRequest entityExtractionParams */
                    entityExtractionParams?: (google.cloud.documentai.v1beta2.IEntityExtractionParams|null);

                    /** ProcessDocumentRequest ocrParams */
                    ocrParams?: (google.cloud.documentai.v1beta2.IOcrParams|null);

                    /** ProcessDocumentRequest automlParams */
                    automlParams?: (google.cloud.documentai.v1beta2.IAutoMlParams|null);
                }

                /** Represents a ProcessDocumentRequest. */
                class ProcessDocumentRequest implements IProcessDocumentRequest {

                    /**
                     * Constructs a new ProcessDocumentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IProcessDocumentRequest);

                    /** ProcessDocumentRequest parent. */
                    public parent: string;

                    /** ProcessDocumentRequest inputConfig. */
                    public inputConfig?: (google.cloud.documentai.v1beta2.IInputConfig|null);

                    /** ProcessDocumentRequest outputConfig. */
                    public outputConfig?: (google.cloud.documentai.v1beta2.IOutputConfig|null);

                    /** ProcessDocumentRequest documentType. */
                    public documentType: string;

                    /** ProcessDocumentRequest tableExtractionParams. */
                    public tableExtractionParams?: (google.cloud.documentai.v1beta2.ITableExtractionParams|null);

                    /** ProcessDocumentRequest formExtractionParams. */
                    public formExtractionParams?: (google.cloud.documentai.v1beta2.IFormExtractionParams|null);

                    /** ProcessDocumentRequest entityExtractionParams. */
                    public entityExtractionParams?: (google.cloud.documentai.v1beta2.IEntityExtractionParams|null);

                    /** ProcessDocumentRequest ocrParams. */
                    public ocrParams?: (google.cloud.documentai.v1beta2.IOcrParams|null);

                    /** ProcessDocumentRequest automlParams. */
                    public automlParams?: (google.cloud.documentai.v1beta2.IAutoMlParams|null);

                    /**
                     * Creates a new ProcessDocumentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessDocumentRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IProcessDocumentRequest): google.cloud.documentai.v1beta2.ProcessDocumentRequest;

                    /**
                     * Encodes the specified ProcessDocumentRequest message. Does not implicitly {@link google.cloud.documentai.v1beta2.ProcessDocumentRequest.verify|verify} messages.
                     * @param message ProcessDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IProcessDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.ProcessDocumentRequest.verify|verify} messages.
                     * @param message ProcessDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IProcessDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessDocumentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.ProcessDocumentRequest;

                    /**
                     * Decodes a ProcessDocumentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.ProcessDocumentRequest;

                    /**
                     * Verifies a ProcessDocumentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessDocumentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessDocumentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.ProcessDocumentRequest;

                    /**
                     * Creates a plain object from a ProcessDocumentRequest message. Also converts values to other types if specified.
                     * @param message ProcessDocumentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.ProcessDocumentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessDocumentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessDocumentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchProcessDocumentsResponse. */
                interface IBatchProcessDocumentsResponse {

                    /** BatchProcessDocumentsResponse responses */
                    responses?: (google.cloud.documentai.v1beta2.IProcessDocumentResponse[]|null);
                }

                /** Represents a BatchProcessDocumentsResponse. */
                class BatchProcessDocumentsResponse implements IBatchProcessDocumentsResponse {

                    /**
                     * Constructs a new BatchProcessDocumentsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IBatchProcessDocumentsResponse);

                    /** BatchProcessDocumentsResponse responses. */
                    public responses: google.cloud.documentai.v1beta2.IProcessDocumentResponse[];

                    /**
                     * Creates a new BatchProcessDocumentsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessDocumentsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IBatchProcessDocumentsResponse): google.cloud.documentai.v1beta2.BatchProcessDocumentsResponse;

                    /**
                     * Encodes the specified BatchProcessDocumentsResponse message. Does not implicitly {@link google.cloud.documentai.v1beta2.BatchProcessDocumentsResponse.verify|verify} messages.
                     * @param message BatchProcessDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IBatchProcessDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessDocumentsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.BatchProcessDocumentsResponse.verify|verify} messages.
                     * @param message BatchProcessDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IBatchProcessDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessDocumentsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.BatchProcessDocumentsResponse;

                    /**
                     * Decodes a BatchProcessDocumentsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.BatchProcessDocumentsResponse;

                    /**
                     * Verifies a BatchProcessDocumentsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessDocumentsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessDocumentsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.BatchProcessDocumentsResponse;

                    /**
                     * Creates a plain object from a BatchProcessDocumentsResponse message. Also converts values to other types if specified.
                     * @param message BatchProcessDocumentsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.BatchProcessDocumentsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessDocumentsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessDocumentsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ProcessDocumentResponse. */
                interface IProcessDocumentResponse {

                    /** ProcessDocumentResponse inputConfig */
                    inputConfig?: (google.cloud.documentai.v1beta2.IInputConfig|null);

                    /** ProcessDocumentResponse outputConfig */
                    outputConfig?: (google.cloud.documentai.v1beta2.IOutputConfig|null);
                }

                /** Represents a ProcessDocumentResponse. */
                class ProcessDocumentResponse implements IProcessDocumentResponse {

                    /**
                     * Constructs a new ProcessDocumentResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IProcessDocumentResponse);

                    /** ProcessDocumentResponse inputConfig. */
                    public inputConfig?: (google.cloud.documentai.v1beta2.IInputConfig|null);

                    /** ProcessDocumentResponse outputConfig. */
                    public outputConfig?: (google.cloud.documentai.v1beta2.IOutputConfig|null);

                    /**
                     * Creates a new ProcessDocumentResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessDocumentResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IProcessDocumentResponse): google.cloud.documentai.v1beta2.ProcessDocumentResponse;

                    /**
                     * Encodes the specified ProcessDocumentResponse message. Does not implicitly {@link google.cloud.documentai.v1beta2.ProcessDocumentResponse.verify|verify} messages.
                     * @param message ProcessDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IProcessDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessDocumentResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.ProcessDocumentResponse.verify|verify} messages.
                     * @param message ProcessDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IProcessDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessDocumentResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.ProcessDocumentResponse;

                    /**
                     * Decodes a ProcessDocumentResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.ProcessDocumentResponse;

                    /**
                     * Verifies a ProcessDocumentResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessDocumentResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessDocumentResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.ProcessDocumentResponse;

                    /**
                     * Creates a plain object from a ProcessDocumentResponse message. Also converts values to other types if specified.
                     * @param message ProcessDocumentResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.ProcessDocumentResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessDocumentResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessDocumentResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an OcrParams. */
                interface IOcrParams {

                    /** OcrParams languageHints */
                    languageHints?: (string[]|null);
                }

                /** Represents an OcrParams. */
                class OcrParams implements IOcrParams {

                    /**
                     * Constructs a new OcrParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IOcrParams);

                    /** OcrParams languageHints. */
                    public languageHints: string[];

                    /**
                     * Creates a new OcrParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OcrParams instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IOcrParams): google.cloud.documentai.v1beta2.OcrParams;

                    /**
                     * Encodes the specified OcrParams message. Does not implicitly {@link google.cloud.documentai.v1beta2.OcrParams.verify|verify} messages.
                     * @param message OcrParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IOcrParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OcrParams message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.OcrParams.verify|verify} messages.
                     * @param message OcrParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IOcrParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OcrParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OcrParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.OcrParams;

                    /**
                     * Decodes an OcrParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OcrParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.OcrParams;

                    /**
                     * Verifies an OcrParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OcrParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OcrParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.OcrParams;

                    /**
                     * Creates a plain object from an OcrParams message. Also converts values to other types if specified.
                     * @param message OcrParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.OcrParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OcrParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OcrParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TableExtractionParams. */
                interface ITableExtractionParams {

                    /** TableExtractionParams enabled */
                    enabled?: (boolean|null);

                    /** TableExtractionParams tableBoundHints */
                    tableBoundHints?: (google.cloud.documentai.v1beta2.ITableBoundHint[]|null);

                    /** TableExtractionParams headerHints */
                    headerHints?: (string[]|null);

                    /** TableExtractionParams modelVersion */
                    modelVersion?: (string|null);
                }

                /** Represents a TableExtractionParams. */
                class TableExtractionParams implements ITableExtractionParams {

                    /**
                     * Constructs a new TableExtractionParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.ITableExtractionParams);

                    /** TableExtractionParams enabled. */
                    public enabled: boolean;

                    /** TableExtractionParams tableBoundHints. */
                    public tableBoundHints: google.cloud.documentai.v1beta2.ITableBoundHint[];

                    /** TableExtractionParams headerHints. */
                    public headerHints: string[];

                    /** TableExtractionParams modelVersion. */
                    public modelVersion: string;

                    /**
                     * Creates a new TableExtractionParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TableExtractionParams instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.ITableExtractionParams): google.cloud.documentai.v1beta2.TableExtractionParams;

                    /**
                     * Encodes the specified TableExtractionParams message. Does not implicitly {@link google.cloud.documentai.v1beta2.TableExtractionParams.verify|verify} messages.
                     * @param message TableExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.ITableExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TableExtractionParams message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.TableExtractionParams.verify|verify} messages.
                     * @param message TableExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.ITableExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TableExtractionParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TableExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.TableExtractionParams;

                    /**
                     * Decodes a TableExtractionParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TableExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.TableExtractionParams;

                    /**
                     * Verifies a TableExtractionParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TableExtractionParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TableExtractionParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.TableExtractionParams;

                    /**
                     * Creates a plain object from a TableExtractionParams message. Also converts values to other types if specified.
                     * @param message TableExtractionParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.TableExtractionParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TableExtractionParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TableExtractionParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TableBoundHint. */
                interface ITableBoundHint {

                    /** TableBoundHint pageNumber */
                    pageNumber?: (number|null);

                    /** TableBoundHint boundingBox */
                    boundingBox?: (google.cloud.documentai.v1beta2.IBoundingPoly|null);
                }

                /** Represents a TableBoundHint. */
                class TableBoundHint implements ITableBoundHint {

                    /**
                     * Constructs a new TableBoundHint.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.ITableBoundHint);

                    /** TableBoundHint pageNumber. */
                    public pageNumber: number;

                    /** TableBoundHint boundingBox. */
                    public boundingBox?: (google.cloud.documentai.v1beta2.IBoundingPoly|null);

                    /**
                     * Creates a new TableBoundHint instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TableBoundHint instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.ITableBoundHint): google.cloud.documentai.v1beta2.TableBoundHint;

                    /**
                     * Encodes the specified TableBoundHint message. Does not implicitly {@link google.cloud.documentai.v1beta2.TableBoundHint.verify|verify} messages.
                     * @param message TableBoundHint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.ITableBoundHint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TableBoundHint message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.TableBoundHint.verify|verify} messages.
                     * @param message TableBoundHint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.ITableBoundHint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TableBoundHint message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TableBoundHint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.TableBoundHint;

                    /**
                     * Decodes a TableBoundHint message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TableBoundHint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.TableBoundHint;

                    /**
                     * Verifies a TableBoundHint message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TableBoundHint message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TableBoundHint
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.TableBoundHint;

                    /**
                     * Creates a plain object from a TableBoundHint message. Also converts values to other types if specified.
                     * @param message TableBoundHint
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.TableBoundHint, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TableBoundHint to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TableBoundHint
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FormExtractionParams. */
                interface IFormExtractionParams {

                    /** FormExtractionParams enabled */
                    enabled?: (boolean|null);

                    /** FormExtractionParams keyValuePairHints */
                    keyValuePairHints?: (google.cloud.documentai.v1beta2.IKeyValuePairHint[]|null);

                    /** FormExtractionParams modelVersion */
                    modelVersion?: (string|null);
                }

                /** Represents a FormExtractionParams. */
                class FormExtractionParams implements IFormExtractionParams {

                    /**
                     * Constructs a new FormExtractionParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IFormExtractionParams);

                    /** FormExtractionParams enabled. */
                    public enabled: boolean;

                    /** FormExtractionParams keyValuePairHints. */
                    public keyValuePairHints: google.cloud.documentai.v1beta2.IKeyValuePairHint[];

                    /** FormExtractionParams modelVersion. */
                    public modelVersion: string;

                    /**
                     * Creates a new FormExtractionParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FormExtractionParams instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IFormExtractionParams): google.cloud.documentai.v1beta2.FormExtractionParams;

                    /**
                     * Encodes the specified FormExtractionParams message. Does not implicitly {@link google.cloud.documentai.v1beta2.FormExtractionParams.verify|verify} messages.
                     * @param message FormExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IFormExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FormExtractionParams message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.FormExtractionParams.verify|verify} messages.
                     * @param message FormExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IFormExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FormExtractionParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FormExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.FormExtractionParams;

                    /**
                     * Decodes a FormExtractionParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FormExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.FormExtractionParams;

                    /**
                     * Verifies a FormExtractionParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FormExtractionParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FormExtractionParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.FormExtractionParams;

                    /**
                     * Creates a plain object from a FormExtractionParams message. Also converts values to other types if specified.
                     * @param message FormExtractionParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.FormExtractionParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FormExtractionParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FormExtractionParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a KeyValuePairHint. */
                interface IKeyValuePairHint {

                    /** KeyValuePairHint key */
                    key?: (string|null);

                    /** KeyValuePairHint valueTypes */
                    valueTypes?: (string[]|null);
                }

                /** Represents a KeyValuePairHint. */
                class KeyValuePairHint implements IKeyValuePairHint {

                    /**
                     * Constructs a new KeyValuePairHint.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IKeyValuePairHint);

                    /** KeyValuePairHint key. */
                    public key: string;

                    /** KeyValuePairHint valueTypes. */
                    public valueTypes: string[];

                    /**
                     * Creates a new KeyValuePairHint instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns KeyValuePairHint instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IKeyValuePairHint): google.cloud.documentai.v1beta2.KeyValuePairHint;

                    /**
                     * Encodes the specified KeyValuePairHint message. Does not implicitly {@link google.cloud.documentai.v1beta2.KeyValuePairHint.verify|verify} messages.
                     * @param message KeyValuePairHint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IKeyValuePairHint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified KeyValuePairHint message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.KeyValuePairHint.verify|verify} messages.
                     * @param message KeyValuePairHint message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IKeyValuePairHint, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a KeyValuePairHint message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns KeyValuePairHint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.KeyValuePairHint;

                    /**
                     * Decodes a KeyValuePairHint message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns KeyValuePairHint
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.KeyValuePairHint;

                    /**
                     * Verifies a KeyValuePairHint message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a KeyValuePairHint message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns KeyValuePairHint
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.KeyValuePairHint;

                    /**
                     * Creates a plain object from a KeyValuePairHint message. Also converts values to other types if specified.
                     * @param message KeyValuePairHint
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.KeyValuePairHint, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this KeyValuePairHint to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for KeyValuePairHint
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EntityExtractionParams. */
                interface IEntityExtractionParams {

                    /** EntityExtractionParams enabled */
                    enabled?: (boolean|null);

                    /** EntityExtractionParams modelVersion */
                    modelVersion?: (string|null);
                }

                /** Represents an EntityExtractionParams. */
                class EntityExtractionParams implements IEntityExtractionParams {

                    /**
                     * Constructs a new EntityExtractionParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IEntityExtractionParams);

                    /** EntityExtractionParams enabled. */
                    public enabled: boolean;

                    /** EntityExtractionParams modelVersion. */
                    public modelVersion: string;

                    /**
                     * Creates a new EntityExtractionParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EntityExtractionParams instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IEntityExtractionParams): google.cloud.documentai.v1beta2.EntityExtractionParams;

                    /**
                     * Encodes the specified EntityExtractionParams message. Does not implicitly {@link google.cloud.documentai.v1beta2.EntityExtractionParams.verify|verify} messages.
                     * @param message EntityExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IEntityExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EntityExtractionParams message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.EntityExtractionParams.verify|verify} messages.
                     * @param message EntityExtractionParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IEntityExtractionParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EntityExtractionParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EntityExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.EntityExtractionParams;

                    /**
                     * Decodes an EntityExtractionParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EntityExtractionParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.EntityExtractionParams;

                    /**
                     * Verifies an EntityExtractionParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EntityExtractionParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EntityExtractionParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.EntityExtractionParams;

                    /**
                     * Creates a plain object from an EntityExtractionParams message. Also converts values to other types if specified.
                     * @param message EntityExtractionParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.EntityExtractionParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EntityExtractionParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EntityExtractionParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an AutoMlParams. */
                interface IAutoMlParams {

                    /** AutoMlParams model */
                    model?: (string|null);
                }

                /** Represents an AutoMlParams. */
                class AutoMlParams implements IAutoMlParams {

                    /**
                     * Constructs a new AutoMlParams.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IAutoMlParams);

                    /** AutoMlParams model. */
                    public model: string;

                    /**
                     * Creates a new AutoMlParams instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns AutoMlParams instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IAutoMlParams): google.cloud.documentai.v1beta2.AutoMlParams;

                    /**
                     * Encodes the specified AutoMlParams message. Does not implicitly {@link google.cloud.documentai.v1beta2.AutoMlParams.verify|verify} messages.
                     * @param message AutoMlParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IAutoMlParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified AutoMlParams message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.AutoMlParams.verify|verify} messages.
                     * @param message AutoMlParams message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IAutoMlParams, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an AutoMlParams message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns AutoMlParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.AutoMlParams;

                    /**
                     * Decodes an AutoMlParams message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns AutoMlParams
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.AutoMlParams;

                    /**
                     * Verifies an AutoMlParams message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an AutoMlParams message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns AutoMlParams
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.AutoMlParams;

                    /**
                     * Creates a plain object from an AutoMlParams message. Also converts values to other types if specified.
                     * @param message AutoMlParams
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.AutoMlParams, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this AutoMlParams to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for AutoMlParams
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an InputConfig. */
                interface IInputConfig {

                    /** InputConfig gcsSource */
                    gcsSource?: (google.cloud.documentai.v1beta2.IGcsSource|null);

                    /** InputConfig contents */
                    contents?: (Uint8Array|string|null);

                    /** InputConfig mimeType */
                    mimeType?: (string|null);
                }

                /** Represents an InputConfig. */
                class InputConfig implements IInputConfig {

                    /**
                     * Constructs a new InputConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IInputConfig);

                    /** InputConfig gcsSource. */
                    public gcsSource?: (google.cloud.documentai.v1beta2.IGcsSource|null);

                    /** InputConfig contents. */
                    public contents?: (Uint8Array|string|null);

                    /** InputConfig mimeType. */
                    public mimeType: string;

                    /** InputConfig source. */
                    public source?: ("gcsSource"|"contents");

                    /**
                     * Creates a new InputConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns InputConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IInputConfig): google.cloud.documentai.v1beta2.InputConfig;

                    /**
                     * Encodes the specified InputConfig message. Does not implicitly {@link google.cloud.documentai.v1beta2.InputConfig.verify|verify} messages.
                     * @param message InputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified InputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.InputConfig.verify|verify} messages.
                     * @param message InputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an InputConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns InputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.InputConfig;

                    /**
                     * Decodes an InputConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns InputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.InputConfig;

                    /**
                     * Verifies an InputConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an InputConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns InputConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.InputConfig;

                    /**
                     * Creates a plain object from an InputConfig message. Also converts values to other types if specified.
                     * @param message InputConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.InputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this InputConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for InputConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an OutputConfig. */
                interface IOutputConfig {

                    /** OutputConfig gcsDestination */
                    gcsDestination?: (google.cloud.documentai.v1beta2.IGcsDestination|null);

                    /** OutputConfig pagesPerShard */
                    pagesPerShard?: (number|null);
                }

                /** Represents an OutputConfig. */
                class OutputConfig implements IOutputConfig {

                    /**
                     * Constructs a new OutputConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IOutputConfig);

                    /** OutputConfig gcsDestination. */
                    public gcsDestination?: (google.cloud.documentai.v1beta2.IGcsDestination|null);

                    /** OutputConfig pagesPerShard. */
                    public pagesPerShard: number;

                    /** OutputConfig destination. */
                    public destination?: "gcsDestination";

                    /**
                     * Creates a new OutputConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OutputConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IOutputConfig): google.cloud.documentai.v1beta2.OutputConfig;

                    /**
                     * Encodes the specified OutputConfig message. Does not implicitly {@link google.cloud.documentai.v1beta2.OutputConfig.verify|verify} messages.
                     * @param message OutputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OutputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.OutputConfig.verify|verify} messages.
                     * @param message OutputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OutputConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OutputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.OutputConfig;

                    /**
                     * Decodes an OutputConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OutputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.OutputConfig;

                    /**
                     * Verifies an OutputConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OutputConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OutputConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.OutputConfig;

                    /**
                     * Creates a plain object from an OutputConfig message. Also converts values to other types if specified.
                     * @param message OutputConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.OutputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OutputConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OutputConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsSource. */
                interface IGcsSource {

                    /** GcsSource uri */
                    uri?: (string|null);
                }

                /** Represents a GcsSource. */
                class GcsSource implements IGcsSource {

                    /**
                     * Constructs a new GcsSource.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IGcsSource);

                    /** GcsSource uri. */
                    public uri: string;

                    /**
                     * Creates a new GcsSource instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsSource instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IGcsSource): google.cloud.documentai.v1beta2.GcsSource;

                    /**
                     * Encodes the specified GcsSource message. Does not implicitly {@link google.cloud.documentai.v1beta2.GcsSource.verify|verify} messages.
                     * @param message GcsSource message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IGcsSource, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsSource message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.GcsSource.verify|verify} messages.
                     * @param message GcsSource message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IGcsSource, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsSource message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsSource
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.GcsSource;

                    /**
                     * Decodes a GcsSource message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsSource
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.GcsSource;

                    /**
                     * Verifies a GcsSource message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsSource message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsSource
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.GcsSource;

                    /**
                     * Creates a plain object from a GcsSource message. Also converts values to other types if specified.
                     * @param message GcsSource
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.GcsSource, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsSource to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsSource
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsDestination. */
                interface IGcsDestination {

                    /** GcsDestination uri */
                    uri?: (string|null);
                }

                /** Represents a GcsDestination. */
                class GcsDestination implements IGcsDestination {

                    /**
                     * Constructs a new GcsDestination.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IGcsDestination);

                    /** GcsDestination uri. */
                    public uri: string;

                    /**
                     * Creates a new GcsDestination instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsDestination instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IGcsDestination): google.cloud.documentai.v1beta2.GcsDestination;

                    /**
                     * Encodes the specified GcsDestination message. Does not implicitly {@link google.cloud.documentai.v1beta2.GcsDestination.verify|verify} messages.
                     * @param message GcsDestination message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IGcsDestination, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsDestination message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.GcsDestination.verify|verify} messages.
                     * @param message GcsDestination message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IGcsDestination, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsDestination message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsDestination
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.GcsDestination;

                    /**
                     * Decodes a GcsDestination message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsDestination
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.GcsDestination;

                    /**
                     * Verifies a GcsDestination message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsDestination message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsDestination
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.GcsDestination;

                    /**
                     * Creates a plain object from a GcsDestination message. Also converts values to other types if specified.
                     * @param message GcsDestination
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.GcsDestination, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsDestination to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsDestination
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an OperationMetadata. */
                interface IOperationMetadata {

                    /** OperationMetadata state */
                    state?: (google.cloud.documentai.v1beta2.OperationMetadata.State|keyof typeof google.cloud.documentai.v1beta2.OperationMetadata.State|null);

                    /** OperationMetadata stateMessage */
                    stateMessage?: (string|null);

                    /** OperationMetadata createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** OperationMetadata updateTime */
                    updateTime?: (google.protobuf.ITimestamp|null);
                }

                /** Represents an OperationMetadata. */
                class OperationMetadata implements IOperationMetadata {

                    /**
                     * Constructs a new OperationMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta2.IOperationMetadata);

                    /** OperationMetadata state. */
                    public state: (google.cloud.documentai.v1beta2.OperationMetadata.State|keyof typeof google.cloud.documentai.v1beta2.OperationMetadata.State);

                    /** OperationMetadata stateMessage. */
                    public stateMessage: string;

                    /** OperationMetadata createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** OperationMetadata updateTime. */
                    public updateTime?: (google.protobuf.ITimestamp|null);

                    /**
                     * Creates a new OperationMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OperationMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta2.IOperationMetadata): google.cloud.documentai.v1beta2.OperationMetadata;

                    /**
                     * Encodes the specified OperationMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta2.OperationMetadata.verify|verify} messages.
                     * @param message OperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta2.IOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OperationMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta2.OperationMetadata.verify|verify} messages.
                     * @param message OperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta2.IOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OperationMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta2.OperationMetadata;

                    /**
                     * Decodes an OperationMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta2.OperationMetadata;

                    /**
                     * Verifies an OperationMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OperationMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OperationMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta2.OperationMetadata;

                    /**
                     * Creates a plain object from an OperationMetadata message. Also converts values to other types if specified.
                     * @param message OperationMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta2.OperationMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OperationMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OperationMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace OperationMetadata {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        ACCEPTED = 1,
                        WAITING = 2,
                        RUNNING = 3,
                        SUCCEEDED = 4,
                        CANCELLED = 5,
                        FAILED = 6
                    }
                }
            }

            /** Namespace v1beta3. */
            namespace v1beta3 {

                /** Properties of a Barcode. */
                interface IBarcode {

                    /** Barcode format */
                    format?: (string|null);

                    /** Barcode valueFormat */
                    valueFormat?: (string|null);

                    /** Barcode rawValue */
                    rawValue?: (string|null);
                }

                /** Represents a Barcode. */
                class Barcode implements IBarcode {

                    /**
                     * Constructs a new Barcode.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBarcode);

                    /** Barcode format. */
                    public format: string;

                    /** Barcode valueFormat. */
                    public valueFormat: string;

                    /** Barcode rawValue. */
                    public rawValue: string;

                    /**
                     * Creates a new Barcode instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Barcode instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBarcode): google.cloud.documentai.v1beta3.Barcode;

                    /**
                     * Encodes the specified Barcode message. Does not implicitly {@link google.cloud.documentai.v1beta3.Barcode.verify|verify} messages.
                     * @param message Barcode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Barcode message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Barcode.verify|verify} messages.
                     * @param message Barcode message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Barcode message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Barcode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Barcode;

                    /**
                     * Decodes a Barcode message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Barcode
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Barcode;

                    /**
                     * Verifies a Barcode message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Barcode message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Barcode
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Barcode;

                    /**
                     * Creates a plain object from a Barcode message. Also converts values to other types if specified.
                     * @param message Barcode
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.Barcode, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Barcode to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Barcode
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Dataset. */
                interface IDataset {

                    /** Dataset gcsManagedConfig */
                    gcsManagedConfig?: (google.cloud.documentai.v1beta3.Dataset.IGCSManagedConfig|null);

                    /** Dataset documentWarehouseConfig */
                    documentWarehouseConfig?: (google.cloud.documentai.v1beta3.Dataset.IDocumentWarehouseConfig|null);

                    /** Dataset unmanagedDatasetConfig */
                    unmanagedDatasetConfig?: (google.cloud.documentai.v1beta3.Dataset.IUnmanagedDatasetConfig|null);

                    /** Dataset spannerIndexingConfig */
                    spannerIndexingConfig?: (google.cloud.documentai.v1beta3.Dataset.ISpannerIndexingConfig|null);

                    /** Dataset name */
                    name?: (string|null);

                    /** Dataset state */
                    state?: (google.cloud.documentai.v1beta3.Dataset.State|keyof typeof google.cloud.documentai.v1beta3.Dataset.State|null);

                    /** Dataset satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** Dataset satisfiesPzi */
                    satisfiesPzi?: (boolean|null);
                }

                /** Represents a Dataset. */
                class Dataset implements IDataset {

                    /**
                     * Constructs a new Dataset.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDataset);

                    /** Dataset gcsManagedConfig. */
                    public gcsManagedConfig?: (google.cloud.documentai.v1beta3.Dataset.IGCSManagedConfig|null);

                    /** Dataset documentWarehouseConfig. */
                    public documentWarehouseConfig?: (google.cloud.documentai.v1beta3.Dataset.IDocumentWarehouseConfig|null);

                    /** Dataset unmanagedDatasetConfig. */
                    public unmanagedDatasetConfig?: (google.cloud.documentai.v1beta3.Dataset.IUnmanagedDatasetConfig|null);

                    /** Dataset spannerIndexingConfig. */
                    public spannerIndexingConfig?: (google.cloud.documentai.v1beta3.Dataset.ISpannerIndexingConfig|null);

                    /** Dataset name. */
                    public name: string;

                    /** Dataset state. */
                    public state: (google.cloud.documentai.v1beta3.Dataset.State|keyof typeof google.cloud.documentai.v1beta3.Dataset.State);

                    /** Dataset satisfiesPzs. */
                    public satisfiesPzs: boolean;

                    /** Dataset satisfiesPzi. */
                    public satisfiesPzi: boolean;

                    /** Dataset storageSource. */
                    public storageSource?: ("gcsManagedConfig"|"documentWarehouseConfig"|"unmanagedDatasetConfig");

                    /** Dataset indexingSource. */
                    public indexingSource?: "spannerIndexingConfig";

                    /**
                     * Creates a new Dataset instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Dataset instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDataset): google.cloud.documentai.v1beta3.Dataset;

                    /**
                     * Encodes the specified Dataset message. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.verify|verify} messages.
                     * @param message Dataset message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDataset, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Dataset message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.verify|verify} messages.
                     * @param message Dataset message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDataset, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Dataset message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Dataset
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Dataset;

                    /**
                     * Decodes a Dataset message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Dataset
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Dataset;

                    /**
                     * Verifies a Dataset message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Dataset message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Dataset
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Dataset;

                    /**
                     * Creates a plain object from a Dataset message. Also converts values to other types if specified.
                     * @param message Dataset
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.Dataset, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Dataset to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Dataset
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Dataset {

                    /** Properties of a GCSManagedConfig. */
                    interface IGCSManagedConfig {

                        /** GCSManagedConfig gcsPrefix */
                        gcsPrefix?: (google.cloud.documentai.v1beta3.IGcsPrefix|null);
                    }

                    /** Represents a GCSManagedConfig. */
                    class GCSManagedConfig implements IGCSManagedConfig {

                        /**
                         * Constructs a new GCSManagedConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Dataset.IGCSManagedConfig);

                        /** GCSManagedConfig gcsPrefix. */
                        public gcsPrefix?: (google.cloud.documentai.v1beta3.IGcsPrefix|null);

                        /**
                         * Creates a new GCSManagedConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns GCSManagedConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Dataset.IGCSManagedConfig): google.cloud.documentai.v1beta3.Dataset.GCSManagedConfig;

                        /**
                         * Encodes the specified GCSManagedConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.GCSManagedConfig.verify|verify} messages.
                         * @param message GCSManagedConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Dataset.IGCSManagedConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified GCSManagedConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.GCSManagedConfig.verify|verify} messages.
                         * @param message GCSManagedConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Dataset.IGCSManagedConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a GCSManagedConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns GCSManagedConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Dataset.GCSManagedConfig;

                        /**
                         * Decodes a GCSManagedConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns GCSManagedConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Dataset.GCSManagedConfig;

                        /**
                         * Verifies a GCSManagedConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a GCSManagedConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns GCSManagedConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Dataset.GCSManagedConfig;

                        /**
                         * Creates a plain object from a GCSManagedConfig message. Also converts values to other types if specified.
                         * @param message GCSManagedConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Dataset.GCSManagedConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this GCSManagedConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for GCSManagedConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a DocumentWarehouseConfig. */
                    interface IDocumentWarehouseConfig {

                        /** DocumentWarehouseConfig collection */
                        collection?: (string|null);

                        /** DocumentWarehouseConfig schema */
                        schema?: (string|null);
                    }

                    /** Represents a DocumentWarehouseConfig. */
                    class DocumentWarehouseConfig implements IDocumentWarehouseConfig {

                        /**
                         * Constructs a new DocumentWarehouseConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Dataset.IDocumentWarehouseConfig);

                        /** DocumentWarehouseConfig collection. */
                        public collection: string;

                        /** DocumentWarehouseConfig schema. */
                        public schema: string;

                        /**
                         * Creates a new DocumentWarehouseConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns DocumentWarehouseConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Dataset.IDocumentWarehouseConfig): google.cloud.documentai.v1beta3.Dataset.DocumentWarehouseConfig;

                        /**
                         * Encodes the specified DocumentWarehouseConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.DocumentWarehouseConfig.verify|verify} messages.
                         * @param message DocumentWarehouseConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Dataset.IDocumentWarehouseConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified DocumentWarehouseConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.DocumentWarehouseConfig.verify|verify} messages.
                         * @param message DocumentWarehouseConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Dataset.IDocumentWarehouseConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a DocumentWarehouseConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns DocumentWarehouseConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Dataset.DocumentWarehouseConfig;

                        /**
                         * Decodes a DocumentWarehouseConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns DocumentWarehouseConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Dataset.DocumentWarehouseConfig;

                        /**
                         * Verifies a DocumentWarehouseConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a DocumentWarehouseConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns DocumentWarehouseConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Dataset.DocumentWarehouseConfig;

                        /**
                         * Creates a plain object from a DocumentWarehouseConfig message. Also converts values to other types if specified.
                         * @param message DocumentWarehouseConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Dataset.DocumentWarehouseConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this DocumentWarehouseConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for DocumentWarehouseConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of an UnmanagedDatasetConfig. */
                    interface IUnmanagedDatasetConfig {
                    }

                    /** Represents an UnmanagedDatasetConfig. */
                    class UnmanagedDatasetConfig implements IUnmanagedDatasetConfig {

                        /**
                         * Constructs a new UnmanagedDatasetConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Dataset.IUnmanagedDatasetConfig);

                        /**
                         * Creates a new UnmanagedDatasetConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns UnmanagedDatasetConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Dataset.IUnmanagedDatasetConfig): google.cloud.documentai.v1beta3.Dataset.UnmanagedDatasetConfig;

                        /**
                         * Encodes the specified UnmanagedDatasetConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.UnmanagedDatasetConfig.verify|verify} messages.
                         * @param message UnmanagedDatasetConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Dataset.IUnmanagedDatasetConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified UnmanagedDatasetConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.UnmanagedDatasetConfig.verify|verify} messages.
                         * @param message UnmanagedDatasetConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Dataset.IUnmanagedDatasetConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an UnmanagedDatasetConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns UnmanagedDatasetConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Dataset.UnmanagedDatasetConfig;

                        /**
                         * Decodes an UnmanagedDatasetConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns UnmanagedDatasetConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Dataset.UnmanagedDatasetConfig;

                        /**
                         * Verifies an UnmanagedDatasetConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an UnmanagedDatasetConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns UnmanagedDatasetConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Dataset.UnmanagedDatasetConfig;

                        /**
                         * Creates a plain object from an UnmanagedDatasetConfig message. Also converts values to other types if specified.
                         * @param message UnmanagedDatasetConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Dataset.UnmanagedDatasetConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this UnmanagedDatasetConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for UnmanagedDatasetConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a SpannerIndexingConfig. */
                    interface ISpannerIndexingConfig {
                    }

                    /** Represents a SpannerIndexingConfig. */
                    class SpannerIndexingConfig implements ISpannerIndexingConfig {

                        /**
                         * Constructs a new SpannerIndexingConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Dataset.ISpannerIndexingConfig);

                        /**
                         * Creates a new SpannerIndexingConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns SpannerIndexingConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Dataset.ISpannerIndexingConfig): google.cloud.documentai.v1beta3.Dataset.SpannerIndexingConfig;

                        /**
                         * Encodes the specified SpannerIndexingConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.SpannerIndexingConfig.verify|verify} messages.
                         * @param message SpannerIndexingConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Dataset.ISpannerIndexingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified SpannerIndexingConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Dataset.SpannerIndexingConfig.verify|verify} messages.
                         * @param message SpannerIndexingConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Dataset.ISpannerIndexingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a SpannerIndexingConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns SpannerIndexingConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Dataset.SpannerIndexingConfig;

                        /**
                         * Decodes a SpannerIndexingConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns SpannerIndexingConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Dataset.SpannerIndexingConfig;

                        /**
                         * Verifies a SpannerIndexingConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a SpannerIndexingConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns SpannerIndexingConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Dataset.SpannerIndexingConfig;

                        /**
                         * Creates a plain object from a SpannerIndexingConfig message. Also converts values to other types if specified.
                         * @param message SpannerIndexingConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Dataset.SpannerIndexingConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this SpannerIndexingConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for SpannerIndexingConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        UNINITIALIZED = 1,
                        INITIALIZING = 2,
                        INITIALIZED = 3
                    }
                }

                /** Properties of a DocumentId. */
                interface IDocumentId {

                    /** DocumentId gcsManagedDocId */
                    gcsManagedDocId?: (google.cloud.documentai.v1beta3.DocumentId.IGCSManagedDocumentId|null);

                    /** DocumentId unmanagedDocId */
                    unmanagedDocId?: (google.cloud.documentai.v1beta3.DocumentId.IUnmanagedDocumentId|null);

                    /** DocumentId revisionRef */
                    revisionRef?: (google.cloud.documentai.v1beta3.IRevisionRef|null);
                }

                /** Represents a DocumentId. */
                class DocumentId implements IDocumentId {

                    /**
                     * Constructs a new DocumentId.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDocumentId);

                    /** DocumentId gcsManagedDocId. */
                    public gcsManagedDocId?: (google.cloud.documentai.v1beta3.DocumentId.IGCSManagedDocumentId|null);

                    /** DocumentId unmanagedDocId. */
                    public unmanagedDocId?: (google.cloud.documentai.v1beta3.DocumentId.IUnmanagedDocumentId|null);

                    /** DocumentId revisionRef. */
                    public revisionRef?: (google.cloud.documentai.v1beta3.IRevisionRef|null);

                    /** DocumentId type. */
                    public type?: ("gcsManagedDocId"|"unmanagedDocId");

                    /**
                     * Creates a new DocumentId instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DocumentId instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDocumentId): google.cloud.documentai.v1beta3.DocumentId;

                    /**
                     * Encodes the specified DocumentId message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentId.verify|verify} messages.
                     * @param message DocumentId message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDocumentId, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DocumentId message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentId.verify|verify} messages.
                     * @param message DocumentId message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDocumentId, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DocumentId message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DocumentId
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentId;

                    /**
                     * Decodes a DocumentId message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DocumentId
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentId;

                    /**
                     * Verifies a DocumentId message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DocumentId message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DocumentId
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentId;

                    /**
                     * Creates a plain object from a DocumentId message. Also converts values to other types if specified.
                     * @param message DocumentId
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DocumentId, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DocumentId to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DocumentId
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace DocumentId {

                    /** Properties of a GCSManagedDocumentId. */
                    interface IGCSManagedDocumentId {

                        /** GCSManagedDocumentId gcsUri */
                        gcsUri?: (string|null);

                        /** GCSManagedDocumentId cwDocId */
                        cwDocId?: (string|null);
                    }

                    /** Represents a GCSManagedDocumentId. */
                    class GCSManagedDocumentId implements IGCSManagedDocumentId {

                        /**
                         * Constructs a new GCSManagedDocumentId.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.DocumentId.IGCSManagedDocumentId);

                        /** GCSManagedDocumentId gcsUri. */
                        public gcsUri: string;

                        /** GCSManagedDocumentId cwDocId. */
                        public cwDocId: string;

                        /**
                         * Creates a new GCSManagedDocumentId instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns GCSManagedDocumentId instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.DocumentId.IGCSManagedDocumentId): google.cloud.documentai.v1beta3.DocumentId.GCSManagedDocumentId;

                        /**
                         * Encodes the specified GCSManagedDocumentId message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentId.GCSManagedDocumentId.verify|verify} messages.
                         * @param message GCSManagedDocumentId message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.DocumentId.IGCSManagedDocumentId, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified GCSManagedDocumentId message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentId.GCSManagedDocumentId.verify|verify} messages.
                         * @param message GCSManagedDocumentId message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.DocumentId.IGCSManagedDocumentId, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a GCSManagedDocumentId message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns GCSManagedDocumentId
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentId.GCSManagedDocumentId;

                        /**
                         * Decodes a GCSManagedDocumentId message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns GCSManagedDocumentId
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentId.GCSManagedDocumentId;

                        /**
                         * Verifies a GCSManagedDocumentId message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a GCSManagedDocumentId message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns GCSManagedDocumentId
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentId.GCSManagedDocumentId;

                        /**
                         * Creates a plain object from a GCSManagedDocumentId message. Also converts values to other types if specified.
                         * @param message GCSManagedDocumentId
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.DocumentId.GCSManagedDocumentId, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this GCSManagedDocumentId to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for GCSManagedDocumentId
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of an UnmanagedDocumentId. */
                    interface IUnmanagedDocumentId {

                        /** UnmanagedDocumentId docId */
                        docId?: (string|null);
                    }

                    /** Represents an UnmanagedDocumentId. */
                    class UnmanagedDocumentId implements IUnmanagedDocumentId {

                        /**
                         * Constructs a new UnmanagedDocumentId.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.DocumentId.IUnmanagedDocumentId);

                        /** UnmanagedDocumentId docId. */
                        public docId: string;

                        /**
                         * Creates a new UnmanagedDocumentId instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns UnmanagedDocumentId instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.DocumentId.IUnmanagedDocumentId): google.cloud.documentai.v1beta3.DocumentId.UnmanagedDocumentId;

                        /**
                         * Encodes the specified UnmanagedDocumentId message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentId.UnmanagedDocumentId.verify|verify} messages.
                         * @param message UnmanagedDocumentId message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.DocumentId.IUnmanagedDocumentId, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified UnmanagedDocumentId message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentId.UnmanagedDocumentId.verify|verify} messages.
                         * @param message UnmanagedDocumentId message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.DocumentId.IUnmanagedDocumentId, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an UnmanagedDocumentId message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns UnmanagedDocumentId
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentId.UnmanagedDocumentId;

                        /**
                         * Decodes an UnmanagedDocumentId message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns UnmanagedDocumentId
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentId.UnmanagedDocumentId;

                        /**
                         * Verifies an UnmanagedDocumentId message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an UnmanagedDocumentId message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns UnmanagedDocumentId
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentId.UnmanagedDocumentId;

                        /**
                         * Creates a plain object from an UnmanagedDocumentId message. Also converts values to other types if specified.
                         * @param message UnmanagedDocumentId
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.DocumentId.UnmanagedDocumentId, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this UnmanagedDocumentId to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for UnmanagedDocumentId
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a DatasetSchema. */
                interface IDatasetSchema {

                    /** DatasetSchema name */
                    name?: (string|null);

                    /** DatasetSchema documentSchema */
                    documentSchema?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);

                    /** DatasetSchema satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** DatasetSchema satisfiesPzi */
                    satisfiesPzi?: (boolean|null);
                }

                /** Represents a DatasetSchema. */
                class DatasetSchema implements IDatasetSchema {

                    /**
                     * Constructs a new DatasetSchema.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDatasetSchema);

                    /** DatasetSchema name. */
                    public name: string;

                    /** DatasetSchema documentSchema. */
                    public documentSchema?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);

                    /** DatasetSchema satisfiesPzs. */
                    public satisfiesPzs: boolean;

                    /** DatasetSchema satisfiesPzi. */
                    public satisfiesPzi: boolean;

                    /**
                     * Creates a new DatasetSchema instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DatasetSchema instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDatasetSchema): google.cloud.documentai.v1beta3.DatasetSchema;

                    /**
                     * Encodes the specified DatasetSchema message. Does not implicitly {@link google.cloud.documentai.v1beta3.DatasetSchema.verify|verify} messages.
                     * @param message DatasetSchema message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDatasetSchema, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DatasetSchema message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DatasetSchema.verify|verify} messages.
                     * @param message DatasetSchema message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDatasetSchema, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DatasetSchema message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DatasetSchema
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DatasetSchema;

                    /**
                     * Decodes a DatasetSchema message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DatasetSchema
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DatasetSchema;

                    /**
                     * Verifies a DatasetSchema message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DatasetSchema message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DatasetSchema
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DatasetSchema;

                    /**
                     * Creates a plain object from a DatasetSchema message. Also converts values to other types if specified.
                     * @param message DatasetSchema
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DatasetSchema, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DatasetSchema to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DatasetSchema
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchDatasetDocuments. */
                interface IBatchDatasetDocuments {

                    /** BatchDatasetDocuments individualDocumentIds */
                    individualDocumentIds?: (google.cloud.documentai.v1beta3.BatchDatasetDocuments.IIndividualDocumentIds|null);

                    /** BatchDatasetDocuments filter */
                    filter?: (string|null);
                }

                /** Represents a BatchDatasetDocuments. */
                class BatchDatasetDocuments implements IBatchDatasetDocuments {

                    /**
                     * Constructs a new BatchDatasetDocuments.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBatchDatasetDocuments);

                    /** BatchDatasetDocuments individualDocumentIds. */
                    public individualDocumentIds?: (google.cloud.documentai.v1beta3.BatchDatasetDocuments.IIndividualDocumentIds|null);

                    /** BatchDatasetDocuments filter. */
                    public filter?: (string|null);

                    /** BatchDatasetDocuments criteria. */
                    public criteria?: ("individualDocumentIds"|"filter");

                    /**
                     * Creates a new BatchDatasetDocuments instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchDatasetDocuments instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBatchDatasetDocuments): google.cloud.documentai.v1beta3.BatchDatasetDocuments;

                    /**
                     * Encodes the specified BatchDatasetDocuments message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDatasetDocuments.verify|verify} messages.
                     * @param message BatchDatasetDocuments message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBatchDatasetDocuments, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchDatasetDocuments message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDatasetDocuments.verify|verify} messages.
                     * @param message BatchDatasetDocuments message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBatchDatasetDocuments, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchDatasetDocuments message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchDatasetDocuments
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchDatasetDocuments;

                    /**
                     * Decodes a BatchDatasetDocuments message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchDatasetDocuments
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchDatasetDocuments;

                    /**
                     * Verifies a BatchDatasetDocuments message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchDatasetDocuments message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchDatasetDocuments
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchDatasetDocuments;

                    /**
                     * Creates a plain object from a BatchDatasetDocuments message. Also converts values to other types if specified.
                     * @param message BatchDatasetDocuments
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.BatchDatasetDocuments, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchDatasetDocuments to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchDatasetDocuments
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BatchDatasetDocuments {

                    /** Properties of an IndividualDocumentIds. */
                    interface IIndividualDocumentIds {

                        /** IndividualDocumentIds documentIds */
                        documentIds?: (google.cloud.documentai.v1beta3.IDocumentId[]|null);
                    }

                    /** Represents an IndividualDocumentIds. */
                    class IndividualDocumentIds implements IIndividualDocumentIds {

                        /**
                         * Constructs a new IndividualDocumentIds.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.BatchDatasetDocuments.IIndividualDocumentIds);

                        /** IndividualDocumentIds documentIds. */
                        public documentIds: google.cloud.documentai.v1beta3.IDocumentId[];

                        /**
                         * Creates a new IndividualDocumentIds instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns IndividualDocumentIds instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.BatchDatasetDocuments.IIndividualDocumentIds): google.cloud.documentai.v1beta3.BatchDatasetDocuments.IndividualDocumentIds;

                        /**
                         * Encodes the specified IndividualDocumentIds message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDatasetDocuments.IndividualDocumentIds.verify|verify} messages.
                         * @param message IndividualDocumentIds message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.BatchDatasetDocuments.IIndividualDocumentIds, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified IndividualDocumentIds message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDatasetDocuments.IndividualDocumentIds.verify|verify} messages.
                         * @param message IndividualDocumentIds message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.BatchDatasetDocuments.IIndividualDocumentIds, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an IndividualDocumentIds message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns IndividualDocumentIds
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchDatasetDocuments.IndividualDocumentIds;

                        /**
                         * Decodes an IndividualDocumentIds message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns IndividualDocumentIds
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchDatasetDocuments.IndividualDocumentIds;

                        /**
                         * Verifies an IndividualDocumentIds message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an IndividualDocumentIds message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns IndividualDocumentIds
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchDatasetDocuments.IndividualDocumentIds;

                        /**
                         * Creates a plain object from an IndividualDocumentIds message. Also converts values to other types if specified.
                         * @param message IndividualDocumentIds
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.BatchDatasetDocuments.IndividualDocumentIds, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this IndividualDocumentIds to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for IndividualDocumentIds
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a Document. */
                interface IDocument {

                    /** Document uri */
                    uri?: (string|null);

                    /** Document content */
                    content?: (Uint8Array|string|null);

                    /** Document mimeType */
                    mimeType?: (string|null);

                    /** Document text */
                    text?: (string|null);

                    /** Document textStyles */
                    textStyles?: (google.cloud.documentai.v1beta3.Document.IStyle[]|null);

                    /** Document pages */
                    pages?: (google.cloud.documentai.v1beta3.Document.IPage[]|null);

                    /** Document entities */
                    entities?: (google.cloud.documentai.v1beta3.Document.IEntity[]|null);

                    /** Document entityRelations */
                    entityRelations?: (google.cloud.documentai.v1beta3.Document.IEntityRelation[]|null);

                    /** Document textChanges */
                    textChanges?: (google.cloud.documentai.v1beta3.Document.ITextChange[]|null);

                    /** Document shardInfo */
                    shardInfo?: (google.cloud.documentai.v1beta3.Document.IShardInfo|null);

                    /** Document error */
                    error?: (google.rpc.IStatus|null);

                    /** Document revisions */
                    revisions?: (google.cloud.documentai.v1beta3.Document.IRevision[]|null);

                    /** Document documentLayout */
                    documentLayout?: (google.cloud.documentai.v1beta3.Document.IDocumentLayout|null);

                    /** Document chunkedDocument */
                    chunkedDocument?: (google.cloud.documentai.v1beta3.Document.IChunkedDocument|null);
                }

                /** Represents a Document. */
                class Document implements IDocument {

                    /**
                     * Constructs a new Document.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDocument);

                    /** Document uri. */
                    public uri?: (string|null);

                    /** Document content. */
                    public content?: (Uint8Array|string|null);

                    /** Document mimeType. */
                    public mimeType: string;

                    /** Document text. */
                    public text: string;

                    /** Document textStyles. */
                    public textStyles: google.cloud.documentai.v1beta3.Document.IStyle[];

                    /** Document pages. */
                    public pages: google.cloud.documentai.v1beta3.Document.IPage[];

                    /** Document entities. */
                    public entities: google.cloud.documentai.v1beta3.Document.IEntity[];

                    /** Document entityRelations. */
                    public entityRelations: google.cloud.documentai.v1beta3.Document.IEntityRelation[];

                    /** Document textChanges. */
                    public textChanges: google.cloud.documentai.v1beta3.Document.ITextChange[];

                    /** Document shardInfo. */
                    public shardInfo?: (google.cloud.documentai.v1beta3.Document.IShardInfo|null);

                    /** Document error. */
                    public error?: (google.rpc.IStatus|null);

                    /** Document revisions. */
                    public revisions: google.cloud.documentai.v1beta3.Document.IRevision[];

                    /** Document documentLayout. */
                    public documentLayout?: (google.cloud.documentai.v1beta3.Document.IDocumentLayout|null);

                    /** Document chunkedDocument. */
                    public chunkedDocument?: (google.cloud.documentai.v1beta3.Document.IChunkedDocument|null);

                    /** Document source. */
                    public source?: ("uri"|"content");

                    /**
                     * Creates a new Document instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Document instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDocument): google.cloud.documentai.v1beta3.Document;

                    /**
                     * Encodes the specified Document message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.verify|verify} messages.
                     * @param message Document message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Document message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.verify|verify} messages.
                     * @param message Document message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Document message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Document
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document;

                    /**
                     * Decodes a Document message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Document
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document;

                    /**
                     * Verifies a Document message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Document message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Document
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document;

                    /**
                     * Creates a plain object from a Document message. Also converts values to other types if specified.
                     * @param message Document
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.Document, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Document to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Document
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Document {

                    /** Properties of a ShardInfo. */
                    interface IShardInfo {

                        /** ShardInfo shardIndex */
                        shardIndex?: (number|Long|string|null);

                        /** ShardInfo shardCount */
                        shardCount?: (number|Long|string|null);

                        /** ShardInfo textOffset */
                        textOffset?: (number|Long|string|null);
                    }

                    /** Represents a ShardInfo. */
                    class ShardInfo implements IShardInfo {

                        /**
                         * Constructs a new ShardInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IShardInfo);

                        /** ShardInfo shardIndex. */
                        public shardIndex: (number|Long|string);

                        /** ShardInfo shardCount. */
                        public shardCount: (number|Long|string);

                        /** ShardInfo textOffset. */
                        public textOffset: (number|Long|string);

                        /**
                         * Creates a new ShardInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ShardInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IShardInfo): google.cloud.documentai.v1beta3.Document.ShardInfo;

                        /**
                         * Encodes the specified ShardInfo message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ShardInfo.verify|verify} messages.
                         * @param message ShardInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IShardInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ShardInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ShardInfo.verify|verify} messages.
                         * @param message ShardInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IShardInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a ShardInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ShardInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.ShardInfo;

                        /**
                         * Decodes a ShardInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ShardInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.ShardInfo;

                        /**
                         * Verifies a ShardInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a ShardInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ShardInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.ShardInfo;

                        /**
                         * Creates a plain object from a ShardInfo message. Also converts values to other types if specified.
                         * @param message ShardInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.ShardInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ShardInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ShardInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a Style. */
                    interface IStyle {

                        /** Style textAnchor */
                        textAnchor?: (google.cloud.documentai.v1beta3.Document.ITextAnchor|null);

                        /** Style color */
                        color?: (google.type.IColor|null);

                        /** Style backgroundColor */
                        backgroundColor?: (google.type.IColor|null);

                        /** Style fontWeight */
                        fontWeight?: (string|null);

                        /** Style textStyle */
                        textStyle?: (string|null);

                        /** Style textDecoration */
                        textDecoration?: (string|null);

                        /** Style fontSize */
                        fontSize?: (google.cloud.documentai.v1beta3.Document.Style.IFontSize|null);

                        /** Style fontFamily */
                        fontFamily?: (string|null);
                    }

                    /** Represents a Style. */
                    class Style implements IStyle {

                        /**
                         * Constructs a new Style.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IStyle);

                        /** Style textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1beta3.Document.ITextAnchor|null);

                        /** Style color. */
                        public color?: (google.type.IColor|null);

                        /** Style backgroundColor. */
                        public backgroundColor?: (google.type.IColor|null);

                        /** Style fontWeight. */
                        public fontWeight: string;

                        /** Style textStyle. */
                        public textStyle: string;

                        /** Style textDecoration. */
                        public textDecoration: string;

                        /** Style fontSize. */
                        public fontSize?: (google.cloud.documentai.v1beta3.Document.Style.IFontSize|null);

                        /** Style fontFamily. */
                        public fontFamily: string;

                        /**
                         * Creates a new Style instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Style instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IStyle): google.cloud.documentai.v1beta3.Document.Style;

                        /**
                         * Encodes the specified Style message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Style.verify|verify} messages.
                         * @param message Style message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IStyle, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Style message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Style.verify|verify} messages.
                         * @param message Style message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IStyle, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Style message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Style
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Style;

                        /**
                         * Decodes a Style message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Style
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Style;

                        /**
                         * Verifies a Style message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Style message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Style
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Style;

                        /**
                         * Creates a plain object from a Style message. Also converts values to other types if specified.
                         * @param message Style
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.Style, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Style to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Style
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Style {

                        /** Properties of a FontSize. */
                        interface IFontSize {

                            /** FontSize size */
                            size?: (number|null);

                            /** FontSize unit */
                            unit?: (string|null);
                        }

                        /** Represents a FontSize. */
                        class FontSize implements IFontSize {

                            /**
                             * Constructs a new FontSize.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Style.IFontSize);

                            /** FontSize size. */
                            public size: number;

                            /** FontSize unit. */
                            public unit: string;

                            /**
                             * Creates a new FontSize instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FontSize instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Style.IFontSize): google.cloud.documentai.v1beta3.Document.Style.FontSize;

                            /**
                             * Encodes the specified FontSize message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Style.FontSize.verify|verify} messages.
                             * @param message FontSize message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Style.IFontSize, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FontSize message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Style.FontSize.verify|verify} messages.
                             * @param message FontSize message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Style.IFontSize, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FontSize message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FontSize
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Style.FontSize;

                            /**
                             * Decodes a FontSize message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FontSize
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Style.FontSize;

                            /**
                             * Verifies a FontSize message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FontSize message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FontSize
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Style.FontSize;

                            /**
                             * Creates a plain object from a FontSize message. Also converts values to other types if specified.
                             * @param message FontSize
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Style.FontSize, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FontSize to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FontSize
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a Page. */
                    interface IPage {

                        /** Page pageNumber */
                        pageNumber?: (number|null);

                        /** Page image */
                        image?: (google.cloud.documentai.v1beta3.Document.Page.IImage|null);

                        /** Page transforms */
                        transforms?: (google.cloud.documentai.v1beta3.Document.Page.IMatrix[]|null);

                        /** Page dimension */
                        dimension?: (google.cloud.documentai.v1beta3.Document.Page.IDimension|null);

                        /** Page layout */
                        layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                        /** Page detectedLanguages */
                        detectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);

                        /** Page blocks */
                        blocks?: (google.cloud.documentai.v1beta3.Document.Page.IBlock[]|null);

                        /** Page paragraphs */
                        paragraphs?: (google.cloud.documentai.v1beta3.Document.Page.IParagraph[]|null);

                        /** Page lines */
                        lines?: (google.cloud.documentai.v1beta3.Document.Page.ILine[]|null);

                        /** Page tokens */
                        tokens?: (google.cloud.documentai.v1beta3.Document.Page.IToken[]|null);

                        /** Page visualElements */
                        visualElements?: (google.cloud.documentai.v1beta3.Document.Page.IVisualElement[]|null);

                        /** Page tables */
                        tables?: (google.cloud.documentai.v1beta3.Document.Page.ITable[]|null);

                        /** Page formFields */
                        formFields?: (google.cloud.documentai.v1beta3.Document.Page.IFormField[]|null);

                        /** Page symbols */
                        symbols?: (google.cloud.documentai.v1beta3.Document.Page.ISymbol[]|null);

                        /** Page detectedBarcodes */
                        detectedBarcodes?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedBarcode[]|null);

                        /** Page imageQualityScores */
                        imageQualityScores?: (google.cloud.documentai.v1beta3.Document.Page.IImageQualityScores|null);

                        /** Page provenance */
                        provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);
                    }

                    /** Represents a Page. */
                    class Page implements IPage {

                        /**
                         * Constructs a new Page.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IPage);

                        /** Page pageNumber. */
                        public pageNumber: number;

                        /** Page image. */
                        public image?: (google.cloud.documentai.v1beta3.Document.Page.IImage|null);

                        /** Page transforms. */
                        public transforms: google.cloud.documentai.v1beta3.Document.Page.IMatrix[];

                        /** Page dimension. */
                        public dimension?: (google.cloud.documentai.v1beta3.Document.Page.IDimension|null);

                        /** Page layout. */
                        public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                        /** Page detectedLanguages. */
                        public detectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                        /** Page blocks. */
                        public blocks: google.cloud.documentai.v1beta3.Document.Page.IBlock[];

                        /** Page paragraphs. */
                        public paragraphs: google.cloud.documentai.v1beta3.Document.Page.IParagraph[];

                        /** Page lines. */
                        public lines: google.cloud.documentai.v1beta3.Document.Page.ILine[];

                        /** Page tokens. */
                        public tokens: google.cloud.documentai.v1beta3.Document.Page.IToken[];

                        /** Page visualElements. */
                        public visualElements: google.cloud.documentai.v1beta3.Document.Page.IVisualElement[];

                        /** Page tables. */
                        public tables: google.cloud.documentai.v1beta3.Document.Page.ITable[];

                        /** Page formFields. */
                        public formFields: google.cloud.documentai.v1beta3.Document.Page.IFormField[];

                        /** Page symbols. */
                        public symbols: google.cloud.documentai.v1beta3.Document.Page.ISymbol[];

                        /** Page detectedBarcodes. */
                        public detectedBarcodes: google.cloud.documentai.v1beta3.Document.Page.IDetectedBarcode[];

                        /** Page imageQualityScores. */
                        public imageQualityScores?: (google.cloud.documentai.v1beta3.Document.Page.IImageQualityScores|null);

                        /** Page provenance. */
                        public provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                        /**
                         * Creates a new Page instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Page instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IPage): google.cloud.documentai.v1beta3.Document.Page;

                        /**
                         * Encodes the specified Page message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.verify|verify} messages.
                         * @param message Page message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IPage, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Page message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.verify|verify} messages.
                         * @param message Page message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IPage, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Page message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Page
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page;

                        /**
                         * Decodes a Page message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Page
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page;

                        /**
                         * Verifies a Page message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Page message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Page
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page;

                        /**
                         * Creates a plain object from a Page message. Also converts values to other types if specified.
                         * @param message Page
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.Page, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Page to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Page
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Page {

                        /** Properties of a Dimension. */
                        interface IDimension {

                            /** Dimension width */
                            width?: (number|null);

                            /** Dimension height */
                            height?: (number|null);

                            /** Dimension unit */
                            unit?: (string|null);
                        }

                        /** Represents a Dimension. */
                        class Dimension implements IDimension {

                            /**
                             * Constructs a new Dimension.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IDimension);

                            /** Dimension width. */
                            public width: number;

                            /** Dimension height. */
                            public height: number;

                            /** Dimension unit. */
                            public unit: string;

                            /**
                             * Creates a new Dimension instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Dimension instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IDimension): google.cloud.documentai.v1beta3.Document.Page.Dimension;

                            /**
                             * Encodes the specified Dimension message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Dimension.verify|verify} messages.
                             * @param message Dimension message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IDimension, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Dimension message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Dimension.verify|verify} messages.
                             * @param message Dimension message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IDimension, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Dimension message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Dimension
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Dimension;

                            /**
                             * Decodes a Dimension message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Dimension
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Dimension;

                            /**
                             * Verifies a Dimension message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Dimension message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Dimension
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Dimension;

                            /**
                             * Creates a plain object from a Dimension message. Also converts values to other types if specified.
                             * @param message Dimension
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Dimension, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Dimension to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Dimension
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of an Image. */
                        interface IImage {

                            /** Image content */
                            content?: (Uint8Array|string|null);

                            /** Image mimeType */
                            mimeType?: (string|null);

                            /** Image width */
                            width?: (number|null);

                            /** Image height */
                            height?: (number|null);
                        }

                        /** Represents an Image. */
                        class Image implements IImage {

                            /**
                             * Constructs a new Image.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IImage);

                            /** Image content. */
                            public content: (Uint8Array|string);

                            /** Image mimeType. */
                            public mimeType: string;

                            /** Image width. */
                            public width: number;

                            /** Image height. */
                            public height: number;

                            /**
                             * Creates a new Image instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Image instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IImage): google.cloud.documentai.v1beta3.Document.Page.Image;

                            /**
                             * Encodes the specified Image message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Image.verify|verify} messages.
                             * @param message Image message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IImage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Image message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Image.verify|verify} messages.
                             * @param message Image message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IImage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes an Image message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Image
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Image;

                            /**
                             * Decodes an Image message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Image
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Image;

                            /**
                             * Verifies an Image message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates an Image message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Image
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Image;

                            /**
                             * Creates a plain object from an Image message. Also converts values to other types if specified.
                             * @param message Image
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Image, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Image to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Image
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Matrix. */
                        interface IMatrix {

                            /** Matrix rows */
                            rows?: (number|null);

                            /** Matrix cols */
                            cols?: (number|null);

                            /** Matrix type */
                            type?: (number|null);

                            /** Matrix data */
                            data?: (Uint8Array|string|null);
                        }

                        /** Represents a Matrix. */
                        class Matrix implements IMatrix {

                            /**
                             * Constructs a new Matrix.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IMatrix);

                            /** Matrix rows. */
                            public rows: number;

                            /** Matrix cols. */
                            public cols: number;

                            /** Matrix type. */
                            public type: number;

                            /** Matrix data. */
                            public data: (Uint8Array|string);

                            /**
                             * Creates a new Matrix instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Matrix instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IMatrix): google.cloud.documentai.v1beta3.Document.Page.Matrix;

                            /**
                             * Encodes the specified Matrix message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Matrix.verify|verify} messages.
                             * @param message Matrix message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IMatrix, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Matrix message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Matrix.verify|verify} messages.
                             * @param message Matrix message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IMatrix, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Matrix message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Matrix
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Matrix;

                            /**
                             * Decodes a Matrix message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Matrix
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Matrix;

                            /**
                             * Verifies a Matrix message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Matrix message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Matrix
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Matrix;

                            /**
                             * Creates a plain object from a Matrix message. Also converts values to other types if specified.
                             * @param message Matrix
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Matrix, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Matrix to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Matrix
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Layout. */
                        interface ILayout {

                            /** Layout textAnchor */
                            textAnchor?: (google.cloud.documentai.v1beta3.Document.ITextAnchor|null);

                            /** Layout confidence */
                            confidence?: (number|null);

                            /** Layout boundingPoly */
                            boundingPoly?: (google.cloud.documentai.v1beta3.IBoundingPoly|null);

                            /** Layout orientation */
                            orientation?: (google.cloud.documentai.v1beta3.Document.Page.Layout.Orientation|keyof typeof google.cloud.documentai.v1beta3.Document.Page.Layout.Orientation|null);
                        }

                        /** Represents a Layout. */
                        class Layout implements ILayout {

                            /**
                             * Constructs a new Layout.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.ILayout);

                            /** Layout textAnchor. */
                            public textAnchor?: (google.cloud.documentai.v1beta3.Document.ITextAnchor|null);

                            /** Layout confidence. */
                            public confidence: number;

                            /** Layout boundingPoly. */
                            public boundingPoly?: (google.cloud.documentai.v1beta3.IBoundingPoly|null);

                            /** Layout orientation. */
                            public orientation: (google.cloud.documentai.v1beta3.Document.Page.Layout.Orientation|keyof typeof google.cloud.documentai.v1beta3.Document.Page.Layout.Orientation);

                            /**
                             * Creates a new Layout instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Layout instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.ILayout): google.cloud.documentai.v1beta3.Document.Page.Layout;

                            /**
                             * Encodes the specified Layout message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Layout.verify|verify} messages.
                             * @param message Layout message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.ILayout, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Layout message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Layout.verify|verify} messages.
                             * @param message Layout message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.ILayout, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Layout message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Layout
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Layout;

                            /**
                             * Decodes a Layout message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Layout
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Layout;

                            /**
                             * Verifies a Layout message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Layout message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Layout
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Layout;

                            /**
                             * Creates a plain object from a Layout message. Also converts values to other types if specified.
                             * @param message Layout
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Layout, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Layout to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Layout
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Layout {

                            /** Orientation enum. */
                            enum Orientation {
                                ORIENTATION_UNSPECIFIED = 0,
                                PAGE_UP = 1,
                                PAGE_RIGHT = 2,
                                PAGE_DOWN = 3,
                                PAGE_LEFT = 4
                            }
                        }

                        /** Properties of a Block. */
                        interface IBlock {

                            /** Block layout */
                            layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Block detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);

                            /** Block provenance */
                            provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);
                        }

                        /** Represents a Block. */
                        class Block implements IBlock {

                            /**
                             * Constructs a new Block.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IBlock);

                            /** Block layout. */
                            public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Block detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                            /** Block provenance. */
                            public provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                            /**
                             * Creates a new Block instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Block instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IBlock): google.cloud.documentai.v1beta3.Document.Page.Block;

                            /**
                             * Encodes the specified Block message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Block.verify|verify} messages.
                             * @param message Block message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Block message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Block.verify|verify} messages.
                             * @param message Block message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Block message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Block
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Block;

                            /**
                             * Decodes a Block message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Block
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Block;

                            /**
                             * Verifies a Block message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Block message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Block
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Block;

                            /**
                             * Creates a plain object from a Block message. Also converts values to other types if specified.
                             * @param message Block
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Block, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Block to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Block
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Paragraph. */
                        interface IParagraph {

                            /** Paragraph layout */
                            layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Paragraph detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);

                            /** Paragraph provenance */
                            provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);
                        }

                        /** Represents a Paragraph. */
                        class Paragraph implements IParagraph {

                            /**
                             * Constructs a new Paragraph.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IParagraph);

                            /** Paragraph layout. */
                            public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Paragraph detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                            /** Paragraph provenance. */
                            public provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                            /**
                             * Creates a new Paragraph instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Paragraph instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IParagraph): google.cloud.documentai.v1beta3.Document.Page.Paragraph;

                            /**
                             * Encodes the specified Paragraph message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Paragraph.verify|verify} messages.
                             * @param message Paragraph message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IParagraph, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Paragraph message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Paragraph.verify|verify} messages.
                             * @param message Paragraph message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IParagraph, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Paragraph message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Paragraph
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Paragraph;

                            /**
                             * Decodes a Paragraph message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Paragraph
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Paragraph;

                            /**
                             * Verifies a Paragraph message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Paragraph message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Paragraph
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Paragraph;

                            /**
                             * Creates a plain object from a Paragraph message. Also converts values to other types if specified.
                             * @param message Paragraph
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Paragraph, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Paragraph to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Paragraph
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Line. */
                        interface ILine {

                            /** Line layout */
                            layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Line detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);

                            /** Line provenance */
                            provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);
                        }

                        /** Represents a Line. */
                        class Line implements ILine {

                            /**
                             * Constructs a new Line.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.ILine);

                            /** Line layout. */
                            public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Line detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                            /** Line provenance. */
                            public provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                            /**
                             * Creates a new Line instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Line instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.ILine): google.cloud.documentai.v1beta3.Document.Page.Line;

                            /**
                             * Encodes the specified Line message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Line.verify|verify} messages.
                             * @param message Line message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.ILine, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Line message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Line.verify|verify} messages.
                             * @param message Line message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.ILine, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Line message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Line
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Line;

                            /**
                             * Decodes a Line message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Line
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Line;

                            /**
                             * Verifies a Line message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Line message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Line
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Line;

                            /**
                             * Creates a plain object from a Line message. Also converts values to other types if specified.
                             * @param message Line
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Line, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Line to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Line
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Token. */
                        interface IToken {

                            /** Token layout */
                            layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Token detectedBreak */
                            detectedBreak?: (google.cloud.documentai.v1beta3.Document.Page.Token.IDetectedBreak|null);

                            /** Token detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);

                            /** Token provenance */
                            provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                            /** Token styleInfo */
                            styleInfo?: (google.cloud.documentai.v1beta3.Document.Page.Token.IStyleInfo|null);
                        }

                        /** Represents a Token. */
                        class Token implements IToken {

                            /**
                             * Constructs a new Token.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IToken);

                            /** Token layout. */
                            public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Token detectedBreak. */
                            public detectedBreak?: (google.cloud.documentai.v1beta3.Document.Page.Token.IDetectedBreak|null);

                            /** Token detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                            /** Token provenance. */
                            public provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                            /** Token styleInfo. */
                            public styleInfo?: (google.cloud.documentai.v1beta3.Document.Page.Token.IStyleInfo|null);

                            /**
                             * Creates a new Token instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Token instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IToken): google.cloud.documentai.v1beta3.Document.Page.Token;

                            /**
                             * Encodes the specified Token message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Token.verify|verify} messages.
                             * @param message Token message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IToken, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Token message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Token.verify|verify} messages.
                             * @param message Token message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IToken, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Token message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Token
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Token;

                            /**
                             * Decodes a Token message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Token
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Token;

                            /**
                             * Verifies a Token message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Token message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Token
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Token;

                            /**
                             * Creates a plain object from a Token message. Also converts values to other types if specified.
                             * @param message Token
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Token, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Token to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Token
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Token {

                            /** Properties of a DetectedBreak. */
                            interface IDetectedBreak {

                                /** DetectedBreak type */
                                type?: (google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak.Type|keyof typeof google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak.Type|null);
                            }

                            /** Represents a DetectedBreak. */
                            class DetectedBreak implements IDetectedBreak {

                                /**
                                 * Constructs a new DetectedBreak.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.Token.IDetectedBreak);

                                /** DetectedBreak type. */
                                public type: (google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak.Type|keyof typeof google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak.Type);

                                /**
                                 * Creates a new DetectedBreak instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns DetectedBreak instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.Token.IDetectedBreak): google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak;

                                /**
                                 * Encodes the specified DetectedBreak message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak.verify|verify} messages.
                                 * @param message DetectedBreak message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.Page.Token.IDetectedBreak, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified DetectedBreak message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak.verify|verify} messages.
                                 * @param message DetectedBreak message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.Token.IDetectedBreak, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a DetectedBreak message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns DetectedBreak
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak;

                                /**
                                 * Decodes a DetectedBreak message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns DetectedBreak
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak;

                                /**
                                 * Verifies a DetectedBreak message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a DetectedBreak message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns DetectedBreak
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak;

                                /**
                                 * Creates a plain object from a DetectedBreak message. Also converts values to other types if specified.
                                 * @param message DetectedBreak
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Token.DetectedBreak, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this DetectedBreak to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for DetectedBreak
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            namespace DetectedBreak {

                                /** Type enum. */
                                enum Type {
                                    TYPE_UNSPECIFIED = 0,
                                    SPACE = 1,
                                    WIDE_SPACE = 2,
                                    HYPHEN = 3
                                }
                            }

                            /** Properties of a StyleInfo. */
                            interface IStyleInfo {

                                /** StyleInfo fontSize */
                                fontSize?: (number|null);

                                /** StyleInfo pixelFontSize */
                                pixelFontSize?: (number|null);

                                /** StyleInfo letterSpacing */
                                letterSpacing?: (number|null);

                                /** StyleInfo fontType */
                                fontType?: (string|null);

                                /** StyleInfo bold */
                                bold?: (boolean|null);

                                /** StyleInfo italic */
                                italic?: (boolean|null);

                                /** StyleInfo underlined */
                                underlined?: (boolean|null);

                                /** StyleInfo strikeout */
                                strikeout?: (boolean|null);

                                /** StyleInfo subscript */
                                subscript?: (boolean|null);

                                /** StyleInfo superscript */
                                superscript?: (boolean|null);

                                /** StyleInfo smallcaps */
                                smallcaps?: (boolean|null);

                                /** StyleInfo fontWeight */
                                fontWeight?: (number|null);

                                /** StyleInfo handwritten */
                                handwritten?: (boolean|null);

                                /** StyleInfo textColor */
                                textColor?: (google.type.IColor|null);

                                /** StyleInfo backgroundColor */
                                backgroundColor?: (google.type.IColor|null);
                            }

                            /** Represents a StyleInfo. */
                            class StyleInfo implements IStyleInfo {

                                /**
                                 * Constructs a new StyleInfo.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.Token.IStyleInfo);

                                /** StyleInfo fontSize. */
                                public fontSize: number;

                                /** StyleInfo pixelFontSize. */
                                public pixelFontSize: number;

                                /** StyleInfo letterSpacing. */
                                public letterSpacing: number;

                                /** StyleInfo fontType. */
                                public fontType: string;

                                /** StyleInfo bold. */
                                public bold: boolean;

                                /** StyleInfo italic. */
                                public italic: boolean;

                                /** StyleInfo underlined. */
                                public underlined: boolean;

                                /** StyleInfo strikeout. */
                                public strikeout: boolean;

                                /** StyleInfo subscript. */
                                public subscript: boolean;

                                /** StyleInfo superscript. */
                                public superscript: boolean;

                                /** StyleInfo smallcaps. */
                                public smallcaps: boolean;

                                /** StyleInfo fontWeight. */
                                public fontWeight: number;

                                /** StyleInfo handwritten. */
                                public handwritten: boolean;

                                /** StyleInfo textColor. */
                                public textColor?: (google.type.IColor|null);

                                /** StyleInfo backgroundColor. */
                                public backgroundColor?: (google.type.IColor|null);

                                /**
                                 * Creates a new StyleInfo instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns StyleInfo instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.Token.IStyleInfo): google.cloud.documentai.v1beta3.Document.Page.Token.StyleInfo;

                                /**
                                 * Encodes the specified StyleInfo message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Token.StyleInfo.verify|verify} messages.
                                 * @param message StyleInfo message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.Page.Token.IStyleInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified StyleInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Token.StyleInfo.verify|verify} messages.
                                 * @param message StyleInfo message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.Token.IStyleInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a StyleInfo message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns StyleInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Token.StyleInfo;

                                /**
                                 * Decodes a StyleInfo message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns StyleInfo
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Token.StyleInfo;

                                /**
                                 * Verifies a StyleInfo message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a StyleInfo message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns StyleInfo
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Token.StyleInfo;

                                /**
                                 * Creates a plain object from a StyleInfo message. Also converts values to other types if specified.
                                 * @param message StyleInfo
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Token.StyleInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this StyleInfo to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for StyleInfo
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }

                        /** Properties of a Symbol. */
                        interface ISymbol {

                            /** Symbol layout */
                            layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Symbol detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a Symbol. */
                        class Symbol implements ISymbol {

                            /**
                             * Constructs a new Symbol.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.ISymbol);

                            /** Symbol layout. */
                            public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Symbol detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new Symbol instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Symbol instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.ISymbol): google.cloud.documentai.v1beta3.Document.Page.Symbol;

                            /**
                             * Encodes the specified Symbol message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Symbol.verify|verify} messages.
                             * @param message Symbol message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.ISymbol, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Symbol message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Symbol.verify|verify} messages.
                             * @param message Symbol message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.ISymbol, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Symbol message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Symbol
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Symbol;

                            /**
                             * Decodes a Symbol message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Symbol
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Symbol;

                            /**
                             * Verifies a Symbol message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Symbol message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Symbol
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Symbol;

                            /**
                             * Creates a plain object from a Symbol message. Also converts values to other types if specified.
                             * @param message Symbol
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Symbol, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Symbol to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Symbol
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a VisualElement. */
                        interface IVisualElement {

                            /** VisualElement layout */
                            layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** VisualElement type */
                            type?: (string|null);

                            /** VisualElement detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);
                        }

                        /** Represents a VisualElement. */
                        class VisualElement implements IVisualElement {

                            /**
                             * Constructs a new VisualElement.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IVisualElement);

                            /** VisualElement layout. */
                            public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** VisualElement type. */
                            public type: string;

                            /** VisualElement detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                            /**
                             * Creates a new VisualElement instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns VisualElement instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IVisualElement): google.cloud.documentai.v1beta3.Document.Page.VisualElement;

                            /**
                             * Encodes the specified VisualElement message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.VisualElement.verify|verify} messages.
                             * @param message VisualElement message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IVisualElement, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified VisualElement message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.VisualElement.verify|verify} messages.
                             * @param message VisualElement message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IVisualElement, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a VisualElement message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns VisualElement
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.VisualElement;

                            /**
                             * Decodes a VisualElement message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns VisualElement
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.VisualElement;

                            /**
                             * Verifies a VisualElement message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a VisualElement message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns VisualElement
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.VisualElement;

                            /**
                             * Creates a plain object from a VisualElement message. Also converts values to other types if specified.
                             * @param message VisualElement
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.VisualElement, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this VisualElement to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for VisualElement
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Table. */
                        interface ITable {

                            /** Table layout */
                            layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Table headerRows */
                            headerRows?: (google.cloud.documentai.v1beta3.Document.Page.Table.ITableRow[]|null);

                            /** Table bodyRows */
                            bodyRows?: (google.cloud.documentai.v1beta3.Document.Page.Table.ITableRow[]|null);

                            /** Table detectedLanguages */
                            detectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);

                            /** Table provenance */
                            provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);
                        }

                        /** Represents a Table. */
                        class Table implements ITable {

                            /**
                             * Constructs a new Table.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.ITable);

                            /** Table layout. */
                            public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** Table headerRows. */
                            public headerRows: google.cloud.documentai.v1beta3.Document.Page.Table.ITableRow[];

                            /** Table bodyRows. */
                            public bodyRows: google.cloud.documentai.v1beta3.Document.Page.Table.ITableRow[];

                            /** Table detectedLanguages. */
                            public detectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                            /** Table provenance. */
                            public provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                            /**
                             * Creates a new Table instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Table instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.ITable): google.cloud.documentai.v1beta3.Document.Page.Table;

                            /**
                             * Encodes the specified Table message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Table.verify|verify} messages.
                             * @param message Table message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.ITable, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Table message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Table.verify|verify} messages.
                             * @param message Table message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.ITable, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Table message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Table
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Table;

                            /**
                             * Decodes a Table message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Table
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Table;

                            /**
                             * Verifies a Table message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Table message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Table
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Table;

                            /**
                             * Creates a plain object from a Table message. Also converts values to other types if specified.
                             * @param message Table
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Table, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Table to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Table
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Table {

                            /** Properties of a TableRow. */
                            interface ITableRow {

                                /** TableRow cells */
                                cells?: (google.cloud.documentai.v1beta3.Document.Page.Table.ITableCell[]|null);
                            }

                            /** Represents a TableRow. */
                            class TableRow implements ITableRow {

                                /**
                                 * Constructs a new TableRow.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.Table.ITableRow);

                                /** TableRow cells. */
                                public cells: google.cloud.documentai.v1beta3.Document.Page.Table.ITableCell[];

                                /**
                                 * Creates a new TableRow instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns TableRow instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.Table.ITableRow): google.cloud.documentai.v1beta3.Document.Page.Table.TableRow;

                                /**
                                 * Encodes the specified TableRow message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Table.TableRow.verify|verify} messages.
                                 * @param message TableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.Page.Table.ITableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified TableRow message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Table.TableRow.verify|verify} messages.
                                 * @param message TableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.Table.ITableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a TableRow message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns TableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Table.TableRow;

                                /**
                                 * Decodes a TableRow message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns TableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Table.TableRow;

                                /**
                                 * Verifies a TableRow message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a TableRow message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns TableRow
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Table.TableRow;

                                /**
                                 * Creates a plain object from a TableRow message. Also converts values to other types if specified.
                                 * @param message TableRow
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Table.TableRow, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this TableRow to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for TableRow
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a TableCell. */
                            interface ITableCell {

                                /** TableCell layout */
                                layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                                /** TableCell rowSpan */
                                rowSpan?: (number|null);

                                /** TableCell colSpan */
                                colSpan?: (number|null);

                                /** TableCell detectedLanguages */
                                detectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);
                            }

                            /** Represents a TableCell. */
                            class TableCell implements ITableCell {

                                /**
                                 * Constructs a new TableCell.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.Table.ITableCell);

                                /** TableCell layout. */
                                public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                                /** TableCell rowSpan. */
                                public rowSpan: number;

                                /** TableCell colSpan. */
                                public colSpan: number;

                                /** TableCell detectedLanguages. */
                                public detectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                                /**
                                 * Creates a new TableCell instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns TableCell instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.Table.ITableCell): google.cloud.documentai.v1beta3.Document.Page.Table.TableCell;

                                /**
                                 * Encodes the specified TableCell message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Table.TableCell.verify|verify} messages.
                                 * @param message TableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.Page.Table.ITableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified TableCell message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.Table.TableCell.verify|verify} messages.
                                 * @param message TableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.Table.ITableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a TableCell message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns TableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.Table.TableCell;

                                /**
                                 * Decodes a TableCell message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns TableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.Table.TableCell;

                                /**
                                 * Verifies a TableCell message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a TableCell message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns TableCell
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.Table.TableCell;

                                /**
                                 * Creates a plain object from a TableCell message. Also converts values to other types if specified.
                                 * @param message TableCell
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.Table.TableCell, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this TableCell to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for TableCell
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }

                        /** Properties of a FormField. */
                        interface IFormField {

                            /** FormField fieldName */
                            fieldName?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** FormField fieldValue */
                            fieldValue?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** FormField nameDetectedLanguages */
                            nameDetectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);

                            /** FormField valueDetectedLanguages */
                            valueDetectedLanguages?: (google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[]|null);

                            /** FormField valueType */
                            valueType?: (string|null);

                            /** FormField correctedKeyText */
                            correctedKeyText?: (string|null);

                            /** FormField correctedValueText */
                            correctedValueText?: (string|null);

                            /** FormField provenance */
                            provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);
                        }

                        /** Represents a FormField. */
                        class FormField implements IFormField {

                            /**
                             * Constructs a new FormField.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IFormField);

                            /** FormField fieldName. */
                            public fieldName?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** FormField fieldValue. */
                            public fieldValue?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** FormField nameDetectedLanguages. */
                            public nameDetectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                            /** FormField valueDetectedLanguages. */
                            public valueDetectedLanguages: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage[];

                            /** FormField valueType. */
                            public valueType: string;

                            /** FormField correctedKeyText. */
                            public correctedKeyText: string;

                            /** FormField correctedValueText. */
                            public correctedValueText: string;

                            /** FormField provenance. */
                            public provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                            /**
                             * Creates a new FormField instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FormField instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IFormField): google.cloud.documentai.v1beta3.Document.Page.FormField;

                            /**
                             * Encodes the specified FormField message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.FormField.verify|verify} messages.
                             * @param message FormField message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IFormField, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FormField message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.FormField.verify|verify} messages.
                             * @param message FormField message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IFormField, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FormField message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FormField
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.FormField;

                            /**
                             * Decodes a FormField message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FormField
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.FormField;

                            /**
                             * Verifies a FormField message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FormField message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FormField
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.FormField;

                            /**
                             * Creates a plain object from a FormField message. Also converts values to other types if specified.
                             * @param message FormField
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.FormField, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FormField to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FormField
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a DetectedBarcode. */
                        interface IDetectedBarcode {

                            /** DetectedBarcode layout */
                            layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** DetectedBarcode barcode */
                            barcode?: (google.cloud.documentai.v1beta3.IBarcode|null);
                        }

                        /** Represents a DetectedBarcode. */
                        class DetectedBarcode implements IDetectedBarcode {

                            /**
                             * Constructs a new DetectedBarcode.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IDetectedBarcode);

                            /** DetectedBarcode layout. */
                            public layout?: (google.cloud.documentai.v1beta3.Document.Page.ILayout|null);

                            /** DetectedBarcode barcode. */
                            public barcode?: (google.cloud.documentai.v1beta3.IBarcode|null);

                            /**
                             * Creates a new DetectedBarcode instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns DetectedBarcode instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IDetectedBarcode): google.cloud.documentai.v1beta3.Document.Page.DetectedBarcode;

                            /**
                             * Encodes the specified DetectedBarcode message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.DetectedBarcode.verify|verify} messages.
                             * @param message DetectedBarcode message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IDetectedBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified DetectedBarcode message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.DetectedBarcode.verify|verify} messages.
                             * @param message DetectedBarcode message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IDetectedBarcode, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a DetectedBarcode message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns DetectedBarcode
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.DetectedBarcode;

                            /**
                             * Decodes a DetectedBarcode message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns DetectedBarcode
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.DetectedBarcode;

                            /**
                             * Verifies a DetectedBarcode message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a DetectedBarcode message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns DetectedBarcode
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.DetectedBarcode;

                            /**
                             * Creates a plain object from a DetectedBarcode message. Also converts values to other types if specified.
                             * @param message DetectedBarcode
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.DetectedBarcode, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this DetectedBarcode to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for DetectedBarcode
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a DetectedLanguage. */
                        interface IDetectedLanguage {

                            /** DetectedLanguage languageCode */
                            languageCode?: (string|null);

                            /** DetectedLanguage confidence */
                            confidence?: (number|null);
                        }

                        /** Represents a DetectedLanguage. */
                        class DetectedLanguage implements IDetectedLanguage {

                            /**
                             * Constructs a new DetectedLanguage.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage);

                            /** DetectedLanguage languageCode. */
                            public languageCode: string;

                            /** DetectedLanguage confidence. */
                            public confidence: number;

                            /**
                             * Creates a new DetectedLanguage instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns DetectedLanguage instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage): google.cloud.documentai.v1beta3.Document.Page.DetectedLanguage;

                            /**
                             * Encodes the specified DetectedLanguage message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.DetectedLanguage.verify|verify} messages.
                             * @param message DetectedLanguage message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified DetectedLanguage message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.DetectedLanguage.verify|verify} messages.
                             * @param message DetectedLanguage message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IDetectedLanguage, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a DetectedLanguage message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns DetectedLanguage
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.DetectedLanguage;

                            /**
                             * Decodes a DetectedLanguage message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns DetectedLanguage
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.DetectedLanguage;

                            /**
                             * Verifies a DetectedLanguage message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a DetectedLanguage message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns DetectedLanguage
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.DetectedLanguage;

                            /**
                             * Creates a plain object from a DetectedLanguage message. Also converts values to other types if specified.
                             * @param message DetectedLanguage
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.DetectedLanguage, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this DetectedLanguage to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for DetectedLanguage
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of an ImageQualityScores. */
                        interface IImageQualityScores {

                            /** ImageQualityScores qualityScore */
                            qualityScore?: (number|null);

                            /** ImageQualityScores detectedDefects */
                            detectedDefects?: (google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.IDetectedDefect[]|null);
                        }

                        /** Represents an ImageQualityScores. */
                        class ImageQualityScores implements IImageQualityScores {

                            /**
                             * Constructs a new ImageQualityScores.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.IImageQualityScores);

                            /** ImageQualityScores qualityScore. */
                            public qualityScore: number;

                            /** ImageQualityScores detectedDefects. */
                            public detectedDefects: google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.IDetectedDefect[];

                            /**
                             * Creates a new ImageQualityScores instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns ImageQualityScores instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.IImageQualityScores): google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores;

                            /**
                             * Encodes the specified ImageQualityScores message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.verify|verify} messages.
                             * @param message ImageQualityScores message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Page.IImageQualityScores, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified ImageQualityScores message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.verify|verify} messages.
                             * @param message ImageQualityScores message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.IImageQualityScores, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes an ImageQualityScores message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns ImageQualityScores
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores;

                            /**
                             * Decodes an ImageQualityScores message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns ImageQualityScores
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores;

                            /**
                             * Verifies an ImageQualityScores message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates an ImageQualityScores message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns ImageQualityScores
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores;

                            /**
                             * Creates a plain object from an ImageQualityScores message. Also converts values to other types if specified.
                             * @param message ImageQualityScores
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this ImageQualityScores to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for ImageQualityScores
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace ImageQualityScores {

                            /** Properties of a DetectedDefect. */
                            interface IDetectedDefect {

                                /** DetectedDefect type */
                                type?: (string|null);

                                /** DetectedDefect confidence */
                                confidence?: (number|null);
                            }

                            /** Represents a DetectedDefect. */
                            class DetectedDefect implements IDetectedDefect {

                                /**
                                 * Constructs a new DetectedDefect.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.IDetectedDefect);

                                /** DetectedDefect type. */
                                public type: string;

                                /** DetectedDefect confidence. */
                                public confidence: number;

                                /**
                                 * Creates a new DetectedDefect instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns DetectedDefect instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.IDetectedDefect): google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Encodes the specified DetectedDefect message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.DetectedDefect.verify|verify} messages.
                                 * @param message DetectedDefect message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.IDetectedDefect, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified DetectedDefect message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.DetectedDefect.verify|verify} messages.
                                 * @param message DetectedDefect message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.IDetectedDefect, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a DetectedDefect message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns DetectedDefect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Decodes a DetectedDefect message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns DetectedDefect
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Verifies a DetectedDefect message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a DetectedDefect message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns DetectedDefect
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.DetectedDefect;

                                /**
                                 * Creates a plain object from a DetectedDefect message. Also converts values to other types if specified.
                                 * @param message DetectedDefect
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.Page.ImageQualityScores.DetectedDefect, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this DetectedDefect to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for DetectedDefect
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }
                    }

                    /** Properties of an Entity. */
                    interface IEntity {

                        /** Entity textAnchor */
                        textAnchor?: (google.cloud.documentai.v1beta3.Document.ITextAnchor|null);

                        /** Entity type */
                        type?: (string|null);

                        /** Entity mentionText */
                        mentionText?: (string|null);

                        /** Entity mentionId */
                        mentionId?: (string|null);

                        /** Entity confidence */
                        confidence?: (number|null);

                        /** Entity pageAnchor */
                        pageAnchor?: (google.cloud.documentai.v1beta3.Document.IPageAnchor|null);

                        /** Entity id */
                        id?: (string|null);

                        /** Entity normalizedValue */
                        normalizedValue?: (google.cloud.documentai.v1beta3.Document.Entity.INormalizedValue|null);

                        /** Entity properties */
                        properties?: (google.cloud.documentai.v1beta3.Document.IEntity[]|null);

                        /** Entity provenance */
                        provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                        /** Entity redacted */
                        redacted?: (boolean|null);
                    }

                    /** Represents an Entity. */
                    class Entity implements IEntity {

                        /**
                         * Constructs a new Entity.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IEntity);

                        /** Entity textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1beta3.Document.ITextAnchor|null);

                        /** Entity type. */
                        public type: string;

                        /** Entity mentionText. */
                        public mentionText: string;

                        /** Entity mentionId. */
                        public mentionId: string;

                        /** Entity confidence. */
                        public confidence: number;

                        /** Entity pageAnchor. */
                        public pageAnchor?: (google.cloud.documentai.v1beta3.Document.IPageAnchor|null);

                        /** Entity id. */
                        public id: string;

                        /** Entity normalizedValue. */
                        public normalizedValue?: (google.cloud.documentai.v1beta3.Document.Entity.INormalizedValue|null);

                        /** Entity properties. */
                        public properties: google.cloud.documentai.v1beta3.Document.IEntity[];

                        /** Entity provenance. */
                        public provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance|null);

                        /** Entity redacted. */
                        public redacted: boolean;

                        /**
                         * Creates a new Entity instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Entity instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IEntity): google.cloud.documentai.v1beta3.Document.Entity;

                        /**
                         * Encodes the specified Entity message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Entity.verify|verify} messages.
                         * @param message Entity message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IEntity, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Entity message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Entity.verify|verify} messages.
                         * @param message Entity message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IEntity, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an Entity message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Entity
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Entity;

                        /**
                         * Decodes an Entity message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Entity
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Entity;

                        /**
                         * Verifies an Entity message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an Entity message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Entity
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Entity;

                        /**
                         * Creates a plain object from an Entity message. Also converts values to other types if specified.
                         * @param message Entity
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.Entity, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Entity to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Entity
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Entity {

                        /** Properties of a NormalizedValue. */
                        interface INormalizedValue {

                            /** NormalizedValue moneyValue */
                            moneyValue?: (google.type.IMoney|null);

                            /** NormalizedValue dateValue */
                            dateValue?: (google.type.IDate|null);

                            /** NormalizedValue datetimeValue */
                            datetimeValue?: (google.type.IDateTime|null);

                            /** NormalizedValue addressValue */
                            addressValue?: (google.type.IPostalAddress|null);

                            /** NormalizedValue booleanValue */
                            booleanValue?: (boolean|null);

                            /** NormalizedValue integerValue */
                            integerValue?: (number|null);

                            /** NormalizedValue floatValue */
                            floatValue?: (number|null);

                            /** NormalizedValue text */
                            text?: (string|null);
                        }

                        /** Represents a NormalizedValue. */
                        class NormalizedValue implements INormalizedValue {

                            /**
                             * Constructs a new NormalizedValue.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Entity.INormalizedValue);

                            /** NormalizedValue moneyValue. */
                            public moneyValue?: (google.type.IMoney|null);

                            /** NormalizedValue dateValue. */
                            public dateValue?: (google.type.IDate|null);

                            /** NormalizedValue datetimeValue. */
                            public datetimeValue?: (google.type.IDateTime|null);

                            /** NormalizedValue addressValue. */
                            public addressValue?: (google.type.IPostalAddress|null);

                            /** NormalizedValue booleanValue. */
                            public booleanValue?: (boolean|null);

                            /** NormalizedValue integerValue. */
                            public integerValue?: (number|null);

                            /** NormalizedValue floatValue. */
                            public floatValue?: (number|null);

                            /** NormalizedValue text. */
                            public text: string;

                            /** NormalizedValue structuredValue. */
                            public structuredValue?: ("moneyValue"|"dateValue"|"datetimeValue"|"addressValue"|"booleanValue"|"integerValue"|"floatValue");

                            /**
                             * Creates a new NormalizedValue instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns NormalizedValue instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Entity.INormalizedValue): google.cloud.documentai.v1beta3.Document.Entity.NormalizedValue;

                            /**
                             * Encodes the specified NormalizedValue message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Entity.NormalizedValue.verify|verify} messages.
                             * @param message NormalizedValue message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Entity.INormalizedValue, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified NormalizedValue message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Entity.NormalizedValue.verify|verify} messages.
                             * @param message NormalizedValue message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Entity.INormalizedValue, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a NormalizedValue message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns NormalizedValue
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Entity.NormalizedValue;

                            /**
                             * Decodes a NormalizedValue message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns NormalizedValue
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Entity.NormalizedValue;

                            /**
                             * Verifies a NormalizedValue message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a NormalizedValue message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns NormalizedValue
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Entity.NormalizedValue;

                            /**
                             * Creates a plain object from a NormalizedValue message. Also converts values to other types if specified.
                             * @param message NormalizedValue
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Entity.NormalizedValue, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this NormalizedValue to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for NormalizedValue
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of an EntityRelation. */
                    interface IEntityRelation {

                        /** EntityRelation subjectId */
                        subjectId?: (string|null);

                        /** EntityRelation objectId */
                        objectId?: (string|null);

                        /** EntityRelation relation */
                        relation?: (string|null);
                    }

                    /** Represents an EntityRelation. */
                    class EntityRelation implements IEntityRelation {

                        /**
                         * Constructs a new EntityRelation.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IEntityRelation);

                        /** EntityRelation subjectId. */
                        public subjectId: string;

                        /** EntityRelation objectId. */
                        public objectId: string;

                        /** EntityRelation relation. */
                        public relation: string;

                        /**
                         * Creates a new EntityRelation instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns EntityRelation instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IEntityRelation): google.cloud.documentai.v1beta3.Document.EntityRelation;

                        /**
                         * Encodes the specified EntityRelation message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.EntityRelation.verify|verify} messages.
                         * @param message EntityRelation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IEntityRelation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified EntityRelation message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.EntityRelation.verify|verify} messages.
                         * @param message EntityRelation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IEntityRelation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an EntityRelation message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns EntityRelation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.EntityRelation;

                        /**
                         * Decodes an EntityRelation message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns EntityRelation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.EntityRelation;

                        /**
                         * Verifies an EntityRelation message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an EntityRelation message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns EntityRelation
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.EntityRelation;

                        /**
                         * Creates a plain object from an EntityRelation message. Also converts values to other types if specified.
                         * @param message EntityRelation
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.EntityRelation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this EntityRelation to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for EntityRelation
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a TextAnchor. */
                    interface ITextAnchor {

                        /** TextAnchor textSegments */
                        textSegments?: (google.cloud.documentai.v1beta3.Document.TextAnchor.ITextSegment[]|null);

                        /** TextAnchor content */
                        content?: (string|null);
                    }

                    /** Represents a TextAnchor. */
                    class TextAnchor implements ITextAnchor {

                        /**
                         * Constructs a new TextAnchor.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.ITextAnchor);

                        /** TextAnchor textSegments. */
                        public textSegments: google.cloud.documentai.v1beta3.Document.TextAnchor.ITextSegment[];

                        /** TextAnchor content. */
                        public content: string;

                        /**
                         * Creates a new TextAnchor instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns TextAnchor instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.ITextAnchor): google.cloud.documentai.v1beta3.Document.TextAnchor;

                        /**
                         * Encodes the specified TextAnchor message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.TextAnchor.verify|verify} messages.
                         * @param message TextAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.ITextAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified TextAnchor message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.TextAnchor.verify|verify} messages.
                         * @param message TextAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.ITextAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a TextAnchor message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns TextAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.TextAnchor;

                        /**
                         * Decodes a TextAnchor message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns TextAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.TextAnchor;

                        /**
                         * Verifies a TextAnchor message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a TextAnchor message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns TextAnchor
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.TextAnchor;

                        /**
                         * Creates a plain object from a TextAnchor message. Also converts values to other types if specified.
                         * @param message TextAnchor
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.TextAnchor, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this TextAnchor to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for TextAnchor
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace TextAnchor {

                        /** Properties of a TextSegment. */
                        interface ITextSegment {

                            /** TextSegment startIndex */
                            startIndex?: (number|Long|string|null);

                            /** TextSegment endIndex */
                            endIndex?: (number|Long|string|null);
                        }

                        /** Represents a TextSegment. */
                        class TextSegment implements ITextSegment {

                            /**
                             * Constructs a new TextSegment.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.TextAnchor.ITextSegment);

                            /** TextSegment startIndex. */
                            public startIndex: (number|Long|string);

                            /** TextSegment endIndex. */
                            public endIndex: (number|Long|string);

                            /**
                             * Creates a new TextSegment instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns TextSegment instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.TextAnchor.ITextSegment): google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment;

                            /**
                             * Encodes the specified TextSegment message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment.verify|verify} messages.
                             * @param message TextSegment message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.TextAnchor.ITextSegment, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified TextSegment message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment.verify|verify} messages.
                             * @param message TextSegment message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.TextAnchor.ITextSegment, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a TextSegment message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns TextSegment
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment;

                            /**
                             * Decodes a TextSegment message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns TextSegment
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment;

                            /**
                             * Verifies a TextSegment message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a TextSegment message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns TextSegment
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment;

                            /**
                             * Creates a plain object from a TextSegment message. Also converts values to other types if specified.
                             * @param message TextSegment
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.TextAnchor.TextSegment, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this TextSegment to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for TextSegment
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a PageAnchor. */
                    interface IPageAnchor {

                        /** PageAnchor pageRefs */
                        pageRefs?: (google.cloud.documentai.v1beta3.Document.PageAnchor.IPageRef[]|null);
                    }

                    /** Represents a PageAnchor. */
                    class PageAnchor implements IPageAnchor {

                        /**
                         * Constructs a new PageAnchor.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IPageAnchor);

                        /** PageAnchor pageRefs. */
                        public pageRefs: google.cloud.documentai.v1beta3.Document.PageAnchor.IPageRef[];

                        /**
                         * Creates a new PageAnchor instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns PageAnchor instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IPageAnchor): google.cloud.documentai.v1beta3.Document.PageAnchor;

                        /**
                         * Encodes the specified PageAnchor message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.PageAnchor.verify|verify} messages.
                         * @param message PageAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IPageAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified PageAnchor message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.PageAnchor.verify|verify} messages.
                         * @param message PageAnchor message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IPageAnchor, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a PageAnchor message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns PageAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.PageAnchor;

                        /**
                         * Decodes a PageAnchor message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns PageAnchor
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.PageAnchor;

                        /**
                         * Verifies a PageAnchor message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a PageAnchor message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns PageAnchor
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.PageAnchor;

                        /**
                         * Creates a plain object from a PageAnchor message. Also converts values to other types if specified.
                         * @param message PageAnchor
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.PageAnchor, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this PageAnchor to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for PageAnchor
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace PageAnchor {

                        /** Properties of a PageRef. */
                        interface IPageRef {

                            /** PageRef page */
                            page?: (number|Long|string|null);

                            /** PageRef layoutType */
                            layoutType?: (google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef.LayoutType|keyof typeof google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef.LayoutType|null);

                            /** PageRef layoutId */
                            layoutId?: (string|null);

                            /** PageRef boundingPoly */
                            boundingPoly?: (google.cloud.documentai.v1beta3.IBoundingPoly|null);

                            /** PageRef confidence */
                            confidence?: (number|null);
                        }

                        /** Represents a PageRef. */
                        class PageRef implements IPageRef {

                            /**
                             * Constructs a new PageRef.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.PageAnchor.IPageRef);

                            /** PageRef page. */
                            public page: (number|Long|string);

                            /** PageRef layoutType. */
                            public layoutType: (google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef.LayoutType|keyof typeof google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef.LayoutType);

                            /** PageRef layoutId. */
                            public layoutId: string;

                            /** PageRef boundingPoly. */
                            public boundingPoly?: (google.cloud.documentai.v1beta3.IBoundingPoly|null);

                            /** PageRef confidence. */
                            public confidence: number;

                            /**
                             * Creates a new PageRef instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns PageRef instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.PageAnchor.IPageRef): google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef;

                            /**
                             * Encodes the specified PageRef message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef.verify|verify} messages.
                             * @param message PageRef message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.PageAnchor.IPageRef, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified PageRef message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef.verify|verify} messages.
                             * @param message PageRef message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.PageAnchor.IPageRef, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a PageRef message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns PageRef
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef;

                            /**
                             * Decodes a PageRef message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns PageRef
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef;

                            /**
                             * Verifies a PageRef message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a PageRef message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns PageRef
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef;

                            /**
                             * Creates a plain object from a PageRef message. Also converts values to other types if specified.
                             * @param message PageRef
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.PageAnchor.PageRef, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this PageRef to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for PageRef
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace PageRef {

                            /** LayoutType enum. */
                            enum LayoutType {
                                LAYOUT_TYPE_UNSPECIFIED = 0,
                                BLOCK = 1,
                                PARAGRAPH = 2,
                                LINE = 3,
                                TOKEN = 4,
                                VISUAL_ELEMENT = 5,
                                TABLE = 6,
                                FORM_FIELD = 7
                            }
                        }
                    }

                    /** Properties of a Provenance. */
                    interface IProvenance {

                        /** Provenance revision */
                        revision?: (number|null);

                        /** Provenance id */
                        id?: (number|null);

                        /** Provenance parents */
                        parents?: (google.cloud.documentai.v1beta3.Document.Provenance.IParent[]|null);

                        /** Provenance type */
                        type?: (google.cloud.documentai.v1beta3.Document.Provenance.OperationType|keyof typeof google.cloud.documentai.v1beta3.Document.Provenance.OperationType|null);
                    }

                    /** Represents a Provenance. */
                    class Provenance implements IProvenance {

                        /**
                         * Constructs a new Provenance.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IProvenance);

                        /** Provenance revision. */
                        public revision: number;

                        /** Provenance id. */
                        public id: number;

                        /** Provenance parents. */
                        public parents: google.cloud.documentai.v1beta3.Document.Provenance.IParent[];

                        /** Provenance type. */
                        public type: (google.cloud.documentai.v1beta3.Document.Provenance.OperationType|keyof typeof google.cloud.documentai.v1beta3.Document.Provenance.OperationType);

                        /**
                         * Creates a new Provenance instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Provenance instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IProvenance): google.cloud.documentai.v1beta3.Document.Provenance;

                        /**
                         * Encodes the specified Provenance message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Provenance.verify|verify} messages.
                         * @param message Provenance message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IProvenance, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Provenance message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Provenance.verify|verify} messages.
                         * @param message Provenance message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IProvenance, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Provenance message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Provenance
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Provenance;

                        /**
                         * Decodes a Provenance message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Provenance
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Provenance;

                        /**
                         * Verifies a Provenance message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Provenance message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Provenance
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Provenance;

                        /**
                         * Creates a plain object from a Provenance message. Also converts values to other types if specified.
                         * @param message Provenance
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.Provenance, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Provenance to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Provenance
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Provenance {

                        /** Properties of a Parent. */
                        interface IParent {

                            /** Parent revision */
                            revision?: (number|null);

                            /** Parent index */
                            index?: (number|null);

                            /** Parent id */
                            id?: (number|null);
                        }

                        /** Represents a Parent. */
                        class Parent implements IParent {

                            /**
                             * Constructs a new Parent.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Provenance.IParent);

                            /** Parent revision. */
                            public revision: number;

                            /** Parent index. */
                            public index: number;

                            /** Parent id. */
                            public id: number;

                            /**
                             * Creates a new Parent instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Parent instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Provenance.IParent): google.cloud.documentai.v1beta3.Document.Provenance.Parent;

                            /**
                             * Encodes the specified Parent message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Provenance.Parent.verify|verify} messages.
                             * @param message Parent message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Provenance.IParent, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Parent message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Provenance.Parent.verify|verify} messages.
                             * @param message Parent message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Provenance.IParent, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Parent message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Parent
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Provenance.Parent;

                            /**
                             * Decodes a Parent message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Parent
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Provenance.Parent;

                            /**
                             * Verifies a Parent message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Parent message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Parent
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Provenance.Parent;

                            /**
                             * Creates a plain object from a Parent message. Also converts values to other types if specified.
                             * @param message Parent
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Provenance.Parent, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Parent to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Parent
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** OperationType enum. */
                        enum OperationType {
                            OPERATION_TYPE_UNSPECIFIED = 0,
                            ADD = 1,
                            REMOVE = 2,
                            UPDATE = 7,
                            REPLACE = 3,
                            EVAL_REQUESTED = 4,
                            EVAL_APPROVED = 5,
                            EVAL_SKIPPED = 6
                        }
                    }

                    /** Properties of a Revision. */
                    interface IRevision {

                        /** Revision agent */
                        agent?: (string|null);

                        /** Revision processor */
                        processor?: (string|null);

                        /** Revision id */
                        id?: (string|null);

                        /** Revision parent */
                        parent?: (number[]|null);

                        /** Revision parentIds */
                        parentIds?: (string[]|null);

                        /** Revision createTime */
                        createTime?: (google.protobuf.ITimestamp|null);

                        /** Revision humanReview */
                        humanReview?: (google.cloud.documentai.v1beta3.Document.Revision.IHumanReview|null);
                    }

                    /** Represents a Revision. */
                    class Revision implements IRevision {

                        /**
                         * Constructs a new Revision.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IRevision);

                        /** Revision agent. */
                        public agent?: (string|null);

                        /** Revision processor. */
                        public processor?: (string|null);

                        /** Revision id. */
                        public id: string;

                        /** Revision parent. */
                        public parent: number[];

                        /** Revision parentIds. */
                        public parentIds: string[];

                        /** Revision createTime. */
                        public createTime?: (google.protobuf.ITimestamp|null);

                        /** Revision humanReview. */
                        public humanReview?: (google.cloud.documentai.v1beta3.Document.Revision.IHumanReview|null);

                        /** Revision source. */
                        public source?: ("agent"|"processor");

                        /**
                         * Creates a new Revision instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Revision instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IRevision): google.cloud.documentai.v1beta3.Document.Revision;

                        /**
                         * Encodes the specified Revision message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Revision.verify|verify} messages.
                         * @param message Revision message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IRevision, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Revision message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Revision.verify|verify} messages.
                         * @param message Revision message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IRevision, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Revision message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Revision
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Revision;

                        /**
                         * Decodes a Revision message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Revision
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Revision;

                        /**
                         * Verifies a Revision message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Revision message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Revision
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Revision;

                        /**
                         * Creates a plain object from a Revision message. Also converts values to other types if specified.
                         * @param message Revision
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.Revision, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Revision to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Revision
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace Revision {

                        /** Properties of a HumanReview. */
                        interface IHumanReview {

                            /** HumanReview state */
                            state?: (string|null);

                            /** HumanReview stateMessage */
                            stateMessage?: (string|null);
                        }

                        /** Represents a HumanReview. */
                        class HumanReview implements IHumanReview {

                            /**
                             * Constructs a new HumanReview.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.Revision.IHumanReview);

                            /** HumanReview state. */
                            public state: string;

                            /** HumanReview stateMessage. */
                            public stateMessage: string;

                            /**
                             * Creates a new HumanReview instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns HumanReview instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.Revision.IHumanReview): google.cloud.documentai.v1beta3.Document.Revision.HumanReview;

                            /**
                             * Encodes the specified HumanReview message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Revision.HumanReview.verify|verify} messages.
                             * @param message HumanReview message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.Revision.IHumanReview, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified HumanReview message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.Revision.HumanReview.verify|verify} messages.
                             * @param message HumanReview message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.Revision.IHumanReview, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a HumanReview message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns HumanReview
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.Revision.HumanReview;

                            /**
                             * Decodes a HumanReview message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns HumanReview
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.Revision.HumanReview;

                            /**
                             * Verifies a HumanReview message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a HumanReview message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns HumanReview
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.Revision.HumanReview;

                            /**
                             * Creates a plain object from a HumanReview message. Also converts values to other types if specified.
                             * @param message HumanReview
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.Revision.HumanReview, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this HumanReview to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for HumanReview
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of a TextChange. */
                    interface ITextChange {

                        /** TextChange textAnchor */
                        textAnchor?: (google.cloud.documentai.v1beta3.Document.ITextAnchor|null);

                        /** TextChange changedText */
                        changedText?: (string|null);

                        /** TextChange provenance */
                        provenance?: (google.cloud.documentai.v1beta3.Document.IProvenance[]|null);
                    }

                    /** Represents a TextChange. */
                    class TextChange implements ITextChange {

                        /**
                         * Constructs a new TextChange.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.ITextChange);

                        /** TextChange textAnchor. */
                        public textAnchor?: (google.cloud.documentai.v1beta3.Document.ITextAnchor|null);

                        /** TextChange changedText. */
                        public changedText: string;

                        /** TextChange provenance. */
                        public provenance: google.cloud.documentai.v1beta3.Document.IProvenance[];

                        /**
                         * Creates a new TextChange instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns TextChange instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.ITextChange): google.cloud.documentai.v1beta3.Document.TextChange;

                        /**
                         * Encodes the specified TextChange message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.TextChange.verify|verify} messages.
                         * @param message TextChange message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.ITextChange, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified TextChange message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.TextChange.verify|verify} messages.
                         * @param message TextChange message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.ITextChange, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a TextChange message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns TextChange
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.TextChange;

                        /**
                         * Decodes a TextChange message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns TextChange
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.TextChange;

                        /**
                         * Verifies a TextChange message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a TextChange message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns TextChange
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.TextChange;

                        /**
                         * Creates a plain object from a TextChange message. Also converts values to other types if specified.
                         * @param message TextChange
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.TextChange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this TextChange to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for TextChange
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a DocumentLayout. */
                    interface IDocumentLayout {

                        /** DocumentLayout blocks */
                        blocks?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock[]|null);
                    }

                    /** Represents a DocumentLayout. */
                    class DocumentLayout implements IDocumentLayout {

                        /**
                         * Constructs a new DocumentLayout.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IDocumentLayout);

                        /** DocumentLayout blocks. */
                        public blocks: google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock[];

                        /**
                         * Creates a new DocumentLayout instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns DocumentLayout instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IDocumentLayout): google.cloud.documentai.v1beta3.Document.DocumentLayout;

                        /**
                         * Encodes the specified DocumentLayout message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.verify|verify} messages.
                         * @param message DocumentLayout message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IDocumentLayout, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified DocumentLayout message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.verify|verify} messages.
                         * @param message DocumentLayout message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IDocumentLayout, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a DocumentLayout message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns DocumentLayout
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.DocumentLayout;

                        /**
                         * Decodes a DocumentLayout message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns DocumentLayout
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.DocumentLayout;

                        /**
                         * Verifies a DocumentLayout message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a DocumentLayout message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns DocumentLayout
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.DocumentLayout;

                        /**
                         * Creates a plain object from a DocumentLayout message. Also converts values to other types if specified.
                         * @param message DocumentLayout
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.DocumentLayout, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this DocumentLayout to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for DocumentLayout
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace DocumentLayout {

                        /** Properties of a DocumentLayoutBlock. */
                        interface IDocumentLayoutBlock {

                            /** DocumentLayoutBlock textBlock */
                            textBlock?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock|null);

                            /** DocumentLayoutBlock tableBlock */
                            tableBlock?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock|null);

                            /** DocumentLayoutBlock listBlock */
                            listBlock?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock|null);

                            /** DocumentLayoutBlock blockId */
                            blockId?: (string|null);

                            /** DocumentLayoutBlock pageSpan */
                            pageSpan?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan|null);
                        }

                        /** Represents a DocumentLayoutBlock. */
                        class DocumentLayoutBlock implements IDocumentLayoutBlock {

                            /**
                             * Constructs a new DocumentLayoutBlock.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock);

                            /** DocumentLayoutBlock textBlock. */
                            public textBlock?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock|null);

                            /** DocumentLayoutBlock tableBlock. */
                            public tableBlock?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock|null);

                            /** DocumentLayoutBlock listBlock. */
                            public listBlock?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock|null);

                            /** DocumentLayoutBlock blockId. */
                            public blockId: string;

                            /** DocumentLayoutBlock pageSpan. */
                            public pageSpan?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan|null);

                            /** DocumentLayoutBlock block. */
                            public block?: ("textBlock"|"tableBlock"|"listBlock");

                            /**
                             * Creates a new DocumentLayoutBlock instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns DocumentLayoutBlock instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock;

                            /**
                             * Encodes the specified DocumentLayoutBlock message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.verify|verify} messages.
                             * @param message DocumentLayoutBlock message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified DocumentLayoutBlock message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.verify|verify} messages.
                             * @param message DocumentLayoutBlock message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a DocumentLayoutBlock message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns DocumentLayoutBlock
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock;

                            /**
                             * Decodes a DocumentLayoutBlock message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns DocumentLayoutBlock
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock;

                            /**
                             * Verifies a DocumentLayoutBlock message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a DocumentLayoutBlock message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns DocumentLayoutBlock
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock;

                            /**
                             * Creates a plain object from a DocumentLayoutBlock message. Also converts values to other types if specified.
                             * @param message DocumentLayoutBlock
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this DocumentLayoutBlock to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for DocumentLayoutBlock
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace DocumentLayoutBlock {

                            /** Properties of a LayoutPageSpan. */
                            interface ILayoutPageSpan {

                                /** LayoutPageSpan pageStart */
                                pageStart?: (number|null);

                                /** LayoutPageSpan pageEnd */
                                pageEnd?: (number|null);
                            }

                            /** Represents a LayoutPageSpan. */
                            class LayoutPageSpan implements ILayoutPageSpan {

                                /**
                                 * Constructs a new LayoutPageSpan.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan);

                                /** LayoutPageSpan pageStart. */
                                public pageStart: number;

                                /** LayoutPageSpan pageEnd. */
                                public pageEnd: number;

                                /**
                                 * Creates a new LayoutPageSpan instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutPageSpan instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan;

                                /**
                                 * Encodes the specified LayoutPageSpan message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan.verify|verify} messages.
                                 * @param message LayoutPageSpan message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutPageSpan message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan.verify|verify} messages.
                                 * @param message LayoutPageSpan message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutPageSpan, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutPageSpan message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutPageSpan
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan;

                                /**
                                 * Decodes a LayoutPageSpan message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutPageSpan
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan;

                                /**
                                 * Verifies a LayoutPageSpan message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutPageSpan message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutPageSpan
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan;

                                /**
                                 * Creates a plain object from a LayoutPageSpan message. Also converts values to other types if specified.
                                 * @param message LayoutPageSpan
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutPageSpan, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutPageSpan to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutPageSpan
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutTextBlock. */
                            interface ILayoutTextBlock {

                                /** LayoutTextBlock text */
                                text?: (string|null);

                                /** LayoutTextBlock type */
                                type?: (string|null);

                                /** LayoutTextBlock blocks */
                                blocks?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock[]|null);
                            }

                            /** Represents a LayoutTextBlock. */
                            class LayoutTextBlock implements ILayoutTextBlock {

                                /**
                                 * Constructs a new LayoutTextBlock.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock);

                                /** LayoutTextBlock text. */
                                public text: string;

                                /** LayoutTextBlock type. */
                                public type: string;

                                /** LayoutTextBlock blocks. */
                                public blocks: google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock[];

                                /**
                                 * Creates a new LayoutTextBlock instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutTextBlock instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock;

                                /**
                                 * Encodes the specified LayoutTextBlock message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock.verify|verify} messages.
                                 * @param message LayoutTextBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutTextBlock message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock.verify|verify} messages.
                                 * @param message LayoutTextBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTextBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutTextBlock message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutTextBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock;

                                /**
                                 * Decodes a LayoutTextBlock message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutTextBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock;

                                /**
                                 * Verifies a LayoutTextBlock message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutTextBlock message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutTextBlock
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock;

                                /**
                                 * Creates a plain object from a LayoutTextBlock message. Also converts values to other types if specified.
                                 * @param message LayoutTextBlock
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTextBlock, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutTextBlock to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutTextBlock
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutTableBlock. */
                            interface ILayoutTableBlock {

                                /** LayoutTableBlock headerRows */
                                headerRows?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow[]|null);

                                /** LayoutTableBlock bodyRows */
                                bodyRows?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow[]|null);

                                /** LayoutTableBlock caption */
                                caption?: (string|null);
                            }

                            /** Represents a LayoutTableBlock. */
                            class LayoutTableBlock implements ILayoutTableBlock {

                                /**
                                 * Constructs a new LayoutTableBlock.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock);

                                /** LayoutTableBlock headerRows. */
                                public headerRows: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow[];

                                /** LayoutTableBlock bodyRows. */
                                public bodyRows: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow[];

                                /** LayoutTableBlock caption. */
                                public caption: string;

                                /**
                                 * Creates a new LayoutTableBlock instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutTableBlock instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock;

                                /**
                                 * Encodes the specified LayoutTableBlock message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock.verify|verify} messages.
                                 * @param message LayoutTableBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutTableBlock message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock.verify|verify} messages.
                                 * @param message LayoutTableBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutTableBlock message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutTableBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock;

                                /**
                                 * Decodes a LayoutTableBlock message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutTableBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock;

                                /**
                                 * Verifies a LayoutTableBlock message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutTableBlock message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutTableBlock
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock;

                                /**
                                 * Creates a plain object from a LayoutTableBlock message. Also converts values to other types if specified.
                                 * @param message LayoutTableBlock
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableBlock, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutTableBlock to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutTableBlock
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutTableRow. */
                            interface ILayoutTableRow {

                                /** LayoutTableRow cells */
                                cells?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell[]|null);
                            }

                            /** Represents a LayoutTableRow. */
                            class LayoutTableRow implements ILayoutTableRow {

                                /**
                                 * Constructs a new LayoutTableRow.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow);

                                /** LayoutTableRow cells. */
                                public cells: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell[];

                                /**
                                 * Creates a new LayoutTableRow instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutTableRow instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow;

                                /**
                                 * Encodes the specified LayoutTableRow message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow.verify|verify} messages.
                                 * @param message LayoutTableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutTableRow message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow.verify|verify} messages.
                                 * @param message LayoutTableRow message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableRow, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutTableRow message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutTableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow;

                                /**
                                 * Decodes a LayoutTableRow message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutTableRow
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow;

                                /**
                                 * Verifies a LayoutTableRow message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutTableRow message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutTableRow
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow;

                                /**
                                 * Creates a plain object from a LayoutTableRow message. Also converts values to other types if specified.
                                 * @param message LayoutTableRow
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableRow, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutTableRow to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutTableRow
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutTableCell. */
                            interface ILayoutTableCell {

                                /** LayoutTableCell blocks */
                                blocks?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock[]|null);

                                /** LayoutTableCell rowSpan */
                                rowSpan?: (number|null);

                                /** LayoutTableCell colSpan */
                                colSpan?: (number|null);
                            }

                            /** Represents a LayoutTableCell. */
                            class LayoutTableCell implements ILayoutTableCell {

                                /**
                                 * Constructs a new LayoutTableCell.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell);

                                /** LayoutTableCell blocks. */
                                public blocks: google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock[];

                                /** LayoutTableCell rowSpan. */
                                public rowSpan: number;

                                /** LayoutTableCell colSpan. */
                                public colSpan: number;

                                /**
                                 * Creates a new LayoutTableCell instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutTableCell instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell;

                                /**
                                 * Encodes the specified LayoutTableCell message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell.verify|verify} messages.
                                 * @param message LayoutTableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutTableCell message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell.verify|verify} messages.
                                 * @param message LayoutTableCell message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutTableCell, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutTableCell message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutTableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell;

                                /**
                                 * Decodes a LayoutTableCell message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutTableCell
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell;

                                /**
                                 * Verifies a LayoutTableCell message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutTableCell message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutTableCell
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell;

                                /**
                                 * Creates a plain object from a LayoutTableCell message. Also converts values to other types if specified.
                                 * @param message LayoutTableCell
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutTableCell, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutTableCell to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutTableCell
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutListBlock. */
                            interface ILayoutListBlock {

                                /** LayoutListBlock listEntries */
                                listEntries?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry[]|null);

                                /** LayoutListBlock type */
                                type?: (string|null);
                            }

                            /** Represents a LayoutListBlock. */
                            class LayoutListBlock implements ILayoutListBlock {

                                /**
                                 * Constructs a new LayoutListBlock.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock);

                                /** LayoutListBlock listEntries. */
                                public listEntries: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry[];

                                /** LayoutListBlock type. */
                                public type: string;

                                /**
                                 * Creates a new LayoutListBlock instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutListBlock instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock;

                                /**
                                 * Encodes the specified LayoutListBlock message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock.verify|verify} messages.
                                 * @param message LayoutListBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutListBlock message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock.verify|verify} messages.
                                 * @param message LayoutListBlock message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListBlock, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutListBlock message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutListBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock;

                                /**
                                 * Decodes a LayoutListBlock message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutListBlock
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock;

                                /**
                                 * Verifies a LayoutListBlock message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutListBlock message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutListBlock
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock;

                                /**
                                 * Creates a plain object from a LayoutListBlock message. Also converts values to other types if specified.
                                 * @param message LayoutListBlock
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListBlock, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutListBlock to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutListBlock
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a LayoutListEntry. */
                            interface ILayoutListEntry {

                                /** LayoutListEntry blocks */
                                blocks?: (google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock[]|null);
                            }

                            /** Represents a LayoutListEntry. */
                            class LayoutListEntry implements ILayoutListEntry {

                                /**
                                 * Constructs a new LayoutListEntry.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry);

                                /** LayoutListEntry blocks. */
                                public blocks: google.cloud.documentai.v1beta3.Document.DocumentLayout.IDocumentLayoutBlock[];

                                /**
                                 * Creates a new LayoutListEntry instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns LayoutListEntry instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry;

                                /**
                                 * Encodes the specified LayoutListEntry message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry.verify|verify} messages.
                                 * @param message LayoutListEntry message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified LayoutListEntry message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry.verify|verify} messages.
                                 * @param message LayoutListEntry message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.ILayoutListEntry, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a LayoutListEntry message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns LayoutListEntry
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry;

                                /**
                                 * Decodes a LayoutListEntry message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns LayoutListEntry
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry;

                                /**
                                 * Verifies a LayoutListEntry message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a LayoutListEntry message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns LayoutListEntry
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry;

                                /**
                                 * Creates a plain object from a LayoutListEntry message. Also converts values to other types if specified.
                                 * @param message LayoutListEntry
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.DocumentLayout.DocumentLayoutBlock.LayoutListEntry, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this LayoutListEntry to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for LayoutListEntry
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }
                    }

                    /** Properties of a ChunkedDocument. */
                    interface IChunkedDocument {

                        /** ChunkedDocument chunks */
                        chunks?: (google.cloud.documentai.v1beta3.Document.ChunkedDocument.IChunk[]|null);
                    }

                    /** Represents a ChunkedDocument. */
                    class ChunkedDocument implements IChunkedDocument {

                        /**
                         * Constructs a new ChunkedDocument.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Document.IChunkedDocument);

                        /** ChunkedDocument chunks. */
                        public chunks: google.cloud.documentai.v1beta3.Document.ChunkedDocument.IChunk[];

                        /**
                         * Creates a new ChunkedDocument instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ChunkedDocument instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Document.IChunkedDocument): google.cloud.documentai.v1beta3.Document.ChunkedDocument;

                        /**
                         * Encodes the specified ChunkedDocument message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.verify|verify} messages.
                         * @param message ChunkedDocument message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Document.IChunkedDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ChunkedDocument message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.verify|verify} messages.
                         * @param message ChunkedDocument message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.IChunkedDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a ChunkedDocument message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ChunkedDocument
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.ChunkedDocument;

                        /**
                         * Decodes a ChunkedDocument message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ChunkedDocument
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.ChunkedDocument;

                        /**
                         * Verifies a ChunkedDocument message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a ChunkedDocument message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ChunkedDocument
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.ChunkedDocument;

                        /**
                         * Creates a plain object from a ChunkedDocument message. Also converts values to other types if specified.
                         * @param message ChunkedDocument
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ChunkedDocument to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ChunkedDocument
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace ChunkedDocument {

                        /** Properties of a Chunk. */
                        interface IChunk {

                            /** Chunk chunkId */
                            chunkId?: (string|null);

                            /** Chunk sourceBlockIds */
                            sourceBlockIds?: (string[]|null);

                            /** Chunk content */
                            content?: (string|null);

                            /** Chunk pageSpan */
                            pageSpan?: (google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);

                            /** Chunk pageHeaders */
                            pageHeaders?: (google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageHeader[]|null);

                            /** Chunk pageFooters */
                            pageFooters?: (google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageFooter[]|null);
                        }

                        /** Represents a Chunk. */
                        class Chunk implements IChunk {

                            /**
                             * Constructs a new Chunk.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.Document.ChunkedDocument.IChunk);

                            /** Chunk chunkId. */
                            public chunkId: string;

                            /** Chunk sourceBlockIds. */
                            public sourceBlockIds: string[];

                            /** Chunk content. */
                            public content: string;

                            /** Chunk pageSpan. */
                            public pageSpan?: (google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);

                            /** Chunk pageHeaders. */
                            public pageHeaders: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageHeader[];

                            /** Chunk pageFooters. */
                            public pageFooters: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageFooter[];

                            /**
                             * Creates a new Chunk instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Chunk instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.Document.ChunkedDocument.IChunk): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk;

                            /**
                             * Encodes the specified Chunk message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.verify|verify} messages.
                             * @param message Chunk message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.IChunk, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Chunk message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.verify|verify} messages.
                             * @param message Chunk message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.IChunk, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Chunk message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Chunk
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk;

                            /**
                             * Decodes a Chunk message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Chunk
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk;

                            /**
                             * Verifies a Chunk message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Chunk message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Chunk
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk;

                            /**
                             * Creates a plain object from a Chunk message. Also converts values to other types if specified.
                             * @param message Chunk
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Chunk to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Chunk
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Chunk {

                            /** Properties of a ChunkPageSpan. */
                            interface IChunkPageSpan {

                                /** ChunkPageSpan pageStart */
                                pageStart?: (number|null);

                                /** ChunkPageSpan pageEnd */
                                pageEnd?: (number|null);
                            }

                            /** Represents a ChunkPageSpan. */
                            class ChunkPageSpan implements IChunkPageSpan {

                                /**
                                 * Constructs a new ChunkPageSpan.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan);

                                /** ChunkPageSpan pageStart. */
                                public pageStart: number;

                                /** ChunkPageSpan pageEnd. */
                                public pageEnd: number;

                                /**
                                 * Creates a new ChunkPageSpan instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns ChunkPageSpan instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageSpan;

                                /**
                                 * Encodes the specified ChunkPageSpan message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageSpan.verify|verify} messages.
                                 * @param message ChunkPageSpan message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified ChunkPageSpan message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageSpan.verify|verify} messages.
                                 * @param message ChunkPageSpan message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a ChunkPageSpan message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns ChunkPageSpan
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageSpan;

                                /**
                                 * Decodes a ChunkPageSpan message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns ChunkPageSpan
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageSpan;

                                /**
                                 * Verifies a ChunkPageSpan message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a ChunkPageSpan message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns ChunkPageSpan
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageSpan;

                                /**
                                 * Creates a plain object from a ChunkPageSpan message. Also converts values to other types if specified.
                                 * @param message ChunkPageSpan
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageSpan, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this ChunkPageSpan to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for ChunkPageSpan
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a ChunkPageHeader. */
                            interface IChunkPageHeader {

                                /** ChunkPageHeader text */
                                text?: (string|null);

                                /** ChunkPageHeader pageSpan */
                                pageSpan?: (google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);
                            }

                            /** Represents a ChunkPageHeader. */
                            class ChunkPageHeader implements IChunkPageHeader {

                                /**
                                 * Constructs a new ChunkPageHeader.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageHeader);

                                /** ChunkPageHeader text. */
                                public text: string;

                                /** ChunkPageHeader pageSpan. */
                                public pageSpan?: (google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);

                                /**
                                 * Creates a new ChunkPageHeader instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns ChunkPageHeader instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageHeader): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageHeader;

                                /**
                                 * Encodes the specified ChunkPageHeader message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageHeader.verify|verify} messages.
                                 * @param message ChunkPageHeader message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified ChunkPageHeader message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageHeader.verify|verify} messages.
                                 * @param message ChunkPageHeader message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageHeader, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a ChunkPageHeader message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns ChunkPageHeader
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageHeader;

                                /**
                                 * Decodes a ChunkPageHeader message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns ChunkPageHeader
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageHeader;

                                /**
                                 * Verifies a ChunkPageHeader message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a ChunkPageHeader message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns ChunkPageHeader
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageHeader;

                                /**
                                 * Creates a plain object from a ChunkPageHeader message. Also converts values to other types if specified.
                                 * @param message ChunkPageHeader
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageHeader, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this ChunkPageHeader to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for ChunkPageHeader
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }

                            /** Properties of a ChunkPageFooter. */
                            interface IChunkPageFooter {

                                /** ChunkPageFooter text */
                                text?: (string|null);

                                /** ChunkPageFooter pageSpan */
                                pageSpan?: (google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);
                            }

                            /** Represents a ChunkPageFooter. */
                            class ChunkPageFooter implements IChunkPageFooter {

                                /**
                                 * Constructs a new ChunkPageFooter.
                                 * @param [properties] Properties to set
                                 */
                                constructor(properties?: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageFooter);

                                /** ChunkPageFooter text. */
                                public text: string;

                                /** ChunkPageFooter pageSpan. */
                                public pageSpan?: (google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageSpan|null);

                                /**
                                 * Creates a new ChunkPageFooter instance using the specified properties.
                                 * @param [properties] Properties to set
                                 * @returns ChunkPageFooter instance
                                 */
                                public static create(properties?: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageFooter): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageFooter;

                                /**
                                 * Encodes the specified ChunkPageFooter message. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageFooter.verify|verify} messages.
                                 * @param message ChunkPageFooter message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encode(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageFooter, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Encodes the specified ChunkPageFooter message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageFooter.verify|verify} messages.
                                 * @param message ChunkPageFooter message or plain object to encode
                                 * @param [writer] Writer to encode to
                                 * @returns Writer
                                 */
                                public static encodeDelimited(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.IChunkPageFooter, writer?: $protobuf.Writer): $protobuf.Writer;

                                /**
                                 * Decodes a ChunkPageFooter message from the specified reader or buffer.
                                 * @param reader Reader or buffer to decode from
                                 * @param [length] Message length if known beforehand
                                 * @returns ChunkPageFooter
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageFooter;

                                /**
                                 * Decodes a ChunkPageFooter message from the specified reader or buffer, length delimited.
                                 * @param reader Reader or buffer to decode from
                                 * @returns ChunkPageFooter
                                 * @throws {Error} If the payload is not a reader or valid buffer
                                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                                 */
                                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageFooter;

                                /**
                                 * Verifies a ChunkPageFooter message.
                                 * @param message Plain object to verify
                                 * @returns `null` if valid, otherwise the reason why it is not
                                 */
                                public static verify(message: { [k: string]: any }): (string|null);

                                /**
                                 * Creates a ChunkPageFooter message from a plain object. Also converts values to their respective internal types.
                                 * @param object Plain object
                                 * @returns ChunkPageFooter
                                 */
                                public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageFooter;

                                /**
                                 * Creates a plain object from a ChunkPageFooter message. Also converts values to other types if specified.
                                 * @param message ChunkPageFooter
                                 * @param [options] Conversion options
                                 * @returns Plain object
                                 */
                                public static toObject(message: google.cloud.documentai.v1beta3.Document.ChunkedDocument.Chunk.ChunkPageFooter, options?: $protobuf.IConversionOptions): { [k: string]: any };

                                /**
                                 * Converts this ChunkPageFooter to JSON.
                                 * @returns JSON object
                                 */
                                public toJSON(): { [k: string]: any };

                                /**
                                 * Gets the default type url for ChunkPageFooter
                                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                                 * @returns The default type url
                                 */
                                public static getTypeUrl(typeUrlPrefix?: string): string;
                            }
                        }
                    }
                }

                /** Properties of a RevisionRef. */
                interface IRevisionRef {

                    /** RevisionRef revisionCase */
                    revisionCase?: (google.cloud.documentai.v1beta3.RevisionRef.RevisionCase|keyof typeof google.cloud.documentai.v1beta3.RevisionRef.RevisionCase|null);

                    /** RevisionRef revisionId */
                    revisionId?: (string|null);

                    /** RevisionRef latestProcessorVersion */
                    latestProcessorVersion?: (string|null);
                }

                /** Represents a RevisionRef. */
                class RevisionRef implements IRevisionRef {

                    /**
                     * Constructs a new RevisionRef.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IRevisionRef);

                    /** RevisionRef revisionCase. */
                    public revisionCase?: (google.cloud.documentai.v1beta3.RevisionRef.RevisionCase|keyof typeof google.cloud.documentai.v1beta3.RevisionRef.RevisionCase|null);

                    /** RevisionRef revisionId. */
                    public revisionId?: (string|null);

                    /** RevisionRef latestProcessorVersion. */
                    public latestProcessorVersion?: (string|null);

                    /** RevisionRef source. */
                    public source?: ("revisionCase"|"revisionId"|"latestProcessorVersion");

                    /**
                     * Creates a new RevisionRef instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RevisionRef instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IRevisionRef): google.cloud.documentai.v1beta3.RevisionRef;

                    /**
                     * Encodes the specified RevisionRef message. Does not implicitly {@link google.cloud.documentai.v1beta3.RevisionRef.verify|verify} messages.
                     * @param message RevisionRef message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IRevisionRef, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RevisionRef message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.RevisionRef.verify|verify} messages.
                     * @param message RevisionRef message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IRevisionRef, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RevisionRef message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RevisionRef
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.RevisionRef;

                    /**
                     * Decodes a RevisionRef message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RevisionRef
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.RevisionRef;

                    /**
                     * Verifies a RevisionRef message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RevisionRef message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RevisionRef
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.RevisionRef;

                    /**
                     * Creates a plain object from a RevisionRef message. Also converts values to other types if specified.
                     * @param message RevisionRef
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.RevisionRef, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RevisionRef to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RevisionRef
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace RevisionRef {

                    /** RevisionCase enum. */
                    enum RevisionCase {
                        REVISION_CASE_UNSPECIFIED = 0,
                        LATEST_HUMAN_REVIEW = 1,
                        LATEST_TIMESTAMP = 2,
                        BASE_OCR_REVISION = 3
                    }
                }

                /** Properties of a Vertex. */
                interface IVertex {

                    /** Vertex x */
                    x?: (number|null);

                    /** Vertex y */
                    y?: (number|null);
                }

                /** Represents a Vertex. */
                class Vertex implements IVertex {

                    /**
                     * Constructs a new Vertex.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IVertex);

                    /** Vertex x. */
                    public x: number;

                    /** Vertex y. */
                    public y: number;

                    /**
                     * Creates a new Vertex instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Vertex instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IVertex): google.cloud.documentai.v1beta3.Vertex;

                    /**
                     * Encodes the specified Vertex message. Does not implicitly {@link google.cloud.documentai.v1beta3.Vertex.verify|verify} messages.
                     * @param message Vertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Vertex message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Vertex.verify|verify} messages.
                     * @param message Vertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Vertex message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Vertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Vertex;

                    /**
                     * Decodes a Vertex message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Vertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Vertex;

                    /**
                     * Verifies a Vertex message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Vertex message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Vertex
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Vertex;

                    /**
                     * Creates a plain object from a Vertex message. Also converts values to other types if specified.
                     * @param message Vertex
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.Vertex, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Vertex to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Vertex
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a NormalizedVertex. */
                interface INormalizedVertex {

                    /** NormalizedVertex x */
                    x?: (number|null);

                    /** NormalizedVertex y */
                    y?: (number|null);
                }

                /** Represents a NormalizedVertex. */
                class NormalizedVertex implements INormalizedVertex {

                    /**
                     * Constructs a new NormalizedVertex.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.INormalizedVertex);

                    /** NormalizedVertex x. */
                    public x: number;

                    /** NormalizedVertex y. */
                    public y: number;

                    /**
                     * Creates a new NormalizedVertex instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns NormalizedVertex instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.INormalizedVertex): google.cloud.documentai.v1beta3.NormalizedVertex;

                    /**
                     * Encodes the specified NormalizedVertex message. Does not implicitly {@link google.cloud.documentai.v1beta3.NormalizedVertex.verify|verify} messages.
                     * @param message NormalizedVertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.INormalizedVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified NormalizedVertex message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.NormalizedVertex.verify|verify} messages.
                     * @param message NormalizedVertex message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.INormalizedVertex, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a NormalizedVertex message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns NormalizedVertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.NormalizedVertex;

                    /**
                     * Decodes a NormalizedVertex message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns NormalizedVertex
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.NormalizedVertex;

                    /**
                     * Verifies a NormalizedVertex message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a NormalizedVertex message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns NormalizedVertex
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.NormalizedVertex;

                    /**
                     * Creates a plain object from a NormalizedVertex message. Also converts values to other types if specified.
                     * @param message NormalizedVertex
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.NormalizedVertex, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this NormalizedVertex to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for NormalizedVertex
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BoundingPoly. */
                interface IBoundingPoly {

                    /** BoundingPoly vertices */
                    vertices?: (google.cloud.documentai.v1beta3.IVertex[]|null);

                    /** BoundingPoly normalizedVertices */
                    normalizedVertices?: (google.cloud.documentai.v1beta3.INormalizedVertex[]|null);
                }

                /** Represents a BoundingPoly. */
                class BoundingPoly implements IBoundingPoly {

                    /**
                     * Constructs a new BoundingPoly.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBoundingPoly);

                    /** BoundingPoly vertices. */
                    public vertices: google.cloud.documentai.v1beta3.IVertex[];

                    /** BoundingPoly normalizedVertices. */
                    public normalizedVertices: google.cloud.documentai.v1beta3.INormalizedVertex[];

                    /**
                     * Creates a new BoundingPoly instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BoundingPoly instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBoundingPoly): google.cloud.documentai.v1beta3.BoundingPoly;

                    /**
                     * Encodes the specified BoundingPoly message. Does not implicitly {@link google.cloud.documentai.v1beta3.BoundingPoly.verify|verify} messages.
                     * @param message BoundingPoly message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBoundingPoly, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BoundingPoly message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BoundingPoly.verify|verify} messages.
                     * @param message BoundingPoly message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBoundingPoly, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BoundingPoly message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BoundingPoly
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BoundingPoly;

                    /**
                     * Decodes a BoundingPoly message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BoundingPoly
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BoundingPoly;

                    /**
                     * Verifies a BoundingPoly message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BoundingPoly message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BoundingPoly
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BoundingPoly;

                    /**
                     * Creates a plain object from a BoundingPoly message. Also converts values to other types if specified.
                     * @param message BoundingPoly
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.BoundingPoly, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BoundingPoly to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BoundingPoly
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a RawDocument. */
                interface IRawDocument {

                    /** RawDocument content */
                    content?: (Uint8Array|string|null);

                    /** RawDocument mimeType */
                    mimeType?: (string|null);

                    /** RawDocument displayName */
                    displayName?: (string|null);
                }

                /** Represents a RawDocument. */
                class RawDocument implements IRawDocument {

                    /**
                     * Constructs a new RawDocument.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IRawDocument);

                    /** RawDocument content. */
                    public content: (Uint8Array|string);

                    /** RawDocument mimeType. */
                    public mimeType: string;

                    /** RawDocument displayName. */
                    public displayName: string;

                    /**
                     * Creates a new RawDocument instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns RawDocument instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IRawDocument): google.cloud.documentai.v1beta3.RawDocument;

                    /**
                     * Encodes the specified RawDocument message. Does not implicitly {@link google.cloud.documentai.v1beta3.RawDocument.verify|verify} messages.
                     * @param message RawDocument message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IRawDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified RawDocument message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.RawDocument.verify|verify} messages.
                     * @param message RawDocument message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IRawDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a RawDocument message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns RawDocument
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.RawDocument;

                    /**
                     * Decodes a RawDocument message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns RawDocument
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.RawDocument;

                    /**
                     * Verifies a RawDocument message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a RawDocument message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns RawDocument
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.RawDocument;

                    /**
                     * Creates a plain object from a RawDocument message. Also converts values to other types if specified.
                     * @param message RawDocument
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.RawDocument, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this RawDocument to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for RawDocument
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsDocument. */
                interface IGcsDocument {

                    /** GcsDocument gcsUri */
                    gcsUri?: (string|null);

                    /** GcsDocument mimeType */
                    mimeType?: (string|null);
                }

                /** Represents a GcsDocument. */
                class GcsDocument implements IGcsDocument {

                    /**
                     * Constructs a new GcsDocument.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGcsDocument);

                    /** GcsDocument gcsUri. */
                    public gcsUri: string;

                    /** GcsDocument mimeType. */
                    public mimeType: string;

                    /**
                     * Creates a new GcsDocument instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsDocument instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGcsDocument): google.cloud.documentai.v1beta3.GcsDocument;

                    /**
                     * Encodes the specified GcsDocument message. Does not implicitly {@link google.cloud.documentai.v1beta3.GcsDocument.verify|verify} messages.
                     * @param message GcsDocument message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGcsDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsDocument message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GcsDocument.verify|verify} messages.
                     * @param message GcsDocument message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGcsDocument, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsDocument message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsDocument
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GcsDocument;

                    /**
                     * Decodes a GcsDocument message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsDocument
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GcsDocument;

                    /**
                     * Verifies a GcsDocument message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsDocument message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsDocument
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GcsDocument;

                    /**
                     * Creates a plain object from a GcsDocument message. Also converts values to other types if specified.
                     * @param message GcsDocument
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GcsDocument, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsDocument to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsDocument
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsDocuments. */
                interface IGcsDocuments {

                    /** GcsDocuments documents */
                    documents?: (google.cloud.documentai.v1beta3.IGcsDocument[]|null);
                }

                /** Represents a GcsDocuments. */
                class GcsDocuments implements IGcsDocuments {

                    /**
                     * Constructs a new GcsDocuments.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGcsDocuments);

                    /** GcsDocuments documents. */
                    public documents: google.cloud.documentai.v1beta3.IGcsDocument[];

                    /**
                     * Creates a new GcsDocuments instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsDocuments instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGcsDocuments): google.cloud.documentai.v1beta3.GcsDocuments;

                    /**
                     * Encodes the specified GcsDocuments message. Does not implicitly {@link google.cloud.documentai.v1beta3.GcsDocuments.verify|verify} messages.
                     * @param message GcsDocuments message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGcsDocuments, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsDocuments message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GcsDocuments.verify|verify} messages.
                     * @param message GcsDocuments message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGcsDocuments, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsDocuments message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsDocuments
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GcsDocuments;

                    /**
                     * Decodes a GcsDocuments message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsDocuments
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GcsDocuments;

                    /**
                     * Verifies a GcsDocuments message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsDocuments message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsDocuments
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GcsDocuments;

                    /**
                     * Creates a plain object from a GcsDocuments message. Also converts values to other types if specified.
                     * @param message GcsDocuments
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GcsDocuments, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsDocuments to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsDocuments
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GcsPrefix. */
                interface IGcsPrefix {

                    /** GcsPrefix gcsUriPrefix */
                    gcsUriPrefix?: (string|null);
                }

                /** Represents a GcsPrefix. */
                class GcsPrefix implements IGcsPrefix {

                    /**
                     * Constructs a new GcsPrefix.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGcsPrefix);

                    /** GcsPrefix gcsUriPrefix. */
                    public gcsUriPrefix: string;

                    /**
                     * Creates a new GcsPrefix instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GcsPrefix instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGcsPrefix): google.cloud.documentai.v1beta3.GcsPrefix;

                    /**
                     * Encodes the specified GcsPrefix message. Does not implicitly {@link google.cloud.documentai.v1beta3.GcsPrefix.verify|verify} messages.
                     * @param message GcsPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGcsPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GcsPrefix message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GcsPrefix.verify|verify} messages.
                     * @param message GcsPrefix message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGcsPrefix, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GcsPrefix message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GcsPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GcsPrefix;

                    /**
                     * Decodes a GcsPrefix message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GcsPrefix
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GcsPrefix;

                    /**
                     * Verifies a GcsPrefix message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GcsPrefix message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GcsPrefix
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GcsPrefix;

                    /**
                     * Creates a plain object from a GcsPrefix message. Also converts values to other types if specified.
                     * @param message GcsPrefix
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GcsPrefix, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GcsPrefix to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GcsPrefix
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchDocumentsInputConfig. */
                interface IBatchDocumentsInputConfig {

                    /** BatchDocumentsInputConfig gcsPrefix */
                    gcsPrefix?: (google.cloud.documentai.v1beta3.IGcsPrefix|null);

                    /** BatchDocumentsInputConfig gcsDocuments */
                    gcsDocuments?: (google.cloud.documentai.v1beta3.IGcsDocuments|null);
                }

                /** Represents a BatchDocumentsInputConfig. */
                class BatchDocumentsInputConfig implements IBatchDocumentsInputConfig {

                    /**
                     * Constructs a new BatchDocumentsInputConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig);

                    /** BatchDocumentsInputConfig gcsPrefix. */
                    public gcsPrefix?: (google.cloud.documentai.v1beta3.IGcsPrefix|null);

                    /** BatchDocumentsInputConfig gcsDocuments. */
                    public gcsDocuments?: (google.cloud.documentai.v1beta3.IGcsDocuments|null);

                    /** BatchDocumentsInputConfig source. */
                    public source?: ("gcsPrefix"|"gcsDocuments");

                    /**
                     * Creates a new BatchDocumentsInputConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchDocumentsInputConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig): google.cloud.documentai.v1beta3.BatchDocumentsInputConfig;

                    /**
                     * Encodes the specified BatchDocumentsInputConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDocumentsInputConfig.verify|verify} messages.
                     * @param message BatchDocumentsInputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchDocumentsInputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDocumentsInputConfig.verify|verify} messages.
                     * @param message BatchDocumentsInputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchDocumentsInputConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchDocumentsInputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchDocumentsInputConfig;

                    /**
                     * Decodes a BatchDocumentsInputConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchDocumentsInputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchDocumentsInputConfig;

                    /**
                     * Verifies a BatchDocumentsInputConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchDocumentsInputConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchDocumentsInputConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchDocumentsInputConfig;

                    /**
                     * Creates a plain object from a BatchDocumentsInputConfig message. Also converts values to other types if specified.
                     * @param message BatchDocumentsInputConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.BatchDocumentsInputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchDocumentsInputConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchDocumentsInputConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DocumentOutputConfig. */
                interface IDocumentOutputConfig {

                    /** DocumentOutputConfig gcsOutputConfig */
                    gcsOutputConfig?: (google.cloud.documentai.v1beta3.DocumentOutputConfig.IGcsOutputConfig|null);
                }

                /** Represents a DocumentOutputConfig. */
                class DocumentOutputConfig implements IDocumentOutputConfig {

                    /**
                     * Constructs a new DocumentOutputConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDocumentOutputConfig);

                    /** DocumentOutputConfig gcsOutputConfig. */
                    public gcsOutputConfig?: (google.cloud.documentai.v1beta3.DocumentOutputConfig.IGcsOutputConfig|null);

                    /** DocumentOutputConfig destination. */
                    public destination?: "gcsOutputConfig";

                    /**
                     * Creates a new DocumentOutputConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DocumentOutputConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDocumentOutputConfig): google.cloud.documentai.v1beta3.DocumentOutputConfig;

                    /**
                     * Encodes the specified DocumentOutputConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentOutputConfig.verify|verify} messages.
                     * @param message DocumentOutputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDocumentOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DocumentOutputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentOutputConfig.verify|verify} messages.
                     * @param message DocumentOutputConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDocumentOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DocumentOutputConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DocumentOutputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentOutputConfig;

                    /**
                     * Decodes a DocumentOutputConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DocumentOutputConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentOutputConfig;

                    /**
                     * Verifies a DocumentOutputConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DocumentOutputConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DocumentOutputConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentOutputConfig;

                    /**
                     * Creates a plain object from a DocumentOutputConfig message. Also converts values to other types if specified.
                     * @param message DocumentOutputConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DocumentOutputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DocumentOutputConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DocumentOutputConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace DocumentOutputConfig {

                    /** Properties of a GcsOutputConfig. */
                    interface IGcsOutputConfig {

                        /** GcsOutputConfig gcsUri */
                        gcsUri?: (string|null);

                        /** GcsOutputConfig fieldMask */
                        fieldMask?: (google.protobuf.IFieldMask|null);

                        /** GcsOutputConfig shardingConfig */
                        shardingConfig?: (google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.IShardingConfig|null);
                    }

                    /** Represents a GcsOutputConfig. */
                    class GcsOutputConfig implements IGcsOutputConfig {

                        /**
                         * Constructs a new GcsOutputConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.DocumentOutputConfig.IGcsOutputConfig);

                        /** GcsOutputConfig gcsUri. */
                        public gcsUri: string;

                        /** GcsOutputConfig fieldMask. */
                        public fieldMask?: (google.protobuf.IFieldMask|null);

                        /** GcsOutputConfig shardingConfig. */
                        public shardingConfig?: (google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.IShardingConfig|null);

                        /**
                         * Creates a new GcsOutputConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns GcsOutputConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.DocumentOutputConfig.IGcsOutputConfig): google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig;

                        /**
                         * Encodes the specified GcsOutputConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.verify|verify} messages.
                         * @param message GcsOutputConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.DocumentOutputConfig.IGcsOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified GcsOutputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.verify|verify} messages.
                         * @param message GcsOutputConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.DocumentOutputConfig.IGcsOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a GcsOutputConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns GcsOutputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig;

                        /**
                         * Decodes a GcsOutputConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns GcsOutputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig;

                        /**
                         * Verifies a GcsOutputConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a GcsOutputConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns GcsOutputConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig;

                        /**
                         * Creates a plain object from a GcsOutputConfig message. Also converts values to other types if specified.
                         * @param message GcsOutputConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this GcsOutputConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for GcsOutputConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace GcsOutputConfig {

                        /** Properties of a ShardingConfig. */
                        interface IShardingConfig {

                            /** ShardingConfig pagesPerShard */
                            pagesPerShard?: (number|null);

                            /** ShardingConfig pagesOverlap */
                            pagesOverlap?: (number|null);
                        }

                        /** Represents a ShardingConfig. */
                        class ShardingConfig implements IShardingConfig {

                            /**
                             * Constructs a new ShardingConfig.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.IShardingConfig);

                            /** ShardingConfig pagesPerShard. */
                            public pagesPerShard: number;

                            /** ShardingConfig pagesOverlap. */
                            public pagesOverlap: number;

                            /**
                             * Creates a new ShardingConfig instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns ShardingConfig instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.IShardingConfig): google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.ShardingConfig;

                            /**
                             * Encodes the specified ShardingConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.ShardingConfig.verify|verify} messages.
                             * @param message ShardingConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.IShardingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified ShardingConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.ShardingConfig.verify|verify} messages.
                             * @param message ShardingConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.IShardingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a ShardingConfig message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns ShardingConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.ShardingConfig;

                            /**
                             * Decodes a ShardingConfig message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns ShardingConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.ShardingConfig;

                            /**
                             * Verifies a ShardingConfig message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a ShardingConfig message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns ShardingConfig
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.ShardingConfig;

                            /**
                             * Creates a plain object from a ShardingConfig message. Also converts values to other types if specified.
                             * @param message ShardingConfig
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.DocumentOutputConfig.GcsOutputConfig.ShardingConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this ShardingConfig to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for ShardingConfig
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }
                }

                /** Properties of an OcrConfig. */
                interface IOcrConfig {

                    /** OcrConfig hints */
                    hints?: (google.cloud.documentai.v1beta3.OcrConfig.IHints|null);

                    /** OcrConfig enableNativePdfParsing */
                    enableNativePdfParsing?: (boolean|null);

                    /** OcrConfig enableImageQualityScores */
                    enableImageQualityScores?: (boolean|null);

                    /** OcrConfig advancedOcrOptions */
                    advancedOcrOptions?: (string[]|null);

                    /** OcrConfig enableSymbol */
                    enableSymbol?: (boolean|null);

                    /** OcrConfig computeStyleInfo */
                    computeStyleInfo?: (boolean|null);

                    /** OcrConfig disableCharacterBoxesDetection */
                    disableCharacterBoxesDetection?: (boolean|null);

                    /** OcrConfig premiumFeatures */
                    premiumFeatures?: (google.cloud.documentai.v1beta3.OcrConfig.IPremiumFeatures|null);
                }

                /** Represents an OcrConfig. */
                class OcrConfig implements IOcrConfig {

                    /**
                     * Constructs a new OcrConfig.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IOcrConfig);

                    /** OcrConfig hints. */
                    public hints?: (google.cloud.documentai.v1beta3.OcrConfig.IHints|null);

                    /** OcrConfig enableNativePdfParsing. */
                    public enableNativePdfParsing: boolean;

                    /** OcrConfig enableImageQualityScores. */
                    public enableImageQualityScores: boolean;

                    /** OcrConfig advancedOcrOptions. */
                    public advancedOcrOptions: string[];

                    /** OcrConfig enableSymbol. */
                    public enableSymbol: boolean;

                    /** OcrConfig computeStyleInfo. */
                    public computeStyleInfo: boolean;

                    /** OcrConfig disableCharacterBoxesDetection. */
                    public disableCharacterBoxesDetection: boolean;

                    /** OcrConfig premiumFeatures. */
                    public premiumFeatures?: (google.cloud.documentai.v1beta3.OcrConfig.IPremiumFeatures|null);

                    /**
                     * Creates a new OcrConfig instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns OcrConfig instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IOcrConfig): google.cloud.documentai.v1beta3.OcrConfig;

                    /**
                     * Encodes the specified OcrConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.OcrConfig.verify|verify} messages.
                     * @param message OcrConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IOcrConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified OcrConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.OcrConfig.verify|verify} messages.
                     * @param message OcrConfig message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IOcrConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an OcrConfig message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns OcrConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.OcrConfig;

                    /**
                     * Decodes an OcrConfig message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns OcrConfig
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.OcrConfig;

                    /**
                     * Verifies an OcrConfig message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an OcrConfig message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns OcrConfig
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.OcrConfig;

                    /**
                     * Creates a plain object from an OcrConfig message. Also converts values to other types if specified.
                     * @param message OcrConfig
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.OcrConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this OcrConfig to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for OcrConfig
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace OcrConfig {

                    /** Properties of a Hints. */
                    interface IHints {

                        /** Hints languageHints */
                        languageHints?: (string[]|null);
                    }

                    /** Represents a Hints. */
                    class Hints implements IHints {

                        /**
                         * Constructs a new Hints.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.OcrConfig.IHints);

                        /** Hints languageHints. */
                        public languageHints: string[];

                        /**
                         * Creates a new Hints instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Hints instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.OcrConfig.IHints): google.cloud.documentai.v1beta3.OcrConfig.Hints;

                        /**
                         * Encodes the specified Hints message. Does not implicitly {@link google.cloud.documentai.v1beta3.OcrConfig.Hints.verify|verify} messages.
                         * @param message Hints message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.OcrConfig.IHints, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Hints message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.OcrConfig.Hints.verify|verify} messages.
                         * @param message Hints message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.OcrConfig.IHints, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Hints message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Hints
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.OcrConfig.Hints;

                        /**
                         * Decodes a Hints message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Hints
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.OcrConfig.Hints;

                        /**
                         * Verifies a Hints message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Hints message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Hints
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.OcrConfig.Hints;

                        /**
                         * Creates a plain object from a Hints message. Also converts values to other types if specified.
                         * @param message Hints
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.OcrConfig.Hints, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Hints to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Hints
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a PremiumFeatures. */
                    interface IPremiumFeatures {

                        /** PremiumFeatures enableSelectionMarkDetection */
                        enableSelectionMarkDetection?: (boolean|null);

                        /** PremiumFeatures computeStyleInfo */
                        computeStyleInfo?: (boolean|null);

                        /** PremiumFeatures enableMathOcr */
                        enableMathOcr?: (boolean|null);
                    }

                    /** Represents a PremiumFeatures. */
                    class PremiumFeatures implements IPremiumFeatures {

                        /**
                         * Constructs a new PremiumFeatures.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.OcrConfig.IPremiumFeatures);

                        /** PremiumFeatures enableSelectionMarkDetection. */
                        public enableSelectionMarkDetection: boolean;

                        /** PremiumFeatures computeStyleInfo. */
                        public computeStyleInfo: boolean;

                        /** PremiumFeatures enableMathOcr. */
                        public enableMathOcr: boolean;

                        /**
                         * Creates a new PremiumFeatures instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns PremiumFeatures instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.OcrConfig.IPremiumFeatures): google.cloud.documentai.v1beta3.OcrConfig.PremiumFeatures;

                        /**
                         * Encodes the specified PremiumFeatures message. Does not implicitly {@link google.cloud.documentai.v1beta3.OcrConfig.PremiumFeatures.verify|verify} messages.
                         * @param message PremiumFeatures message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.OcrConfig.IPremiumFeatures, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified PremiumFeatures message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.OcrConfig.PremiumFeatures.verify|verify} messages.
                         * @param message PremiumFeatures message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.OcrConfig.IPremiumFeatures, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a PremiumFeatures message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns PremiumFeatures
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.OcrConfig.PremiumFeatures;

                        /**
                         * Decodes a PremiumFeatures message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns PremiumFeatures
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.OcrConfig.PremiumFeatures;

                        /**
                         * Verifies a PremiumFeatures message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a PremiumFeatures message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns PremiumFeatures
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.OcrConfig.PremiumFeatures;

                        /**
                         * Creates a plain object from a PremiumFeatures message. Also converts values to other types if specified.
                         * @param message PremiumFeatures
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.OcrConfig.PremiumFeatures, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this PremiumFeatures to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for PremiumFeatures
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a SummaryOptions. */
                interface ISummaryOptions {

                    /** SummaryOptions length */
                    length?: (google.cloud.documentai.v1beta3.SummaryOptions.Length|keyof typeof google.cloud.documentai.v1beta3.SummaryOptions.Length|null);

                    /** SummaryOptions format */
                    format?: (google.cloud.documentai.v1beta3.SummaryOptions.Format|keyof typeof google.cloud.documentai.v1beta3.SummaryOptions.Format|null);
                }

                /** Represents a SummaryOptions. */
                class SummaryOptions implements ISummaryOptions {

                    /**
                     * Constructs a new SummaryOptions.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.ISummaryOptions);

                    /** SummaryOptions length. */
                    public length: (google.cloud.documentai.v1beta3.SummaryOptions.Length|keyof typeof google.cloud.documentai.v1beta3.SummaryOptions.Length);

                    /** SummaryOptions format. */
                    public format: (google.cloud.documentai.v1beta3.SummaryOptions.Format|keyof typeof google.cloud.documentai.v1beta3.SummaryOptions.Format);

                    /**
                     * Creates a new SummaryOptions instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SummaryOptions instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.ISummaryOptions): google.cloud.documentai.v1beta3.SummaryOptions;

                    /**
                     * Encodes the specified SummaryOptions message. Does not implicitly {@link google.cloud.documentai.v1beta3.SummaryOptions.verify|verify} messages.
                     * @param message SummaryOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.ISummaryOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SummaryOptions message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.SummaryOptions.verify|verify} messages.
                     * @param message SummaryOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.ISummaryOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SummaryOptions message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SummaryOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.SummaryOptions;

                    /**
                     * Decodes a SummaryOptions message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SummaryOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.SummaryOptions;

                    /**
                     * Verifies a SummaryOptions message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SummaryOptions message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SummaryOptions
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.SummaryOptions;

                    /**
                     * Creates a plain object from a SummaryOptions message. Also converts values to other types if specified.
                     * @param message SummaryOptions
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.SummaryOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SummaryOptions to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SummaryOptions
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace SummaryOptions {

                    /** Length enum. */
                    enum Length {
                        LENGTH_UNSPECIFIED = 0,
                        BRIEF = 1,
                        MODERATE = 2,
                        COMPREHENSIVE = 3
                    }

                    /** Format enum. */
                    enum Format {
                        FORMAT_UNSPECIFIED = 0,
                        PARAGRAPH = 1,
                        BULLETS = 2
                    }
                }

                /** Properties of a FieldExtractionMetadata. */
                interface IFieldExtractionMetadata {

                    /** FieldExtractionMetadata summaryOptions */
                    summaryOptions?: (google.cloud.documentai.v1beta3.ISummaryOptions|null);
                }

                /** Represents a FieldExtractionMetadata. */
                class FieldExtractionMetadata implements IFieldExtractionMetadata {

                    /**
                     * Constructs a new FieldExtractionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IFieldExtractionMetadata);

                    /** FieldExtractionMetadata summaryOptions. */
                    public summaryOptions?: (google.cloud.documentai.v1beta3.ISummaryOptions|null);

                    /**
                     * Creates a new FieldExtractionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FieldExtractionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IFieldExtractionMetadata): google.cloud.documentai.v1beta3.FieldExtractionMetadata;

                    /**
                     * Encodes the specified FieldExtractionMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.FieldExtractionMetadata.verify|verify} messages.
                     * @param message FieldExtractionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IFieldExtractionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FieldExtractionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.FieldExtractionMetadata.verify|verify} messages.
                     * @param message FieldExtractionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IFieldExtractionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FieldExtractionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FieldExtractionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.FieldExtractionMetadata;

                    /**
                     * Decodes a FieldExtractionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FieldExtractionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.FieldExtractionMetadata;

                    /**
                     * Verifies a FieldExtractionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FieldExtractionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FieldExtractionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.FieldExtractionMetadata;

                    /**
                     * Creates a plain object from a FieldExtractionMetadata message. Also converts values to other types if specified.
                     * @param message FieldExtractionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.FieldExtractionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FieldExtractionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FieldExtractionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a PropertyMetadata. */
                interface IPropertyMetadata {

                    /** PropertyMetadata inactive */
                    inactive?: (boolean|null);

                    /** PropertyMetadata fieldExtractionMetadata */
                    fieldExtractionMetadata?: (google.cloud.documentai.v1beta3.IFieldExtractionMetadata|null);
                }

                /** Represents a PropertyMetadata. */
                class PropertyMetadata implements IPropertyMetadata {

                    /**
                     * Constructs a new PropertyMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IPropertyMetadata);

                    /** PropertyMetadata inactive. */
                    public inactive: boolean;

                    /** PropertyMetadata fieldExtractionMetadata. */
                    public fieldExtractionMetadata?: (google.cloud.documentai.v1beta3.IFieldExtractionMetadata|null);

                    /**
                     * Creates a new PropertyMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns PropertyMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IPropertyMetadata): google.cloud.documentai.v1beta3.PropertyMetadata;

                    /**
                     * Encodes the specified PropertyMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.PropertyMetadata.verify|verify} messages.
                     * @param message PropertyMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IPropertyMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified PropertyMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.PropertyMetadata.verify|verify} messages.
                     * @param message PropertyMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IPropertyMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a PropertyMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns PropertyMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.PropertyMetadata;

                    /**
                     * Decodes a PropertyMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns PropertyMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.PropertyMetadata;

                    /**
                     * Verifies a PropertyMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a PropertyMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns PropertyMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.PropertyMetadata;

                    /**
                     * Creates a plain object from a PropertyMetadata message. Also converts values to other types if specified.
                     * @param message PropertyMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.PropertyMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this PropertyMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for PropertyMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EntityTypeMetadata. */
                interface IEntityTypeMetadata {

                    /** EntityTypeMetadata inactive */
                    inactive?: (boolean|null);
                }

                /** Represents an EntityTypeMetadata. */
                class EntityTypeMetadata implements IEntityTypeMetadata {

                    /**
                     * Constructs a new EntityTypeMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IEntityTypeMetadata);

                    /** EntityTypeMetadata inactive. */
                    public inactive: boolean;

                    /**
                     * Creates a new EntityTypeMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EntityTypeMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IEntityTypeMetadata): google.cloud.documentai.v1beta3.EntityTypeMetadata;

                    /**
                     * Encodes the specified EntityTypeMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.EntityTypeMetadata.verify|verify} messages.
                     * @param message EntityTypeMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IEntityTypeMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EntityTypeMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.EntityTypeMetadata.verify|verify} messages.
                     * @param message EntityTypeMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IEntityTypeMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EntityTypeMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EntityTypeMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.EntityTypeMetadata;

                    /**
                     * Decodes an EntityTypeMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EntityTypeMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.EntityTypeMetadata;

                    /**
                     * Verifies an EntityTypeMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EntityTypeMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EntityTypeMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.EntityTypeMetadata;

                    /**
                     * Creates a plain object from an EntityTypeMetadata message. Also converts values to other types if specified.
                     * @param message EntityTypeMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.EntityTypeMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EntityTypeMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EntityTypeMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DocumentSchema. */
                interface IDocumentSchema {

                    /** DocumentSchema displayName */
                    displayName?: (string|null);

                    /** DocumentSchema description */
                    description?: (string|null);

                    /** DocumentSchema entityTypes */
                    entityTypes?: (google.cloud.documentai.v1beta3.DocumentSchema.IEntityType[]|null);

                    /** DocumentSchema metadata */
                    metadata?: (google.cloud.documentai.v1beta3.DocumentSchema.IMetadata|null);
                }

                /** Represents a DocumentSchema. */
                class DocumentSchema implements IDocumentSchema {

                    /**
                     * Constructs a new DocumentSchema.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDocumentSchema);

                    /** DocumentSchema displayName. */
                    public displayName: string;

                    /** DocumentSchema description. */
                    public description: string;

                    /** DocumentSchema entityTypes. */
                    public entityTypes: google.cloud.documentai.v1beta3.DocumentSchema.IEntityType[];

                    /** DocumentSchema metadata. */
                    public metadata?: (google.cloud.documentai.v1beta3.DocumentSchema.IMetadata|null);

                    /**
                     * Creates a new DocumentSchema instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DocumentSchema instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDocumentSchema): google.cloud.documentai.v1beta3.DocumentSchema;

                    /**
                     * Encodes the specified DocumentSchema message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.verify|verify} messages.
                     * @param message DocumentSchema message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDocumentSchema, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DocumentSchema message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.verify|verify} messages.
                     * @param message DocumentSchema message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDocumentSchema, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DocumentSchema message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DocumentSchema
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentSchema;

                    /**
                     * Decodes a DocumentSchema message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DocumentSchema
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentSchema;

                    /**
                     * Verifies a DocumentSchema message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DocumentSchema message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DocumentSchema
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentSchema;

                    /**
                     * Creates a plain object from a DocumentSchema message. Also converts values to other types if specified.
                     * @param message DocumentSchema
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DocumentSchema, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DocumentSchema to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DocumentSchema
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace DocumentSchema {

                    /** Properties of an EntityType. */
                    interface IEntityType {

                        /** EntityType enumValues */
                        enumValues?: (google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IEnumValues|null);

                        /** EntityType displayName */
                        displayName?: (string|null);

                        /** EntityType name */
                        name?: (string|null);

                        /** EntityType description */
                        description?: (string|null);

                        /** EntityType baseTypes */
                        baseTypes?: (string[]|null);

                        /** EntityType properties */
                        properties?: (google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IProperty[]|null);

                        /** EntityType entityTypeMetadata */
                        entityTypeMetadata?: (google.cloud.documentai.v1beta3.IEntityTypeMetadata|null);
                    }

                    /** Represents an EntityType. */
                    class EntityType implements IEntityType {

                        /**
                         * Constructs a new EntityType.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.DocumentSchema.IEntityType);

                        /** EntityType enumValues. */
                        public enumValues?: (google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IEnumValues|null);

                        /** EntityType displayName. */
                        public displayName: string;

                        /** EntityType name. */
                        public name: string;

                        /** EntityType description. */
                        public description: string;

                        /** EntityType baseTypes. */
                        public baseTypes: string[];

                        /** EntityType properties. */
                        public properties: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IProperty[];

                        /** EntityType entityTypeMetadata. */
                        public entityTypeMetadata?: (google.cloud.documentai.v1beta3.IEntityTypeMetadata|null);

                        /** EntityType valueSource. */
                        public valueSource?: "enumValues";

                        /**
                         * Creates a new EntityType instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns EntityType instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.DocumentSchema.IEntityType): google.cloud.documentai.v1beta3.DocumentSchema.EntityType;

                        /**
                         * Encodes the specified EntityType message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.EntityType.verify|verify} messages.
                         * @param message EntityType message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.DocumentSchema.IEntityType, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified EntityType message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.EntityType.verify|verify} messages.
                         * @param message EntityType message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.DocumentSchema.IEntityType, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an EntityType message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns EntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentSchema.EntityType;

                        /**
                         * Decodes an EntityType message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns EntityType
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentSchema.EntityType;

                        /**
                         * Verifies an EntityType message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an EntityType message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns EntityType
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentSchema.EntityType;

                        /**
                         * Creates a plain object from an EntityType message. Also converts values to other types if specified.
                         * @param message EntityType
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.DocumentSchema.EntityType, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this EntityType to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for EntityType
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace EntityType {

                        /** Properties of an EnumValues. */
                        interface IEnumValues {

                            /** EnumValues values */
                            values?: (string[]|null);
                        }

                        /** Represents an EnumValues. */
                        class EnumValues implements IEnumValues {

                            /**
                             * Constructs a new EnumValues.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IEnumValues);

                            /** EnumValues values. */
                            public values: string[];

                            /**
                             * Creates a new EnumValues instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns EnumValues instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IEnumValues): google.cloud.documentai.v1beta3.DocumentSchema.EntityType.EnumValues;

                            /**
                             * Encodes the specified EnumValues message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.EntityType.EnumValues.verify|verify} messages.
                             * @param message EnumValues message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IEnumValues, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified EnumValues message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.EntityType.EnumValues.verify|verify} messages.
                             * @param message EnumValues message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IEnumValues, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes an EnumValues message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns EnumValues
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentSchema.EntityType.EnumValues;

                            /**
                             * Decodes an EnumValues message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns EnumValues
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentSchema.EntityType.EnumValues;

                            /**
                             * Verifies an EnumValues message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates an EnumValues message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns EnumValues
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentSchema.EntityType.EnumValues;

                            /**
                             * Creates a plain object from an EnumValues message. Also converts values to other types if specified.
                             * @param message EnumValues
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.EnumValues, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this EnumValues to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for EnumValues
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a Property. */
                        interface IProperty {

                            /** Property name */
                            name?: (string|null);

                            /** Property description */
                            description?: (string|null);

                            /** Property displayName */
                            displayName?: (string|null);

                            /** Property valueType */
                            valueType?: (string|null);

                            /** Property occurrenceType */
                            occurrenceType?: (google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property.OccurrenceType|keyof typeof google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property.OccurrenceType|null);

                            /** Property propertyMetadata */
                            propertyMetadata?: (google.cloud.documentai.v1beta3.IPropertyMetadata|null);
                        }

                        /** Represents a Property. */
                        class Property implements IProperty {

                            /**
                             * Constructs a new Property.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IProperty);

                            /** Property name. */
                            public name: string;

                            /** Property description. */
                            public description: string;

                            /** Property displayName. */
                            public displayName: string;

                            /** Property valueType. */
                            public valueType: string;

                            /** Property occurrenceType. */
                            public occurrenceType: (google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property.OccurrenceType|keyof typeof google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property.OccurrenceType);

                            /** Property propertyMetadata. */
                            public propertyMetadata?: (google.cloud.documentai.v1beta3.IPropertyMetadata|null);

                            /**
                             * Creates a new Property instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns Property instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IProperty): google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property;

                            /**
                             * Encodes the specified Property message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property.verify|verify} messages.
                             * @param message Property message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IProperty, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified Property message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property.verify|verify} messages.
                             * @param message Property message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.IProperty, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a Property message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns Property
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property;

                            /**
                             * Decodes a Property message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns Property
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property;

                            /**
                             * Verifies a Property message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a Property message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns Property
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property;

                            /**
                             * Creates a plain object from a Property message. Also converts values to other types if specified.
                             * @param message Property
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.DocumentSchema.EntityType.Property, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this Property to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for Property
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace Property {

                            /** OccurrenceType enum. */
                            enum OccurrenceType {
                                OCCURRENCE_TYPE_UNSPECIFIED = 0,
                                OPTIONAL_ONCE = 1,
                                OPTIONAL_MULTIPLE = 2,
                                REQUIRED_ONCE = 3,
                                REQUIRED_MULTIPLE = 4
                            }
                        }
                    }

                    /** Properties of a Metadata. */
                    interface IMetadata {

                        /** Metadata documentSplitter */
                        documentSplitter?: (boolean|null);

                        /** Metadata documentAllowMultipleLabels */
                        documentAllowMultipleLabels?: (boolean|null);

                        /** Metadata prefixedNamingOnProperties */
                        prefixedNamingOnProperties?: (boolean|null);

                        /** Metadata skipNamingValidation */
                        skipNamingValidation?: (boolean|null);
                    }

                    /** Represents a Metadata. */
                    class Metadata implements IMetadata {

                        /**
                         * Constructs a new Metadata.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.DocumentSchema.IMetadata);

                        /** Metadata documentSplitter. */
                        public documentSplitter: boolean;

                        /** Metadata documentAllowMultipleLabels. */
                        public documentAllowMultipleLabels: boolean;

                        /** Metadata prefixedNamingOnProperties. */
                        public prefixedNamingOnProperties: boolean;

                        /** Metadata skipNamingValidation. */
                        public skipNamingValidation: boolean;

                        /**
                         * Creates a new Metadata instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Metadata instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.DocumentSchema.IMetadata): google.cloud.documentai.v1beta3.DocumentSchema.Metadata;

                        /**
                         * Encodes the specified Metadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.Metadata.verify|verify} messages.
                         * @param message Metadata message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.DocumentSchema.IMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Metadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentSchema.Metadata.verify|verify} messages.
                         * @param message Metadata message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.DocumentSchema.IMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Metadata message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Metadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentSchema.Metadata;

                        /**
                         * Decodes a Metadata message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Metadata
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentSchema.Metadata;

                        /**
                         * Verifies a Metadata message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Metadata message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Metadata
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentSchema.Metadata;

                        /**
                         * Creates a plain object from a Metadata message. Also converts values to other types if specified.
                         * @param message Metadata
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.DocumentSchema.Metadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Metadata to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Metadata
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Represents a DocumentProcessorService */
                class DocumentProcessorService extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new DocumentProcessorService service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new DocumentProcessorService service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): DocumentProcessorService;

                    /**
                     * Calls ProcessDocument.
                     * @param request ProcessRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ProcessResponse
                     */
                    public processDocument(request: google.cloud.documentai.v1beta3.IProcessRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.ProcessDocumentCallback): void;

                    /**
                     * Calls ProcessDocument.
                     * @param request ProcessRequest message or plain object
                     * @returns Promise
                     */
                    public processDocument(request: google.cloud.documentai.v1beta3.IProcessRequest): Promise<google.cloud.documentai.v1beta3.ProcessResponse>;

                    /**
                     * Calls BatchProcessDocuments.
                     * @param request BatchProcessRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public batchProcessDocuments(request: google.cloud.documentai.v1beta3.IBatchProcessRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.BatchProcessDocumentsCallback): void;

                    /**
                     * Calls BatchProcessDocuments.
                     * @param request BatchProcessRequest message or plain object
                     * @returns Promise
                     */
                    public batchProcessDocuments(request: google.cloud.documentai.v1beta3.IBatchProcessRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls FetchProcessorTypes.
                     * @param request FetchProcessorTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and FetchProcessorTypesResponse
                     */
                    public fetchProcessorTypes(request: google.cloud.documentai.v1beta3.IFetchProcessorTypesRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.FetchProcessorTypesCallback): void;

                    /**
                     * Calls FetchProcessorTypes.
                     * @param request FetchProcessorTypesRequest message or plain object
                     * @returns Promise
                     */
                    public fetchProcessorTypes(request: google.cloud.documentai.v1beta3.IFetchProcessorTypesRequest): Promise<google.cloud.documentai.v1beta3.FetchProcessorTypesResponse>;

                    /**
                     * Calls ListProcessorTypes.
                     * @param request ListProcessorTypesRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ListProcessorTypesResponse
                     */
                    public listProcessorTypes(request: google.cloud.documentai.v1beta3.IListProcessorTypesRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.ListProcessorTypesCallback): void;

                    /**
                     * Calls ListProcessorTypes.
                     * @param request ListProcessorTypesRequest message or plain object
                     * @returns Promise
                     */
                    public listProcessorTypes(request: google.cloud.documentai.v1beta3.IListProcessorTypesRequest): Promise<google.cloud.documentai.v1beta3.ListProcessorTypesResponse>;

                    /**
                     * Calls GetProcessorType.
                     * @param request GetProcessorTypeRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ProcessorType
                     */
                    public getProcessorType(request: google.cloud.documentai.v1beta3.IGetProcessorTypeRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.GetProcessorTypeCallback): void;

                    /**
                     * Calls GetProcessorType.
                     * @param request GetProcessorTypeRequest message or plain object
                     * @returns Promise
                     */
                    public getProcessorType(request: google.cloud.documentai.v1beta3.IGetProcessorTypeRequest): Promise<google.cloud.documentai.v1beta3.ProcessorType>;

                    /**
                     * Calls ListProcessors.
                     * @param request ListProcessorsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ListProcessorsResponse
                     */
                    public listProcessors(request: google.cloud.documentai.v1beta3.IListProcessorsRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.ListProcessorsCallback): void;

                    /**
                     * Calls ListProcessors.
                     * @param request ListProcessorsRequest message or plain object
                     * @returns Promise
                     */
                    public listProcessors(request: google.cloud.documentai.v1beta3.IListProcessorsRequest): Promise<google.cloud.documentai.v1beta3.ListProcessorsResponse>;

                    /**
                     * Calls GetProcessor.
                     * @param request GetProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Processor
                     */
                    public getProcessor(request: google.cloud.documentai.v1beta3.IGetProcessorRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.GetProcessorCallback): void;

                    /**
                     * Calls GetProcessor.
                     * @param request GetProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public getProcessor(request: google.cloud.documentai.v1beta3.IGetProcessorRequest): Promise<google.cloud.documentai.v1beta3.Processor>;

                    /**
                     * Calls TrainProcessorVersion.
                     * @param request TrainProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public trainProcessorVersion(request: google.cloud.documentai.v1beta3.ITrainProcessorVersionRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.TrainProcessorVersionCallback): void;

                    /**
                     * Calls TrainProcessorVersion.
                     * @param request TrainProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public trainProcessorVersion(request: google.cloud.documentai.v1beta3.ITrainProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls GetProcessorVersion.
                     * @param request GetProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ProcessorVersion
                     */
                    public getProcessorVersion(request: google.cloud.documentai.v1beta3.IGetProcessorVersionRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.GetProcessorVersionCallback): void;

                    /**
                     * Calls GetProcessorVersion.
                     * @param request GetProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public getProcessorVersion(request: google.cloud.documentai.v1beta3.IGetProcessorVersionRequest): Promise<google.cloud.documentai.v1beta3.ProcessorVersion>;

                    /**
                     * Calls ListProcessorVersions.
                     * @param request ListProcessorVersionsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ListProcessorVersionsResponse
                     */
                    public listProcessorVersions(request: google.cloud.documentai.v1beta3.IListProcessorVersionsRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.ListProcessorVersionsCallback): void;

                    /**
                     * Calls ListProcessorVersions.
                     * @param request ListProcessorVersionsRequest message or plain object
                     * @returns Promise
                     */
                    public listProcessorVersions(request: google.cloud.documentai.v1beta3.IListProcessorVersionsRequest): Promise<google.cloud.documentai.v1beta3.ListProcessorVersionsResponse>;

                    /**
                     * Calls DeleteProcessorVersion.
                     * @param request DeleteProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteProcessorVersion(request: google.cloud.documentai.v1beta3.IDeleteProcessorVersionRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.DeleteProcessorVersionCallback): void;

                    /**
                     * Calls DeleteProcessorVersion.
                     * @param request DeleteProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public deleteProcessorVersion(request: google.cloud.documentai.v1beta3.IDeleteProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls DeployProcessorVersion.
                     * @param request DeployProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deployProcessorVersion(request: google.cloud.documentai.v1beta3.IDeployProcessorVersionRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.DeployProcessorVersionCallback): void;

                    /**
                     * Calls DeployProcessorVersion.
                     * @param request DeployProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public deployProcessorVersion(request: google.cloud.documentai.v1beta3.IDeployProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls UndeployProcessorVersion.
                     * @param request UndeployProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public undeployProcessorVersion(request: google.cloud.documentai.v1beta3.IUndeployProcessorVersionRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.UndeployProcessorVersionCallback): void;

                    /**
                     * Calls UndeployProcessorVersion.
                     * @param request UndeployProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public undeployProcessorVersion(request: google.cloud.documentai.v1beta3.IUndeployProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls CreateProcessor.
                     * @param request CreateProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Processor
                     */
                    public createProcessor(request: google.cloud.documentai.v1beta3.ICreateProcessorRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.CreateProcessorCallback): void;

                    /**
                     * Calls CreateProcessor.
                     * @param request CreateProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public createProcessor(request: google.cloud.documentai.v1beta3.ICreateProcessorRequest): Promise<google.cloud.documentai.v1beta3.Processor>;

                    /**
                     * Calls DeleteProcessor.
                     * @param request DeleteProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public deleteProcessor(request: google.cloud.documentai.v1beta3.IDeleteProcessorRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.DeleteProcessorCallback): void;

                    /**
                     * Calls DeleteProcessor.
                     * @param request DeleteProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public deleteProcessor(request: google.cloud.documentai.v1beta3.IDeleteProcessorRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls EnableProcessor.
                     * @param request EnableProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public enableProcessor(request: google.cloud.documentai.v1beta3.IEnableProcessorRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.EnableProcessorCallback): void;

                    /**
                     * Calls EnableProcessor.
                     * @param request EnableProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public enableProcessor(request: google.cloud.documentai.v1beta3.IEnableProcessorRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls DisableProcessor.
                     * @param request DisableProcessorRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public disableProcessor(request: google.cloud.documentai.v1beta3.IDisableProcessorRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.DisableProcessorCallback): void;

                    /**
                     * Calls DisableProcessor.
                     * @param request DisableProcessorRequest message or plain object
                     * @returns Promise
                     */
                    public disableProcessor(request: google.cloud.documentai.v1beta3.IDisableProcessorRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls SetDefaultProcessorVersion.
                     * @param request SetDefaultProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public setDefaultProcessorVersion(request: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.SetDefaultProcessorVersionCallback): void;

                    /**
                     * Calls SetDefaultProcessorVersion.
                     * @param request SetDefaultProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public setDefaultProcessorVersion(request: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls ReviewDocument.
                     * @param request ReviewDocumentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public reviewDocument(request: google.cloud.documentai.v1beta3.IReviewDocumentRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.ReviewDocumentCallback): void;

                    /**
                     * Calls ReviewDocument.
                     * @param request ReviewDocumentRequest message or plain object
                     * @returns Promise
                     */
                    public reviewDocument(request: google.cloud.documentai.v1beta3.IReviewDocumentRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls EvaluateProcessorVersion.
                     * @param request EvaluateProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public evaluateProcessorVersion(request: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.EvaluateProcessorVersionCallback): void;

                    /**
                     * Calls EvaluateProcessorVersion.
                     * @param request EvaluateProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public evaluateProcessorVersion(request: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls GetEvaluation.
                     * @param request GetEvaluationRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Evaluation
                     */
                    public getEvaluation(request: google.cloud.documentai.v1beta3.IGetEvaluationRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.GetEvaluationCallback): void;

                    /**
                     * Calls GetEvaluation.
                     * @param request GetEvaluationRequest message or plain object
                     * @returns Promise
                     */
                    public getEvaluation(request: google.cloud.documentai.v1beta3.IGetEvaluationRequest): Promise<google.cloud.documentai.v1beta3.Evaluation>;

                    /**
                     * Calls ListEvaluations.
                     * @param request ListEvaluationsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ListEvaluationsResponse
                     */
                    public listEvaluations(request: google.cloud.documentai.v1beta3.IListEvaluationsRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.ListEvaluationsCallback): void;

                    /**
                     * Calls ListEvaluations.
                     * @param request ListEvaluationsRequest message or plain object
                     * @returns Promise
                     */
                    public listEvaluations(request: google.cloud.documentai.v1beta3.IListEvaluationsRequest): Promise<google.cloud.documentai.v1beta3.ListEvaluationsResponse>;

                    /**
                     * Calls ImportProcessorVersion.
                     * @param request ImportProcessorVersionRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public importProcessorVersion(request: google.cloud.documentai.v1beta3.IImportProcessorVersionRequest, callback: google.cloud.documentai.v1beta3.DocumentProcessorService.ImportProcessorVersionCallback): void;

                    /**
                     * Calls ImportProcessorVersion.
                     * @param request ImportProcessorVersionRequest message or plain object
                     * @returns Promise
                     */
                    public importProcessorVersion(request: google.cloud.documentai.v1beta3.IImportProcessorVersionRequest): Promise<google.longrunning.Operation>;
                }

                namespace DocumentProcessorService {

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|processDocument}.
                     * @param error Error, if any
                     * @param [response] ProcessResponse
                     */
                    type ProcessDocumentCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.ProcessResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|batchProcessDocuments}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type BatchProcessDocumentsCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|fetchProcessorTypes}.
                     * @param error Error, if any
                     * @param [response] FetchProcessorTypesResponse
                     */
                    type FetchProcessorTypesCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.FetchProcessorTypesResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|listProcessorTypes}.
                     * @param error Error, if any
                     * @param [response] ListProcessorTypesResponse
                     */
                    type ListProcessorTypesCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.ListProcessorTypesResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|getProcessorType}.
                     * @param error Error, if any
                     * @param [response] ProcessorType
                     */
                    type GetProcessorTypeCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.ProcessorType) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|listProcessors}.
                     * @param error Error, if any
                     * @param [response] ListProcessorsResponse
                     */
                    type ListProcessorsCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.ListProcessorsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|getProcessor}.
                     * @param error Error, if any
                     * @param [response] Processor
                     */
                    type GetProcessorCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.Processor) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|trainProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type TrainProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|getProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] ProcessorVersion
                     */
                    type GetProcessorVersionCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.ProcessorVersion) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|listProcessorVersions}.
                     * @param error Error, if any
                     * @param [response] ListProcessorVersionsResponse
                     */
                    type ListProcessorVersionsCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.ListProcessorVersionsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|deleteProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|deployProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeployProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|undeployProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UndeployProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|createProcessor}.
                     * @param error Error, if any
                     * @param [response] Processor
                     */
                    type CreateProcessorCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.Processor) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|deleteProcessor}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DeleteProcessorCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|enableProcessor}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type EnableProcessorCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|disableProcessor}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type DisableProcessorCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|setDefaultProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type SetDefaultProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|reviewDocument}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ReviewDocumentCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|evaluateProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type EvaluateProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|getEvaluation}.
                     * @param error Error, if any
                     * @param [response] Evaluation
                     */
                    type GetEvaluationCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.Evaluation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|listEvaluations}.
                     * @param error Error, if any
                     * @param [response] ListEvaluationsResponse
                     */
                    type ListEvaluationsCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.ListEvaluationsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentProcessorService|importProcessorVersion}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ImportProcessorVersionCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;
                }

                /** Properties of a ProcessOptions. */
                interface IProcessOptions {

                    /** ProcessOptions individualPageSelector */
                    individualPageSelector?: (google.cloud.documentai.v1beta3.ProcessOptions.IIndividualPageSelector|null);

                    /** ProcessOptions fromStart */
                    fromStart?: (number|null);

                    /** ProcessOptions fromEnd */
                    fromEnd?: (number|null);

                    /** ProcessOptions ocrConfig */
                    ocrConfig?: (google.cloud.documentai.v1beta3.IOcrConfig|null);

                    /** ProcessOptions layoutConfig */
                    layoutConfig?: (google.cloud.documentai.v1beta3.ProcessOptions.ILayoutConfig|null);

                    /** ProcessOptions schemaOverride */
                    schemaOverride?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);
                }

                /** Represents a ProcessOptions. */
                class ProcessOptions implements IProcessOptions {

                    /**
                     * Constructs a new ProcessOptions.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IProcessOptions);

                    /** ProcessOptions individualPageSelector. */
                    public individualPageSelector?: (google.cloud.documentai.v1beta3.ProcessOptions.IIndividualPageSelector|null);

                    /** ProcessOptions fromStart. */
                    public fromStart?: (number|null);

                    /** ProcessOptions fromEnd. */
                    public fromEnd?: (number|null);

                    /** ProcessOptions ocrConfig. */
                    public ocrConfig?: (google.cloud.documentai.v1beta3.IOcrConfig|null);

                    /** ProcessOptions layoutConfig. */
                    public layoutConfig?: (google.cloud.documentai.v1beta3.ProcessOptions.ILayoutConfig|null);

                    /** ProcessOptions schemaOverride. */
                    public schemaOverride?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);

                    /** ProcessOptions pageRange. */
                    public pageRange?: ("individualPageSelector"|"fromStart"|"fromEnd");

                    /**
                     * Creates a new ProcessOptions instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessOptions instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IProcessOptions): google.cloud.documentai.v1beta3.ProcessOptions;

                    /**
                     * Encodes the specified ProcessOptions message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessOptions.verify|verify} messages.
                     * @param message ProcessOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IProcessOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessOptions message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessOptions.verify|verify} messages.
                     * @param message ProcessOptions message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IProcessOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessOptions message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessOptions;

                    /**
                     * Decodes a ProcessOptions message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessOptions
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessOptions;

                    /**
                     * Verifies a ProcessOptions message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessOptions message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessOptions
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessOptions;

                    /**
                     * Creates a plain object from a ProcessOptions message. Also converts values to other types if specified.
                     * @param message ProcessOptions
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ProcessOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessOptions to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessOptions
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ProcessOptions {

                    /** Properties of a LayoutConfig. */
                    interface ILayoutConfig {

                        /** LayoutConfig chunkingConfig */
                        chunkingConfig?: (google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.IChunkingConfig|null);

                        /** LayoutConfig returnImages */
                        returnImages?: (boolean|null);

                        /** LayoutConfig returnBoundingBoxes */
                        returnBoundingBoxes?: (boolean|null);

                        /** LayoutConfig enableLlmLayoutParsing */
                        enableLlmLayoutParsing?: (boolean|null);
                    }

                    /** Represents a LayoutConfig. */
                    class LayoutConfig implements ILayoutConfig {

                        /**
                         * Constructs a new LayoutConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.ProcessOptions.ILayoutConfig);

                        /** LayoutConfig chunkingConfig. */
                        public chunkingConfig?: (google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.IChunkingConfig|null);

                        /** LayoutConfig returnImages. */
                        public returnImages: boolean;

                        /** LayoutConfig returnBoundingBoxes. */
                        public returnBoundingBoxes: boolean;

                        /** LayoutConfig enableLlmLayoutParsing. */
                        public enableLlmLayoutParsing: boolean;

                        /**
                         * Creates a new LayoutConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns LayoutConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.ProcessOptions.ILayoutConfig): google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig;

                        /**
                         * Encodes the specified LayoutConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.verify|verify} messages.
                         * @param message LayoutConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.ProcessOptions.ILayoutConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified LayoutConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.verify|verify} messages.
                         * @param message LayoutConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.ProcessOptions.ILayoutConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a LayoutConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns LayoutConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig;

                        /**
                         * Decodes a LayoutConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns LayoutConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig;

                        /**
                         * Verifies a LayoutConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a LayoutConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns LayoutConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig;

                        /**
                         * Creates a plain object from a LayoutConfig message. Also converts values to other types if specified.
                         * @param message LayoutConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this LayoutConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for LayoutConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace LayoutConfig {

                        /** Properties of a ChunkingConfig. */
                        interface IChunkingConfig {

                            /** ChunkingConfig chunkSize */
                            chunkSize?: (number|null);

                            /** ChunkingConfig includeAncestorHeadings */
                            includeAncestorHeadings?: (boolean|null);

                            /** ChunkingConfig semanticChunkingGroupSize */
                            semanticChunkingGroupSize?: (boolean|null);

                            /** ChunkingConfig breakpointPercentileThreshold */
                            breakpointPercentileThreshold?: (number|null);
                        }

                        /** Represents a ChunkingConfig. */
                        class ChunkingConfig implements IChunkingConfig {

                            /**
                             * Constructs a new ChunkingConfig.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.IChunkingConfig);

                            /** ChunkingConfig chunkSize. */
                            public chunkSize: number;

                            /** ChunkingConfig includeAncestorHeadings. */
                            public includeAncestorHeadings: boolean;

                            /** ChunkingConfig semanticChunkingGroupSize. */
                            public semanticChunkingGroupSize: boolean;

                            /** ChunkingConfig breakpointPercentileThreshold. */
                            public breakpointPercentileThreshold: number;

                            /**
                             * Creates a new ChunkingConfig instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns ChunkingConfig instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.IChunkingConfig): google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.ChunkingConfig;

                            /**
                             * Encodes the specified ChunkingConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.ChunkingConfig.verify|verify} messages.
                             * @param message ChunkingConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.IChunkingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified ChunkingConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.ChunkingConfig.verify|verify} messages.
                             * @param message ChunkingConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.IChunkingConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a ChunkingConfig message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns ChunkingConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.ChunkingConfig;

                            /**
                             * Decodes a ChunkingConfig message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns ChunkingConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.ChunkingConfig;

                            /**
                             * Verifies a ChunkingConfig message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a ChunkingConfig message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns ChunkingConfig
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.ChunkingConfig;

                            /**
                             * Creates a plain object from a ChunkingConfig message. Also converts values to other types if specified.
                             * @param message ChunkingConfig
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.ProcessOptions.LayoutConfig.ChunkingConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this ChunkingConfig to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for ChunkingConfig
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }

                    /** Properties of an IndividualPageSelector. */
                    interface IIndividualPageSelector {

                        /** IndividualPageSelector pages */
                        pages?: (number[]|null);
                    }

                    /** Represents an IndividualPageSelector. */
                    class IndividualPageSelector implements IIndividualPageSelector {

                        /**
                         * Constructs a new IndividualPageSelector.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.ProcessOptions.IIndividualPageSelector);

                        /** IndividualPageSelector pages. */
                        public pages: number[];

                        /**
                         * Creates a new IndividualPageSelector instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns IndividualPageSelector instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.ProcessOptions.IIndividualPageSelector): google.cloud.documentai.v1beta3.ProcessOptions.IndividualPageSelector;

                        /**
                         * Encodes the specified IndividualPageSelector message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessOptions.IndividualPageSelector.verify|verify} messages.
                         * @param message IndividualPageSelector message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.ProcessOptions.IIndividualPageSelector, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified IndividualPageSelector message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessOptions.IndividualPageSelector.verify|verify} messages.
                         * @param message IndividualPageSelector message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.ProcessOptions.IIndividualPageSelector, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an IndividualPageSelector message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns IndividualPageSelector
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessOptions.IndividualPageSelector;

                        /**
                         * Decodes an IndividualPageSelector message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns IndividualPageSelector
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessOptions.IndividualPageSelector;

                        /**
                         * Verifies an IndividualPageSelector message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an IndividualPageSelector message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns IndividualPageSelector
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessOptions.IndividualPageSelector;

                        /**
                         * Creates a plain object from an IndividualPageSelector message. Also converts values to other types if specified.
                         * @param message IndividualPageSelector
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.ProcessOptions.IndividualPageSelector, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this IndividualPageSelector to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for IndividualPageSelector
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a ProcessRequest. */
                interface IProcessRequest {

                    /** ProcessRequest inlineDocument */
                    inlineDocument?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ProcessRequest rawDocument */
                    rawDocument?: (google.cloud.documentai.v1beta3.IRawDocument|null);

                    /** ProcessRequest gcsDocument */
                    gcsDocument?: (google.cloud.documentai.v1beta3.IGcsDocument|null);

                    /** ProcessRequest name */
                    name?: (string|null);

                    /** ProcessRequest document */
                    document?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ProcessRequest skipHumanReview */
                    skipHumanReview?: (boolean|null);

                    /** ProcessRequest fieldMask */
                    fieldMask?: (google.protobuf.IFieldMask|null);

                    /** ProcessRequest processOptions */
                    processOptions?: (google.cloud.documentai.v1beta3.IProcessOptions|null);

                    /** ProcessRequest labels */
                    labels?: ({ [k: string]: string }|null);

                    /** ProcessRequest imagelessMode */
                    imagelessMode?: (boolean|null);
                }

                /** Represents a ProcessRequest. */
                class ProcessRequest implements IProcessRequest {

                    /**
                     * Constructs a new ProcessRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IProcessRequest);

                    /** ProcessRequest inlineDocument. */
                    public inlineDocument?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ProcessRequest rawDocument. */
                    public rawDocument?: (google.cloud.documentai.v1beta3.IRawDocument|null);

                    /** ProcessRequest gcsDocument. */
                    public gcsDocument?: (google.cloud.documentai.v1beta3.IGcsDocument|null);

                    /** ProcessRequest name. */
                    public name: string;

                    /** ProcessRequest document. */
                    public document?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ProcessRequest skipHumanReview. */
                    public skipHumanReview: boolean;

                    /** ProcessRequest fieldMask. */
                    public fieldMask?: (google.protobuf.IFieldMask|null);

                    /** ProcessRequest processOptions. */
                    public processOptions?: (google.cloud.documentai.v1beta3.IProcessOptions|null);

                    /** ProcessRequest labels. */
                    public labels: { [k: string]: string };

                    /** ProcessRequest imagelessMode. */
                    public imagelessMode: boolean;

                    /** ProcessRequest source. */
                    public source?: ("inlineDocument"|"rawDocument"|"gcsDocument");

                    /**
                     * Creates a new ProcessRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IProcessRequest): google.cloud.documentai.v1beta3.ProcessRequest;

                    /**
                     * Encodes the specified ProcessRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessRequest.verify|verify} messages.
                     * @param message ProcessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IProcessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessRequest.verify|verify} messages.
                     * @param message ProcessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IProcessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessRequest;

                    /**
                     * Decodes a ProcessRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessRequest;

                    /**
                     * Verifies a ProcessRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessRequest;

                    /**
                     * Creates a plain object from a ProcessRequest message. Also converts values to other types if specified.
                     * @param message ProcessRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ProcessRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a HumanReviewStatus. */
                interface IHumanReviewStatus {

                    /** HumanReviewStatus state */
                    state?: (google.cloud.documentai.v1beta3.HumanReviewStatus.State|keyof typeof google.cloud.documentai.v1beta3.HumanReviewStatus.State|null);

                    /** HumanReviewStatus stateMessage */
                    stateMessage?: (string|null);

                    /** HumanReviewStatus humanReviewOperation */
                    humanReviewOperation?: (string|null);
                }

                /** Represents a HumanReviewStatus. */
                class HumanReviewStatus implements IHumanReviewStatus {

                    /**
                     * Constructs a new HumanReviewStatus.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IHumanReviewStatus);

                    /** HumanReviewStatus state. */
                    public state: (google.cloud.documentai.v1beta3.HumanReviewStatus.State|keyof typeof google.cloud.documentai.v1beta3.HumanReviewStatus.State);

                    /** HumanReviewStatus stateMessage. */
                    public stateMessage: string;

                    /** HumanReviewStatus humanReviewOperation. */
                    public humanReviewOperation: string;

                    /**
                     * Creates a new HumanReviewStatus instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns HumanReviewStatus instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IHumanReviewStatus): google.cloud.documentai.v1beta3.HumanReviewStatus;

                    /**
                     * Encodes the specified HumanReviewStatus message. Does not implicitly {@link google.cloud.documentai.v1beta3.HumanReviewStatus.verify|verify} messages.
                     * @param message HumanReviewStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IHumanReviewStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified HumanReviewStatus message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.HumanReviewStatus.verify|verify} messages.
                     * @param message HumanReviewStatus message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IHumanReviewStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a HumanReviewStatus message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns HumanReviewStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.HumanReviewStatus;

                    /**
                     * Decodes a HumanReviewStatus message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns HumanReviewStatus
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.HumanReviewStatus;

                    /**
                     * Verifies a HumanReviewStatus message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a HumanReviewStatus message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns HumanReviewStatus
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.HumanReviewStatus;

                    /**
                     * Creates a plain object from a HumanReviewStatus message. Also converts values to other types if specified.
                     * @param message HumanReviewStatus
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.HumanReviewStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this HumanReviewStatus to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for HumanReviewStatus
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace HumanReviewStatus {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        SKIPPED = 1,
                        VALIDATION_PASSED = 2,
                        IN_PROGRESS = 3,
                        ERROR = 4
                    }
                }

                /** Properties of a ProcessResponse. */
                interface IProcessResponse {

                    /** ProcessResponse document */
                    document?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ProcessResponse humanReviewOperation */
                    humanReviewOperation?: (string|null);

                    /** ProcessResponse humanReviewStatus */
                    humanReviewStatus?: (google.cloud.documentai.v1beta3.IHumanReviewStatus|null);
                }

                /** Represents a ProcessResponse. */
                class ProcessResponse implements IProcessResponse {

                    /**
                     * Constructs a new ProcessResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IProcessResponse);

                    /** ProcessResponse document. */
                    public document?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ProcessResponse humanReviewOperation. */
                    public humanReviewOperation: string;

                    /** ProcessResponse humanReviewStatus. */
                    public humanReviewStatus?: (google.cloud.documentai.v1beta3.IHumanReviewStatus|null);

                    /**
                     * Creates a new ProcessResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IProcessResponse): google.cloud.documentai.v1beta3.ProcessResponse;

                    /**
                     * Encodes the specified ProcessResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessResponse.verify|verify} messages.
                     * @param message ProcessResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IProcessResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessResponse.verify|verify} messages.
                     * @param message ProcessResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IProcessResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessResponse;

                    /**
                     * Decodes a ProcessResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessResponse;

                    /**
                     * Verifies a ProcessResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessResponse;

                    /**
                     * Creates a plain object from a ProcessResponse message. Also converts values to other types if specified.
                     * @param message ProcessResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ProcessResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchProcessRequest. */
                interface IBatchProcessRequest {

                    /** BatchProcessRequest name */
                    name?: (string|null);

                    /** BatchProcessRequest inputConfigs */
                    inputConfigs?: (google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchInputConfig[]|null);

                    /** BatchProcessRequest outputConfig */
                    outputConfig?: (google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchOutputConfig|null);

                    /** BatchProcessRequest inputDocuments */
                    inputDocuments?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);

                    /** BatchProcessRequest documentOutputConfig */
                    documentOutputConfig?: (google.cloud.documentai.v1beta3.IDocumentOutputConfig|null);

                    /** BatchProcessRequest skipHumanReview */
                    skipHumanReview?: (boolean|null);

                    /** BatchProcessRequest processOptions */
                    processOptions?: (google.cloud.documentai.v1beta3.IProcessOptions|null);

                    /** BatchProcessRequest labels */
                    labels?: ({ [k: string]: string }|null);
                }

                /** Represents a BatchProcessRequest. */
                class BatchProcessRequest implements IBatchProcessRequest {

                    /**
                     * Constructs a new BatchProcessRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBatchProcessRequest);

                    /** BatchProcessRequest name. */
                    public name: string;

                    /** BatchProcessRequest inputConfigs. */
                    public inputConfigs: google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchInputConfig[];

                    /** BatchProcessRequest outputConfig. */
                    public outputConfig?: (google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchOutputConfig|null);

                    /** BatchProcessRequest inputDocuments. */
                    public inputDocuments?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);

                    /** BatchProcessRequest documentOutputConfig. */
                    public documentOutputConfig?: (google.cloud.documentai.v1beta3.IDocumentOutputConfig|null);

                    /** BatchProcessRequest skipHumanReview. */
                    public skipHumanReview: boolean;

                    /** BatchProcessRequest processOptions. */
                    public processOptions?: (google.cloud.documentai.v1beta3.IProcessOptions|null);

                    /** BatchProcessRequest labels. */
                    public labels: { [k: string]: string };

                    /**
                     * Creates a new BatchProcessRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBatchProcessRequest): google.cloud.documentai.v1beta3.BatchProcessRequest;

                    /**
                     * Encodes the specified BatchProcessRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessRequest.verify|verify} messages.
                     * @param message BatchProcessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBatchProcessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessRequest.verify|verify} messages.
                     * @param message BatchProcessRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBatchProcessRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchProcessRequest;

                    /**
                     * Decodes a BatchProcessRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchProcessRequest;

                    /**
                     * Verifies a BatchProcessRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchProcessRequest;

                    /**
                     * Creates a plain object from a BatchProcessRequest message. Also converts values to other types if specified.
                     * @param message BatchProcessRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.BatchProcessRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BatchProcessRequest {

                    /** Properties of a BatchInputConfig. */
                    interface IBatchInputConfig {

                        /** BatchInputConfig gcsSource */
                        gcsSource?: (string|null);

                        /** BatchInputConfig mimeType */
                        mimeType?: (string|null);
                    }

                    /** Represents a BatchInputConfig. */
                    class BatchInputConfig implements IBatchInputConfig {

                        /**
                         * Constructs a new BatchInputConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchInputConfig);

                        /** BatchInputConfig gcsSource. */
                        public gcsSource: string;

                        /** BatchInputConfig mimeType. */
                        public mimeType: string;

                        /**
                         * Creates a new BatchInputConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns BatchInputConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchInputConfig): google.cloud.documentai.v1beta3.BatchProcessRequest.BatchInputConfig;

                        /**
                         * Encodes the specified BatchInputConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessRequest.BatchInputConfig.verify|verify} messages.
                         * @param message BatchInputConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified BatchInputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessRequest.BatchInputConfig.verify|verify} messages.
                         * @param message BatchInputConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchInputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a BatchInputConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns BatchInputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchProcessRequest.BatchInputConfig;

                        /**
                         * Decodes a BatchInputConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns BatchInputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchProcessRequest.BatchInputConfig;

                        /**
                         * Verifies a BatchInputConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a BatchInputConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns BatchInputConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchProcessRequest.BatchInputConfig;

                        /**
                         * Creates a plain object from a BatchInputConfig message. Also converts values to other types if specified.
                         * @param message BatchInputConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.BatchProcessRequest.BatchInputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this BatchInputConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for BatchInputConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a BatchOutputConfig. */
                    interface IBatchOutputConfig {

                        /** BatchOutputConfig gcsDestination */
                        gcsDestination?: (string|null);
                    }

                    /** Represents a BatchOutputConfig. */
                    class BatchOutputConfig implements IBatchOutputConfig {

                        /**
                         * Constructs a new BatchOutputConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchOutputConfig);

                        /** BatchOutputConfig gcsDestination. */
                        public gcsDestination: string;

                        /**
                         * Creates a new BatchOutputConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns BatchOutputConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchOutputConfig): google.cloud.documentai.v1beta3.BatchProcessRequest.BatchOutputConfig;

                        /**
                         * Encodes the specified BatchOutputConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessRequest.BatchOutputConfig.verify|verify} messages.
                         * @param message BatchOutputConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified BatchOutputConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessRequest.BatchOutputConfig.verify|verify} messages.
                         * @param message BatchOutputConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.BatchProcessRequest.IBatchOutputConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a BatchOutputConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns BatchOutputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchProcessRequest.BatchOutputConfig;

                        /**
                         * Decodes a BatchOutputConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns BatchOutputConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchProcessRequest.BatchOutputConfig;

                        /**
                         * Verifies a BatchOutputConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a BatchOutputConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns BatchOutputConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchProcessRequest.BatchOutputConfig;

                        /**
                         * Creates a plain object from a BatchOutputConfig message. Also converts values to other types if specified.
                         * @param message BatchOutputConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.BatchProcessRequest.BatchOutputConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this BatchOutputConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for BatchOutputConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a BatchProcessResponse. */
                interface IBatchProcessResponse {
                }

                /** Represents a BatchProcessResponse. */
                class BatchProcessResponse implements IBatchProcessResponse {

                    /**
                     * Constructs a new BatchProcessResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBatchProcessResponse);

                    /**
                     * Creates a new BatchProcessResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBatchProcessResponse): google.cloud.documentai.v1beta3.BatchProcessResponse;

                    /**
                     * Encodes the specified BatchProcessResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessResponse.verify|verify} messages.
                     * @param message BatchProcessResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBatchProcessResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessResponse.verify|verify} messages.
                     * @param message BatchProcessResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBatchProcessResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchProcessResponse;

                    /**
                     * Decodes a BatchProcessResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchProcessResponse;

                    /**
                     * Verifies a BatchProcessResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchProcessResponse;

                    /**
                     * Creates a plain object from a BatchProcessResponse message. Also converts values to other types if specified.
                     * @param message BatchProcessResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.BatchProcessResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchProcessMetadata. */
                interface IBatchProcessMetadata {

                    /** BatchProcessMetadata state */
                    state?: (google.cloud.documentai.v1beta3.BatchProcessMetadata.State|keyof typeof google.cloud.documentai.v1beta3.BatchProcessMetadata.State|null);

                    /** BatchProcessMetadata stateMessage */
                    stateMessage?: (string|null);

                    /** BatchProcessMetadata createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** BatchProcessMetadata updateTime */
                    updateTime?: (google.protobuf.ITimestamp|null);

                    /** BatchProcessMetadata individualProcessStatuses */
                    individualProcessStatuses?: (google.cloud.documentai.v1beta3.BatchProcessMetadata.IIndividualProcessStatus[]|null);
                }

                /** Represents a BatchProcessMetadata. */
                class BatchProcessMetadata implements IBatchProcessMetadata {

                    /**
                     * Constructs a new BatchProcessMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBatchProcessMetadata);

                    /** BatchProcessMetadata state. */
                    public state: (google.cloud.documentai.v1beta3.BatchProcessMetadata.State|keyof typeof google.cloud.documentai.v1beta3.BatchProcessMetadata.State);

                    /** BatchProcessMetadata stateMessage. */
                    public stateMessage: string;

                    /** BatchProcessMetadata createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** BatchProcessMetadata updateTime. */
                    public updateTime?: (google.protobuf.ITimestamp|null);

                    /** BatchProcessMetadata individualProcessStatuses. */
                    public individualProcessStatuses: google.cloud.documentai.v1beta3.BatchProcessMetadata.IIndividualProcessStatus[];

                    /**
                     * Creates a new BatchProcessMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchProcessMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBatchProcessMetadata): google.cloud.documentai.v1beta3.BatchProcessMetadata;

                    /**
                     * Encodes the specified BatchProcessMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessMetadata.verify|verify} messages.
                     * @param message BatchProcessMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBatchProcessMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchProcessMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessMetadata.verify|verify} messages.
                     * @param message BatchProcessMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBatchProcessMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchProcessMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchProcessMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchProcessMetadata;

                    /**
                     * Decodes a BatchProcessMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchProcessMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchProcessMetadata;

                    /**
                     * Verifies a BatchProcessMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchProcessMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchProcessMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchProcessMetadata;

                    /**
                     * Creates a plain object from a BatchProcessMetadata message. Also converts values to other types if specified.
                     * @param message BatchProcessMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.BatchProcessMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchProcessMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchProcessMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BatchProcessMetadata {

                    /** Properties of an IndividualProcessStatus. */
                    interface IIndividualProcessStatus {

                        /** IndividualProcessStatus inputGcsSource */
                        inputGcsSource?: (string|null);

                        /** IndividualProcessStatus status */
                        status?: (google.rpc.IStatus|null);

                        /** IndividualProcessStatus outputGcsDestination */
                        outputGcsDestination?: (string|null);

                        /** IndividualProcessStatus humanReviewOperation */
                        humanReviewOperation?: (string|null);

                        /** IndividualProcessStatus humanReviewStatus */
                        humanReviewStatus?: (google.cloud.documentai.v1beta3.IHumanReviewStatus|null);
                    }

                    /** Represents an IndividualProcessStatus. */
                    class IndividualProcessStatus implements IIndividualProcessStatus {

                        /**
                         * Constructs a new IndividualProcessStatus.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.BatchProcessMetadata.IIndividualProcessStatus);

                        /** IndividualProcessStatus inputGcsSource. */
                        public inputGcsSource: string;

                        /** IndividualProcessStatus status. */
                        public status?: (google.rpc.IStatus|null);

                        /** IndividualProcessStatus outputGcsDestination. */
                        public outputGcsDestination: string;

                        /** IndividualProcessStatus humanReviewOperation. */
                        public humanReviewOperation: string;

                        /** IndividualProcessStatus humanReviewStatus. */
                        public humanReviewStatus?: (google.cloud.documentai.v1beta3.IHumanReviewStatus|null);

                        /**
                         * Creates a new IndividualProcessStatus instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns IndividualProcessStatus instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.BatchProcessMetadata.IIndividualProcessStatus): google.cloud.documentai.v1beta3.BatchProcessMetadata.IndividualProcessStatus;

                        /**
                         * Encodes the specified IndividualProcessStatus message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessMetadata.IndividualProcessStatus.verify|verify} messages.
                         * @param message IndividualProcessStatus message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.BatchProcessMetadata.IIndividualProcessStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified IndividualProcessStatus message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchProcessMetadata.IndividualProcessStatus.verify|verify} messages.
                         * @param message IndividualProcessStatus message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.BatchProcessMetadata.IIndividualProcessStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an IndividualProcessStatus message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns IndividualProcessStatus
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchProcessMetadata.IndividualProcessStatus;

                        /**
                         * Decodes an IndividualProcessStatus message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns IndividualProcessStatus
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchProcessMetadata.IndividualProcessStatus;

                        /**
                         * Verifies an IndividualProcessStatus message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an IndividualProcessStatus message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns IndividualProcessStatus
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchProcessMetadata.IndividualProcessStatus;

                        /**
                         * Creates a plain object from an IndividualProcessStatus message. Also converts values to other types if specified.
                         * @param message IndividualProcessStatus
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.BatchProcessMetadata.IndividualProcessStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this IndividualProcessStatus to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for IndividualProcessStatus
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        WAITING = 1,
                        RUNNING = 2,
                        SUCCEEDED = 3,
                        CANCELLING = 4,
                        CANCELLED = 5,
                        FAILED = 6
                    }
                }

                /** Properties of a FetchProcessorTypesRequest. */
                interface IFetchProcessorTypesRequest {

                    /** FetchProcessorTypesRequest parent */
                    parent?: (string|null);
                }

                /** Represents a FetchProcessorTypesRequest. */
                class FetchProcessorTypesRequest implements IFetchProcessorTypesRequest {

                    /**
                     * Constructs a new FetchProcessorTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IFetchProcessorTypesRequest);

                    /** FetchProcessorTypesRequest parent. */
                    public parent: string;

                    /**
                     * Creates a new FetchProcessorTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FetchProcessorTypesRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IFetchProcessorTypesRequest): google.cloud.documentai.v1beta3.FetchProcessorTypesRequest;

                    /**
                     * Encodes the specified FetchProcessorTypesRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.FetchProcessorTypesRequest.verify|verify} messages.
                     * @param message FetchProcessorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IFetchProcessorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FetchProcessorTypesRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.FetchProcessorTypesRequest.verify|verify} messages.
                     * @param message FetchProcessorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IFetchProcessorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FetchProcessorTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FetchProcessorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.FetchProcessorTypesRequest;

                    /**
                     * Decodes a FetchProcessorTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FetchProcessorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.FetchProcessorTypesRequest;

                    /**
                     * Verifies a FetchProcessorTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FetchProcessorTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FetchProcessorTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.FetchProcessorTypesRequest;

                    /**
                     * Creates a plain object from a FetchProcessorTypesRequest message. Also converts values to other types if specified.
                     * @param message FetchProcessorTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.FetchProcessorTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FetchProcessorTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FetchProcessorTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a FetchProcessorTypesResponse. */
                interface IFetchProcessorTypesResponse {

                    /** FetchProcessorTypesResponse processorTypes */
                    processorTypes?: (google.cloud.documentai.v1beta3.IProcessorType[]|null);
                }

                /** Represents a FetchProcessorTypesResponse. */
                class FetchProcessorTypesResponse implements IFetchProcessorTypesResponse {

                    /**
                     * Constructs a new FetchProcessorTypesResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IFetchProcessorTypesResponse);

                    /** FetchProcessorTypesResponse processorTypes. */
                    public processorTypes: google.cloud.documentai.v1beta3.IProcessorType[];

                    /**
                     * Creates a new FetchProcessorTypesResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns FetchProcessorTypesResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IFetchProcessorTypesResponse): google.cloud.documentai.v1beta3.FetchProcessorTypesResponse;

                    /**
                     * Encodes the specified FetchProcessorTypesResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.FetchProcessorTypesResponse.verify|verify} messages.
                     * @param message FetchProcessorTypesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IFetchProcessorTypesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified FetchProcessorTypesResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.FetchProcessorTypesResponse.verify|verify} messages.
                     * @param message FetchProcessorTypesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IFetchProcessorTypesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a FetchProcessorTypesResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns FetchProcessorTypesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.FetchProcessorTypesResponse;

                    /**
                     * Decodes a FetchProcessorTypesResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns FetchProcessorTypesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.FetchProcessorTypesResponse;

                    /**
                     * Verifies a FetchProcessorTypesResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a FetchProcessorTypesResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns FetchProcessorTypesResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.FetchProcessorTypesResponse;

                    /**
                     * Creates a plain object from a FetchProcessorTypesResponse message. Also converts values to other types if specified.
                     * @param message FetchProcessorTypesResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.FetchProcessorTypesResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this FetchProcessorTypesResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for FetchProcessorTypesResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorTypesRequest. */
                interface IListProcessorTypesRequest {

                    /** ListProcessorTypesRequest parent */
                    parent?: (string|null);

                    /** ListProcessorTypesRequest pageSize */
                    pageSize?: (number|null);

                    /** ListProcessorTypesRequest pageToken */
                    pageToken?: (string|null);
                }

                /** Represents a ListProcessorTypesRequest. */
                class ListProcessorTypesRequest implements IListProcessorTypesRequest {

                    /**
                     * Constructs a new ListProcessorTypesRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListProcessorTypesRequest);

                    /** ListProcessorTypesRequest parent. */
                    public parent: string;

                    /** ListProcessorTypesRequest pageSize. */
                    public pageSize: number;

                    /** ListProcessorTypesRequest pageToken. */
                    public pageToken: string;

                    /**
                     * Creates a new ListProcessorTypesRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorTypesRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListProcessorTypesRequest): google.cloud.documentai.v1beta3.ListProcessorTypesRequest;

                    /**
                     * Encodes the specified ListProcessorTypesRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorTypesRequest.verify|verify} messages.
                     * @param message ListProcessorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListProcessorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorTypesRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorTypesRequest.verify|verify} messages.
                     * @param message ListProcessorTypesRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListProcessorTypesRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorTypesRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListProcessorTypesRequest;

                    /**
                     * Decodes a ListProcessorTypesRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorTypesRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListProcessorTypesRequest;

                    /**
                     * Verifies a ListProcessorTypesRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorTypesRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorTypesRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListProcessorTypesRequest;

                    /**
                     * Creates a plain object from a ListProcessorTypesRequest message. Also converts values to other types if specified.
                     * @param message ListProcessorTypesRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListProcessorTypesRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorTypesRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorTypesRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorTypesResponse. */
                interface IListProcessorTypesResponse {

                    /** ListProcessorTypesResponse processorTypes */
                    processorTypes?: (google.cloud.documentai.v1beta3.IProcessorType[]|null);

                    /** ListProcessorTypesResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a ListProcessorTypesResponse. */
                class ListProcessorTypesResponse implements IListProcessorTypesResponse {

                    /**
                     * Constructs a new ListProcessorTypesResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListProcessorTypesResponse);

                    /** ListProcessorTypesResponse processorTypes. */
                    public processorTypes: google.cloud.documentai.v1beta3.IProcessorType[];

                    /** ListProcessorTypesResponse nextPageToken. */
                    public nextPageToken: string;

                    /**
                     * Creates a new ListProcessorTypesResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorTypesResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListProcessorTypesResponse): google.cloud.documentai.v1beta3.ListProcessorTypesResponse;

                    /**
                     * Encodes the specified ListProcessorTypesResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorTypesResponse.verify|verify} messages.
                     * @param message ListProcessorTypesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListProcessorTypesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorTypesResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorTypesResponse.verify|verify} messages.
                     * @param message ListProcessorTypesResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListProcessorTypesResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorTypesResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorTypesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListProcessorTypesResponse;

                    /**
                     * Decodes a ListProcessorTypesResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorTypesResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListProcessorTypesResponse;

                    /**
                     * Verifies a ListProcessorTypesResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorTypesResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorTypesResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListProcessorTypesResponse;

                    /**
                     * Creates a plain object from a ListProcessorTypesResponse message. Also converts values to other types if specified.
                     * @param message ListProcessorTypesResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListProcessorTypesResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorTypesResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorTypesResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorsRequest. */
                interface IListProcessorsRequest {

                    /** ListProcessorsRequest parent */
                    parent?: (string|null);

                    /** ListProcessorsRequest pageSize */
                    pageSize?: (number|null);

                    /** ListProcessorsRequest pageToken */
                    pageToken?: (string|null);
                }

                /** Represents a ListProcessorsRequest. */
                class ListProcessorsRequest implements IListProcessorsRequest {

                    /**
                     * Constructs a new ListProcessorsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListProcessorsRequest);

                    /** ListProcessorsRequest parent. */
                    public parent: string;

                    /** ListProcessorsRequest pageSize. */
                    public pageSize: number;

                    /** ListProcessorsRequest pageToken. */
                    public pageToken: string;

                    /**
                     * Creates a new ListProcessorsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListProcessorsRequest): google.cloud.documentai.v1beta3.ListProcessorsRequest;

                    /**
                     * Encodes the specified ListProcessorsRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorsRequest.verify|verify} messages.
                     * @param message ListProcessorsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListProcessorsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorsRequest.verify|verify} messages.
                     * @param message ListProcessorsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListProcessorsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListProcessorsRequest;

                    /**
                     * Decodes a ListProcessorsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListProcessorsRequest;

                    /**
                     * Verifies a ListProcessorsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListProcessorsRequest;

                    /**
                     * Creates a plain object from a ListProcessorsRequest message. Also converts values to other types if specified.
                     * @param message ListProcessorsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListProcessorsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorsResponse. */
                interface IListProcessorsResponse {

                    /** ListProcessorsResponse processors */
                    processors?: (google.cloud.documentai.v1beta3.IProcessor[]|null);

                    /** ListProcessorsResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a ListProcessorsResponse. */
                class ListProcessorsResponse implements IListProcessorsResponse {

                    /**
                     * Constructs a new ListProcessorsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListProcessorsResponse);

                    /** ListProcessorsResponse processors. */
                    public processors: google.cloud.documentai.v1beta3.IProcessor[];

                    /** ListProcessorsResponse nextPageToken. */
                    public nextPageToken: string;

                    /**
                     * Creates a new ListProcessorsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListProcessorsResponse): google.cloud.documentai.v1beta3.ListProcessorsResponse;

                    /**
                     * Encodes the specified ListProcessorsResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorsResponse.verify|verify} messages.
                     * @param message ListProcessorsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListProcessorsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorsResponse.verify|verify} messages.
                     * @param message ListProcessorsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListProcessorsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListProcessorsResponse;

                    /**
                     * Decodes a ListProcessorsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListProcessorsResponse;

                    /**
                     * Verifies a ListProcessorsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListProcessorsResponse;

                    /**
                     * Creates a plain object from a ListProcessorsResponse message. Also converts values to other types if specified.
                     * @param message ListProcessorsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListProcessorsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetProcessorTypeRequest. */
                interface IGetProcessorTypeRequest {

                    /** GetProcessorTypeRequest name */
                    name?: (string|null);
                }

                /** Represents a GetProcessorTypeRequest. */
                class GetProcessorTypeRequest implements IGetProcessorTypeRequest {

                    /**
                     * Constructs a new GetProcessorTypeRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGetProcessorTypeRequest);

                    /** GetProcessorTypeRequest name. */
                    public name: string;

                    /**
                     * Creates a new GetProcessorTypeRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetProcessorTypeRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGetProcessorTypeRequest): google.cloud.documentai.v1beta3.GetProcessorTypeRequest;

                    /**
                     * Encodes the specified GetProcessorTypeRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.GetProcessorTypeRequest.verify|verify} messages.
                     * @param message GetProcessorTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGetProcessorTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetProcessorTypeRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GetProcessorTypeRequest.verify|verify} messages.
                     * @param message GetProcessorTypeRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGetProcessorTypeRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetProcessorTypeRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetProcessorTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GetProcessorTypeRequest;

                    /**
                     * Decodes a GetProcessorTypeRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetProcessorTypeRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GetProcessorTypeRequest;

                    /**
                     * Verifies a GetProcessorTypeRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetProcessorTypeRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetProcessorTypeRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GetProcessorTypeRequest;

                    /**
                     * Creates a plain object from a GetProcessorTypeRequest message. Also converts values to other types if specified.
                     * @param message GetProcessorTypeRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GetProcessorTypeRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetProcessorTypeRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetProcessorTypeRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetProcessorRequest. */
                interface IGetProcessorRequest {

                    /** GetProcessorRequest name */
                    name?: (string|null);
                }

                /** Represents a GetProcessorRequest. */
                class GetProcessorRequest implements IGetProcessorRequest {

                    /**
                     * Constructs a new GetProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGetProcessorRequest);

                    /** GetProcessorRequest name. */
                    public name: string;

                    /**
                     * Creates a new GetProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGetProcessorRequest): google.cloud.documentai.v1beta3.GetProcessorRequest;

                    /**
                     * Encodes the specified GetProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.GetProcessorRequest.verify|verify} messages.
                     * @param message GetProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGetProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GetProcessorRequest.verify|verify} messages.
                     * @param message GetProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGetProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GetProcessorRequest;

                    /**
                     * Decodes a GetProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GetProcessorRequest;

                    /**
                     * Verifies a GetProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GetProcessorRequest;

                    /**
                     * Creates a plain object from a GetProcessorRequest message. Also converts values to other types if specified.
                     * @param message GetProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GetProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetProcessorVersionRequest. */
                interface IGetProcessorVersionRequest {

                    /** GetProcessorVersionRequest name */
                    name?: (string|null);
                }

                /** Represents a GetProcessorVersionRequest. */
                class GetProcessorVersionRequest implements IGetProcessorVersionRequest {

                    /**
                     * Constructs a new GetProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGetProcessorVersionRequest);

                    /** GetProcessorVersionRequest name. */
                    public name: string;

                    /**
                     * Creates a new GetProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGetProcessorVersionRequest): google.cloud.documentai.v1beta3.GetProcessorVersionRequest;

                    /**
                     * Encodes the specified GetProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.GetProcessorVersionRequest.verify|verify} messages.
                     * @param message GetProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGetProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GetProcessorVersionRequest.verify|verify} messages.
                     * @param message GetProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGetProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GetProcessorVersionRequest;

                    /**
                     * Decodes a GetProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GetProcessorVersionRequest;

                    /**
                     * Verifies a GetProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GetProcessorVersionRequest;

                    /**
                     * Creates a plain object from a GetProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message GetProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GetProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorVersionsRequest. */
                interface IListProcessorVersionsRequest {

                    /** ListProcessorVersionsRequest parent */
                    parent?: (string|null);

                    /** ListProcessorVersionsRequest pageSize */
                    pageSize?: (number|null);

                    /** ListProcessorVersionsRequest pageToken */
                    pageToken?: (string|null);
                }

                /** Represents a ListProcessorVersionsRequest. */
                class ListProcessorVersionsRequest implements IListProcessorVersionsRequest {

                    /**
                     * Constructs a new ListProcessorVersionsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListProcessorVersionsRequest);

                    /** ListProcessorVersionsRequest parent. */
                    public parent: string;

                    /** ListProcessorVersionsRequest pageSize. */
                    public pageSize: number;

                    /** ListProcessorVersionsRequest pageToken. */
                    public pageToken: string;

                    /**
                     * Creates a new ListProcessorVersionsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorVersionsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListProcessorVersionsRequest): google.cloud.documentai.v1beta3.ListProcessorVersionsRequest;

                    /**
                     * Encodes the specified ListProcessorVersionsRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorVersionsRequest.verify|verify} messages.
                     * @param message ListProcessorVersionsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListProcessorVersionsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorVersionsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorVersionsRequest.verify|verify} messages.
                     * @param message ListProcessorVersionsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListProcessorVersionsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorVersionsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorVersionsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListProcessorVersionsRequest;

                    /**
                     * Decodes a ListProcessorVersionsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorVersionsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListProcessorVersionsRequest;

                    /**
                     * Verifies a ListProcessorVersionsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorVersionsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorVersionsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListProcessorVersionsRequest;

                    /**
                     * Creates a plain object from a ListProcessorVersionsRequest message. Also converts values to other types if specified.
                     * @param message ListProcessorVersionsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListProcessorVersionsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorVersionsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorVersionsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListProcessorVersionsResponse. */
                interface IListProcessorVersionsResponse {

                    /** ListProcessorVersionsResponse processorVersions */
                    processorVersions?: (google.cloud.documentai.v1beta3.IProcessorVersion[]|null);

                    /** ListProcessorVersionsResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a ListProcessorVersionsResponse. */
                class ListProcessorVersionsResponse implements IListProcessorVersionsResponse {

                    /**
                     * Constructs a new ListProcessorVersionsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListProcessorVersionsResponse);

                    /** ListProcessorVersionsResponse processorVersions. */
                    public processorVersions: google.cloud.documentai.v1beta3.IProcessorVersion[];

                    /** ListProcessorVersionsResponse nextPageToken. */
                    public nextPageToken: string;

                    /**
                     * Creates a new ListProcessorVersionsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListProcessorVersionsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListProcessorVersionsResponse): google.cloud.documentai.v1beta3.ListProcessorVersionsResponse;

                    /**
                     * Encodes the specified ListProcessorVersionsResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorVersionsResponse.verify|verify} messages.
                     * @param message ListProcessorVersionsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListProcessorVersionsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListProcessorVersionsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListProcessorVersionsResponse.verify|verify} messages.
                     * @param message ListProcessorVersionsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListProcessorVersionsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListProcessorVersionsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListProcessorVersionsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListProcessorVersionsResponse;

                    /**
                     * Decodes a ListProcessorVersionsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListProcessorVersionsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListProcessorVersionsResponse;

                    /**
                     * Verifies a ListProcessorVersionsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListProcessorVersionsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListProcessorVersionsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListProcessorVersionsResponse;

                    /**
                     * Creates a plain object from a ListProcessorVersionsResponse message. Also converts values to other types if specified.
                     * @param message ListProcessorVersionsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListProcessorVersionsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListProcessorVersionsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListProcessorVersionsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteProcessorVersionRequest. */
                interface IDeleteProcessorVersionRequest {

                    /** DeleteProcessorVersionRequest name */
                    name?: (string|null);
                }

                /** Represents a DeleteProcessorVersionRequest. */
                class DeleteProcessorVersionRequest implements IDeleteProcessorVersionRequest {

                    /**
                     * Constructs a new DeleteProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDeleteProcessorVersionRequest);

                    /** DeleteProcessorVersionRequest name. */
                    public name: string;

                    /**
                     * Creates a new DeleteProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDeleteProcessorVersionRequest): google.cloud.documentai.v1beta3.DeleteProcessorVersionRequest;

                    /**
                     * Encodes the specified DeleteProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.DeleteProcessorVersionRequest.verify|verify} messages.
                     * @param message DeleteProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDeleteProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DeleteProcessorVersionRequest.verify|verify} messages.
                     * @param message DeleteProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDeleteProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DeleteProcessorVersionRequest;

                    /**
                     * Decodes a DeleteProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DeleteProcessorVersionRequest;

                    /**
                     * Verifies a DeleteProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DeleteProcessorVersionRequest;

                    /**
                     * Creates a plain object from a DeleteProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message DeleteProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DeleteProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteProcessorVersionMetadata. */
                interface IDeleteProcessorVersionMetadata {

                    /** DeleteProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents a DeleteProcessorVersionMetadata. */
                class DeleteProcessorVersionMetadata implements IDeleteProcessorVersionMetadata {

                    /**
                     * Constructs a new DeleteProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDeleteProcessorVersionMetadata);

                    /** DeleteProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new DeleteProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDeleteProcessorVersionMetadata): google.cloud.documentai.v1beta3.DeleteProcessorVersionMetadata;

                    /**
                     * Encodes the specified DeleteProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.DeleteProcessorVersionMetadata.verify|verify} messages.
                     * @param message DeleteProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDeleteProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DeleteProcessorVersionMetadata.verify|verify} messages.
                     * @param message DeleteProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDeleteProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DeleteProcessorVersionMetadata;

                    /**
                     * Decodes a DeleteProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DeleteProcessorVersionMetadata;

                    /**
                     * Verifies a DeleteProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DeleteProcessorVersionMetadata;

                    /**
                     * Creates a plain object from a DeleteProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message DeleteProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DeleteProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeployProcessorVersionRequest. */
                interface IDeployProcessorVersionRequest {

                    /** DeployProcessorVersionRequest name */
                    name?: (string|null);
                }

                /** Represents a DeployProcessorVersionRequest. */
                class DeployProcessorVersionRequest implements IDeployProcessorVersionRequest {

                    /**
                     * Constructs a new DeployProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDeployProcessorVersionRequest);

                    /** DeployProcessorVersionRequest name. */
                    public name: string;

                    /**
                     * Creates a new DeployProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeployProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDeployProcessorVersionRequest): google.cloud.documentai.v1beta3.DeployProcessorVersionRequest;

                    /**
                     * Encodes the specified DeployProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.DeployProcessorVersionRequest.verify|verify} messages.
                     * @param message DeployProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDeployProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeployProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DeployProcessorVersionRequest.verify|verify} messages.
                     * @param message DeployProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDeployProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeployProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeployProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DeployProcessorVersionRequest;

                    /**
                     * Decodes a DeployProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeployProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DeployProcessorVersionRequest;

                    /**
                     * Verifies a DeployProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeployProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeployProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DeployProcessorVersionRequest;

                    /**
                     * Creates a plain object from a DeployProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message DeployProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DeployProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeployProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeployProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeployProcessorVersionResponse. */
                interface IDeployProcessorVersionResponse {
                }

                /** Represents a DeployProcessorVersionResponse. */
                class DeployProcessorVersionResponse implements IDeployProcessorVersionResponse {

                    /**
                     * Constructs a new DeployProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDeployProcessorVersionResponse);

                    /**
                     * Creates a new DeployProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeployProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDeployProcessorVersionResponse): google.cloud.documentai.v1beta3.DeployProcessorVersionResponse;

                    /**
                     * Encodes the specified DeployProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.DeployProcessorVersionResponse.verify|verify} messages.
                     * @param message DeployProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDeployProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeployProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DeployProcessorVersionResponse.verify|verify} messages.
                     * @param message DeployProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDeployProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeployProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeployProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DeployProcessorVersionResponse;

                    /**
                     * Decodes a DeployProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeployProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DeployProcessorVersionResponse;

                    /**
                     * Verifies a DeployProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeployProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeployProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DeployProcessorVersionResponse;

                    /**
                     * Creates a plain object from a DeployProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message DeployProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DeployProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeployProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeployProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeployProcessorVersionMetadata. */
                interface IDeployProcessorVersionMetadata {

                    /** DeployProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents a DeployProcessorVersionMetadata. */
                class DeployProcessorVersionMetadata implements IDeployProcessorVersionMetadata {

                    /**
                     * Constructs a new DeployProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDeployProcessorVersionMetadata);

                    /** DeployProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new DeployProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeployProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDeployProcessorVersionMetadata): google.cloud.documentai.v1beta3.DeployProcessorVersionMetadata;

                    /**
                     * Encodes the specified DeployProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.DeployProcessorVersionMetadata.verify|verify} messages.
                     * @param message DeployProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDeployProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeployProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DeployProcessorVersionMetadata.verify|verify} messages.
                     * @param message DeployProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDeployProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeployProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeployProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DeployProcessorVersionMetadata;

                    /**
                     * Decodes a DeployProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeployProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DeployProcessorVersionMetadata;

                    /**
                     * Verifies a DeployProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeployProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeployProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DeployProcessorVersionMetadata;

                    /**
                     * Creates a plain object from a DeployProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message DeployProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DeployProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeployProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeployProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UndeployProcessorVersionRequest. */
                interface IUndeployProcessorVersionRequest {

                    /** UndeployProcessorVersionRequest name */
                    name?: (string|null);
                }

                /** Represents an UndeployProcessorVersionRequest. */
                class UndeployProcessorVersionRequest implements IUndeployProcessorVersionRequest {

                    /**
                     * Constructs a new UndeployProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IUndeployProcessorVersionRequest);

                    /** UndeployProcessorVersionRequest name. */
                    public name: string;

                    /**
                     * Creates a new UndeployProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UndeployProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IUndeployProcessorVersionRequest): google.cloud.documentai.v1beta3.UndeployProcessorVersionRequest;

                    /**
                     * Encodes the specified UndeployProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.UndeployProcessorVersionRequest.verify|verify} messages.
                     * @param message UndeployProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IUndeployProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UndeployProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.UndeployProcessorVersionRequest.verify|verify} messages.
                     * @param message UndeployProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IUndeployProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UndeployProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UndeployProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.UndeployProcessorVersionRequest;

                    /**
                     * Decodes an UndeployProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UndeployProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.UndeployProcessorVersionRequest;

                    /**
                     * Verifies an UndeployProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UndeployProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UndeployProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.UndeployProcessorVersionRequest;

                    /**
                     * Creates a plain object from an UndeployProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message UndeployProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.UndeployProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UndeployProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UndeployProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UndeployProcessorVersionResponse. */
                interface IUndeployProcessorVersionResponse {
                }

                /** Represents an UndeployProcessorVersionResponse. */
                class UndeployProcessorVersionResponse implements IUndeployProcessorVersionResponse {

                    /**
                     * Constructs a new UndeployProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IUndeployProcessorVersionResponse);

                    /**
                     * Creates a new UndeployProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UndeployProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IUndeployProcessorVersionResponse): google.cloud.documentai.v1beta3.UndeployProcessorVersionResponse;

                    /**
                     * Encodes the specified UndeployProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.UndeployProcessorVersionResponse.verify|verify} messages.
                     * @param message UndeployProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IUndeployProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UndeployProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.UndeployProcessorVersionResponse.verify|verify} messages.
                     * @param message UndeployProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IUndeployProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UndeployProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UndeployProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.UndeployProcessorVersionResponse;

                    /**
                     * Decodes an UndeployProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UndeployProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.UndeployProcessorVersionResponse;

                    /**
                     * Verifies an UndeployProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UndeployProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UndeployProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.UndeployProcessorVersionResponse;

                    /**
                     * Creates a plain object from an UndeployProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message UndeployProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.UndeployProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UndeployProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UndeployProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UndeployProcessorVersionMetadata. */
                interface IUndeployProcessorVersionMetadata {

                    /** UndeployProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents an UndeployProcessorVersionMetadata. */
                class UndeployProcessorVersionMetadata implements IUndeployProcessorVersionMetadata {

                    /**
                     * Constructs a new UndeployProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IUndeployProcessorVersionMetadata);

                    /** UndeployProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new UndeployProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UndeployProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IUndeployProcessorVersionMetadata): google.cloud.documentai.v1beta3.UndeployProcessorVersionMetadata;

                    /**
                     * Encodes the specified UndeployProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.UndeployProcessorVersionMetadata.verify|verify} messages.
                     * @param message UndeployProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IUndeployProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UndeployProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.UndeployProcessorVersionMetadata.verify|verify} messages.
                     * @param message UndeployProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IUndeployProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UndeployProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UndeployProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.UndeployProcessorVersionMetadata;

                    /**
                     * Decodes an UndeployProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UndeployProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.UndeployProcessorVersionMetadata;

                    /**
                     * Verifies an UndeployProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UndeployProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UndeployProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.UndeployProcessorVersionMetadata;

                    /**
                     * Creates a plain object from an UndeployProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message UndeployProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.UndeployProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UndeployProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UndeployProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a CreateProcessorRequest. */
                interface ICreateProcessorRequest {

                    /** CreateProcessorRequest parent */
                    parent?: (string|null);

                    /** CreateProcessorRequest processor */
                    processor?: (google.cloud.documentai.v1beta3.IProcessor|null);
                }

                /** Represents a CreateProcessorRequest. */
                class CreateProcessorRequest implements ICreateProcessorRequest {

                    /**
                     * Constructs a new CreateProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.ICreateProcessorRequest);

                    /** CreateProcessorRequest parent. */
                    public parent: string;

                    /** CreateProcessorRequest processor. */
                    public processor?: (google.cloud.documentai.v1beta3.IProcessor|null);

                    /**
                     * Creates a new CreateProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CreateProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.ICreateProcessorRequest): google.cloud.documentai.v1beta3.CreateProcessorRequest;

                    /**
                     * Encodes the specified CreateProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.CreateProcessorRequest.verify|verify} messages.
                     * @param message CreateProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.ICreateProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CreateProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.CreateProcessorRequest.verify|verify} messages.
                     * @param message CreateProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.ICreateProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CreateProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CreateProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.CreateProcessorRequest;

                    /**
                     * Decodes a CreateProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CreateProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.CreateProcessorRequest;

                    /**
                     * Verifies a CreateProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CreateProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CreateProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.CreateProcessorRequest;

                    /**
                     * Creates a plain object from a CreateProcessorRequest message. Also converts values to other types if specified.
                     * @param message CreateProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.CreateProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CreateProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CreateProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteProcessorRequest. */
                interface IDeleteProcessorRequest {

                    /** DeleteProcessorRequest name */
                    name?: (string|null);
                }

                /** Represents a DeleteProcessorRequest. */
                class DeleteProcessorRequest implements IDeleteProcessorRequest {

                    /**
                     * Constructs a new DeleteProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDeleteProcessorRequest);

                    /** DeleteProcessorRequest name. */
                    public name: string;

                    /**
                     * Creates a new DeleteProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDeleteProcessorRequest): google.cloud.documentai.v1beta3.DeleteProcessorRequest;

                    /**
                     * Encodes the specified DeleteProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.DeleteProcessorRequest.verify|verify} messages.
                     * @param message DeleteProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDeleteProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DeleteProcessorRequest.verify|verify} messages.
                     * @param message DeleteProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDeleteProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DeleteProcessorRequest;

                    /**
                     * Decodes a DeleteProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DeleteProcessorRequest;

                    /**
                     * Verifies a DeleteProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DeleteProcessorRequest;

                    /**
                     * Creates a plain object from a DeleteProcessorRequest message. Also converts values to other types if specified.
                     * @param message DeleteProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DeleteProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DeleteProcessorMetadata. */
                interface IDeleteProcessorMetadata {

                    /** DeleteProcessorMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents a DeleteProcessorMetadata. */
                class DeleteProcessorMetadata implements IDeleteProcessorMetadata {

                    /**
                     * Constructs a new DeleteProcessorMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDeleteProcessorMetadata);

                    /** DeleteProcessorMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new DeleteProcessorMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DeleteProcessorMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDeleteProcessorMetadata): google.cloud.documentai.v1beta3.DeleteProcessorMetadata;

                    /**
                     * Encodes the specified DeleteProcessorMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.DeleteProcessorMetadata.verify|verify} messages.
                     * @param message DeleteProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDeleteProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DeleteProcessorMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DeleteProcessorMetadata.verify|verify} messages.
                     * @param message DeleteProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDeleteProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DeleteProcessorMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DeleteProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DeleteProcessorMetadata;

                    /**
                     * Decodes a DeleteProcessorMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DeleteProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DeleteProcessorMetadata;

                    /**
                     * Verifies a DeleteProcessorMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DeleteProcessorMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DeleteProcessorMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DeleteProcessorMetadata;

                    /**
                     * Creates a plain object from a DeleteProcessorMetadata message. Also converts values to other types if specified.
                     * @param message DeleteProcessorMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DeleteProcessorMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DeleteProcessorMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DeleteProcessorMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EnableProcessorRequest. */
                interface IEnableProcessorRequest {

                    /** EnableProcessorRequest name */
                    name?: (string|null);
                }

                /** Represents an EnableProcessorRequest. */
                class EnableProcessorRequest implements IEnableProcessorRequest {

                    /**
                     * Constructs a new EnableProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IEnableProcessorRequest);

                    /** EnableProcessorRequest name. */
                    public name: string;

                    /**
                     * Creates a new EnableProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EnableProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IEnableProcessorRequest): google.cloud.documentai.v1beta3.EnableProcessorRequest;

                    /**
                     * Encodes the specified EnableProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.EnableProcessorRequest.verify|verify} messages.
                     * @param message EnableProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IEnableProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EnableProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.EnableProcessorRequest.verify|verify} messages.
                     * @param message EnableProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IEnableProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EnableProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EnableProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.EnableProcessorRequest;

                    /**
                     * Decodes an EnableProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EnableProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.EnableProcessorRequest;

                    /**
                     * Verifies an EnableProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EnableProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EnableProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.EnableProcessorRequest;

                    /**
                     * Creates a plain object from an EnableProcessorRequest message. Also converts values to other types if specified.
                     * @param message EnableProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.EnableProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EnableProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EnableProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EnableProcessorResponse. */
                interface IEnableProcessorResponse {
                }

                /** Represents an EnableProcessorResponse. */
                class EnableProcessorResponse implements IEnableProcessorResponse {

                    /**
                     * Constructs a new EnableProcessorResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IEnableProcessorResponse);

                    /**
                     * Creates a new EnableProcessorResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EnableProcessorResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IEnableProcessorResponse): google.cloud.documentai.v1beta3.EnableProcessorResponse;

                    /**
                     * Encodes the specified EnableProcessorResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.EnableProcessorResponse.verify|verify} messages.
                     * @param message EnableProcessorResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IEnableProcessorResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EnableProcessorResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.EnableProcessorResponse.verify|verify} messages.
                     * @param message EnableProcessorResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IEnableProcessorResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EnableProcessorResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EnableProcessorResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.EnableProcessorResponse;

                    /**
                     * Decodes an EnableProcessorResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EnableProcessorResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.EnableProcessorResponse;

                    /**
                     * Verifies an EnableProcessorResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EnableProcessorResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EnableProcessorResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.EnableProcessorResponse;

                    /**
                     * Creates a plain object from an EnableProcessorResponse message. Also converts values to other types if specified.
                     * @param message EnableProcessorResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.EnableProcessorResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EnableProcessorResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EnableProcessorResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EnableProcessorMetadata. */
                interface IEnableProcessorMetadata {

                    /** EnableProcessorMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents an EnableProcessorMetadata. */
                class EnableProcessorMetadata implements IEnableProcessorMetadata {

                    /**
                     * Constructs a new EnableProcessorMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IEnableProcessorMetadata);

                    /** EnableProcessorMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new EnableProcessorMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EnableProcessorMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IEnableProcessorMetadata): google.cloud.documentai.v1beta3.EnableProcessorMetadata;

                    /**
                     * Encodes the specified EnableProcessorMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.EnableProcessorMetadata.verify|verify} messages.
                     * @param message EnableProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IEnableProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EnableProcessorMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.EnableProcessorMetadata.verify|verify} messages.
                     * @param message EnableProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IEnableProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EnableProcessorMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EnableProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.EnableProcessorMetadata;

                    /**
                     * Decodes an EnableProcessorMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EnableProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.EnableProcessorMetadata;

                    /**
                     * Verifies an EnableProcessorMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EnableProcessorMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EnableProcessorMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.EnableProcessorMetadata;

                    /**
                     * Creates a plain object from an EnableProcessorMetadata message. Also converts values to other types if specified.
                     * @param message EnableProcessorMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.EnableProcessorMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EnableProcessorMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EnableProcessorMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisableProcessorRequest. */
                interface IDisableProcessorRequest {

                    /** DisableProcessorRequest name */
                    name?: (string|null);
                }

                /** Represents a DisableProcessorRequest. */
                class DisableProcessorRequest implements IDisableProcessorRequest {

                    /**
                     * Constructs a new DisableProcessorRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDisableProcessorRequest);

                    /** DisableProcessorRequest name. */
                    public name: string;

                    /**
                     * Creates a new DisableProcessorRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisableProcessorRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDisableProcessorRequest): google.cloud.documentai.v1beta3.DisableProcessorRequest;

                    /**
                     * Encodes the specified DisableProcessorRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.DisableProcessorRequest.verify|verify} messages.
                     * @param message DisableProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDisableProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisableProcessorRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DisableProcessorRequest.verify|verify} messages.
                     * @param message DisableProcessorRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDisableProcessorRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisableProcessorRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisableProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DisableProcessorRequest;

                    /**
                     * Decodes a DisableProcessorRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisableProcessorRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DisableProcessorRequest;

                    /**
                     * Verifies a DisableProcessorRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisableProcessorRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisableProcessorRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DisableProcessorRequest;

                    /**
                     * Creates a plain object from a DisableProcessorRequest message. Also converts values to other types if specified.
                     * @param message DisableProcessorRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DisableProcessorRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisableProcessorRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisableProcessorRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisableProcessorResponse. */
                interface IDisableProcessorResponse {
                }

                /** Represents a DisableProcessorResponse. */
                class DisableProcessorResponse implements IDisableProcessorResponse {

                    /**
                     * Constructs a new DisableProcessorResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDisableProcessorResponse);

                    /**
                     * Creates a new DisableProcessorResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisableProcessorResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDisableProcessorResponse): google.cloud.documentai.v1beta3.DisableProcessorResponse;

                    /**
                     * Encodes the specified DisableProcessorResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.DisableProcessorResponse.verify|verify} messages.
                     * @param message DisableProcessorResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDisableProcessorResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisableProcessorResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DisableProcessorResponse.verify|verify} messages.
                     * @param message DisableProcessorResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDisableProcessorResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisableProcessorResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisableProcessorResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DisableProcessorResponse;

                    /**
                     * Decodes a DisableProcessorResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisableProcessorResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DisableProcessorResponse;

                    /**
                     * Verifies a DisableProcessorResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisableProcessorResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisableProcessorResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DisableProcessorResponse;

                    /**
                     * Creates a plain object from a DisableProcessorResponse message. Also converts values to other types if specified.
                     * @param message DisableProcessorResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DisableProcessorResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisableProcessorResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisableProcessorResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DisableProcessorMetadata. */
                interface IDisableProcessorMetadata {

                    /** DisableProcessorMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents a DisableProcessorMetadata. */
                class DisableProcessorMetadata implements IDisableProcessorMetadata {

                    /**
                     * Constructs a new DisableProcessorMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDisableProcessorMetadata);

                    /** DisableProcessorMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new DisableProcessorMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DisableProcessorMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDisableProcessorMetadata): google.cloud.documentai.v1beta3.DisableProcessorMetadata;

                    /**
                     * Encodes the specified DisableProcessorMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.DisableProcessorMetadata.verify|verify} messages.
                     * @param message DisableProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDisableProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DisableProcessorMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DisableProcessorMetadata.verify|verify} messages.
                     * @param message DisableProcessorMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDisableProcessorMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DisableProcessorMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DisableProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DisableProcessorMetadata;

                    /**
                     * Decodes a DisableProcessorMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DisableProcessorMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DisableProcessorMetadata;

                    /**
                     * Verifies a DisableProcessorMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DisableProcessorMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DisableProcessorMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DisableProcessorMetadata;

                    /**
                     * Creates a plain object from a DisableProcessorMetadata message. Also converts values to other types if specified.
                     * @param message DisableProcessorMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DisableProcessorMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DisableProcessorMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DisableProcessorMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetDefaultProcessorVersionRequest. */
                interface ISetDefaultProcessorVersionRequest {

                    /** SetDefaultProcessorVersionRequest processor */
                    processor?: (string|null);

                    /** SetDefaultProcessorVersionRequest defaultProcessorVersion */
                    defaultProcessorVersion?: (string|null);
                }

                /** Represents a SetDefaultProcessorVersionRequest. */
                class SetDefaultProcessorVersionRequest implements ISetDefaultProcessorVersionRequest {

                    /**
                     * Constructs a new SetDefaultProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionRequest);

                    /** SetDefaultProcessorVersionRequest processor. */
                    public processor: string;

                    /** SetDefaultProcessorVersionRequest defaultProcessorVersion. */
                    public defaultProcessorVersion: string;

                    /**
                     * Creates a new SetDefaultProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetDefaultProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionRequest): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionRequest;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.SetDefaultProcessorVersionRequest.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.SetDefaultProcessorVersionRequest.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetDefaultProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetDefaultProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionRequest;

                    /**
                     * Decodes a SetDefaultProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetDefaultProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionRequest;

                    /**
                     * Verifies a SetDefaultProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetDefaultProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetDefaultProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionRequest;

                    /**
                     * Creates a plain object from a SetDefaultProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message SetDefaultProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.SetDefaultProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetDefaultProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetDefaultProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetDefaultProcessorVersionResponse. */
                interface ISetDefaultProcessorVersionResponse {
                }

                /** Represents a SetDefaultProcessorVersionResponse. */
                class SetDefaultProcessorVersionResponse implements ISetDefaultProcessorVersionResponse {

                    /**
                     * Constructs a new SetDefaultProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionResponse);

                    /**
                     * Creates a new SetDefaultProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetDefaultProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionResponse): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionResponse;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.SetDefaultProcessorVersionResponse.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.SetDefaultProcessorVersionResponse.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetDefaultProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetDefaultProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionResponse;

                    /**
                     * Decodes a SetDefaultProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetDefaultProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionResponse;

                    /**
                     * Verifies a SetDefaultProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetDefaultProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetDefaultProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionResponse;

                    /**
                     * Creates a plain object from a SetDefaultProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message SetDefaultProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.SetDefaultProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetDefaultProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetDefaultProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a SetDefaultProcessorVersionMetadata. */
                interface ISetDefaultProcessorVersionMetadata {

                    /** SetDefaultProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents a SetDefaultProcessorVersionMetadata. */
                class SetDefaultProcessorVersionMetadata implements ISetDefaultProcessorVersionMetadata {

                    /**
                     * Constructs a new SetDefaultProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionMetadata);

                    /** SetDefaultProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new SetDefaultProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns SetDefaultProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionMetadata): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionMetadata;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.SetDefaultProcessorVersionMetadata.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified SetDefaultProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.SetDefaultProcessorVersionMetadata.verify|verify} messages.
                     * @param message SetDefaultProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.ISetDefaultProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a SetDefaultProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns SetDefaultProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionMetadata;

                    /**
                     * Decodes a SetDefaultProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns SetDefaultProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionMetadata;

                    /**
                     * Verifies a SetDefaultProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a SetDefaultProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns SetDefaultProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.SetDefaultProcessorVersionMetadata;

                    /**
                     * Creates a plain object from a SetDefaultProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message SetDefaultProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.SetDefaultProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this SetDefaultProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for SetDefaultProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TrainProcessorVersionRequest. */
                interface ITrainProcessorVersionRequest {

                    /** TrainProcessorVersionRequest customDocumentExtractionOptions */
                    customDocumentExtractionOptions?: (google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions|null);

                    /** TrainProcessorVersionRequest foundationModelTuningOptions */
                    foundationModelTuningOptions?: (google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IFoundationModelTuningOptions|null);

                    /** TrainProcessorVersionRequest parent */
                    parent?: (string|null);

                    /** TrainProcessorVersionRequest processorVersion */
                    processorVersion?: (google.cloud.documentai.v1beta3.IProcessorVersion|null);

                    /** TrainProcessorVersionRequest documentSchema */
                    documentSchema?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);

                    /** TrainProcessorVersionRequest inputData */
                    inputData?: (google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IInputData|null);

                    /** TrainProcessorVersionRequest baseProcessorVersion */
                    baseProcessorVersion?: (string|null);
                }

                /** Represents a TrainProcessorVersionRequest. */
                class TrainProcessorVersionRequest implements ITrainProcessorVersionRequest {

                    /**
                     * Constructs a new TrainProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.ITrainProcessorVersionRequest);

                    /** TrainProcessorVersionRequest customDocumentExtractionOptions. */
                    public customDocumentExtractionOptions?: (google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions|null);

                    /** TrainProcessorVersionRequest foundationModelTuningOptions. */
                    public foundationModelTuningOptions?: (google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IFoundationModelTuningOptions|null);

                    /** TrainProcessorVersionRequest parent. */
                    public parent: string;

                    /** TrainProcessorVersionRequest processorVersion. */
                    public processorVersion?: (google.cloud.documentai.v1beta3.IProcessorVersion|null);

                    /** TrainProcessorVersionRequest documentSchema. */
                    public documentSchema?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);

                    /** TrainProcessorVersionRequest inputData. */
                    public inputData?: (google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IInputData|null);

                    /** TrainProcessorVersionRequest baseProcessorVersion. */
                    public baseProcessorVersion: string;

                    /** TrainProcessorVersionRequest processorFlags. */
                    public processorFlags?: ("customDocumentExtractionOptions"|"foundationModelTuningOptions");

                    /**
                     * Creates a new TrainProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TrainProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.ITrainProcessorVersionRequest): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest;

                    /**
                     * Encodes the specified TrainProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.verify|verify} messages.
                     * @param message TrainProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.ITrainProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TrainProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.verify|verify} messages.
                     * @param message TrainProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.ITrainProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TrainProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TrainProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest;

                    /**
                     * Decodes a TrainProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TrainProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest;

                    /**
                     * Verifies a TrainProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TrainProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TrainProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest;

                    /**
                     * Creates a plain object from a TrainProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message TrainProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TrainProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TrainProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TrainProcessorVersionRequest {

                    /** Properties of an InputData. */
                    interface IInputData {

                        /** InputData trainingDocuments */
                        trainingDocuments?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);

                        /** InputData testDocuments */
                        testDocuments?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);
                    }

                    /** Represents an InputData. */
                    class InputData implements IInputData {

                        /**
                         * Constructs a new InputData.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IInputData);

                        /** InputData trainingDocuments. */
                        public trainingDocuments?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);

                        /** InputData testDocuments. */
                        public testDocuments?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);

                        /**
                         * Creates a new InputData instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns InputData instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IInputData): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.InputData;

                        /**
                         * Encodes the specified InputData message. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.InputData.verify|verify} messages.
                         * @param message InputData message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IInputData, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified InputData message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.InputData.verify|verify} messages.
                         * @param message InputData message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IInputData, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an InputData message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns InputData
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.InputData;

                        /**
                         * Decodes an InputData message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns InputData
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.InputData;

                        /**
                         * Verifies an InputData message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an InputData message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns InputData
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.InputData;

                        /**
                         * Creates a plain object from an InputData message. Also converts values to other types if specified.
                         * @param message InputData
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.InputData, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this InputData to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for InputData
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a CustomDocumentExtractionOptions. */
                    interface ICustomDocumentExtractionOptions {

                        /** CustomDocumentExtractionOptions trainingMethod */
                        trainingMethod?: (google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.TrainingMethod|keyof typeof google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.TrainingMethod|null);
                    }

                    /** Represents a CustomDocumentExtractionOptions. */
                    class CustomDocumentExtractionOptions implements ICustomDocumentExtractionOptions {

                        /**
                         * Constructs a new CustomDocumentExtractionOptions.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions);

                        /** CustomDocumentExtractionOptions trainingMethod. */
                        public trainingMethod: (google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.TrainingMethod|keyof typeof google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.TrainingMethod);

                        /**
                         * Creates a new CustomDocumentExtractionOptions instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns CustomDocumentExtractionOptions instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions;

                        /**
                         * Encodes the specified CustomDocumentExtractionOptions message. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.verify|verify} messages.
                         * @param message CustomDocumentExtractionOptions message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified CustomDocumentExtractionOptions message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions.verify|verify} messages.
                         * @param message CustomDocumentExtractionOptions message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.ICustomDocumentExtractionOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a CustomDocumentExtractionOptions message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns CustomDocumentExtractionOptions
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions;

                        /**
                         * Decodes a CustomDocumentExtractionOptions message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns CustomDocumentExtractionOptions
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions;

                        /**
                         * Verifies a CustomDocumentExtractionOptions message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a CustomDocumentExtractionOptions message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns CustomDocumentExtractionOptions
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions;

                        /**
                         * Creates a plain object from a CustomDocumentExtractionOptions message. Also converts values to other types if specified.
                         * @param message CustomDocumentExtractionOptions
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.CustomDocumentExtractionOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this CustomDocumentExtractionOptions to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for CustomDocumentExtractionOptions
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace CustomDocumentExtractionOptions {

                        /** TrainingMethod enum. */
                        enum TrainingMethod {
                            TRAINING_METHOD_UNSPECIFIED = 0,
                            MODEL_BASED = 1,
                            TEMPLATE_BASED = 2
                        }
                    }

                    /** Properties of a FoundationModelTuningOptions. */
                    interface IFoundationModelTuningOptions {

                        /** FoundationModelTuningOptions trainSteps */
                        trainSteps?: (number|null);

                        /** FoundationModelTuningOptions learningRateMultiplier */
                        learningRateMultiplier?: (number|null);
                    }

                    /** Represents a FoundationModelTuningOptions. */
                    class FoundationModelTuningOptions implements IFoundationModelTuningOptions {

                        /**
                         * Constructs a new FoundationModelTuningOptions.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IFoundationModelTuningOptions);

                        /** FoundationModelTuningOptions trainSteps. */
                        public trainSteps: number;

                        /** FoundationModelTuningOptions learningRateMultiplier. */
                        public learningRateMultiplier: number;

                        /**
                         * Creates a new FoundationModelTuningOptions instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns FoundationModelTuningOptions instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IFoundationModelTuningOptions): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.FoundationModelTuningOptions;

                        /**
                         * Encodes the specified FoundationModelTuningOptions message. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.FoundationModelTuningOptions.verify|verify} messages.
                         * @param message FoundationModelTuningOptions message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IFoundationModelTuningOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified FoundationModelTuningOptions message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.FoundationModelTuningOptions.verify|verify} messages.
                         * @param message FoundationModelTuningOptions message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.IFoundationModelTuningOptions, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a FoundationModelTuningOptions message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns FoundationModelTuningOptions
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.FoundationModelTuningOptions;

                        /**
                         * Decodes a FoundationModelTuningOptions message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns FoundationModelTuningOptions
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.FoundationModelTuningOptions;

                        /**
                         * Verifies a FoundationModelTuningOptions message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a FoundationModelTuningOptions message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns FoundationModelTuningOptions
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.FoundationModelTuningOptions;

                        /**
                         * Creates a plain object from a FoundationModelTuningOptions message. Also converts values to other types if specified.
                         * @param message FoundationModelTuningOptions
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.TrainProcessorVersionRequest.FoundationModelTuningOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this FoundationModelTuningOptions to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for FoundationModelTuningOptions
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a TrainProcessorVersionResponse. */
                interface ITrainProcessorVersionResponse {

                    /** TrainProcessorVersionResponse processorVersion */
                    processorVersion?: (string|null);
                }

                /** Represents a TrainProcessorVersionResponse. */
                class TrainProcessorVersionResponse implements ITrainProcessorVersionResponse {

                    /**
                     * Constructs a new TrainProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.ITrainProcessorVersionResponse);

                    /** TrainProcessorVersionResponse processorVersion. */
                    public processorVersion: string;

                    /**
                     * Creates a new TrainProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TrainProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.ITrainProcessorVersionResponse): google.cloud.documentai.v1beta3.TrainProcessorVersionResponse;

                    /**
                     * Encodes the specified TrainProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionResponse.verify|verify} messages.
                     * @param message TrainProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.ITrainProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TrainProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionResponse.verify|verify} messages.
                     * @param message TrainProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.ITrainProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TrainProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TrainProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.TrainProcessorVersionResponse;

                    /**
                     * Decodes a TrainProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TrainProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.TrainProcessorVersionResponse;

                    /**
                     * Verifies a TrainProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TrainProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TrainProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.TrainProcessorVersionResponse;

                    /**
                     * Creates a plain object from a TrainProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message TrainProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.TrainProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TrainProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TrainProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a TrainProcessorVersionMetadata. */
                interface ITrainProcessorVersionMetadata {

                    /** TrainProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /** TrainProcessorVersionMetadata trainingDatasetValidation */
                    trainingDatasetValidation?: (google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.IDatasetValidation|null);

                    /** TrainProcessorVersionMetadata testDatasetValidation */
                    testDatasetValidation?: (google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.IDatasetValidation|null);
                }

                /** Represents a TrainProcessorVersionMetadata. */
                class TrainProcessorVersionMetadata implements ITrainProcessorVersionMetadata {

                    /**
                     * Constructs a new TrainProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.ITrainProcessorVersionMetadata);

                    /** TrainProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /** TrainProcessorVersionMetadata trainingDatasetValidation. */
                    public trainingDatasetValidation?: (google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.IDatasetValidation|null);

                    /** TrainProcessorVersionMetadata testDatasetValidation. */
                    public testDatasetValidation?: (google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.IDatasetValidation|null);

                    /**
                     * Creates a new TrainProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns TrainProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.ITrainProcessorVersionMetadata): google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata;

                    /**
                     * Encodes the specified TrainProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.verify|verify} messages.
                     * @param message TrainProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.ITrainProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified TrainProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.verify|verify} messages.
                     * @param message TrainProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.ITrainProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a TrainProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns TrainProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata;

                    /**
                     * Decodes a TrainProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns TrainProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata;

                    /**
                     * Verifies a TrainProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a TrainProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns TrainProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata;

                    /**
                     * Creates a plain object from a TrainProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message TrainProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this TrainProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for TrainProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace TrainProcessorVersionMetadata {

                    /** Properties of a DatasetValidation. */
                    interface IDatasetValidation {

                        /** DatasetValidation documentErrorCount */
                        documentErrorCount?: (number|null);

                        /** DatasetValidation datasetErrorCount */
                        datasetErrorCount?: (number|null);

                        /** DatasetValidation documentErrors */
                        documentErrors?: (google.rpc.IStatus[]|null);

                        /** DatasetValidation datasetErrors */
                        datasetErrors?: (google.rpc.IStatus[]|null);
                    }

                    /** Represents a DatasetValidation. */
                    class DatasetValidation implements IDatasetValidation {

                        /**
                         * Constructs a new DatasetValidation.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.IDatasetValidation);

                        /** DatasetValidation documentErrorCount. */
                        public documentErrorCount: number;

                        /** DatasetValidation datasetErrorCount. */
                        public datasetErrorCount: number;

                        /** DatasetValidation documentErrors. */
                        public documentErrors: google.rpc.IStatus[];

                        /** DatasetValidation datasetErrors. */
                        public datasetErrors: google.rpc.IStatus[];

                        /**
                         * Creates a new DatasetValidation instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns DatasetValidation instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.IDatasetValidation): google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.DatasetValidation;

                        /**
                         * Encodes the specified DatasetValidation message. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.DatasetValidation.verify|verify} messages.
                         * @param message DatasetValidation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.IDatasetValidation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified DatasetValidation message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.DatasetValidation.verify|verify} messages.
                         * @param message DatasetValidation message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.IDatasetValidation, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a DatasetValidation message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns DatasetValidation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.DatasetValidation;

                        /**
                         * Decodes a DatasetValidation message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns DatasetValidation
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.DatasetValidation;

                        /**
                         * Verifies a DatasetValidation message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a DatasetValidation message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns DatasetValidation
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.DatasetValidation;

                        /**
                         * Creates a plain object from a DatasetValidation message. Also converts values to other types if specified.
                         * @param message DatasetValidation
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.TrainProcessorVersionMetadata.DatasetValidation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this DatasetValidation to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for DatasetValidation
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a ReviewDocumentRequest. */
                interface IReviewDocumentRequest {

                    /** ReviewDocumentRequest inlineDocument */
                    inlineDocument?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ReviewDocumentRequest humanReviewConfig */
                    humanReviewConfig?: (string|null);

                    /** ReviewDocumentRequest document */
                    document?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ReviewDocumentRequest enableSchemaValidation */
                    enableSchemaValidation?: (boolean|null);

                    /** ReviewDocumentRequest priority */
                    priority?: (google.cloud.documentai.v1beta3.ReviewDocumentRequest.Priority|keyof typeof google.cloud.documentai.v1beta3.ReviewDocumentRequest.Priority|null);

                    /** ReviewDocumentRequest documentSchema */
                    documentSchema?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);
                }

                /** Represents a ReviewDocumentRequest. */
                class ReviewDocumentRequest implements IReviewDocumentRequest {

                    /**
                     * Constructs a new ReviewDocumentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IReviewDocumentRequest);

                    /** ReviewDocumentRequest inlineDocument. */
                    public inlineDocument?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ReviewDocumentRequest humanReviewConfig. */
                    public humanReviewConfig: string;

                    /** ReviewDocumentRequest document. */
                    public document?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /** ReviewDocumentRequest enableSchemaValidation. */
                    public enableSchemaValidation: boolean;

                    /** ReviewDocumentRequest priority. */
                    public priority: (google.cloud.documentai.v1beta3.ReviewDocumentRequest.Priority|keyof typeof google.cloud.documentai.v1beta3.ReviewDocumentRequest.Priority);

                    /** ReviewDocumentRequest documentSchema. */
                    public documentSchema?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);

                    /** ReviewDocumentRequest source. */
                    public source?: "inlineDocument";

                    /**
                     * Creates a new ReviewDocumentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReviewDocumentRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IReviewDocumentRequest): google.cloud.documentai.v1beta3.ReviewDocumentRequest;

                    /**
                     * Encodes the specified ReviewDocumentRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.ReviewDocumentRequest.verify|verify} messages.
                     * @param message ReviewDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IReviewDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReviewDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ReviewDocumentRequest.verify|verify} messages.
                     * @param message ReviewDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IReviewDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReviewDocumentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReviewDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ReviewDocumentRequest;

                    /**
                     * Decodes a ReviewDocumentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReviewDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ReviewDocumentRequest;

                    /**
                     * Verifies a ReviewDocumentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReviewDocumentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReviewDocumentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ReviewDocumentRequest;

                    /**
                     * Creates a plain object from a ReviewDocumentRequest message. Also converts values to other types if specified.
                     * @param message ReviewDocumentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ReviewDocumentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReviewDocumentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReviewDocumentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ReviewDocumentRequest {

                    /** Priority enum. */
                    enum Priority {
                        DEFAULT = 0,
                        URGENT = 1
                    }
                }

                /** Properties of a ReviewDocumentResponse. */
                interface IReviewDocumentResponse {

                    /** ReviewDocumentResponse gcsDestination */
                    gcsDestination?: (string|null);

                    /** ReviewDocumentResponse state */
                    state?: (google.cloud.documentai.v1beta3.ReviewDocumentResponse.State|keyof typeof google.cloud.documentai.v1beta3.ReviewDocumentResponse.State|null);

                    /** ReviewDocumentResponse rejectionReason */
                    rejectionReason?: (string|null);
                }

                /** Represents a ReviewDocumentResponse. */
                class ReviewDocumentResponse implements IReviewDocumentResponse {

                    /**
                     * Constructs a new ReviewDocumentResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IReviewDocumentResponse);

                    /** ReviewDocumentResponse gcsDestination. */
                    public gcsDestination: string;

                    /** ReviewDocumentResponse state. */
                    public state: (google.cloud.documentai.v1beta3.ReviewDocumentResponse.State|keyof typeof google.cloud.documentai.v1beta3.ReviewDocumentResponse.State);

                    /** ReviewDocumentResponse rejectionReason. */
                    public rejectionReason: string;

                    /**
                     * Creates a new ReviewDocumentResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReviewDocumentResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IReviewDocumentResponse): google.cloud.documentai.v1beta3.ReviewDocumentResponse;

                    /**
                     * Encodes the specified ReviewDocumentResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.ReviewDocumentResponse.verify|verify} messages.
                     * @param message ReviewDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IReviewDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReviewDocumentResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ReviewDocumentResponse.verify|verify} messages.
                     * @param message ReviewDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IReviewDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReviewDocumentResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReviewDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ReviewDocumentResponse;

                    /**
                     * Decodes a ReviewDocumentResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReviewDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ReviewDocumentResponse;

                    /**
                     * Verifies a ReviewDocumentResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReviewDocumentResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReviewDocumentResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ReviewDocumentResponse;

                    /**
                     * Creates a plain object from a ReviewDocumentResponse message. Also converts values to other types if specified.
                     * @param message ReviewDocumentResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ReviewDocumentResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReviewDocumentResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReviewDocumentResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ReviewDocumentResponse {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        REJECTED = 1,
                        SUCCEEDED = 2
                    }
                }

                /** Properties of a ReviewDocumentOperationMetadata. */
                interface IReviewDocumentOperationMetadata {

                    /** ReviewDocumentOperationMetadata state */
                    state?: (google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata.State|keyof typeof google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata.State|null);

                    /** ReviewDocumentOperationMetadata stateMessage */
                    stateMessage?: (string|null);

                    /** ReviewDocumentOperationMetadata createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** ReviewDocumentOperationMetadata updateTime */
                    updateTime?: (google.protobuf.ITimestamp|null);

                    /** ReviewDocumentOperationMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /** ReviewDocumentOperationMetadata questionId */
                    questionId?: (string|null);
                }

                /** Represents a ReviewDocumentOperationMetadata. */
                class ReviewDocumentOperationMetadata implements IReviewDocumentOperationMetadata {

                    /**
                     * Constructs a new ReviewDocumentOperationMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IReviewDocumentOperationMetadata);

                    /** ReviewDocumentOperationMetadata state. */
                    public state: (google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata.State|keyof typeof google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata.State);

                    /** ReviewDocumentOperationMetadata stateMessage. */
                    public stateMessage: string;

                    /** ReviewDocumentOperationMetadata createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** ReviewDocumentOperationMetadata updateTime. */
                    public updateTime?: (google.protobuf.ITimestamp|null);

                    /** ReviewDocumentOperationMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /** ReviewDocumentOperationMetadata questionId. */
                    public questionId: string;

                    /**
                     * Creates a new ReviewDocumentOperationMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ReviewDocumentOperationMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IReviewDocumentOperationMetadata): google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata;

                    /**
                     * Encodes the specified ReviewDocumentOperationMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata.verify|verify} messages.
                     * @param message ReviewDocumentOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IReviewDocumentOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ReviewDocumentOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata.verify|verify} messages.
                     * @param message ReviewDocumentOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IReviewDocumentOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ReviewDocumentOperationMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ReviewDocumentOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata;

                    /**
                     * Decodes a ReviewDocumentOperationMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ReviewDocumentOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata;

                    /**
                     * Verifies a ReviewDocumentOperationMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ReviewDocumentOperationMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ReviewDocumentOperationMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata;

                    /**
                     * Creates a plain object from a ReviewDocumentOperationMetadata message. Also converts values to other types if specified.
                     * @param message ReviewDocumentOperationMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ReviewDocumentOperationMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ReviewDocumentOperationMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ReviewDocumentOperationMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ReviewDocumentOperationMetadata {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        RUNNING = 1,
                        CANCELLING = 2,
                        SUCCEEDED = 3,
                        FAILED = 4,
                        CANCELLED = 5
                    }
                }

                /** Properties of an EvaluateProcessorVersionRequest. */
                interface IEvaluateProcessorVersionRequest {

                    /** EvaluateProcessorVersionRequest processorVersion */
                    processorVersion?: (string|null);

                    /** EvaluateProcessorVersionRequest evaluationDocuments */
                    evaluationDocuments?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);
                }

                /** Represents an EvaluateProcessorVersionRequest. */
                class EvaluateProcessorVersionRequest implements IEvaluateProcessorVersionRequest {

                    /**
                     * Constructs a new EvaluateProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionRequest);

                    /** EvaluateProcessorVersionRequest processorVersion. */
                    public processorVersion: string;

                    /** EvaluateProcessorVersionRequest evaluationDocuments. */
                    public evaluationDocuments?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);

                    /**
                     * Creates a new EvaluateProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EvaluateProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionRequest): google.cloud.documentai.v1beta3.EvaluateProcessorVersionRequest;

                    /**
                     * Encodes the specified EvaluateProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.EvaluateProcessorVersionRequest.verify|verify} messages.
                     * @param message EvaluateProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EvaluateProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.EvaluateProcessorVersionRequest.verify|verify} messages.
                     * @param message EvaluateProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EvaluateProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EvaluateProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.EvaluateProcessorVersionRequest;

                    /**
                     * Decodes an EvaluateProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EvaluateProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.EvaluateProcessorVersionRequest;

                    /**
                     * Verifies an EvaluateProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EvaluateProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EvaluateProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.EvaluateProcessorVersionRequest;

                    /**
                     * Creates a plain object from an EvaluateProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message EvaluateProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.EvaluateProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EvaluateProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EvaluateProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EvaluateProcessorVersionMetadata. */
                interface IEvaluateProcessorVersionMetadata {

                    /** EvaluateProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents an EvaluateProcessorVersionMetadata. */
                class EvaluateProcessorVersionMetadata implements IEvaluateProcessorVersionMetadata {

                    /**
                     * Constructs a new EvaluateProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionMetadata);

                    /** EvaluateProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new EvaluateProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EvaluateProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionMetadata): google.cloud.documentai.v1beta3.EvaluateProcessorVersionMetadata;

                    /**
                     * Encodes the specified EvaluateProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.EvaluateProcessorVersionMetadata.verify|verify} messages.
                     * @param message EvaluateProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EvaluateProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.EvaluateProcessorVersionMetadata.verify|verify} messages.
                     * @param message EvaluateProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EvaluateProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EvaluateProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.EvaluateProcessorVersionMetadata;

                    /**
                     * Decodes an EvaluateProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EvaluateProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.EvaluateProcessorVersionMetadata;

                    /**
                     * Verifies an EvaluateProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EvaluateProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EvaluateProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.EvaluateProcessorVersionMetadata;

                    /**
                     * Creates a plain object from an EvaluateProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message EvaluateProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.EvaluateProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EvaluateProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EvaluateProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EvaluateProcessorVersionResponse. */
                interface IEvaluateProcessorVersionResponse {

                    /** EvaluateProcessorVersionResponse evaluation */
                    evaluation?: (string|null);
                }

                /** Represents an EvaluateProcessorVersionResponse. */
                class EvaluateProcessorVersionResponse implements IEvaluateProcessorVersionResponse {

                    /**
                     * Constructs a new EvaluateProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionResponse);

                    /** EvaluateProcessorVersionResponse evaluation. */
                    public evaluation: string;

                    /**
                     * Creates a new EvaluateProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EvaluateProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionResponse): google.cloud.documentai.v1beta3.EvaluateProcessorVersionResponse;

                    /**
                     * Encodes the specified EvaluateProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.EvaluateProcessorVersionResponse.verify|verify} messages.
                     * @param message EvaluateProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EvaluateProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.EvaluateProcessorVersionResponse.verify|verify} messages.
                     * @param message EvaluateProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IEvaluateProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EvaluateProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EvaluateProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.EvaluateProcessorVersionResponse;

                    /**
                     * Decodes an EvaluateProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EvaluateProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.EvaluateProcessorVersionResponse;

                    /**
                     * Verifies an EvaluateProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EvaluateProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EvaluateProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.EvaluateProcessorVersionResponse;

                    /**
                     * Creates a plain object from an EvaluateProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message EvaluateProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.EvaluateProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EvaluateProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EvaluateProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetEvaluationRequest. */
                interface IGetEvaluationRequest {

                    /** GetEvaluationRequest name */
                    name?: (string|null);
                }

                /** Represents a GetEvaluationRequest. */
                class GetEvaluationRequest implements IGetEvaluationRequest {

                    /**
                     * Constructs a new GetEvaluationRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGetEvaluationRequest);

                    /** GetEvaluationRequest name. */
                    public name: string;

                    /**
                     * Creates a new GetEvaluationRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetEvaluationRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGetEvaluationRequest): google.cloud.documentai.v1beta3.GetEvaluationRequest;

                    /**
                     * Encodes the specified GetEvaluationRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.GetEvaluationRequest.verify|verify} messages.
                     * @param message GetEvaluationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGetEvaluationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetEvaluationRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GetEvaluationRequest.verify|verify} messages.
                     * @param message GetEvaluationRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGetEvaluationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetEvaluationRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetEvaluationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GetEvaluationRequest;

                    /**
                     * Decodes a GetEvaluationRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetEvaluationRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GetEvaluationRequest;

                    /**
                     * Verifies a GetEvaluationRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetEvaluationRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetEvaluationRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GetEvaluationRequest;

                    /**
                     * Creates a plain object from a GetEvaluationRequest message. Also converts values to other types if specified.
                     * @param message GetEvaluationRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GetEvaluationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetEvaluationRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetEvaluationRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListEvaluationsRequest. */
                interface IListEvaluationsRequest {

                    /** ListEvaluationsRequest parent */
                    parent?: (string|null);

                    /** ListEvaluationsRequest pageSize */
                    pageSize?: (number|null);

                    /** ListEvaluationsRequest pageToken */
                    pageToken?: (string|null);
                }

                /** Represents a ListEvaluationsRequest. */
                class ListEvaluationsRequest implements IListEvaluationsRequest {

                    /**
                     * Constructs a new ListEvaluationsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListEvaluationsRequest);

                    /** ListEvaluationsRequest parent. */
                    public parent: string;

                    /** ListEvaluationsRequest pageSize. */
                    public pageSize: number;

                    /** ListEvaluationsRequest pageToken. */
                    public pageToken: string;

                    /**
                     * Creates a new ListEvaluationsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListEvaluationsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListEvaluationsRequest): google.cloud.documentai.v1beta3.ListEvaluationsRequest;

                    /**
                     * Encodes the specified ListEvaluationsRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListEvaluationsRequest.verify|verify} messages.
                     * @param message ListEvaluationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListEvaluationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListEvaluationsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListEvaluationsRequest.verify|verify} messages.
                     * @param message ListEvaluationsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListEvaluationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListEvaluationsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListEvaluationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListEvaluationsRequest;

                    /**
                     * Decodes a ListEvaluationsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListEvaluationsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListEvaluationsRequest;

                    /**
                     * Verifies a ListEvaluationsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListEvaluationsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListEvaluationsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListEvaluationsRequest;

                    /**
                     * Creates a plain object from a ListEvaluationsRequest message. Also converts values to other types if specified.
                     * @param message ListEvaluationsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListEvaluationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListEvaluationsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListEvaluationsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListEvaluationsResponse. */
                interface IListEvaluationsResponse {

                    /** ListEvaluationsResponse evaluations */
                    evaluations?: (google.cloud.documentai.v1beta3.IEvaluation[]|null);

                    /** ListEvaluationsResponse nextPageToken */
                    nextPageToken?: (string|null);
                }

                /** Represents a ListEvaluationsResponse. */
                class ListEvaluationsResponse implements IListEvaluationsResponse {

                    /**
                     * Constructs a new ListEvaluationsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListEvaluationsResponse);

                    /** ListEvaluationsResponse evaluations. */
                    public evaluations: google.cloud.documentai.v1beta3.IEvaluation[];

                    /** ListEvaluationsResponse nextPageToken. */
                    public nextPageToken: string;

                    /**
                     * Creates a new ListEvaluationsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListEvaluationsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListEvaluationsResponse): google.cloud.documentai.v1beta3.ListEvaluationsResponse;

                    /**
                     * Encodes the specified ListEvaluationsResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListEvaluationsResponse.verify|verify} messages.
                     * @param message ListEvaluationsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListEvaluationsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListEvaluationsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListEvaluationsResponse.verify|verify} messages.
                     * @param message ListEvaluationsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListEvaluationsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListEvaluationsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListEvaluationsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListEvaluationsResponse;

                    /**
                     * Decodes a ListEvaluationsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListEvaluationsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListEvaluationsResponse;

                    /**
                     * Verifies a ListEvaluationsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListEvaluationsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListEvaluationsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListEvaluationsResponse;

                    /**
                     * Creates a plain object from a ListEvaluationsResponse message. Also converts values to other types if specified.
                     * @param message ListEvaluationsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListEvaluationsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListEvaluationsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListEvaluationsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ImportProcessorVersionRequest. */
                interface IImportProcessorVersionRequest {

                    /** ImportProcessorVersionRequest processorVersionSource */
                    processorVersionSource?: (string|null);

                    /** ImportProcessorVersionRequest externalProcessorVersionSource */
                    externalProcessorVersionSource?: (google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.IExternalProcessorVersionSource|null);

                    /** ImportProcessorVersionRequest parent */
                    parent?: (string|null);
                }

                /** Represents an ImportProcessorVersionRequest. */
                class ImportProcessorVersionRequest implements IImportProcessorVersionRequest {

                    /**
                     * Constructs a new ImportProcessorVersionRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IImportProcessorVersionRequest);

                    /** ImportProcessorVersionRequest processorVersionSource. */
                    public processorVersionSource?: (string|null);

                    /** ImportProcessorVersionRequest externalProcessorVersionSource. */
                    public externalProcessorVersionSource?: (google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.IExternalProcessorVersionSource|null);

                    /** ImportProcessorVersionRequest parent. */
                    public parent: string;

                    /** ImportProcessorVersionRequest source. */
                    public source?: ("processorVersionSource"|"externalProcessorVersionSource");

                    /**
                     * Creates a new ImportProcessorVersionRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ImportProcessorVersionRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IImportProcessorVersionRequest): google.cloud.documentai.v1beta3.ImportProcessorVersionRequest;

                    /**
                     * Encodes the specified ImportProcessorVersionRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.verify|verify} messages.
                     * @param message ImportProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IImportProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ImportProcessorVersionRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.verify|verify} messages.
                     * @param message ImportProcessorVersionRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IImportProcessorVersionRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ImportProcessorVersionRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ImportProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportProcessorVersionRequest;

                    /**
                     * Decodes an ImportProcessorVersionRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ImportProcessorVersionRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportProcessorVersionRequest;

                    /**
                     * Verifies an ImportProcessorVersionRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ImportProcessorVersionRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ImportProcessorVersionRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportProcessorVersionRequest;

                    /**
                     * Creates a plain object from an ImportProcessorVersionRequest message. Also converts values to other types if specified.
                     * @param message ImportProcessorVersionRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ImportProcessorVersionRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ImportProcessorVersionRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ImportProcessorVersionRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ImportProcessorVersionRequest {

                    /** Properties of an ExternalProcessorVersionSource. */
                    interface IExternalProcessorVersionSource {

                        /** ExternalProcessorVersionSource processorVersion */
                        processorVersion?: (string|null);

                        /** ExternalProcessorVersionSource serviceEndpoint */
                        serviceEndpoint?: (string|null);
                    }

                    /** Represents an ExternalProcessorVersionSource. */
                    class ExternalProcessorVersionSource implements IExternalProcessorVersionSource {

                        /**
                         * Constructs a new ExternalProcessorVersionSource.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.IExternalProcessorVersionSource);

                        /** ExternalProcessorVersionSource processorVersion. */
                        public processorVersion: string;

                        /** ExternalProcessorVersionSource serviceEndpoint. */
                        public serviceEndpoint: string;

                        /**
                         * Creates a new ExternalProcessorVersionSource instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ExternalProcessorVersionSource instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.IExternalProcessorVersionSource): google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.ExternalProcessorVersionSource;

                        /**
                         * Encodes the specified ExternalProcessorVersionSource message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.ExternalProcessorVersionSource.verify|verify} messages.
                         * @param message ExternalProcessorVersionSource message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.IExternalProcessorVersionSource, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ExternalProcessorVersionSource message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.ExternalProcessorVersionSource.verify|verify} messages.
                         * @param message ExternalProcessorVersionSource message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.IExternalProcessorVersionSource, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an ExternalProcessorVersionSource message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ExternalProcessorVersionSource
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.ExternalProcessorVersionSource;

                        /**
                         * Decodes an ExternalProcessorVersionSource message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ExternalProcessorVersionSource
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.ExternalProcessorVersionSource;

                        /**
                         * Verifies an ExternalProcessorVersionSource message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an ExternalProcessorVersionSource message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ExternalProcessorVersionSource
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.ExternalProcessorVersionSource;

                        /**
                         * Creates a plain object from an ExternalProcessorVersionSource message. Also converts values to other types if specified.
                         * @param message ExternalProcessorVersionSource
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.ImportProcessorVersionRequest.ExternalProcessorVersionSource, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ExternalProcessorVersionSource to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ExternalProcessorVersionSource
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of an ImportProcessorVersionResponse. */
                interface IImportProcessorVersionResponse {

                    /** ImportProcessorVersionResponse processorVersion */
                    processorVersion?: (string|null);
                }

                /** Represents an ImportProcessorVersionResponse. */
                class ImportProcessorVersionResponse implements IImportProcessorVersionResponse {

                    /**
                     * Constructs a new ImportProcessorVersionResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IImportProcessorVersionResponse);

                    /** ImportProcessorVersionResponse processorVersion. */
                    public processorVersion: string;

                    /**
                     * Creates a new ImportProcessorVersionResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ImportProcessorVersionResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IImportProcessorVersionResponse): google.cloud.documentai.v1beta3.ImportProcessorVersionResponse;

                    /**
                     * Encodes the specified ImportProcessorVersionResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportProcessorVersionResponse.verify|verify} messages.
                     * @param message ImportProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IImportProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ImportProcessorVersionResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportProcessorVersionResponse.verify|verify} messages.
                     * @param message ImportProcessorVersionResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IImportProcessorVersionResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ImportProcessorVersionResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ImportProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportProcessorVersionResponse;

                    /**
                     * Decodes an ImportProcessorVersionResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ImportProcessorVersionResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportProcessorVersionResponse;

                    /**
                     * Verifies an ImportProcessorVersionResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ImportProcessorVersionResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ImportProcessorVersionResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportProcessorVersionResponse;

                    /**
                     * Creates a plain object from an ImportProcessorVersionResponse message. Also converts values to other types if specified.
                     * @param message ImportProcessorVersionResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ImportProcessorVersionResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ImportProcessorVersionResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ImportProcessorVersionResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ImportProcessorVersionMetadata. */
                interface IImportProcessorVersionMetadata {

                    /** ImportProcessorVersionMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents an ImportProcessorVersionMetadata. */
                class ImportProcessorVersionMetadata implements IImportProcessorVersionMetadata {

                    /**
                     * Constructs a new ImportProcessorVersionMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IImportProcessorVersionMetadata);

                    /** ImportProcessorVersionMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new ImportProcessorVersionMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ImportProcessorVersionMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IImportProcessorVersionMetadata): google.cloud.documentai.v1beta3.ImportProcessorVersionMetadata;

                    /**
                     * Encodes the specified ImportProcessorVersionMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportProcessorVersionMetadata.verify|verify} messages.
                     * @param message ImportProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IImportProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ImportProcessorVersionMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportProcessorVersionMetadata.verify|verify} messages.
                     * @param message ImportProcessorVersionMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IImportProcessorVersionMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ImportProcessorVersionMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ImportProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportProcessorVersionMetadata;

                    /**
                     * Decodes an ImportProcessorVersionMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ImportProcessorVersionMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportProcessorVersionMetadata;

                    /**
                     * Verifies an ImportProcessorVersionMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ImportProcessorVersionMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ImportProcessorVersionMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportProcessorVersionMetadata;

                    /**
                     * Creates a plain object from an ImportProcessorVersionMetadata message. Also converts values to other types if specified.
                     * @param message ImportProcessorVersionMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ImportProcessorVersionMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ImportProcessorVersionMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ImportProcessorVersionMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an EvaluationReference. */
                interface IEvaluationReference {

                    /** EvaluationReference operation */
                    operation?: (string|null);

                    /** EvaluationReference evaluation */
                    evaluation?: (string|null);

                    /** EvaluationReference aggregateMetrics */
                    aggregateMetrics?: (google.cloud.documentai.v1beta3.Evaluation.IMetrics|null);

                    /** EvaluationReference aggregateMetricsExact */
                    aggregateMetricsExact?: (google.cloud.documentai.v1beta3.Evaluation.IMetrics|null);
                }

                /** Represents an EvaluationReference. */
                class EvaluationReference implements IEvaluationReference {

                    /**
                     * Constructs a new EvaluationReference.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IEvaluationReference);

                    /** EvaluationReference operation. */
                    public operation: string;

                    /** EvaluationReference evaluation. */
                    public evaluation: string;

                    /** EvaluationReference aggregateMetrics. */
                    public aggregateMetrics?: (google.cloud.documentai.v1beta3.Evaluation.IMetrics|null);

                    /** EvaluationReference aggregateMetricsExact. */
                    public aggregateMetricsExact?: (google.cloud.documentai.v1beta3.Evaluation.IMetrics|null);

                    /**
                     * Creates a new EvaluationReference instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns EvaluationReference instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IEvaluationReference): google.cloud.documentai.v1beta3.EvaluationReference;

                    /**
                     * Encodes the specified EvaluationReference message. Does not implicitly {@link google.cloud.documentai.v1beta3.EvaluationReference.verify|verify} messages.
                     * @param message EvaluationReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IEvaluationReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified EvaluationReference message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.EvaluationReference.verify|verify} messages.
                     * @param message EvaluationReference message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IEvaluationReference, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an EvaluationReference message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns EvaluationReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.EvaluationReference;

                    /**
                     * Decodes an EvaluationReference message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns EvaluationReference
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.EvaluationReference;

                    /**
                     * Verifies an EvaluationReference message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an EvaluationReference message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns EvaluationReference
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.EvaluationReference;

                    /**
                     * Creates a plain object from an EvaluationReference message. Also converts values to other types if specified.
                     * @param message EvaluationReference
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.EvaluationReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this EvaluationReference to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for EvaluationReference
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an Evaluation. */
                interface IEvaluation {

                    /** Evaluation name */
                    name?: (string|null);

                    /** Evaluation createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** Evaluation documentCounters */
                    documentCounters?: (google.cloud.documentai.v1beta3.Evaluation.ICounters|null);

                    /** Evaluation allEntitiesMetrics */
                    allEntitiesMetrics?: (google.cloud.documentai.v1beta3.Evaluation.IMultiConfidenceMetrics|null);

                    /** Evaluation entityMetrics */
                    entityMetrics?: ({ [k: string]: google.cloud.documentai.v1beta3.Evaluation.IMultiConfidenceMetrics }|null);

                    /** Evaluation kmsKeyName */
                    kmsKeyName?: (string|null);

                    /** Evaluation kmsKeyVersionName */
                    kmsKeyVersionName?: (string|null);
                }

                /** Represents an Evaluation. */
                class Evaluation implements IEvaluation {

                    /**
                     * Constructs a new Evaluation.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IEvaluation);

                    /** Evaluation name. */
                    public name: string;

                    /** Evaluation createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** Evaluation documentCounters. */
                    public documentCounters?: (google.cloud.documentai.v1beta3.Evaluation.ICounters|null);

                    /** Evaluation allEntitiesMetrics. */
                    public allEntitiesMetrics?: (google.cloud.documentai.v1beta3.Evaluation.IMultiConfidenceMetrics|null);

                    /** Evaluation entityMetrics. */
                    public entityMetrics: { [k: string]: google.cloud.documentai.v1beta3.Evaluation.IMultiConfidenceMetrics };

                    /** Evaluation kmsKeyName. */
                    public kmsKeyName: string;

                    /** Evaluation kmsKeyVersionName. */
                    public kmsKeyVersionName: string;

                    /**
                     * Creates a new Evaluation instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Evaluation instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IEvaluation): google.cloud.documentai.v1beta3.Evaluation;

                    /**
                     * Encodes the specified Evaluation message. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.verify|verify} messages.
                     * @param message Evaluation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IEvaluation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Evaluation message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.verify|verify} messages.
                     * @param message Evaluation message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IEvaluation, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an Evaluation message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Evaluation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Evaluation;

                    /**
                     * Decodes an Evaluation message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Evaluation
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Evaluation;

                    /**
                     * Verifies an Evaluation message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an Evaluation message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Evaluation
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Evaluation;

                    /**
                     * Creates a plain object from an Evaluation message. Also converts values to other types if specified.
                     * @param message Evaluation
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.Evaluation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Evaluation to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Evaluation
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Evaluation {

                    /** Properties of a Counters. */
                    interface ICounters {

                        /** Counters inputDocumentsCount */
                        inputDocumentsCount?: (number|null);

                        /** Counters invalidDocumentsCount */
                        invalidDocumentsCount?: (number|null);

                        /** Counters failedDocumentsCount */
                        failedDocumentsCount?: (number|null);

                        /** Counters evaluatedDocumentsCount */
                        evaluatedDocumentsCount?: (number|null);
                    }

                    /** Represents a Counters. */
                    class Counters implements ICounters {

                        /**
                         * Constructs a new Counters.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Evaluation.ICounters);

                        /** Counters inputDocumentsCount. */
                        public inputDocumentsCount: number;

                        /** Counters invalidDocumentsCount. */
                        public invalidDocumentsCount: number;

                        /** Counters failedDocumentsCount. */
                        public failedDocumentsCount: number;

                        /** Counters evaluatedDocumentsCount. */
                        public evaluatedDocumentsCount: number;

                        /**
                         * Creates a new Counters instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Counters instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Evaluation.ICounters): google.cloud.documentai.v1beta3.Evaluation.Counters;

                        /**
                         * Encodes the specified Counters message. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.Counters.verify|verify} messages.
                         * @param message Counters message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Evaluation.ICounters, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Counters message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.Counters.verify|verify} messages.
                         * @param message Counters message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Evaluation.ICounters, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Counters message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Counters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Evaluation.Counters;

                        /**
                         * Decodes a Counters message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Counters
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Evaluation.Counters;

                        /**
                         * Verifies a Counters message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Counters message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Counters
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Evaluation.Counters;

                        /**
                         * Creates a plain object from a Counters message. Also converts values to other types if specified.
                         * @param message Counters
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Evaluation.Counters, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Counters to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Counters
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a Metrics. */
                    interface IMetrics {

                        /** Metrics precision */
                        precision?: (number|null);

                        /** Metrics recall */
                        recall?: (number|null);

                        /** Metrics f1Score */
                        f1Score?: (number|null);

                        /** Metrics predictedOccurrencesCount */
                        predictedOccurrencesCount?: (number|null);

                        /** Metrics groundTruthOccurrencesCount */
                        groundTruthOccurrencesCount?: (number|null);

                        /** Metrics predictedDocumentCount */
                        predictedDocumentCount?: (number|null);

                        /** Metrics groundTruthDocumentCount */
                        groundTruthDocumentCount?: (number|null);

                        /** Metrics truePositivesCount */
                        truePositivesCount?: (number|null);

                        /** Metrics falsePositivesCount */
                        falsePositivesCount?: (number|null);

                        /** Metrics falseNegativesCount */
                        falseNegativesCount?: (number|null);

                        /** Metrics totalDocumentsCount */
                        totalDocumentsCount?: (number|null);
                    }

                    /** Represents a Metrics. */
                    class Metrics implements IMetrics {

                        /**
                         * Constructs a new Metrics.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Evaluation.IMetrics);

                        /** Metrics precision. */
                        public precision: number;

                        /** Metrics recall. */
                        public recall: number;

                        /** Metrics f1Score. */
                        public f1Score: number;

                        /** Metrics predictedOccurrencesCount. */
                        public predictedOccurrencesCount: number;

                        /** Metrics groundTruthOccurrencesCount. */
                        public groundTruthOccurrencesCount: number;

                        /** Metrics predictedDocumentCount. */
                        public predictedDocumentCount: number;

                        /** Metrics groundTruthDocumentCount. */
                        public groundTruthDocumentCount: number;

                        /** Metrics truePositivesCount. */
                        public truePositivesCount: number;

                        /** Metrics falsePositivesCount. */
                        public falsePositivesCount: number;

                        /** Metrics falseNegativesCount. */
                        public falseNegativesCount: number;

                        /** Metrics totalDocumentsCount. */
                        public totalDocumentsCount: number;

                        /**
                         * Creates a new Metrics instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns Metrics instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Evaluation.IMetrics): google.cloud.documentai.v1beta3.Evaluation.Metrics;

                        /**
                         * Encodes the specified Metrics message. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.Metrics.verify|verify} messages.
                         * @param message Metrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Evaluation.IMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified Metrics message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.Metrics.verify|verify} messages.
                         * @param message Metrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Evaluation.IMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a Metrics message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns Metrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Evaluation.Metrics;

                        /**
                         * Decodes a Metrics message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns Metrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Evaluation.Metrics;

                        /**
                         * Verifies a Metrics message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a Metrics message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns Metrics
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Evaluation.Metrics;

                        /**
                         * Creates a plain object from a Metrics message. Also converts values to other types if specified.
                         * @param message Metrics
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Evaluation.Metrics, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this Metrics to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for Metrics
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a ConfidenceLevelMetrics. */
                    interface IConfidenceLevelMetrics {

                        /** ConfidenceLevelMetrics confidenceLevel */
                        confidenceLevel?: (number|null);

                        /** ConfidenceLevelMetrics metrics */
                        metrics?: (google.cloud.documentai.v1beta3.Evaluation.IMetrics|null);
                    }

                    /** Represents a ConfidenceLevelMetrics. */
                    class ConfidenceLevelMetrics implements IConfidenceLevelMetrics {

                        /**
                         * Constructs a new ConfidenceLevelMetrics.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Evaluation.IConfidenceLevelMetrics);

                        /** ConfidenceLevelMetrics confidenceLevel. */
                        public confidenceLevel: number;

                        /** ConfidenceLevelMetrics metrics. */
                        public metrics?: (google.cloud.documentai.v1beta3.Evaluation.IMetrics|null);

                        /**
                         * Creates a new ConfidenceLevelMetrics instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ConfidenceLevelMetrics instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Evaluation.IConfidenceLevelMetrics): google.cloud.documentai.v1beta3.Evaluation.ConfidenceLevelMetrics;

                        /**
                         * Encodes the specified ConfidenceLevelMetrics message. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.ConfidenceLevelMetrics.verify|verify} messages.
                         * @param message ConfidenceLevelMetrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Evaluation.IConfidenceLevelMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ConfidenceLevelMetrics message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.ConfidenceLevelMetrics.verify|verify} messages.
                         * @param message ConfidenceLevelMetrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Evaluation.IConfidenceLevelMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a ConfidenceLevelMetrics message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ConfidenceLevelMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Evaluation.ConfidenceLevelMetrics;

                        /**
                         * Decodes a ConfidenceLevelMetrics message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ConfidenceLevelMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Evaluation.ConfidenceLevelMetrics;

                        /**
                         * Verifies a ConfidenceLevelMetrics message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a ConfidenceLevelMetrics message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ConfidenceLevelMetrics
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Evaluation.ConfidenceLevelMetrics;

                        /**
                         * Creates a plain object from a ConfidenceLevelMetrics message. Also converts values to other types if specified.
                         * @param message ConfidenceLevelMetrics
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Evaluation.ConfidenceLevelMetrics, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ConfidenceLevelMetrics to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ConfidenceLevelMetrics
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a MultiConfidenceMetrics. */
                    interface IMultiConfidenceMetrics {

                        /** MultiConfidenceMetrics confidenceLevelMetrics */
                        confidenceLevelMetrics?: (google.cloud.documentai.v1beta3.Evaluation.IConfidenceLevelMetrics[]|null);

                        /** MultiConfidenceMetrics confidenceLevelMetricsExact */
                        confidenceLevelMetricsExact?: (google.cloud.documentai.v1beta3.Evaluation.IConfidenceLevelMetrics[]|null);

                        /** MultiConfidenceMetrics auprc */
                        auprc?: (number|null);

                        /** MultiConfidenceMetrics estimatedCalibrationError */
                        estimatedCalibrationError?: (number|null);

                        /** MultiConfidenceMetrics auprcExact */
                        auprcExact?: (number|null);

                        /** MultiConfidenceMetrics estimatedCalibrationErrorExact */
                        estimatedCalibrationErrorExact?: (number|null);

                        /** MultiConfidenceMetrics metricsType */
                        metricsType?: (google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics.MetricsType|keyof typeof google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics.MetricsType|null);
                    }

                    /** Represents a MultiConfidenceMetrics. */
                    class MultiConfidenceMetrics implements IMultiConfidenceMetrics {

                        /**
                         * Constructs a new MultiConfidenceMetrics.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.Evaluation.IMultiConfidenceMetrics);

                        /** MultiConfidenceMetrics confidenceLevelMetrics. */
                        public confidenceLevelMetrics: google.cloud.documentai.v1beta3.Evaluation.IConfidenceLevelMetrics[];

                        /** MultiConfidenceMetrics confidenceLevelMetricsExact. */
                        public confidenceLevelMetricsExact: google.cloud.documentai.v1beta3.Evaluation.IConfidenceLevelMetrics[];

                        /** MultiConfidenceMetrics auprc. */
                        public auprc: number;

                        /** MultiConfidenceMetrics estimatedCalibrationError. */
                        public estimatedCalibrationError: number;

                        /** MultiConfidenceMetrics auprcExact. */
                        public auprcExact: number;

                        /** MultiConfidenceMetrics estimatedCalibrationErrorExact. */
                        public estimatedCalibrationErrorExact: number;

                        /** MultiConfidenceMetrics metricsType. */
                        public metricsType: (google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics.MetricsType|keyof typeof google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics.MetricsType);

                        /**
                         * Creates a new MultiConfidenceMetrics instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns MultiConfidenceMetrics instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.Evaluation.IMultiConfidenceMetrics): google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics;

                        /**
                         * Encodes the specified MultiConfidenceMetrics message. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics.verify|verify} messages.
                         * @param message MultiConfidenceMetrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.Evaluation.IMultiConfidenceMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified MultiConfidenceMetrics message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics.verify|verify} messages.
                         * @param message MultiConfidenceMetrics message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.Evaluation.IMultiConfidenceMetrics, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a MultiConfidenceMetrics message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns MultiConfidenceMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics;

                        /**
                         * Decodes a MultiConfidenceMetrics message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns MultiConfidenceMetrics
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics;

                        /**
                         * Verifies a MultiConfidenceMetrics message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a MultiConfidenceMetrics message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns MultiConfidenceMetrics
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics;

                        /**
                         * Creates a plain object from a MultiConfidenceMetrics message. Also converts values to other types if specified.
                         * @param message MultiConfidenceMetrics
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.Evaluation.MultiConfidenceMetrics, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this MultiConfidenceMetrics to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for MultiConfidenceMetrics
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace MultiConfidenceMetrics {

                        /** MetricsType enum. */
                        enum MetricsType {
                            METRICS_TYPE_UNSPECIFIED = 0,
                            AGGREGATE = 1
                        }
                    }
                }

                /** Properties of a CommonOperationMetadata. */
                interface ICommonOperationMetadata {

                    /** CommonOperationMetadata state */
                    state?: (google.cloud.documentai.v1beta3.CommonOperationMetadata.State|keyof typeof google.cloud.documentai.v1beta3.CommonOperationMetadata.State|null);

                    /** CommonOperationMetadata stateMessage */
                    stateMessage?: (string|null);

                    /** CommonOperationMetadata resource */
                    resource?: (string|null);

                    /** CommonOperationMetadata createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** CommonOperationMetadata updateTime */
                    updateTime?: (google.protobuf.ITimestamp|null);
                }

                /** Represents a CommonOperationMetadata. */
                class CommonOperationMetadata implements ICommonOperationMetadata {

                    /**
                     * Constructs a new CommonOperationMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.ICommonOperationMetadata);

                    /** CommonOperationMetadata state. */
                    public state: (google.cloud.documentai.v1beta3.CommonOperationMetadata.State|keyof typeof google.cloud.documentai.v1beta3.CommonOperationMetadata.State);

                    /** CommonOperationMetadata stateMessage. */
                    public stateMessage: string;

                    /** CommonOperationMetadata resource. */
                    public resource: string;

                    /** CommonOperationMetadata createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** CommonOperationMetadata updateTime. */
                    public updateTime?: (google.protobuf.ITimestamp|null);

                    /**
                     * Creates a new CommonOperationMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns CommonOperationMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.ICommonOperationMetadata): google.cloud.documentai.v1beta3.CommonOperationMetadata;

                    /**
                     * Encodes the specified CommonOperationMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.CommonOperationMetadata.verify|verify} messages.
                     * @param message CommonOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.ICommonOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified CommonOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.CommonOperationMetadata.verify|verify} messages.
                     * @param message CommonOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.ICommonOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a CommonOperationMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns CommonOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.CommonOperationMetadata;

                    /**
                     * Decodes a CommonOperationMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns CommonOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.CommonOperationMetadata;

                    /**
                     * Verifies a CommonOperationMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a CommonOperationMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns CommonOperationMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.CommonOperationMetadata;

                    /**
                     * Creates a plain object from a CommonOperationMetadata message. Also converts values to other types if specified.
                     * @param message CommonOperationMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.CommonOperationMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this CommonOperationMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for CommonOperationMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace CommonOperationMetadata {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        RUNNING = 1,
                        CANCELLING = 2,
                        SUCCEEDED = 3,
                        FAILED = 4,
                        CANCELLED = 5
                    }
                }

                /** Properties of a ProcessorVersion. */
                interface IProcessorVersion {

                    /** ProcessorVersion name */
                    name?: (string|null);

                    /** ProcessorVersion displayName */
                    displayName?: (string|null);

                    /** ProcessorVersion documentSchema */
                    documentSchema?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);

                    /** ProcessorVersion state */
                    state?: (google.cloud.documentai.v1beta3.ProcessorVersion.State|keyof typeof google.cloud.documentai.v1beta3.ProcessorVersion.State|null);

                    /** ProcessorVersion createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** ProcessorVersion latestEvaluation */
                    latestEvaluation?: (google.cloud.documentai.v1beta3.IEvaluationReference|null);

                    /** ProcessorVersion kmsKeyName */
                    kmsKeyName?: (string|null);

                    /** ProcessorVersion kmsKeyVersionName */
                    kmsKeyVersionName?: (string|null);

                    /** ProcessorVersion googleManaged */
                    googleManaged?: (boolean|null);

                    /** ProcessorVersion deprecationInfo */
                    deprecationInfo?: (google.cloud.documentai.v1beta3.ProcessorVersion.IDeprecationInfo|null);

                    /** ProcessorVersion modelType */
                    modelType?: (google.cloud.documentai.v1beta3.ProcessorVersion.ModelType|keyof typeof google.cloud.documentai.v1beta3.ProcessorVersion.ModelType|null);

                    /** ProcessorVersion satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** ProcessorVersion satisfiesPzi */
                    satisfiesPzi?: (boolean|null);

                    /** ProcessorVersion genAiModelInfo */
                    genAiModelInfo?: (google.cloud.documentai.v1beta3.ProcessorVersion.IGenAiModelInfo|null);
                }

                /** Represents a ProcessorVersion. */
                class ProcessorVersion implements IProcessorVersion {

                    /**
                     * Constructs a new ProcessorVersion.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IProcessorVersion);

                    /** ProcessorVersion name. */
                    public name: string;

                    /** ProcessorVersion displayName. */
                    public displayName: string;

                    /** ProcessorVersion documentSchema. */
                    public documentSchema?: (google.cloud.documentai.v1beta3.IDocumentSchema|null);

                    /** ProcessorVersion state. */
                    public state: (google.cloud.documentai.v1beta3.ProcessorVersion.State|keyof typeof google.cloud.documentai.v1beta3.ProcessorVersion.State);

                    /** ProcessorVersion createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** ProcessorVersion latestEvaluation. */
                    public latestEvaluation?: (google.cloud.documentai.v1beta3.IEvaluationReference|null);

                    /** ProcessorVersion kmsKeyName. */
                    public kmsKeyName: string;

                    /** ProcessorVersion kmsKeyVersionName. */
                    public kmsKeyVersionName: string;

                    /** ProcessorVersion googleManaged. */
                    public googleManaged: boolean;

                    /** ProcessorVersion deprecationInfo. */
                    public deprecationInfo?: (google.cloud.documentai.v1beta3.ProcessorVersion.IDeprecationInfo|null);

                    /** ProcessorVersion modelType. */
                    public modelType: (google.cloud.documentai.v1beta3.ProcessorVersion.ModelType|keyof typeof google.cloud.documentai.v1beta3.ProcessorVersion.ModelType);

                    /** ProcessorVersion satisfiesPzs. */
                    public satisfiesPzs: boolean;

                    /** ProcessorVersion satisfiesPzi. */
                    public satisfiesPzi: boolean;

                    /** ProcessorVersion genAiModelInfo. */
                    public genAiModelInfo?: (google.cloud.documentai.v1beta3.ProcessorVersion.IGenAiModelInfo|null);

                    /**
                     * Creates a new ProcessorVersion instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessorVersion instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IProcessorVersion): google.cloud.documentai.v1beta3.ProcessorVersion;

                    /**
                     * Encodes the specified ProcessorVersion message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.verify|verify} messages.
                     * @param message ProcessorVersion message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IProcessorVersion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessorVersion message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.verify|verify} messages.
                     * @param message ProcessorVersion message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IProcessorVersion, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessorVersion message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessorVersion
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessorVersion;

                    /**
                     * Decodes a ProcessorVersion message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessorVersion
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessorVersion;

                    /**
                     * Verifies a ProcessorVersion message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessorVersion message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessorVersion
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessorVersion;

                    /**
                     * Creates a plain object from a ProcessorVersion message. Also converts values to other types if specified.
                     * @param message ProcessorVersion
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ProcessorVersion, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessorVersion to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessorVersion
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ProcessorVersion {

                    /** Properties of a DeprecationInfo. */
                    interface IDeprecationInfo {

                        /** DeprecationInfo deprecationTime */
                        deprecationTime?: (google.protobuf.ITimestamp|null);

                        /** DeprecationInfo replacementProcessorVersion */
                        replacementProcessorVersion?: (string|null);
                    }

                    /** Represents a DeprecationInfo. */
                    class DeprecationInfo implements IDeprecationInfo {

                        /**
                         * Constructs a new DeprecationInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.ProcessorVersion.IDeprecationInfo);

                        /** DeprecationInfo deprecationTime. */
                        public deprecationTime?: (google.protobuf.ITimestamp|null);

                        /** DeprecationInfo replacementProcessorVersion. */
                        public replacementProcessorVersion: string;

                        /**
                         * Creates a new DeprecationInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns DeprecationInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.ProcessorVersion.IDeprecationInfo): google.cloud.documentai.v1beta3.ProcessorVersion.DeprecationInfo;

                        /**
                         * Encodes the specified DeprecationInfo message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.DeprecationInfo.verify|verify} messages.
                         * @param message DeprecationInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.ProcessorVersion.IDeprecationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified DeprecationInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.DeprecationInfo.verify|verify} messages.
                         * @param message DeprecationInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.ProcessorVersion.IDeprecationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a DeprecationInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns DeprecationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessorVersion.DeprecationInfo;

                        /**
                         * Decodes a DeprecationInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns DeprecationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessorVersion.DeprecationInfo;

                        /**
                         * Verifies a DeprecationInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a DeprecationInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns DeprecationInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessorVersion.DeprecationInfo;

                        /**
                         * Creates a plain object from a DeprecationInfo message. Also converts values to other types if specified.
                         * @param message DeprecationInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.ProcessorVersion.DeprecationInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this DeprecationInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for DeprecationInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of a GenAiModelInfo. */
                    interface IGenAiModelInfo {

                        /** GenAiModelInfo foundationGenAiModelInfo */
                        foundationGenAiModelInfo?: (google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo|null);

                        /** GenAiModelInfo customGenAiModelInfo */
                        customGenAiModelInfo?: (google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo|null);
                    }

                    /** Represents a GenAiModelInfo. */
                    class GenAiModelInfo implements IGenAiModelInfo {

                        /**
                         * Constructs a new GenAiModelInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.ProcessorVersion.IGenAiModelInfo);

                        /** GenAiModelInfo foundationGenAiModelInfo. */
                        public foundationGenAiModelInfo?: (google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo|null);

                        /** GenAiModelInfo customGenAiModelInfo. */
                        public customGenAiModelInfo?: (google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo|null);

                        /** GenAiModelInfo modelInfo. */
                        public modelInfo?: ("foundationGenAiModelInfo"|"customGenAiModelInfo");

                        /**
                         * Creates a new GenAiModelInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns GenAiModelInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.ProcessorVersion.IGenAiModelInfo): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo;

                        /**
                         * Encodes the specified GenAiModelInfo message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.verify|verify} messages.
                         * @param message GenAiModelInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.ProcessorVersion.IGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified GenAiModelInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.verify|verify} messages.
                         * @param message GenAiModelInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.ProcessorVersion.IGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a GenAiModelInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns GenAiModelInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo;

                        /**
                         * Decodes a GenAiModelInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns GenAiModelInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo;

                        /**
                         * Verifies a GenAiModelInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a GenAiModelInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns GenAiModelInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo;

                        /**
                         * Creates a plain object from a GenAiModelInfo message. Also converts values to other types if specified.
                         * @param message GenAiModelInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this GenAiModelInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for GenAiModelInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace GenAiModelInfo {

                        /** Properties of a FoundationGenAiModelInfo. */
                        interface IFoundationGenAiModelInfo {

                            /** FoundationGenAiModelInfo finetuningAllowed */
                            finetuningAllowed?: (boolean|null);

                            /** FoundationGenAiModelInfo minTrainLabeledDocuments */
                            minTrainLabeledDocuments?: (number|null);
                        }

                        /** Represents a FoundationGenAiModelInfo. */
                        class FoundationGenAiModelInfo implements IFoundationGenAiModelInfo {

                            /**
                             * Constructs a new FoundationGenAiModelInfo.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo);

                            /** FoundationGenAiModelInfo finetuningAllowed. */
                            public finetuningAllowed: boolean;

                            /** FoundationGenAiModelInfo minTrainLabeledDocuments. */
                            public minTrainLabeledDocuments: number;

                            /**
                             * Creates a new FoundationGenAiModelInfo instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns FoundationGenAiModelInfo instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo;

                            /**
                             * Encodes the specified FoundationGenAiModelInfo message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo.verify|verify} messages.
                             * @param message FoundationGenAiModelInfo message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified FoundationGenAiModelInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo.verify|verify} messages.
                             * @param message FoundationGenAiModelInfo message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.IFoundationGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a FoundationGenAiModelInfo message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns FoundationGenAiModelInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo;

                            /**
                             * Decodes a FoundationGenAiModelInfo message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns FoundationGenAiModelInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo;

                            /**
                             * Verifies a FoundationGenAiModelInfo message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a FoundationGenAiModelInfo message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns FoundationGenAiModelInfo
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo;

                            /**
                             * Creates a plain object from a FoundationGenAiModelInfo message. Also converts values to other types if specified.
                             * @param message FoundationGenAiModelInfo
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.FoundationGenAiModelInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this FoundationGenAiModelInfo to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for FoundationGenAiModelInfo
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        /** Properties of a CustomGenAiModelInfo. */
                        interface ICustomGenAiModelInfo {

                            /** CustomGenAiModelInfo customModelType */
                            customModelType?: (google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.CustomModelType|keyof typeof google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.CustomModelType|null);

                            /** CustomGenAiModelInfo baseProcessorVersionId */
                            baseProcessorVersionId?: (string|null);
                        }

                        /** Represents a CustomGenAiModelInfo. */
                        class CustomGenAiModelInfo implements ICustomGenAiModelInfo {

                            /**
                             * Constructs a new CustomGenAiModelInfo.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo);

                            /** CustomGenAiModelInfo customModelType. */
                            public customModelType: (google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.CustomModelType|keyof typeof google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.CustomModelType);

                            /** CustomGenAiModelInfo baseProcessorVersionId. */
                            public baseProcessorVersionId: string;

                            /**
                             * Creates a new CustomGenAiModelInfo instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns CustomGenAiModelInfo instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo;

                            /**
                             * Encodes the specified CustomGenAiModelInfo message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.verify|verify} messages.
                             * @param message CustomGenAiModelInfo message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified CustomGenAiModelInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo.verify|verify} messages.
                             * @param message CustomGenAiModelInfo message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.ICustomGenAiModelInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes a CustomGenAiModelInfo message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns CustomGenAiModelInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo;

                            /**
                             * Decodes a CustomGenAiModelInfo message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns CustomGenAiModelInfo
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo;

                            /**
                             * Verifies a CustomGenAiModelInfo message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates a CustomGenAiModelInfo message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns CustomGenAiModelInfo
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo;

                            /**
                             * Creates a plain object from a CustomGenAiModelInfo message. Also converts values to other types if specified.
                             * @param message CustomGenAiModelInfo
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.ProcessorVersion.GenAiModelInfo.CustomGenAiModelInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this CustomGenAiModelInfo to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for CustomGenAiModelInfo
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }

                        namespace CustomGenAiModelInfo {

                            /** CustomModelType enum. */
                            enum CustomModelType {
                                CUSTOM_MODEL_TYPE_UNSPECIFIED = 0,
                                VERSIONED_FOUNDATION = 1,
                                FINE_TUNED = 2
                            }
                        }
                    }

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        DEPLOYED = 1,
                        DEPLOYING = 2,
                        UNDEPLOYED = 3,
                        UNDEPLOYING = 4,
                        CREATING = 5,
                        DELETING = 6,
                        FAILED = 7,
                        IMPORTING = 8
                    }

                    /** ModelType enum. */
                    enum ModelType {
                        MODEL_TYPE_UNSPECIFIED = 0,
                        MODEL_TYPE_GENERATIVE = 1,
                        MODEL_TYPE_CUSTOM = 2
                    }
                }

                /** Properties of a ProcessorVersionAlias. */
                interface IProcessorVersionAlias {

                    /** ProcessorVersionAlias alias */
                    alias?: (string|null);

                    /** ProcessorVersionAlias processorVersion */
                    processorVersion?: (string|null);
                }

                /** Represents a ProcessorVersionAlias. */
                class ProcessorVersionAlias implements IProcessorVersionAlias {

                    /**
                     * Constructs a new ProcessorVersionAlias.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IProcessorVersionAlias);

                    /** ProcessorVersionAlias alias. */
                    public alias: string;

                    /** ProcessorVersionAlias processorVersion. */
                    public processorVersion: string;

                    /**
                     * Creates a new ProcessorVersionAlias instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessorVersionAlias instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IProcessorVersionAlias): google.cloud.documentai.v1beta3.ProcessorVersionAlias;

                    /**
                     * Encodes the specified ProcessorVersionAlias message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersionAlias.verify|verify} messages.
                     * @param message ProcessorVersionAlias message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IProcessorVersionAlias, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessorVersionAlias message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorVersionAlias.verify|verify} messages.
                     * @param message ProcessorVersionAlias message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IProcessorVersionAlias, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessorVersionAlias message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessorVersionAlias
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessorVersionAlias;

                    /**
                     * Decodes a ProcessorVersionAlias message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessorVersionAlias
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessorVersionAlias;

                    /**
                     * Verifies a ProcessorVersionAlias message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessorVersionAlias message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessorVersionAlias
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessorVersionAlias;

                    /**
                     * Creates a plain object from a ProcessorVersionAlias message. Also converts values to other types if specified.
                     * @param message ProcessorVersionAlias
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ProcessorVersionAlias, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessorVersionAlias to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessorVersionAlias
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a Processor. */
                interface IProcessor {

                    /** Processor name */
                    name?: (string|null);

                    /** Processor type */
                    type?: (string|null);

                    /** Processor displayName */
                    displayName?: (string|null);

                    /** Processor state */
                    state?: (google.cloud.documentai.v1beta3.Processor.State|keyof typeof google.cloud.documentai.v1beta3.Processor.State|null);

                    /** Processor defaultProcessorVersion */
                    defaultProcessorVersion?: (string|null);

                    /** Processor processorVersionAliases */
                    processorVersionAliases?: (google.cloud.documentai.v1beta3.IProcessorVersionAlias[]|null);

                    /** Processor processEndpoint */
                    processEndpoint?: (string|null);

                    /** Processor createTime */
                    createTime?: (google.protobuf.ITimestamp|null);

                    /** Processor kmsKeyName */
                    kmsKeyName?: (string|null);

                    /** Processor satisfiesPzs */
                    satisfiesPzs?: (boolean|null);

                    /** Processor satisfiesPzi */
                    satisfiesPzi?: (boolean|null);
                }

                /** Represents a Processor. */
                class Processor implements IProcessor {

                    /**
                     * Constructs a new Processor.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IProcessor);

                    /** Processor name. */
                    public name: string;

                    /** Processor type. */
                    public type: string;

                    /** Processor displayName. */
                    public displayName: string;

                    /** Processor state. */
                    public state: (google.cloud.documentai.v1beta3.Processor.State|keyof typeof google.cloud.documentai.v1beta3.Processor.State);

                    /** Processor defaultProcessorVersion. */
                    public defaultProcessorVersion: string;

                    /** Processor processorVersionAliases. */
                    public processorVersionAliases: google.cloud.documentai.v1beta3.IProcessorVersionAlias[];

                    /** Processor processEndpoint. */
                    public processEndpoint: string;

                    /** Processor createTime. */
                    public createTime?: (google.protobuf.ITimestamp|null);

                    /** Processor kmsKeyName. */
                    public kmsKeyName: string;

                    /** Processor satisfiesPzs. */
                    public satisfiesPzs: boolean;

                    /** Processor satisfiesPzi. */
                    public satisfiesPzi: boolean;

                    /**
                     * Creates a new Processor instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns Processor instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IProcessor): google.cloud.documentai.v1beta3.Processor;

                    /**
                     * Encodes the specified Processor message. Does not implicitly {@link google.cloud.documentai.v1beta3.Processor.verify|verify} messages.
                     * @param message Processor message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IProcessor, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified Processor message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.Processor.verify|verify} messages.
                     * @param message Processor message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IProcessor, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a Processor message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns Processor
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.Processor;

                    /**
                     * Decodes a Processor message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns Processor
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.Processor;

                    /**
                     * Verifies a Processor message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a Processor message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns Processor
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.Processor;

                    /**
                     * Creates a plain object from a Processor message. Also converts values to other types if specified.
                     * @param message Processor
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.Processor, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this Processor to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for Processor
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace Processor {

                    /** State enum. */
                    enum State {
                        STATE_UNSPECIFIED = 0,
                        ENABLED = 1,
                        DISABLED = 2,
                        ENABLING = 3,
                        DISABLING = 4,
                        CREATING = 5,
                        FAILED = 6,
                        DELETING = 7
                    }
                }

                /** Properties of a ProcessorType. */
                interface IProcessorType {

                    /** ProcessorType name */
                    name?: (string|null);

                    /** ProcessorType type */
                    type?: (string|null);

                    /** ProcessorType category */
                    category?: (string|null);

                    /** ProcessorType availableLocations */
                    availableLocations?: (google.cloud.documentai.v1beta3.ProcessorType.ILocationInfo[]|null);

                    /** ProcessorType allowCreation */
                    allowCreation?: (boolean|null);

                    /** ProcessorType launchStage */
                    launchStage?: (google.api.LaunchStage|keyof typeof google.api.LaunchStage|null);

                    /** ProcessorType sampleDocumentUris */
                    sampleDocumentUris?: (string[]|null);
                }

                /** Represents a ProcessorType. */
                class ProcessorType implements IProcessorType {

                    /**
                     * Constructs a new ProcessorType.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IProcessorType);

                    /** ProcessorType name. */
                    public name: string;

                    /** ProcessorType type. */
                    public type: string;

                    /** ProcessorType category. */
                    public category: string;

                    /** ProcessorType availableLocations. */
                    public availableLocations: google.cloud.documentai.v1beta3.ProcessorType.ILocationInfo[];

                    /** ProcessorType allowCreation. */
                    public allowCreation: boolean;

                    /** ProcessorType launchStage. */
                    public launchStage: (google.api.LaunchStage|keyof typeof google.api.LaunchStage);

                    /** ProcessorType sampleDocumentUris. */
                    public sampleDocumentUris: string[];

                    /**
                     * Creates a new ProcessorType instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ProcessorType instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IProcessorType): google.cloud.documentai.v1beta3.ProcessorType;

                    /**
                     * Encodes the specified ProcessorType message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorType.verify|verify} messages.
                     * @param message ProcessorType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IProcessorType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ProcessorType message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorType.verify|verify} messages.
                     * @param message ProcessorType message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IProcessorType, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ProcessorType message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ProcessorType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessorType;

                    /**
                     * Decodes a ProcessorType message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ProcessorType
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessorType;

                    /**
                     * Verifies a ProcessorType message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ProcessorType message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ProcessorType
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessorType;

                    /**
                     * Creates a plain object from a ProcessorType message. Also converts values to other types if specified.
                     * @param message ProcessorType
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ProcessorType, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ProcessorType to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ProcessorType
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ProcessorType {

                    /** Properties of a LocationInfo. */
                    interface ILocationInfo {

                        /** LocationInfo locationId */
                        locationId?: (string|null);
                    }

                    /** Represents a LocationInfo. */
                    class LocationInfo implements ILocationInfo {

                        /**
                         * Constructs a new LocationInfo.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.ProcessorType.ILocationInfo);

                        /** LocationInfo locationId. */
                        public locationId: string;

                        /**
                         * Creates a new LocationInfo instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns LocationInfo instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.ProcessorType.ILocationInfo): google.cloud.documentai.v1beta3.ProcessorType.LocationInfo;

                        /**
                         * Encodes the specified LocationInfo message. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorType.LocationInfo.verify|verify} messages.
                         * @param message LocationInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.ProcessorType.ILocationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified LocationInfo message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ProcessorType.LocationInfo.verify|verify} messages.
                         * @param message LocationInfo message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.ProcessorType.ILocationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a LocationInfo message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns LocationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ProcessorType.LocationInfo;

                        /**
                         * Decodes a LocationInfo message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns LocationInfo
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ProcessorType.LocationInfo;

                        /**
                         * Verifies a LocationInfo message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a LocationInfo message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns LocationInfo
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ProcessorType.LocationInfo;

                        /**
                         * Creates a plain object from a LocationInfo message. Also converts values to other types if specified.
                         * @param message LocationInfo
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.ProcessorType.LocationInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this LocationInfo to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for LocationInfo
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Represents a DocumentService */
                class DocumentService extends $protobuf.rpc.Service {

                    /**
                     * Constructs a new DocumentService service.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     */
                    constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

                    /**
                     * Creates new DocumentService service using the specified rpc implementation.
                     * @param rpcImpl RPC implementation
                     * @param [requestDelimited=false] Whether requests are length-delimited
                     * @param [responseDelimited=false] Whether responses are length-delimited
                     * @returns RPC service. Useful where requests and/or responses are streamed.
                     */
                    public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): DocumentService;

                    /**
                     * Calls UpdateDataset.
                     * @param request UpdateDatasetRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public updateDataset(request: google.cloud.documentai.v1beta3.IUpdateDatasetRequest, callback: google.cloud.documentai.v1beta3.DocumentService.UpdateDatasetCallback): void;

                    /**
                     * Calls UpdateDataset.
                     * @param request UpdateDatasetRequest message or plain object
                     * @returns Promise
                     */
                    public updateDataset(request: google.cloud.documentai.v1beta3.IUpdateDatasetRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls ImportDocuments.
                     * @param request ImportDocumentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public importDocuments(request: google.cloud.documentai.v1beta3.IImportDocumentsRequest, callback: google.cloud.documentai.v1beta3.DocumentService.ImportDocumentsCallback): void;

                    /**
                     * Calls ImportDocuments.
                     * @param request ImportDocumentsRequest message or plain object
                     * @returns Promise
                     */
                    public importDocuments(request: google.cloud.documentai.v1beta3.IImportDocumentsRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls GetDocument.
                     * @param request GetDocumentRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and GetDocumentResponse
                     */
                    public getDocument(request: google.cloud.documentai.v1beta3.IGetDocumentRequest, callback: google.cloud.documentai.v1beta3.DocumentService.GetDocumentCallback): void;

                    /**
                     * Calls GetDocument.
                     * @param request GetDocumentRequest message or plain object
                     * @returns Promise
                     */
                    public getDocument(request: google.cloud.documentai.v1beta3.IGetDocumentRequest): Promise<google.cloud.documentai.v1beta3.GetDocumentResponse>;

                    /**
                     * Calls ListDocuments.
                     * @param request ListDocumentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and ListDocumentsResponse
                     */
                    public listDocuments(request: google.cloud.documentai.v1beta3.IListDocumentsRequest, callback: google.cloud.documentai.v1beta3.DocumentService.ListDocumentsCallback): void;

                    /**
                     * Calls ListDocuments.
                     * @param request ListDocumentsRequest message or plain object
                     * @returns Promise
                     */
                    public listDocuments(request: google.cloud.documentai.v1beta3.IListDocumentsRequest): Promise<google.cloud.documentai.v1beta3.ListDocumentsResponse>;

                    /**
                     * Calls BatchDeleteDocuments.
                     * @param request BatchDeleteDocumentsRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and Operation
                     */
                    public batchDeleteDocuments(request: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsRequest, callback: google.cloud.documentai.v1beta3.DocumentService.BatchDeleteDocumentsCallback): void;

                    /**
                     * Calls BatchDeleteDocuments.
                     * @param request BatchDeleteDocumentsRequest message or plain object
                     * @returns Promise
                     */
                    public batchDeleteDocuments(request: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsRequest): Promise<google.longrunning.Operation>;

                    /**
                     * Calls GetDatasetSchema.
                     * @param request GetDatasetSchemaRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DatasetSchema
                     */
                    public getDatasetSchema(request: google.cloud.documentai.v1beta3.IGetDatasetSchemaRequest, callback: google.cloud.documentai.v1beta3.DocumentService.GetDatasetSchemaCallback): void;

                    /**
                     * Calls GetDatasetSchema.
                     * @param request GetDatasetSchemaRequest message or plain object
                     * @returns Promise
                     */
                    public getDatasetSchema(request: google.cloud.documentai.v1beta3.IGetDatasetSchemaRequest): Promise<google.cloud.documentai.v1beta3.DatasetSchema>;

                    /**
                     * Calls UpdateDatasetSchema.
                     * @param request UpdateDatasetSchemaRequest message or plain object
                     * @param callback Node-style callback called with the error, if any, and DatasetSchema
                     */
                    public updateDatasetSchema(request: google.cloud.documentai.v1beta3.IUpdateDatasetSchemaRequest, callback: google.cloud.documentai.v1beta3.DocumentService.UpdateDatasetSchemaCallback): void;

                    /**
                     * Calls UpdateDatasetSchema.
                     * @param request UpdateDatasetSchemaRequest message or plain object
                     * @returns Promise
                     */
                    public updateDatasetSchema(request: google.cloud.documentai.v1beta3.IUpdateDatasetSchemaRequest): Promise<google.cloud.documentai.v1beta3.DatasetSchema>;
                }

                namespace DocumentService {

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentService|updateDataset}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type UpdateDatasetCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentService|importDocuments}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type ImportDocumentsCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentService|getDocument}.
                     * @param error Error, if any
                     * @param [response] GetDocumentResponse
                     */
                    type GetDocumentCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.GetDocumentResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentService|listDocuments}.
                     * @param error Error, if any
                     * @param [response] ListDocumentsResponse
                     */
                    type ListDocumentsCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.ListDocumentsResponse) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentService|batchDeleteDocuments}.
                     * @param error Error, if any
                     * @param [response] Operation
                     */
                    type BatchDeleteDocumentsCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentService|getDatasetSchema}.
                     * @param error Error, if any
                     * @param [response] DatasetSchema
                     */
                    type GetDatasetSchemaCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.DatasetSchema) => void;

                    /**
                     * Callback as used by {@link google.cloud.documentai.v1beta3.DocumentService|updateDatasetSchema}.
                     * @param error Error, if any
                     * @param [response] DatasetSchema
                     */
                    type UpdateDatasetSchemaCallback = (error: (Error|null), response?: google.cloud.documentai.v1beta3.DatasetSchema) => void;
                }

                /** DatasetSplitType enum. */
                enum DatasetSplitType {
                    DATASET_SPLIT_TYPE_UNSPECIFIED = 0,
                    DATASET_SPLIT_TRAIN = 1,
                    DATASET_SPLIT_TEST = 2,
                    DATASET_SPLIT_UNASSIGNED = 3
                }

                /** DocumentLabelingState enum. */
                enum DocumentLabelingState {
                    DOCUMENT_LABELING_STATE_UNSPECIFIED = 0,
                    DOCUMENT_LABELED = 1,
                    DOCUMENT_UNLABELED = 2,
                    DOCUMENT_AUTO_LABELED = 3
                }

                /** Properties of an UpdateDatasetRequest. */
                interface IUpdateDatasetRequest {

                    /** UpdateDatasetRequest dataset */
                    dataset?: (google.cloud.documentai.v1beta3.IDataset|null);

                    /** UpdateDatasetRequest updateMask */
                    updateMask?: (google.protobuf.IFieldMask|null);
                }

                /** Represents an UpdateDatasetRequest. */
                class UpdateDatasetRequest implements IUpdateDatasetRequest {

                    /**
                     * Constructs a new UpdateDatasetRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IUpdateDatasetRequest);

                    /** UpdateDatasetRequest dataset. */
                    public dataset?: (google.cloud.documentai.v1beta3.IDataset|null);

                    /** UpdateDatasetRequest updateMask. */
                    public updateMask?: (google.protobuf.IFieldMask|null);

                    /**
                     * Creates a new UpdateDatasetRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateDatasetRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IUpdateDatasetRequest): google.cloud.documentai.v1beta3.UpdateDatasetRequest;

                    /**
                     * Encodes the specified UpdateDatasetRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.UpdateDatasetRequest.verify|verify} messages.
                     * @param message UpdateDatasetRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IUpdateDatasetRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateDatasetRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.UpdateDatasetRequest.verify|verify} messages.
                     * @param message UpdateDatasetRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IUpdateDatasetRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateDatasetRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateDatasetRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.UpdateDatasetRequest;

                    /**
                     * Decodes an UpdateDatasetRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateDatasetRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.UpdateDatasetRequest;

                    /**
                     * Verifies an UpdateDatasetRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateDatasetRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateDatasetRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.UpdateDatasetRequest;

                    /**
                     * Creates a plain object from an UpdateDatasetRequest message. Also converts values to other types if specified.
                     * @param message UpdateDatasetRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.UpdateDatasetRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateDatasetRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateDatasetRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateDatasetOperationMetadata. */
                interface IUpdateDatasetOperationMetadata {

                    /** UpdateDatasetOperationMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);
                }

                /** Represents an UpdateDatasetOperationMetadata. */
                class UpdateDatasetOperationMetadata implements IUpdateDatasetOperationMetadata {

                    /**
                     * Constructs a new UpdateDatasetOperationMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IUpdateDatasetOperationMetadata);

                    /** UpdateDatasetOperationMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /**
                     * Creates a new UpdateDatasetOperationMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateDatasetOperationMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IUpdateDatasetOperationMetadata): google.cloud.documentai.v1beta3.UpdateDatasetOperationMetadata;

                    /**
                     * Encodes the specified UpdateDatasetOperationMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.UpdateDatasetOperationMetadata.verify|verify} messages.
                     * @param message UpdateDatasetOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IUpdateDatasetOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateDatasetOperationMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.UpdateDatasetOperationMetadata.verify|verify} messages.
                     * @param message UpdateDatasetOperationMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IUpdateDatasetOperationMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateDatasetOperationMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateDatasetOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.UpdateDatasetOperationMetadata;

                    /**
                     * Decodes an UpdateDatasetOperationMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateDatasetOperationMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.UpdateDatasetOperationMetadata;

                    /**
                     * Verifies an UpdateDatasetOperationMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateDatasetOperationMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateDatasetOperationMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.UpdateDatasetOperationMetadata;

                    /**
                     * Creates a plain object from an UpdateDatasetOperationMetadata message. Also converts values to other types if specified.
                     * @param message UpdateDatasetOperationMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.UpdateDatasetOperationMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateDatasetOperationMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateDatasetOperationMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ImportDocumentsRequest. */
                interface IImportDocumentsRequest {

                    /** ImportDocumentsRequest dataset */
                    dataset?: (string|null);

                    /** ImportDocumentsRequest batchDocumentsImportConfigs */
                    batchDocumentsImportConfigs?: (google.cloud.documentai.v1beta3.ImportDocumentsRequest.IBatchDocumentsImportConfig[]|null);
                }

                /** Represents an ImportDocumentsRequest. */
                class ImportDocumentsRequest implements IImportDocumentsRequest {

                    /**
                     * Constructs a new ImportDocumentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IImportDocumentsRequest);

                    /** ImportDocumentsRequest dataset. */
                    public dataset: string;

                    /** ImportDocumentsRequest batchDocumentsImportConfigs. */
                    public batchDocumentsImportConfigs: google.cloud.documentai.v1beta3.ImportDocumentsRequest.IBatchDocumentsImportConfig[];

                    /**
                     * Creates a new ImportDocumentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ImportDocumentsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IImportDocumentsRequest): google.cloud.documentai.v1beta3.ImportDocumentsRequest;

                    /**
                     * Encodes the specified ImportDocumentsRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsRequest.verify|verify} messages.
                     * @param message ImportDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IImportDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ImportDocumentsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsRequest.verify|verify} messages.
                     * @param message ImportDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IImportDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ImportDocumentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ImportDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportDocumentsRequest;

                    /**
                     * Decodes an ImportDocumentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ImportDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportDocumentsRequest;

                    /**
                     * Verifies an ImportDocumentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ImportDocumentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ImportDocumentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportDocumentsRequest;

                    /**
                     * Creates a plain object from an ImportDocumentsRequest message. Also converts values to other types if specified.
                     * @param message ImportDocumentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ImportDocumentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ImportDocumentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ImportDocumentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ImportDocumentsRequest {

                    /** Properties of a BatchDocumentsImportConfig. */
                    interface IBatchDocumentsImportConfig {

                        /** BatchDocumentsImportConfig datasetSplit */
                        datasetSplit?: (google.cloud.documentai.v1beta3.DatasetSplitType|keyof typeof google.cloud.documentai.v1beta3.DatasetSplitType|null);

                        /** BatchDocumentsImportConfig autoSplitConfig */
                        autoSplitConfig?: (google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.IAutoSplitConfig|null);

                        /** BatchDocumentsImportConfig batchInputConfig */
                        batchInputConfig?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);
                    }

                    /** Represents a BatchDocumentsImportConfig. */
                    class BatchDocumentsImportConfig implements IBatchDocumentsImportConfig {

                        /**
                         * Constructs a new BatchDocumentsImportConfig.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.ImportDocumentsRequest.IBatchDocumentsImportConfig);

                        /** BatchDocumentsImportConfig datasetSplit. */
                        public datasetSplit?: (google.cloud.documentai.v1beta3.DatasetSplitType|keyof typeof google.cloud.documentai.v1beta3.DatasetSplitType|null);

                        /** BatchDocumentsImportConfig autoSplitConfig. */
                        public autoSplitConfig?: (google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.IAutoSplitConfig|null);

                        /** BatchDocumentsImportConfig batchInputConfig. */
                        public batchInputConfig?: (google.cloud.documentai.v1beta3.IBatchDocumentsInputConfig|null);

                        /** BatchDocumentsImportConfig splitTypeConfig. */
                        public splitTypeConfig?: ("datasetSplit"|"autoSplitConfig");

                        /**
                         * Creates a new BatchDocumentsImportConfig instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns BatchDocumentsImportConfig instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.ImportDocumentsRequest.IBatchDocumentsImportConfig): google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig;

                        /**
                         * Encodes the specified BatchDocumentsImportConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.verify|verify} messages.
                         * @param message BatchDocumentsImportConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.ImportDocumentsRequest.IBatchDocumentsImportConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified BatchDocumentsImportConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.verify|verify} messages.
                         * @param message BatchDocumentsImportConfig message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.ImportDocumentsRequest.IBatchDocumentsImportConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes a BatchDocumentsImportConfig message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns BatchDocumentsImportConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig;

                        /**
                         * Decodes a BatchDocumentsImportConfig message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns BatchDocumentsImportConfig
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig;

                        /**
                         * Verifies a BatchDocumentsImportConfig message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates a BatchDocumentsImportConfig message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns BatchDocumentsImportConfig
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig;

                        /**
                         * Creates a plain object from a BatchDocumentsImportConfig message. Also converts values to other types if specified.
                         * @param message BatchDocumentsImportConfig
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this BatchDocumentsImportConfig to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for BatchDocumentsImportConfig
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    namespace BatchDocumentsImportConfig {

                        /** Properties of an AutoSplitConfig. */
                        interface IAutoSplitConfig {

                            /** AutoSplitConfig trainingSplitRatio */
                            trainingSplitRatio?: (number|null);
                        }

                        /** Represents an AutoSplitConfig. */
                        class AutoSplitConfig implements IAutoSplitConfig {

                            /**
                             * Constructs a new AutoSplitConfig.
                             * @param [properties] Properties to set
                             */
                            constructor(properties?: google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.IAutoSplitConfig);

                            /** AutoSplitConfig trainingSplitRatio. */
                            public trainingSplitRatio: number;

                            /**
                             * Creates a new AutoSplitConfig instance using the specified properties.
                             * @param [properties] Properties to set
                             * @returns AutoSplitConfig instance
                             */
                            public static create(properties?: google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.IAutoSplitConfig): google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.AutoSplitConfig;

                            /**
                             * Encodes the specified AutoSplitConfig message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.AutoSplitConfig.verify|verify} messages.
                             * @param message AutoSplitConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encode(message: google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.IAutoSplitConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Encodes the specified AutoSplitConfig message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.AutoSplitConfig.verify|verify} messages.
                             * @param message AutoSplitConfig message or plain object to encode
                             * @param [writer] Writer to encode to
                             * @returns Writer
                             */
                            public static encodeDelimited(message: google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.IAutoSplitConfig, writer?: $protobuf.Writer): $protobuf.Writer;

                            /**
                             * Decodes an AutoSplitConfig message from the specified reader or buffer.
                             * @param reader Reader or buffer to decode from
                             * @param [length] Message length if known beforehand
                             * @returns AutoSplitConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.AutoSplitConfig;

                            /**
                             * Decodes an AutoSplitConfig message from the specified reader or buffer, length delimited.
                             * @param reader Reader or buffer to decode from
                             * @returns AutoSplitConfig
                             * @throws {Error} If the payload is not a reader or valid buffer
                             * @throws {$protobuf.util.ProtocolError} If required fields are missing
                             */
                            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.AutoSplitConfig;

                            /**
                             * Verifies an AutoSplitConfig message.
                             * @param message Plain object to verify
                             * @returns `null` if valid, otherwise the reason why it is not
                             */
                            public static verify(message: { [k: string]: any }): (string|null);

                            /**
                             * Creates an AutoSplitConfig message from a plain object. Also converts values to their respective internal types.
                             * @param object Plain object
                             * @returns AutoSplitConfig
                             */
                            public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.AutoSplitConfig;

                            /**
                             * Creates a plain object from an AutoSplitConfig message. Also converts values to other types if specified.
                             * @param message AutoSplitConfig
                             * @param [options] Conversion options
                             * @returns Plain object
                             */
                            public static toObject(message: google.cloud.documentai.v1beta3.ImportDocumentsRequest.BatchDocumentsImportConfig.AutoSplitConfig, options?: $protobuf.IConversionOptions): { [k: string]: any };

                            /**
                             * Converts this AutoSplitConfig to JSON.
                             * @returns JSON object
                             */
                            public toJSON(): { [k: string]: any };

                            /**
                             * Gets the default type url for AutoSplitConfig
                             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                             * @returns The default type url
                             */
                            public static getTypeUrl(typeUrlPrefix?: string): string;
                        }
                    }
                }

                /** Properties of an ImportDocumentsResponse. */
                interface IImportDocumentsResponse {
                }

                /** Represents an ImportDocumentsResponse. */
                class ImportDocumentsResponse implements IImportDocumentsResponse {

                    /**
                     * Constructs a new ImportDocumentsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IImportDocumentsResponse);

                    /**
                     * Creates a new ImportDocumentsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ImportDocumentsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IImportDocumentsResponse): google.cloud.documentai.v1beta3.ImportDocumentsResponse;

                    /**
                     * Encodes the specified ImportDocumentsResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsResponse.verify|verify} messages.
                     * @param message ImportDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IImportDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ImportDocumentsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsResponse.verify|verify} messages.
                     * @param message ImportDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IImportDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ImportDocumentsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ImportDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportDocumentsResponse;

                    /**
                     * Decodes an ImportDocumentsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ImportDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportDocumentsResponse;

                    /**
                     * Verifies an ImportDocumentsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ImportDocumentsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ImportDocumentsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportDocumentsResponse;

                    /**
                     * Creates a plain object from an ImportDocumentsResponse message. Also converts values to other types if specified.
                     * @param message ImportDocumentsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ImportDocumentsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ImportDocumentsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ImportDocumentsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an ImportDocumentsMetadata. */
                interface IImportDocumentsMetadata {

                    /** ImportDocumentsMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /** ImportDocumentsMetadata individualImportStatuses */
                    individualImportStatuses?: (google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IIndividualImportStatus[]|null);

                    /** ImportDocumentsMetadata importConfigValidationResults */
                    importConfigValidationResults?: (google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IImportConfigValidationResult[]|null);

                    /** ImportDocumentsMetadata totalDocumentCount */
                    totalDocumentCount?: (number|null);
                }

                /** Represents an ImportDocumentsMetadata. */
                class ImportDocumentsMetadata implements IImportDocumentsMetadata {

                    /**
                     * Constructs a new ImportDocumentsMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IImportDocumentsMetadata);

                    /** ImportDocumentsMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /** ImportDocumentsMetadata individualImportStatuses. */
                    public individualImportStatuses: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IIndividualImportStatus[];

                    /** ImportDocumentsMetadata importConfigValidationResults. */
                    public importConfigValidationResults: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IImportConfigValidationResult[];

                    /** ImportDocumentsMetadata totalDocumentCount. */
                    public totalDocumentCount: number;

                    /**
                     * Creates a new ImportDocumentsMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ImportDocumentsMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IImportDocumentsMetadata): google.cloud.documentai.v1beta3.ImportDocumentsMetadata;

                    /**
                     * Encodes the specified ImportDocumentsMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsMetadata.verify|verify} messages.
                     * @param message ImportDocumentsMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IImportDocumentsMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ImportDocumentsMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsMetadata.verify|verify} messages.
                     * @param message ImportDocumentsMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IImportDocumentsMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an ImportDocumentsMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ImportDocumentsMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportDocumentsMetadata;

                    /**
                     * Decodes an ImportDocumentsMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ImportDocumentsMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportDocumentsMetadata;

                    /**
                     * Verifies an ImportDocumentsMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an ImportDocumentsMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ImportDocumentsMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportDocumentsMetadata;

                    /**
                     * Creates a plain object from an ImportDocumentsMetadata message. Also converts values to other types if specified.
                     * @param message ImportDocumentsMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ImportDocumentsMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ImportDocumentsMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ImportDocumentsMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace ImportDocumentsMetadata {

                    /** Properties of an IndividualImportStatus. */
                    interface IIndividualImportStatus {

                        /** IndividualImportStatus inputGcsSource */
                        inputGcsSource?: (string|null);

                        /** IndividualImportStatus status */
                        status?: (google.rpc.IStatus|null);

                        /** IndividualImportStatus outputDocumentId */
                        outputDocumentId?: (google.cloud.documentai.v1beta3.IDocumentId|null);
                    }

                    /** Represents an IndividualImportStatus. */
                    class IndividualImportStatus implements IIndividualImportStatus {

                        /**
                         * Constructs a new IndividualImportStatus.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IIndividualImportStatus);

                        /** IndividualImportStatus inputGcsSource. */
                        public inputGcsSource: string;

                        /** IndividualImportStatus status. */
                        public status?: (google.rpc.IStatus|null);

                        /** IndividualImportStatus outputDocumentId. */
                        public outputDocumentId?: (google.cloud.documentai.v1beta3.IDocumentId|null);

                        /**
                         * Creates a new IndividualImportStatus instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns IndividualImportStatus instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IIndividualImportStatus): google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IndividualImportStatus;

                        /**
                         * Encodes the specified IndividualImportStatus message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IndividualImportStatus.verify|verify} messages.
                         * @param message IndividualImportStatus message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IIndividualImportStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified IndividualImportStatus message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IndividualImportStatus.verify|verify} messages.
                         * @param message IndividualImportStatus message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IIndividualImportStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an IndividualImportStatus message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns IndividualImportStatus
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IndividualImportStatus;

                        /**
                         * Decodes an IndividualImportStatus message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns IndividualImportStatus
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IndividualImportStatus;

                        /**
                         * Verifies an IndividualImportStatus message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an IndividualImportStatus message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns IndividualImportStatus
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IndividualImportStatus;

                        /**
                         * Creates a plain object from an IndividualImportStatus message. Also converts values to other types if specified.
                         * @param message IndividualImportStatus
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IndividualImportStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this IndividualImportStatus to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for IndividualImportStatus
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }

                    /** Properties of an ImportConfigValidationResult. */
                    interface IImportConfigValidationResult {

                        /** ImportConfigValidationResult inputGcsSource */
                        inputGcsSource?: (string|null);

                        /** ImportConfigValidationResult status */
                        status?: (google.rpc.IStatus|null);
                    }

                    /** Represents an ImportConfigValidationResult. */
                    class ImportConfigValidationResult implements IImportConfigValidationResult {

                        /**
                         * Constructs a new ImportConfigValidationResult.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IImportConfigValidationResult);

                        /** ImportConfigValidationResult inputGcsSource. */
                        public inputGcsSource: string;

                        /** ImportConfigValidationResult status. */
                        public status?: (google.rpc.IStatus|null);

                        /**
                         * Creates a new ImportConfigValidationResult instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns ImportConfigValidationResult instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IImportConfigValidationResult): google.cloud.documentai.v1beta3.ImportDocumentsMetadata.ImportConfigValidationResult;

                        /**
                         * Encodes the specified ImportConfigValidationResult message. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsMetadata.ImportConfigValidationResult.verify|verify} messages.
                         * @param message ImportConfigValidationResult message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IImportConfigValidationResult, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified ImportConfigValidationResult message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ImportDocumentsMetadata.ImportConfigValidationResult.verify|verify} messages.
                         * @param message ImportConfigValidationResult message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.IImportConfigValidationResult, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an ImportConfigValidationResult message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns ImportConfigValidationResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ImportDocumentsMetadata.ImportConfigValidationResult;

                        /**
                         * Decodes an ImportConfigValidationResult message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns ImportConfigValidationResult
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ImportDocumentsMetadata.ImportConfigValidationResult;

                        /**
                         * Verifies an ImportConfigValidationResult message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an ImportConfigValidationResult message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns ImportConfigValidationResult
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ImportDocumentsMetadata.ImportConfigValidationResult;

                        /**
                         * Creates a plain object from an ImportConfigValidationResult message. Also converts values to other types if specified.
                         * @param message ImportConfigValidationResult
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.ImportDocumentsMetadata.ImportConfigValidationResult, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this ImportConfigValidationResult to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for ImportConfigValidationResult
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a GetDocumentRequest. */
                interface IGetDocumentRequest {

                    /** GetDocumentRequest dataset */
                    dataset?: (string|null);

                    /** GetDocumentRequest documentId */
                    documentId?: (google.cloud.documentai.v1beta3.IDocumentId|null);

                    /** GetDocumentRequest readMask */
                    readMask?: (google.protobuf.IFieldMask|null);

                    /** GetDocumentRequest pageRange */
                    pageRange?: (google.cloud.documentai.v1beta3.IDocumentPageRange|null);
                }

                /** Represents a GetDocumentRequest. */
                class GetDocumentRequest implements IGetDocumentRequest {

                    /**
                     * Constructs a new GetDocumentRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGetDocumentRequest);

                    /** GetDocumentRequest dataset. */
                    public dataset: string;

                    /** GetDocumentRequest documentId. */
                    public documentId?: (google.cloud.documentai.v1beta3.IDocumentId|null);

                    /** GetDocumentRequest readMask. */
                    public readMask?: (google.protobuf.IFieldMask|null);

                    /** GetDocumentRequest pageRange. */
                    public pageRange?: (google.cloud.documentai.v1beta3.IDocumentPageRange|null);

                    /**
                     * Creates a new GetDocumentRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetDocumentRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGetDocumentRequest): google.cloud.documentai.v1beta3.GetDocumentRequest;

                    /**
                     * Encodes the specified GetDocumentRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.GetDocumentRequest.verify|verify} messages.
                     * @param message GetDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGetDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetDocumentRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GetDocumentRequest.verify|verify} messages.
                     * @param message GetDocumentRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGetDocumentRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetDocumentRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GetDocumentRequest;

                    /**
                     * Decodes a GetDocumentRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetDocumentRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GetDocumentRequest;

                    /**
                     * Verifies a GetDocumentRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetDocumentRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetDocumentRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GetDocumentRequest;

                    /**
                     * Creates a plain object from a GetDocumentRequest message. Also converts values to other types if specified.
                     * @param message GetDocumentRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GetDocumentRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetDocumentRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetDocumentRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a GetDocumentResponse. */
                interface IGetDocumentResponse {

                    /** GetDocumentResponse document */
                    document?: (google.cloud.documentai.v1beta3.IDocument|null);
                }

                /** Represents a GetDocumentResponse. */
                class GetDocumentResponse implements IGetDocumentResponse {

                    /**
                     * Constructs a new GetDocumentResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGetDocumentResponse);

                    /** GetDocumentResponse document. */
                    public document?: (google.cloud.documentai.v1beta3.IDocument|null);

                    /**
                     * Creates a new GetDocumentResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetDocumentResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGetDocumentResponse): google.cloud.documentai.v1beta3.GetDocumentResponse;

                    /**
                     * Encodes the specified GetDocumentResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.GetDocumentResponse.verify|verify} messages.
                     * @param message GetDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGetDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetDocumentResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GetDocumentResponse.verify|verify} messages.
                     * @param message GetDocumentResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGetDocumentResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetDocumentResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GetDocumentResponse;

                    /**
                     * Decodes a GetDocumentResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetDocumentResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GetDocumentResponse;

                    /**
                     * Verifies a GetDocumentResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetDocumentResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetDocumentResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GetDocumentResponse;

                    /**
                     * Creates a plain object from a GetDocumentResponse message. Also converts values to other types if specified.
                     * @param message GetDocumentResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GetDocumentResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetDocumentResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetDocumentResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListDocumentsRequest. */
                interface IListDocumentsRequest {

                    /** ListDocumentsRequest dataset */
                    dataset?: (string|null);

                    /** ListDocumentsRequest pageSize */
                    pageSize?: (number|null);

                    /** ListDocumentsRequest pageToken */
                    pageToken?: (string|null);

                    /** ListDocumentsRequest filter */
                    filter?: (string|null);

                    /** ListDocumentsRequest returnTotalSize */
                    returnTotalSize?: (boolean|null);

                    /** ListDocumentsRequest skip */
                    skip?: (number|null);
                }

                /** Represents a ListDocumentsRequest. */
                class ListDocumentsRequest implements IListDocumentsRequest {

                    /**
                     * Constructs a new ListDocumentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListDocumentsRequest);

                    /** ListDocumentsRequest dataset. */
                    public dataset: string;

                    /** ListDocumentsRequest pageSize. */
                    public pageSize: number;

                    /** ListDocumentsRequest pageToken. */
                    public pageToken: string;

                    /** ListDocumentsRequest filter. */
                    public filter: string;

                    /** ListDocumentsRequest returnTotalSize. */
                    public returnTotalSize: boolean;

                    /** ListDocumentsRequest skip. */
                    public skip: number;

                    /**
                     * Creates a new ListDocumentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListDocumentsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListDocumentsRequest): google.cloud.documentai.v1beta3.ListDocumentsRequest;

                    /**
                     * Encodes the specified ListDocumentsRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListDocumentsRequest.verify|verify} messages.
                     * @param message ListDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListDocumentsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListDocumentsRequest.verify|verify} messages.
                     * @param message ListDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListDocumentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListDocumentsRequest;

                    /**
                     * Decodes a ListDocumentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListDocumentsRequest;

                    /**
                     * Verifies a ListDocumentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListDocumentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListDocumentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListDocumentsRequest;

                    /**
                     * Creates a plain object from a ListDocumentsRequest message. Also converts values to other types if specified.
                     * @param message ListDocumentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListDocumentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListDocumentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListDocumentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a ListDocumentsResponse. */
                interface IListDocumentsResponse {

                    /** ListDocumentsResponse documentMetadata */
                    documentMetadata?: (google.cloud.documentai.v1beta3.IDocumentMetadata[]|null);

                    /** ListDocumentsResponse nextPageToken */
                    nextPageToken?: (string|null);

                    /** ListDocumentsResponse totalSize */
                    totalSize?: (number|null);
                }

                /** Represents a ListDocumentsResponse. */
                class ListDocumentsResponse implements IListDocumentsResponse {

                    /**
                     * Constructs a new ListDocumentsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IListDocumentsResponse);

                    /** ListDocumentsResponse documentMetadata. */
                    public documentMetadata: google.cloud.documentai.v1beta3.IDocumentMetadata[];

                    /** ListDocumentsResponse nextPageToken. */
                    public nextPageToken: string;

                    /** ListDocumentsResponse totalSize. */
                    public totalSize: number;

                    /**
                     * Creates a new ListDocumentsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns ListDocumentsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IListDocumentsResponse): google.cloud.documentai.v1beta3.ListDocumentsResponse;

                    /**
                     * Encodes the specified ListDocumentsResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.ListDocumentsResponse.verify|verify} messages.
                     * @param message ListDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IListDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified ListDocumentsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.ListDocumentsResponse.verify|verify} messages.
                     * @param message ListDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IListDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a ListDocumentsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns ListDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.ListDocumentsResponse;

                    /**
                     * Decodes a ListDocumentsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns ListDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.ListDocumentsResponse;

                    /**
                     * Verifies a ListDocumentsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a ListDocumentsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns ListDocumentsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.ListDocumentsResponse;

                    /**
                     * Creates a plain object from a ListDocumentsResponse message. Also converts values to other types if specified.
                     * @param message ListDocumentsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.ListDocumentsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this ListDocumentsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for ListDocumentsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchDeleteDocumentsRequest. */
                interface IBatchDeleteDocumentsRequest {

                    /** BatchDeleteDocumentsRequest dataset */
                    dataset?: (string|null);

                    /** BatchDeleteDocumentsRequest datasetDocuments */
                    datasetDocuments?: (google.cloud.documentai.v1beta3.IBatchDatasetDocuments|null);
                }

                /** Represents a BatchDeleteDocumentsRequest. */
                class BatchDeleteDocumentsRequest implements IBatchDeleteDocumentsRequest {

                    /**
                     * Constructs a new BatchDeleteDocumentsRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsRequest);

                    /** BatchDeleteDocumentsRequest dataset. */
                    public dataset: string;

                    /** BatchDeleteDocumentsRequest datasetDocuments. */
                    public datasetDocuments?: (google.cloud.documentai.v1beta3.IBatchDatasetDocuments|null);

                    /**
                     * Creates a new BatchDeleteDocumentsRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchDeleteDocumentsRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsRequest): google.cloud.documentai.v1beta3.BatchDeleteDocumentsRequest;

                    /**
                     * Encodes the specified BatchDeleteDocumentsRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDeleteDocumentsRequest.verify|verify} messages.
                     * @param message BatchDeleteDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchDeleteDocumentsRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDeleteDocumentsRequest.verify|verify} messages.
                     * @param message BatchDeleteDocumentsRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchDeleteDocumentsRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchDeleteDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchDeleteDocumentsRequest;

                    /**
                     * Decodes a BatchDeleteDocumentsRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchDeleteDocumentsRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchDeleteDocumentsRequest;

                    /**
                     * Verifies a BatchDeleteDocumentsRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchDeleteDocumentsRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchDeleteDocumentsRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchDeleteDocumentsRequest;

                    /**
                     * Creates a plain object from a BatchDeleteDocumentsRequest message. Also converts values to other types if specified.
                     * @param message BatchDeleteDocumentsRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.BatchDeleteDocumentsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchDeleteDocumentsRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchDeleteDocumentsRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchDeleteDocumentsResponse. */
                interface IBatchDeleteDocumentsResponse {
                }

                /** Represents a BatchDeleteDocumentsResponse. */
                class BatchDeleteDocumentsResponse implements IBatchDeleteDocumentsResponse {

                    /**
                     * Constructs a new BatchDeleteDocumentsResponse.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsResponse);

                    /**
                     * Creates a new BatchDeleteDocumentsResponse instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchDeleteDocumentsResponse instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsResponse): google.cloud.documentai.v1beta3.BatchDeleteDocumentsResponse;

                    /**
                     * Encodes the specified BatchDeleteDocumentsResponse message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDeleteDocumentsResponse.verify|verify} messages.
                     * @param message BatchDeleteDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchDeleteDocumentsResponse message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDeleteDocumentsResponse.verify|verify} messages.
                     * @param message BatchDeleteDocumentsResponse message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchDeleteDocumentsResponse message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchDeleteDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchDeleteDocumentsResponse;

                    /**
                     * Decodes a BatchDeleteDocumentsResponse message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchDeleteDocumentsResponse
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchDeleteDocumentsResponse;

                    /**
                     * Verifies a BatchDeleteDocumentsResponse message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchDeleteDocumentsResponse message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchDeleteDocumentsResponse
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchDeleteDocumentsResponse;

                    /**
                     * Creates a plain object from a BatchDeleteDocumentsResponse message. Also converts values to other types if specified.
                     * @param message BatchDeleteDocumentsResponse
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.BatchDeleteDocumentsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchDeleteDocumentsResponse to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchDeleteDocumentsResponse
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a BatchDeleteDocumentsMetadata. */
                interface IBatchDeleteDocumentsMetadata {

                    /** BatchDeleteDocumentsMetadata commonMetadata */
                    commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /** BatchDeleteDocumentsMetadata individualBatchDeleteStatuses */
                    individualBatchDeleteStatuses?: (google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IIndividualBatchDeleteStatus[]|null);

                    /** BatchDeleteDocumentsMetadata totalDocumentCount */
                    totalDocumentCount?: (number|null);

                    /** BatchDeleteDocumentsMetadata errorDocumentCount */
                    errorDocumentCount?: (number|null);
                }

                /** Represents a BatchDeleteDocumentsMetadata. */
                class BatchDeleteDocumentsMetadata implements IBatchDeleteDocumentsMetadata {

                    /**
                     * Constructs a new BatchDeleteDocumentsMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsMetadata);

                    /** BatchDeleteDocumentsMetadata commonMetadata. */
                    public commonMetadata?: (google.cloud.documentai.v1beta3.ICommonOperationMetadata|null);

                    /** BatchDeleteDocumentsMetadata individualBatchDeleteStatuses. */
                    public individualBatchDeleteStatuses: google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IIndividualBatchDeleteStatus[];

                    /** BatchDeleteDocumentsMetadata totalDocumentCount. */
                    public totalDocumentCount: number;

                    /** BatchDeleteDocumentsMetadata errorDocumentCount. */
                    public errorDocumentCount: number;

                    /**
                     * Creates a new BatchDeleteDocumentsMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns BatchDeleteDocumentsMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsMetadata): google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata;

                    /**
                     * Encodes the specified BatchDeleteDocumentsMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.verify|verify} messages.
                     * @param message BatchDeleteDocumentsMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified BatchDeleteDocumentsMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.verify|verify} messages.
                     * @param message BatchDeleteDocumentsMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IBatchDeleteDocumentsMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a BatchDeleteDocumentsMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns BatchDeleteDocumentsMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata;

                    /**
                     * Decodes a BatchDeleteDocumentsMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns BatchDeleteDocumentsMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata;

                    /**
                     * Verifies a BatchDeleteDocumentsMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a BatchDeleteDocumentsMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns BatchDeleteDocumentsMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata;

                    /**
                     * Creates a plain object from a BatchDeleteDocumentsMetadata message. Also converts values to other types if specified.
                     * @param message BatchDeleteDocumentsMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this BatchDeleteDocumentsMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for BatchDeleteDocumentsMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                namespace BatchDeleteDocumentsMetadata {

                    /** Properties of an IndividualBatchDeleteStatus. */
                    interface IIndividualBatchDeleteStatus {

                        /** IndividualBatchDeleteStatus documentId */
                        documentId?: (google.cloud.documentai.v1beta3.IDocumentId|null);

                        /** IndividualBatchDeleteStatus status */
                        status?: (google.rpc.IStatus|null);
                    }

                    /** Represents an IndividualBatchDeleteStatus. */
                    class IndividualBatchDeleteStatus implements IIndividualBatchDeleteStatus {

                        /**
                         * Constructs a new IndividualBatchDeleteStatus.
                         * @param [properties] Properties to set
                         */
                        constructor(properties?: google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IIndividualBatchDeleteStatus);

                        /** IndividualBatchDeleteStatus documentId. */
                        public documentId?: (google.cloud.documentai.v1beta3.IDocumentId|null);

                        /** IndividualBatchDeleteStatus status. */
                        public status?: (google.rpc.IStatus|null);

                        /**
                         * Creates a new IndividualBatchDeleteStatus instance using the specified properties.
                         * @param [properties] Properties to set
                         * @returns IndividualBatchDeleteStatus instance
                         */
                        public static create(properties?: google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IIndividualBatchDeleteStatus): google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IndividualBatchDeleteStatus;

                        /**
                         * Encodes the specified IndividualBatchDeleteStatus message. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IndividualBatchDeleteStatus.verify|verify} messages.
                         * @param message IndividualBatchDeleteStatus message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encode(message: google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IIndividualBatchDeleteStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Encodes the specified IndividualBatchDeleteStatus message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IndividualBatchDeleteStatus.verify|verify} messages.
                         * @param message IndividualBatchDeleteStatus message or plain object to encode
                         * @param [writer] Writer to encode to
                         * @returns Writer
                         */
                        public static encodeDelimited(message: google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IIndividualBatchDeleteStatus, writer?: $protobuf.Writer): $protobuf.Writer;

                        /**
                         * Decodes an IndividualBatchDeleteStatus message from the specified reader or buffer.
                         * @param reader Reader or buffer to decode from
                         * @param [length] Message length if known beforehand
                         * @returns IndividualBatchDeleteStatus
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IndividualBatchDeleteStatus;

                        /**
                         * Decodes an IndividualBatchDeleteStatus message from the specified reader or buffer, length delimited.
                         * @param reader Reader or buffer to decode from
                         * @returns IndividualBatchDeleteStatus
                         * @throws {Error} If the payload is not a reader or valid buffer
                         * @throws {$protobuf.util.ProtocolError} If required fields are missing
                         */
                        public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IndividualBatchDeleteStatus;

                        /**
                         * Verifies an IndividualBatchDeleteStatus message.
                         * @param message Plain object to verify
                         * @returns `null` if valid, otherwise the reason why it is not
                         */
                        public static verify(message: { [k: string]: any }): (string|null);

                        /**
                         * Creates an IndividualBatchDeleteStatus message from a plain object. Also converts values to their respective internal types.
                         * @param object Plain object
                         * @returns IndividualBatchDeleteStatus
                         */
                        public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IndividualBatchDeleteStatus;

                        /**
                         * Creates a plain object from an IndividualBatchDeleteStatus message. Also converts values to other types if specified.
                         * @param message IndividualBatchDeleteStatus
                         * @param [options] Conversion options
                         * @returns Plain object
                         */
                        public static toObject(message: google.cloud.documentai.v1beta3.BatchDeleteDocumentsMetadata.IndividualBatchDeleteStatus, options?: $protobuf.IConversionOptions): { [k: string]: any };

                        /**
                         * Converts this IndividualBatchDeleteStatus to JSON.
                         * @returns JSON object
                         */
                        public toJSON(): { [k: string]: any };

                        /**
                         * Gets the default type url for IndividualBatchDeleteStatus
                         * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                         * @returns The default type url
                         */
                        public static getTypeUrl(typeUrlPrefix?: string): string;
                    }
                }

                /** Properties of a GetDatasetSchemaRequest. */
                interface IGetDatasetSchemaRequest {

                    /** GetDatasetSchemaRequest name */
                    name?: (string|null);

                    /** GetDatasetSchemaRequest visibleFieldsOnly */
                    visibleFieldsOnly?: (boolean|null);
                }

                /** Represents a GetDatasetSchemaRequest. */
                class GetDatasetSchemaRequest implements IGetDatasetSchemaRequest {

                    /**
                     * Constructs a new GetDatasetSchemaRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IGetDatasetSchemaRequest);

                    /** GetDatasetSchemaRequest name. */
                    public name: string;

                    /** GetDatasetSchemaRequest visibleFieldsOnly. */
                    public visibleFieldsOnly: boolean;

                    /**
                     * Creates a new GetDatasetSchemaRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns GetDatasetSchemaRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IGetDatasetSchemaRequest): google.cloud.documentai.v1beta3.GetDatasetSchemaRequest;

                    /**
                     * Encodes the specified GetDatasetSchemaRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.GetDatasetSchemaRequest.verify|verify} messages.
                     * @param message GetDatasetSchemaRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IGetDatasetSchemaRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified GetDatasetSchemaRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.GetDatasetSchemaRequest.verify|verify} messages.
                     * @param message GetDatasetSchemaRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IGetDatasetSchemaRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a GetDatasetSchemaRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns GetDatasetSchemaRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.GetDatasetSchemaRequest;

                    /**
                     * Decodes a GetDatasetSchemaRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns GetDatasetSchemaRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.GetDatasetSchemaRequest;

                    /**
                     * Verifies a GetDatasetSchemaRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a GetDatasetSchemaRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns GetDatasetSchemaRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.GetDatasetSchemaRequest;

                    /**
                     * Creates a plain object from a GetDatasetSchemaRequest message. Also converts values to other types if specified.
                     * @param message GetDatasetSchemaRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.GetDatasetSchemaRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this GetDatasetSchemaRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for GetDatasetSchemaRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of an UpdateDatasetSchemaRequest. */
                interface IUpdateDatasetSchemaRequest {

                    /** UpdateDatasetSchemaRequest datasetSchema */
                    datasetSchema?: (google.cloud.documentai.v1beta3.IDatasetSchema|null);

                    /** UpdateDatasetSchemaRequest updateMask */
                    updateMask?: (google.protobuf.IFieldMask|null);
                }

                /** Represents an UpdateDatasetSchemaRequest. */
                class UpdateDatasetSchemaRequest implements IUpdateDatasetSchemaRequest {

                    /**
                     * Constructs a new UpdateDatasetSchemaRequest.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IUpdateDatasetSchemaRequest);

                    /** UpdateDatasetSchemaRequest datasetSchema. */
                    public datasetSchema?: (google.cloud.documentai.v1beta3.IDatasetSchema|null);

                    /** UpdateDatasetSchemaRequest updateMask. */
                    public updateMask?: (google.protobuf.IFieldMask|null);

                    /**
                     * Creates a new UpdateDatasetSchemaRequest instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns UpdateDatasetSchemaRequest instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IUpdateDatasetSchemaRequest): google.cloud.documentai.v1beta3.UpdateDatasetSchemaRequest;

                    /**
                     * Encodes the specified UpdateDatasetSchemaRequest message. Does not implicitly {@link google.cloud.documentai.v1beta3.UpdateDatasetSchemaRequest.verify|verify} messages.
                     * @param message UpdateDatasetSchemaRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IUpdateDatasetSchemaRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified UpdateDatasetSchemaRequest message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.UpdateDatasetSchemaRequest.verify|verify} messages.
                     * @param message UpdateDatasetSchemaRequest message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IUpdateDatasetSchemaRequest, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes an UpdateDatasetSchemaRequest message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns UpdateDatasetSchemaRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.UpdateDatasetSchemaRequest;

                    /**
                     * Decodes an UpdateDatasetSchemaRequest message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns UpdateDatasetSchemaRequest
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.UpdateDatasetSchemaRequest;

                    /**
                     * Verifies an UpdateDatasetSchemaRequest message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates an UpdateDatasetSchemaRequest message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns UpdateDatasetSchemaRequest
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.UpdateDatasetSchemaRequest;

                    /**
                     * Creates a plain object from an UpdateDatasetSchemaRequest message. Also converts values to other types if specified.
                     * @param message UpdateDatasetSchemaRequest
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.UpdateDatasetSchemaRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this UpdateDatasetSchemaRequest to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for UpdateDatasetSchemaRequest
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DocumentPageRange. */
                interface IDocumentPageRange {

                    /** DocumentPageRange start */
                    start?: (number|null);

                    /** DocumentPageRange end */
                    end?: (number|null);
                }

                /** Represents a DocumentPageRange. */
                class DocumentPageRange implements IDocumentPageRange {

                    /**
                     * Constructs a new DocumentPageRange.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDocumentPageRange);

                    /** DocumentPageRange start. */
                    public start: number;

                    /** DocumentPageRange end. */
                    public end: number;

                    /**
                     * Creates a new DocumentPageRange instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DocumentPageRange instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDocumentPageRange): google.cloud.documentai.v1beta3.DocumentPageRange;

                    /**
                     * Encodes the specified DocumentPageRange message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentPageRange.verify|verify} messages.
                     * @param message DocumentPageRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDocumentPageRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DocumentPageRange message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentPageRange.verify|verify} messages.
                     * @param message DocumentPageRange message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDocumentPageRange, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DocumentPageRange message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DocumentPageRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentPageRange;

                    /**
                     * Decodes a DocumentPageRange message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DocumentPageRange
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentPageRange;

                    /**
                     * Verifies a DocumentPageRange message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DocumentPageRange message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DocumentPageRange
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentPageRange;

                    /**
                     * Creates a plain object from a DocumentPageRange message. Also converts values to other types if specified.
                     * @param message DocumentPageRange
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DocumentPageRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DocumentPageRange to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DocumentPageRange
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }

                /** Properties of a DocumentMetadata. */
                interface IDocumentMetadata {

                    /** DocumentMetadata documentId */
                    documentId?: (google.cloud.documentai.v1beta3.IDocumentId|null);

                    /** DocumentMetadata pageCount */
                    pageCount?: (number|null);

                    /** DocumentMetadata datasetType */
                    datasetType?: (google.cloud.documentai.v1beta3.DatasetSplitType|keyof typeof google.cloud.documentai.v1beta3.DatasetSplitType|null);

                    /** DocumentMetadata labelingState */
                    labelingState?: (google.cloud.documentai.v1beta3.DocumentLabelingState|keyof typeof google.cloud.documentai.v1beta3.DocumentLabelingState|null);

                    /** DocumentMetadata displayName */
                    displayName?: (string|null);
                }

                /** Represents a DocumentMetadata. */
                class DocumentMetadata implements IDocumentMetadata {

                    /**
                     * Constructs a new DocumentMetadata.
                     * @param [properties] Properties to set
                     */
                    constructor(properties?: google.cloud.documentai.v1beta3.IDocumentMetadata);

                    /** DocumentMetadata documentId. */
                    public documentId?: (google.cloud.documentai.v1beta3.IDocumentId|null);

                    /** DocumentMetadata pageCount. */
                    public pageCount: number;

                    /** DocumentMetadata datasetType. */
                    public datasetType: (google.cloud.documentai.v1beta3.DatasetSplitType|keyof typeof google.cloud.documentai.v1beta3.DatasetSplitType);

                    /** DocumentMetadata labelingState. */
                    public labelingState: (google.cloud.documentai.v1beta3.DocumentLabelingState|keyof typeof google.cloud.documentai.v1beta3.DocumentLabelingState);

                    /** DocumentMetadata displayName. */
                    public displayName: string;

                    /**
                     * Creates a new DocumentMetadata instance using the specified properties.
                     * @param [properties] Properties to set
                     * @returns DocumentMetadata instance
                     */
                    public static create(properties?: google.cloud.documentai.v1beta3.IDocumentMetadata): google.cloud.documentai.v1beta3.DocumentMetadata;

                    /**
                     * Encodes the specified DocumentMetadata message. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentMetadata.verify|verify} messages.
                     * @param message DocumentMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encode(message: google.cloud.documentai.v1beta3.IDocumentMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Encodes the specified DocumentMetadata message, length delimited. Does not implicitly {@link google.cloud.documentai.v1beta3.DocumentMetadata.verify|verify} messages.
                     * @param message DocumentMetadata message or plain object to encode
                     * @param [writer] Writer to encode to
                     * @returns Writer
                     */
                    public static encodeDelimited(message: google.cloud.documentai.v1beta3.IDocumentMetadata, writer?: $protobuf.Writer): $protobuf.Writer;

                    /**
                     * Decodes a DocumentMetadata message from the specified reader or buffer.
                     * @param reader Reader or buffer to decode from
                     * @param [length] Message length if known beforehand
                     * @returns DocumentMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.cloud.documentai.v1beta3.DocumentMetadata;

                    /**
                     * Decodes a DocumentMetadata message from the specified reader or buffer, length delimited.
                     * @param reader Reader or buffer to decode from
                     * @returns DocumentMetadata
                     * @throws {Error} If the payload is not a reader or valid buffer
                     * @throws {$protobuf.util.ProtocolError} If required fields are missing
                     */
                    public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.cloud.documentai.v1beta3.DocumentMetadata;

                    /**
                     * Verifies a DocumentMetadata message.
                     * @param message Plain object to verify
                     * @returns `null` if valid, otherwise the reason why it is not
                     */
                    public static verify(message: { [k: string]: any }): (string|null);

                    /**
                     * Creates a DocumentMetadata message from a plain object. Also converts values to their respective internal types.
                     * @param object Plain object
                     * @returns DocumentMetadata
                     */
                    public static fromObject(object: { [k: string]: any }): google.cloud.documentai.v1beta3.DocumentMetadata;

                    /**
                     * Creates a plain object from a DocumentMetadata message. Also converts values to other types if specified.
                     * @param message DocumentMetadata
                     * @param [options] Conversion options
                     * @returns Plain object
                     */
                    public static toObject(message: google.cloud.documentai.v1beta3.DocumentMetadata, options?: $protobuf.IConversionOptions): { [k: string]: any };

                    /**
                     * Converts this DocumentMetadata to JSON.
                     * @returns JSON object
                     */
                    public toJSON(): { [k: string]: any };

                    /**
                     * Gets the default type url for DocumentMetadata
                     * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                     * @returns The default type url
                     */
                    public static getTypeUrl(typeUrlPrefix?: string): string;
                }
            }
        }
    }

    /** Namespace api. */
    namespace api {

        /** FieldBehavior enum. */
        enum FieldBehavior {
            FIELD_BEHAVIOR_UNSPECIFIED = 0,
            OPTIONAL = 1,
            REQUIRED = 2,
            OUTPUT_ONLY = 3,
            INPUT_ONLY = 4,
            IMMUTABLE = 5,
            UNORDERED_LIST = 6,
            NON_EMPTY_DEFAULT = 7,
            IDENTIFIER = 8
        }

        /** Properties of a Http. */
        interface IHttp {

            /** Http rules */
            rules?: (google.api.IHttpRule[]|null);

            /** Http fullyDecodeReservedExpansion */
            fullyDecodeReservedExpansion?: (boolean|null);
        }

        /** Represents a Http. */
        class Http implements IHttp {

            /**
             * Constructs a new Http.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IHttp);

            /** Http rules. */
            public rules: google.api.IHttpRule[];

            /** Http fullyDecodeReservedExpansion. */
            public fullyDecodeReservedExpansion: boolean;

            /**
             * Creates a new Http instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Http instance
             */
            public static create(properties?: google.api.IHttp): google.api.Http;

            /**
             * Encodes the specified Http message. Does not implicitly {@link google.api.Http.verify|verify} messages.
             * @param message Http message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IHttp, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Http message, length delimited. Does not implicitly {@link google.api.Http.verify|verify} messages.
             * @param message Http message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IHttp, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a Http message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Http
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.Http;

            /**
             * Decodes a Http message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Http
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.Http;

            /**
             * Verifies a Http message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a Http message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Http
             */
            public static fromObject(object: { [k: string]: any }): google.api.Http;

            /**
             * Creates a plain object from a Http message. Also converts values to other types if specified.
             * @param message Http
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.Http, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Http to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Http
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a HttpRule. */
        interface IHttpRule {

            /** HttpRule selector */
            selector?: (string|null);

            /** HttpRule get */
            get?: (string|null);

            /** HttpRule put */
            put?: (string|null);

            /** HttpRule post */
            post?: (string|null);

            /** HttpRule delete */
            "delete"?: (string|null);

            /** HttpRule patch */
            patch?: (string|null);

            /** HttpRule custom */
            custom?: (google.api.ICustomHttpPattern|null);

            /** HttpRule body */
            body?: (string|null);

            /** HttpRule responseBody */
            responseBody?: (string|null);

            /** HttpRule additionalBindings */
            additionalBindings?: (google.api.IHttpRule[]|null);
        }

        /** Represents a HttpRule. */
        class HttpRule implements IHttpRule {

            /**
             * Constructs a new HttpRule.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IHttpRule);

            /** HttpRule selector. */
            public selector: string;

            /** HttpRule get. */
            public get?: (string|null);

            /** HttpRule put. */
            public put?: (string|null);

            /** HttpRule post. */
            public post?: (string|null);

            /** HttpRule delete. */
            public delete?: (string|null);

            /** HttpRule patch. */
            public patch?: (string|null);

            /** HttpRule custom. */
            public custom?: (google.api.ICustomHttpPattern|null);

            /** HttpRule body. */
            public body: string;

            /** HttpRule responseBody. */
            public responseBody: string;

            /** HttpRule additionalBindings. */
            public additionalBindings: google.api.IHttpRule[];

            /** HttpRule pattern. */
            public pattern?: ("get"|"put"|"post"|"delete"|"patch"|"custom");

            /**
             * Creates a new HttpRule instance using the specified properties.
             * @param [properties] Properties to set
             * @returns HttpRule instance
             */
            public static create(properties?: google.api.IHttpRule): google.api.HttpRule;

            /**
             * Encodes the specified HttpRule message. Does not implicitly {@link google.api.HttpRule.verify|verify} messages.
             * @param message HttpRule message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IHttpRule, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified HttpRule message, length delimited. Does not implicitly {@link google.api.HttpRule.verify|verify} messages.
             * @param message HttpRule message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IHttpRule, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a HttpRule message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns HttpRule
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.HttpRule;

            /**
             * Decodes a HttpRule message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns HttpRule
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.HttpRule;

            /**
             * Verifies a HttpRule message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a HttpRule message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns HttpRule
             */
            public static fromObject(object: { [k: string]: any }): google.api.HttpRule;

            /**
             * Creates a plain object from a HttpRule message. Also converts values to other types if specified.
             * @param message HttpRule
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.HttpRule, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this HttpRule to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for HttpRule
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a CustomHttpPattern. */
        interface ICustomHttpPattern {

            /** CustomHttpPattern kind */
            kind?: (string|null);

            /** CustomHttpPattern path */
            path?: (string|null);
        }

        /** Represents a CustomHttpPattern. */
        class CustomHttpPattern implements ICustomHttpPattern {

            /**
             * Constructs a new CustomHttpPattern.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.ICustomHttpPattern);

            /** CustomHttpPattern kind. */
            public kind: string;

            /** CustomHttpPattern path. */
            public path: string;

            /**
             * Creates a new CustomHttpPattern instance using the specified properties.
             * @param [properties] Properties to set
             * @returns CustomHttpPattern instance
             */
            public static create(properties?: google.api.ICustomHttpPattern): google.api.CustomHttpPattern;

            /**
             * Encodes the specified CustomHttpPattern message. Does not implicitly {@link google.api.CustomHttpPattern.verify|verify} messages.
             * @param message CustomHttpPattern message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.ICustomHttpPattern, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified CustomHttpPattern message, length delimited. Does not implicitly {@link google.api.CustomHttpPattern.verify|verify} messages.
             * @param message CustomHttpPattern message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.ICustomHttpPattern, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a CustomHttpPattern message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns CustomHttpPattern
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.CustomHttpPattern;

            /**
             * Decodes a CustomHttpPattern message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns CustomHttpPattern
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.CustomHttpPattern;

            /**
             * Verifies a CustomHttpPattern message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a CustomHttpPattern message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns CustomHttpPattern
             */
            public static fromObject(object: { [k: string]: any }): google.api.CustomHttpPattern;

            /**
             * Creates a plain object from a CustomHttpPattern message. Also converts values to other types if specified.
             * @param message CustomHttpPattern
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.CustomHttpPattern, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this CustomHttpPattern to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for CustomHttpPattern
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a CommonLanguageSettings. */
        interface ICommonLanguageSettings {

            /** CommonLanguageSettings referenceDocsUri */
            referenceDocsUri?: (string|null);

            /** CommonLanguageSettings destinations */
            destinations?: (google.api.ClientLibraryDestination[]|null);
        }

        /** Represents a CommonLanguageSettings. */
        class CommonLanguageSettings implements ICommonLanguageSettings {

            /**
             * Constructs a new CommonLanguageSettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.ICommonLanguageSettings);

            /** CommonLanguageSettings referenceDocsUri. */
            public referenceDocsUri: string;

            /** CommonLanguageSettings destinations. */
            public destinations: google.api.ClientLibraryDestination[];

            /**
             * Creates a new CommonLanguageSettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns CommonLanguageSettings instance
             */
            public static create(properties?: google.api.ICommonLanguageSettings): google.api.CommonLanguageSettings;

            /**
             * Encodes the specified CommonLanguageSettings message. Does not implicitly {@link google.api.CommonLanguageSettings.verify|verify} messages.
             * @param message CommonLanguageSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.ICommonLanguageSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified CommonLanguageSettings message, length delimited. Does not implicitly {@link google.api.CommonLanguageSettings.verify|verify} messages.
             * @param message CommonLanguageSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.ICommonLanguageSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a CommonLanguageSettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns CommonLanguageSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.CommonLanguageSettings;

            /**
             * Decodes a CommonLanguageSettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns CommonLanguageSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.CommonLanguageSettings;

            /**
             * Verifies a CommonLanguageSettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a CommonLanguageSettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns CommonLanguageSettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.CommonLanguageSettings;

            /**
             * Creates a plain object from a CommonLanguageSettings message. Also converts values to other types if specified.
             * @param message CommonLanguageSettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.CommonLanguageSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this CommonLanguageSettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for CommonLanguageSettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a ClientLibrarySettings. */
        interface IClientLibrarySettings {

            /** ClientLibrarySettings version */
            version?: (string|null);

            /** ClientLibrarySettings launchStage */
            launchStage?: (google.api.LaunchStage|keyof typeof google.api.LaunchStage|null);

            /** ClientLibrarySettings restNumericEnums */
            restNumericEnums?: (boolean|null);

            /** ClientLibrarySettings javaSettings */
            javaSettings?: (google.api.IJavaSettings|null);

            /** ClientLibrarySettings cppSettings */
            cppSettings?: (google.api.ICppSettings|null);

            /** ClientLibrarySettings phpSettings */
            phpSettings?: (google.api.IPhpSettings|null);

            /** ClientLibrarySettings pythonSettings */
            pythonSettings?: (google.api.IPythonSettings|null);

            /** ClientLibrarySettings nodeSettings */
            nodeSettings?: (google.api.INodeSettings|null);

            /** ClientLibrarySettings dotnetSettings */
            dotnetSettings?: (google.api.IDotnetSettings|null);

            /** ClientLibrarySettings rubySettings */
            rubySettings?: (google.api.IRubySettings|null);

            /** ClientLibrarySettings goSettings */
            goSettings?: (google.api.IGoSettings|null);
        }

        /** Represents a ClientLibrarySettings. */
        class ClientLibrarySettings implements IClientLibrarySettings {

            /**
             * Constructs a new ClientLibrarySettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IClientLibrarySettings);

            /** ClientLibrarySettings version. */
            public version: string;

            /** ClientLibrarySettings launchStage. */
            public launchStage: (google.api.LaunchStage|keyof typeof google.api.LaunchStage);

            /** ClientLibrarySettings restNumericEnums. */
            public restNumericEnums: boolean;

            /** ClientLibrarySettings javaSettings. */
            public javaSettings?: (google.api.IJavaSettings|null);

            /** ClientLibrarySettings cppSettings. */
            public cppSettings?: (google.api.ICppSettings|null);

            /** ClientLibrarySettings phpSettings. */
            public phpSettings?: (google.api.IPhpSettings|null);

            /** ClientLibrarySettings pythonSettings. */
            public pythonSettings?: (google.api.IPythonSettings|null);

            /** ClientLibrarySettings nodeSettings. */
            public nodeSettings?: (google.api.INodeSettings|null);

            /** ClientLibrarySettings dotnetSettings. */
            public dotnetSettings?: (google.api.IDotnetSettings|null);

            /** ClientLibrarySettings rubySettings. */
            public rubySettings?: (google.api.IRubySettings|null);

            /** ClientLibrarySettings goSettings. */
            public goSettings?: (google.api.IGoSettings|null);

            /**
             * Creates a new ClientLibrarySettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ClientLibrarySettings instance
             */
            public static create(properties?: google.api.IClientLibrarySettings): google.api.ClientLibrarySettings;

            /**
             * Encodes the specified ClientLibrarySettings message. Does not implicitly {@link google.api.ClientLibrarySettings.verify|verify} messages.
             * @param message ClientLibrarySettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IClientLibrarySettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ClientLibrarySettings message, length delimited. Does not implicitly {@link google.api.ClientLibrarySettings.verify|verify} messages.
             * @param message ClientLibrarySettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IClientLibrarySettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ClientLibrarySettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ClientLibrarySettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.ClientLibrarySettings;

            /**
             * Decodes a ClientLibrarySettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ClientLibrarySettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.ClientLibrarySettings;

            /**
             * Verifies a ClientLibrarySettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ClientLibrarySettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ClientLibrarySettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.ClientLibrarySettings;

            /**
             * Creates a plain object from a ClientLibrarySettings message. Also converts values to other types if specified.
             * @param message ClientLibrarySettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.ClientLibrarySettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ClientLibrarySettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ClientLibrarySettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a Publishing. */
        interface IPublishing {

            /** Publishing methodSettings */
            methodSettings?: (google.api.IMethodSettings[]|null);

            /** Publishing newIssueUri */
            newIssueUri?: (string|null);

            /** Publishing documentationUri */
            documentationUri?: (string|null);

            /** Publishing apiShortName */
            apiShortName?: (string|null);

            /** Publishing githubLabel */
            githubLabel?: (string|null);

            /** Publishing codeownerGithubTeams */
            codeownerGithubTeams?: (string[]|null);

            /** Publishing docTagPrefix */
            docTagPrefix?: (string|null);

            /** Publishing organization */
            organization?: (google.api.ClientLibraryOrganization|keyof typeof google.api.ClientLibraryOrganization|null);

            /** Publishing librarySettings */
            librarySettings?: (google.api.IClientLibrarySettings[]|null);

            /** Publishing protoReferenceDocumentationUri */
            protoReferenceDocumentationUri?: (string|null);
        }

        /** Represents a Publishing. */
        class Publishing implements IPublishing {

            /**
             * Constructs a new Publishing.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IPublishing);

            /** Publishing methodSettings. */
            public methodSettings: google.api.IMethodSettings[];

            /** Publishing newIssueUri. */
            public newIssueUri: string;

            /** Publishing documentationUri. */
            public documentationUri: string;

            /** Publishing apiShortName. */
            public apiShortName: string;

            /** Publishing githubLabel. */
            public githubLabel: string;

            /** Publishing codeownerGithubTeams. */
            public codeownerGithubTeams: string[];

            /** Publishing docTagPrefix. */
            public docTagPrefix: string;

            /** Publishing organization. */
            public organization: (google.api.ClientLibraryOrganization|keyof typeof google.api.ClientLibraryOrganization);

            /** Publishing librarySettings. */
            public librarySettings: google.api.IClientLibrarySettings[];

            /** Publishing protoReferenceDocumentationUri. */
            public protoReferenceDocumentationUri: string;

            /**
             * Creates a new Publishing instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Publishing instance
             */
            public static create(properties?: google.api.IPublishing): google.api.Publishing;

            /**
             * Encodes the specified Publishing message. Does not implicitly {@link google.api.Publishing.verify|verify} messages.
             * @param message Publishing message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IPublishing, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Publishing message, length delimited. Does not implicitly {@link google.api.Publishing.verify|verify} messages.
             * @param message Publishing message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IPublishing, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a Publishing message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Publishing
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.Publishing;

            /**
             * Decodes a Publishing message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Publishing
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.Publishing;

            /**
             * Verifies a Publishing message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a Publishing message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Publishing
             */
            public static fromObject(object: { [k: string]: any }): google.api.Publishing;

            /**
             * Creates a plain object from a Publishing message. Also converts values to other types if specified.
             * @param message Publishing
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.Publishing, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Publishing to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Publishing
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a JavaSettings. */
        interface IJavaSettings {

            /** JavaSettings libraryPackage */
            libraryPackage?: (string|null);

            /** JavaSettings serviceClassNames */
            serviceClassNames?: ({ [k: string]: string }|null);

            /** JavaSettings common */
            common?: (google.api.ICommonLanguageSettings|null);
        }

        /** Represents a JavaSettings. */
        class JavaSettings implements IJavaSettings {

            /**
             * Constructs a new JavaSettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IJavaSettings);

            /** JavaSettings libraryPackage. */
            public libraryPackage: string;

            /** JavaSettings serviceClassNames. */
            public serviceClassNames: { [k: string]: string };

            /** JavaSettings common. */
            public common?: (google.api.ICommonLanguageSettings|null);

            /**
             * Creates a new JavaSettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns JavaSettings instance
             */
            public static create(properties?: google.api.IJavaSettings): google.api.JavaSettings;

            /**
             * Encodes the specified JavaSettings message. Does not implicitly {@link google.api.JavaSettings.verify|verify} messages.
             * @param message JavaSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IJavaSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified JavaSettings message, length delimited. Does not implicitly {@link google.api.JavaSettings.verify|verify} messages.
             * @param message JavaSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IJavaSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a JavaSettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns JavaSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.JavaSettings;

            /**
             * Decodes a JavaSettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns JavaSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.JavaSettings;

            /**
             * Verifies a JavaSettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a JavaSettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns JavaSettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.JavaSettings;

            /**
             * Creates a plain object from a JavaSettings message. Also converts values to other types if specified.
             * @param message JavaSettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.JavaSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this JavaSettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for JavaSettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a CppSettings. */
        interface ICppSettings {

            /** CppSettings common */
            common?: (google.api.ICommonLanguageSettings|null);
        }

        /** Represents a CppSettings. */
        class CppSettings implements ICppSettings {

            /**
             * Constructs a new CppSettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.ICppSettings);

            /** CppSettings common. */
            public common?: (google.api.ICommonLanguageSettings|null);

            /**
             * Creates a new CppSettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns CppSettings instance
             */
            public static create(properties?: google.api.ICppSettings): google.api.CppSettings;

            /**
             * Encodes the specified CppSettings message. Does not implicitly {@link google.api.CppSettings.verify|verify} messages.
             * @param message CppSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.ICppSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified CppSettings message, length delimited. Does not implicitly {@link google.api.CppSettings.verify|verify} messages.
             * @param message CppSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.ICppSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a CppSettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns CppSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.CppSettings;

            /**
             * Decodes a CppSettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns CppSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.CppSettings;

            /**
             * Verifies a CppSettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a CppSettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns CppSettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.CppSettings;

            /**
             * Creates a plain object from a CppSettings message. Also converts values to other types if specified.
             * @param message CppSettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.CppSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this CppSettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for CppSettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a PhpSettings. */
        interface IPhpSettings {

            /** PhpSettings common */
            common?: (google.api.ICommonLanguageSettings|null);
        }

        /** Represents a PhpSettings. */
        class PhpSettings implements IPhpSettings {

            /**
             * Constructs a new PhpSettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IPhpSettings);

            /** PhpSettings common. */
            public common?: (google.api.ICommonLanguageSettings|null);

            /**
             * Creates a new PhpSettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns PhpSettings instance
             */
            public static create(properties?: google.api.IPhpSettings): google.api.PhpSettings;

            /**
             * Encodes the specified PhpSettings message. Does not implicitly {@link google.api.PhpSettings.verify|verify} messages.
             * @param message PhpSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IPhpSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified PhpSettings message, length delimited. Does not implicitly {@link google.api.PhpSettings.verify|verify} messages.
             * @param message PhpSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IPhpSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a PhpSettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns PhpSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.PhpSettings;

            /**
             * Decodes a PhpSettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns PhpSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.PhpSettings;

            /**
             * Verifies a PhpSettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a PhpSettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns PhpSettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.PhpSettings;

            /**
             * Creates a plain object from a PhpSettings message. Also converts values to other types if specified.
             * @param message PhpSettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.PhpSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this PhpSettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for PhpSettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a PythonSettings. */
        interface IPythonSettings {

            /** PythonSettings common */
            common?: (google.api.ICommonLanguageSettings|null);
        }

        /** Represents a PythonSettings. */
        class PythonSettings implements IPythonSettings {

            /**
             * Constructs a new PythonSettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IPythonSettings);

            /** PythonSettings common. */
            public common?: (google.api.ICommonLanguageSettings|null);

            /**
             * Creates a new PythonSettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns PythonSettings instance
             */
            public static create(properties?: google.api.IPythonSettings): google.api.PythonSettings;

            /**
             * Encodes the specified PythonSettings message. Does not implicitly {@link google.api.PythonSettings.verify|verify} messages.
             * @param message PythonSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IPythonSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified PythonSettings message, length delimited. Does not implicitly {@link google.api.PythonSettings.verify|verify} messages.
             * @param message PythonSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IPythonSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a PythonSettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns PythonSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.PythonSettings;

            /**
             * Decodes a PythonSettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns PythonSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.PythonSettings;

            /**
             * Verifies a PythonSettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a PythonSettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns PythonSettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.PythonSettings;

            /**
             * Creates a plain object from a PythonSettings message. Also converts values to other types if specified.
             * @param message PythonSettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.PythonSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this PythonSettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for PythonSettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a NodeSettings. */
        interface INodeSettings {

            /** NodeSettings common */
            common?: (google.api.ICommonLanguageSettings|null);
        }

        /** Represents a NodeSettings. */
        class NodeSettings implements INodeSettings {

            /**
             * Constructs a new NodeSettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.INodeSettings);

            /** NodeSettings common. */
            public common?: (google.api.ICommonLanguageSettings|null);

            /**
             * Creates a new NodeSettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns NodeSettings instance
             */
            public static create(properties?: google.api.INodeSettings): google.api.NodeSettings;

            /**
             * Encodes the specified NodeSettings message. Does not implicitly {@link google.api.NodeSettings.verify|verify} messages.
             * @param message NodeSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.INodeSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified NodeSettings message, length delimited. Does not implicitly {@link google.api.NodeSettings.verify|verify} messages.
             * @param message NodeSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.INodeSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a NodeSettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns NodeSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.NodeSettings;

            /**
             * Decodes a NodeSettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns NodeSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.NodeSettings;

            /**
             * Verifies a NodeSettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a NodeSettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns NodeSettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.NodeSettings;

            /**
             * Creates a plain object from a NodeSettings message. Also converts values to other types if specified.
             * @param message NodeSettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.NodeSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this NodeSettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for NodeSettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a DotnetSettings. */
        interface IDotnetSettings {

            /** DotnetSettings common */
            common?: (google.api.ICommonLanguageSettings|null);

            /** DotnetSettings renamedServices */
            renamedServices?: ({ [k: string]: string }|null);

            /** DotnetSettings renamedResources */
            renamedResources?: ({ [k: string]: string }|null);

            /** DotnetSettings ignoredResources */
            ignoredResources?: (string[]|null);

            /** DotnetSettings forcedNamespaceAliases */
            forcedNamespaceAliases?: (string[]|null);

            /** DotnetSettings handwrittenSignatures */
            handwrittenSignatures?: (string[]|null);
        }

        /** Represents a DotnetSettings. */
        class DotnetSettings implements IDotnetSettings {

            /**
             * Constructs a new DotnetSettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IDotnetSettings);

            /** DotnetSettings common. */
            public common?: (google.api.ICommonLanguageSettings|null);

            /** DotnetSettings renamedServices. */
            public renamedServices: { [k: string]: string };

            /** DotnetSettings renamedResources. */
            public renamedResources: { [k: string]: string };

            /** DotnetSettings ignoredResources. */
            public ignoredResources: string[];

            /** DotnetSettings forcedNamespaceAliases. */
            public forcedNamespaceAliases: string[];

            /** DotnetSettings handwrittenSignatures. */
            public handwrittenSignatures: string[];

            /**
             * Creates a new DotnetSettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns DotnetSettings instance
             */
            public static create(properties?: google.api.IDotnetSettings): google.api.DotnetSettings;

            /**
             * Encodes the specified DotnetSettings message. Does not implicitly {@link google.api.DotnetSettings.verify|verify} messages.
             * @param message DotnetSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IDotnetSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified DotnetSettings message, length delimited. Does not implicitly {@link google.api.DotnetSettings.verify|verify} messages.
             * @param message DotnetSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IDotnetSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a DotnetSettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns DotnetSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.DotnetSettings;

            /**
             * Decodes a DotnetSettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns DotnetSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.DotnetSettings;

            /**
             * Verifies a DotnetSettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a DotnetSettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns DotnetSettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.DotnetSettings;

            /**
             * Creates a plain object from a DotnetSettings message. Also converts values to other types if specified.
             * @param message DotnetSettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.DotnetSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this DotnetSettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for DotnetSettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a RubySettings. */
        interface IRubySettings {

            /** RubySettings common */
            common?: (google.api.ICommonLanguageSettings|null);
        }

        /** Represents a RubySettings. */
        class RubySettings implements IRubySettings {

            /**
             * Constructs a new RubySettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IRubySettings);

            /** RubySettings common. */
            public common?: (google.api.ICommonLanguageSettings|null);

            /**
             * Creates a new RubySettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns RubySettings instance
             */
            public static create(properties?: google.api.IRubySettings): google.api.RubySettings;

            /**
             * Encodes the specified RubySettings message. Does not implicitly {@link google.api.RubySettings.verify|verify} messages.
             * @param message RubySettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IRubySettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified RubySettings message, length delimited. Does not implicitly {@link google.api.RubySettings.verify|verify} messages.
             * @param message RubySettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IRubySettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a RubySettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns RubySettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.RubySettings;

            /**
             * Decodes a RubySettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns RubySettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.RubySettings;

            /**
             * Verifies a RubySettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a RubySettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns RubySettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.RubySettings;

            /**
             * Creates a plain object from a RubySettings message. Also converts values to other types if specified.
             * @param message RubySettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.RubySettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this RubySettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for RubySettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a GoSettings. */
        interface IGoSettings {

            /** GoSettings common */
            common?: (google.api.ICommonLanguageSettings|null);
        }

        /** Represents a GoSettings. */
        class GoSettings implements IGoSettings {

            /**
             * Constructs a new GoSettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IGoSettings);

            /** GoSettings common. */
            public common?: (google.api.ICommonLanguageSettings|null);

            /**
             * Creates a new GoSettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns GoSettings instance
             */
            public static create(properties?: google.api.IGoSettings): google.api.GoSettings;

            /**
             * Encodes the specified GoSettings message. Does not implicitly {@link google.api.GoSettings.verify|verify} messages.
             * @param message GoSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IGoSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified GoSettings message, length delimited. Does not implicitly {@link google.api.GoSettings.verify|verify} messages.
             * @param message GoSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IGoSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a GoSettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns GoSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.GoSettings;

            /**
             * Decodes a GoSettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns GoSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.GoSettings;

            /**
             * Verifies a GoSettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a GoSettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns GoSettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.GoSettings;

            /**
             * Creates a plain object from a GoSettings message. Also converts values to other types if specified.
             * @param message GoSettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.GoSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this GoSettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for GoSettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a MethodSettings. */
        interface IMethodSettings {

            /** MethodSettings selector */
            selector?: (string|null);

            /** MethodSettings longRunning */
            longRunning?: (google.api.MethodSettings.ILongRunning|null);

            /** MethodSettings autoPopulatedFields */
            autoPopulatedFields?: (string[]|null);
        }

        /** Represents a MethodSettings. */
        class MethodSettings implements IMethodSettings {

            /**
             * Constructs a new MethodSettings.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IMethodSettings);

            /** MethodSettings selector. */
            public selector: string;

            /** MethodSettings longRunning. */
            public longRunning?: (google.api.MethodSettings.ILongRunning|null);

            /** MethodSettings autoPopulatedFields. */
            public autoPopulatedFields: string[];

            /**
             * Creates a new MethodSettings instance using the specified properties.
             * @param [properties] Properties to set
             * @returns MethodSettings instance
             */
            public static create(properties?: google.api.IMethodSettings): google.api.MethodSettings;

            /**
             * Encodes the specified MethodSettings message. Does not implicitly {@link google.api.MethodSettings.verify|verify} messages.
             * @param message MethodSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IMethodSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified MethodSettings message, length delimited. Does not implicitly {@link google.api.MethodSettings.verify|verify} messages.
             * @param message MethodSettings message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IMethodSettings, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a MethodSettings message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns MethodSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.MethodSettings;

            /**
             * Decodes a MethodSettings message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns MethodSettings
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.MethodSettings;

            /**
             * Verifies a MethodSettings message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a MethodSettings message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns MethodSettings
             */
            public static fromObject(object: { [k: string]: any }): google.api.MethodSettings;

            /**
             * Creates a plain object from a MethodSettings message. Also converts values to other types if specified.
             * @param message MethodSettings
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.MethodSettings, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this MethodSettings to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for MethodSettings
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace MethodSettings {

            /** Properties of a LongRunning. */
            interface ILongRunning {

                /** LongRunning initialPollDelay */
                initialPollDelay?: (google.protobuf.IDuration|null);

                /** LongRunning pollDelayMultiplier */
                pollDelayMultiplier?: (number|null);

                /** LongRunning maxPollDelay */
                maxPollDelay?: (google.protobuf.IDuration|null);

                /** LongRunning totalPollTimeout */
                totalPollTimeout?: (google.protobuf.IDuration|null);
            }

            /** Represents a LongRunning. */
            class LongRunning implements ILongRunning {

                /**
                 * Constructs a new LongRunning.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.api.MethodSettings.ILongRunning);

                /** LongRunning initialPollDelay. */
                public initialPollDelay?: (google.protobuf.IDuration|null);

                /** LongRunning pollDelayMultiplier. */
                public pollDelayMultiplier: number;

                /** LongRunning maxPollDelay. */
                public maxPollDelay?: (google.protobuf.IDuration|null);

                /** LongRunning totalPollTimeout. */
                public totalPollTimeout?: (google.protobuf.IDuration|null);

                /**
                 * Creates a new LongRunning instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns LongRunning instance
                 */
                public static create(properties?: google.api.MethodSettings.ILongRunning): google.api.MethodSettings.LongRunning;

                /**
                 * Encodes the specified LongRunning message. Does not implicitly {@link google.api.MethodSettings.LongRunning.verify|verify} messages.
                 * @param message LongRunning message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.api.MethodSettings.ILongRunning, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified LongRunning message, length delimited. Does not implicitly {@link google.api.MethodSettings.LongRunning.verify|verify} messages.
                 * @param message LongRunning message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.api.MethodSettings.ILongRunning, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes a LongRunning message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns LongRunning
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.MethodSettings.LongRunning;

                /**
                 * Decodes a LongRunning message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns LongRunning
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.MethodSettings.LongRunning;

                /**
                 * Verifies a LongRunning message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates a LongRunning message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns LongRunning
                 */
                public static fromObject(object: { [k: string]: any }): google.api.MethodSettings.LongRunning;

                /**
                 * Creates a plain object from a LongRunning message. Also converts values to other types if specified.
                 * @param message LongRunning
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.api.MethodSettings.LongRunning, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this LongRunning to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for LongRunning
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** ClientLibraryOrganization enum. */
        enum ClientLibraryOrganization {
            CLIENT_LIBRARY_ORGANIZATION_UNSPECIFIED = 0,
            CLOUD = 1,
            ADS = 2,
            PHOTOS = 3,
            STREET_VIEW = 4,
            SHOPPING = 5,
            GEO = 6,
            GENERATIVE_AI = 7
        }

        /** ClientLibraryDestination enum. */
        enum ClientLibraryDestination {
            CLIENT_LIBRARY_DESTINATION_UNSPECIFIED = 0,
            GITHUB = 10,
            PACKAGE_MANAGER = 20
        }

        /** LaunchStage enum. */
        enum LaunchStage {
            LAUNCH_STAGE_UNSPECIFIED = 0,
            UNIMPLEMENTED = 6,
            PRELAUNCH = 7,
            EARLY_ACCESS = 1,
            ALPHA = 2,
            BETA = 3,
            GA = 4,
            DEPRECATED = 5
        }

        /** Properties of a ResourceDescriptor. */
        interface IResourceDescriptor {

            /** ResourceDescriptor type */
            type?: (string|null);

            /** ResourceDescriptor pattern */
            pattern?: (string[]|null);

            /** ResourceDescriptor nameField */
            nameField?: (string|null);

            /** ResourceDescriptor history */
            history?: (google.api.ResourceDescriptor.History|keyof typeof google.api.ResourceDescriptor.History|null);

            /** ResourceDescriptor plural */
            plural?: (string|null);

            /** ResourceDescriptor singular */
            singular?: (string|null);

            /** ResourceDescriptor style */
            style?: (google.api.ResourceDescriptor.Style[]|null);
        }

        /** Represents a ResourceDescriptor. */
        class ResourceDescriptor implements IResourceDescriptor {

            /**
             * Constructs a new ResourceDescriptor.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IResourceDescriptor);

            /** ResourceDescriptor type. */
            public type: string;

            /** ResourceDescriptor pattern. */
            public pattern: string[];

            /** ResourceDescriptor nameField. */
            public nameField: string;

            /** ResourceDescriptor history. */
            public history: (google.api.ResourceDescriptor.History|keyof typeof google.api.ResourceDescriptor.History);

            /** ResourceDescriptor plural. */
            public plural: string;

            /** ResourceDescriptor singular. */
            public singular: string;

            /** ResourceDescriptor style. */
            public style: google.api.ResourceDescriptor.Style[];

            /**
             * Creates a new ResourceDescriptor instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ResourceDescriptor instance
             */
            public static create(properties?: google.api.IResourceDescriptor): google.api.ResourceDescriptor;

            /**
             * Encodes the specified ResourceDescriptor message. Does not implicitly {@link google.api.ResourceDescriptor.verify|verify} messages.
             * @param message ResourceDescriptor message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IResourceDescriptor, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ResourceDescriptor message, length delimited. Does not implicitly {@link google.api.ResourceDescriptor.verify|verify} messages.
             * @param message ResourceDescriptor message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IResourceDescriptor, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ResourceDescriptor message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ResourceDescriptor
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.ResourceDescriptor;

            /**
             * Decodes a ResourceDescriptor message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ResourceDescriptor
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.ResourceDescriptor;

            /**
             * Verifies a ResourceDescriptor message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ResourceDescriptor message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ResourceDescriptor
             */
            public static fromObject(object: { [k: string]: any }): google.api.ResourceDescriptor;

            /**
             * Creates a plain object from a ResourceDescriptor message. Also converts values to other types if specified.
             * @param message ResourceDescriptor
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.ResourceDescriptor, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ResourceDescriptor to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ResourceDescriptor
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace ResourceDescriptor {

            /** History enum. */
            enum History {
                HISTORY_UNSPECIFIED = 0,
                ORIGINALLY_SINGLE_PATTERN = 1,
                FUTURE_MULTI_PATTERN = 2
            }

            /** Style enum. */
            enum Style {
                STYLE_UNSPECIFIED = 0,
                DECLARATIVE_FRIENDLY = 1
            }
        }

        /** Properties of a ResourceReference. */
        interface IResourceReference {

            /** ResourceReference type */
            type?: (string|null);

            /** ResourceReference childType */
            childType?: (string|null);
        }

        /** Represents a ResourceReference. */
        class ResourceReference implements IResourceReference {

            /**
             * Constructs a new ResourceReference.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.api.IResourceReference);

            /** ResourceReference type. */
            public type: string;

            /** ResourceReference childType. */
            public childType: string;

            /**
             * Creates a new ResourceReference instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ResourceReference instance
             */
            public static create(properties?: google.api.IResourceReference): google.api.ResourceReference;

            /**
             * Encodes the specified ResourceReference message. Does not implicitly {@link google.api.ResourceReference.verify|verify} messages.
             * @param message ResourceReference message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.api.IResourceReference, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ResourceReference message, length delimited. Does not implicitly {@link google.api.ResourceReference.verify|verify} messages.
             * @param message ResourceReference message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.api.IResourceReference, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ResourceReference message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ResourceReference
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.api.ResourceReference;

            /**
             * Decodes a ResourceReference message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ResourceReference
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.api.ResourceReference;

            /**
             * Verifies a ResourceReference message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ResourceReference message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ResourceReference
             */
            public static fromObject(object: { [k: string]: any }): google.api.ResourceReference;

            /**
             * Creates a plain object from a ResourceReference message. Also converts values to other types if specified.
             * @param message ResourceReference
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.api.ResourceReference, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ResourceReference to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ResourceReference
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }
    }

    /** Namespace protobuf. */
    namespace protobuf {

        /** Properties of a FileDescriptorSet. */
        interface IFileDescriptorSet {

            /** FileDescriptorSet file */
            file?: (google.protobuf.IFileDescriptorProto[]|null);
        }

        /** Represents a FileDescriptorSet. */
        class FileDescriptorSet implements IFileDescriptorSet {

            /**
             * Constructs a new FileDescriptorSet.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFileDescriptorSet);

            /** FileDescriptorSet file. */
            public file: google.protobuf.IFileDescriptorProto[];

            /**
             * Creates a new FileDescriptorSet instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FileDescriptorSet instance
             */
            public static create(properties?: google.protobuf.IFileDescriptorSet): google.protobuf.FileDescriptorSet;

            /**
             * Encodes the specified FileDescriptorSet message. Does not implicitly {@link google.protobuf.FileDescriptorSet.verify|verify} messages.
             * @param message FileDescriptorSet message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFileDescriptorSet, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FileDescriptorSet message, length delimited. Does not implicitly {@link google.protobuf.FileDescriptorSet.verify|verify} messages.
             * @param message FileDescriptorSet message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFileDescriptorSet, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FileDescriptorSet message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FileDescriptorSet
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FileDescriptorSet;

            /**
             * Decodes a FileDescriptorSet message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FileDescriptorSet
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FileDescriptorSet;

            /**
             * Verifies a FileDescriptorSet message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FileDescriptorSet message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FileDescriptorSet
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FileDescriptorSet;

            /**
             * Creates a plain object from a FileDescriptorSet message. Also converts values to other types if specified.
             * @param message FileDescriptorSet
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FileDescriptorSet, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FileDescriptorSet to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FileDescriptorSet
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Edition enum. */
        enum Edition {
            EDITION_UNKNOWN = 0,
            EDITION_PROTO2 = 998,
            EDITION_PROTO3 = 999,
            EDITION_2023 = 1000,
            EDITION_2024 = 1001,
            EDITION_1_TEST_ONLY = 1,
            EDITION_2_TEST_ONLY = 2,
            EDITION_99997_TEST_ONLY = 99997,
            EDITION_99998_TEST_ONLY = 99998,
            EDITION_99999_TEST_ONLY = 99999,
            EDITION_MAX = 2147483647
        }

        /** Properties of a FileDescriptorProto. */
        interface IFileDescriptorProto {

            /** FileDescriptorProto name */
            name?: (string|null);

            /** FileDescriptorProto package */
            "package"?: (string|null);

            /** FileDescriptorProto dependency */
            dependency?: (string[]|null);

            /** FileDescriptorProto publicDependency */
            publicDependency?: (number[]|null);

            /** FileDescriptorProto weakDependency */
            weakDependency?: (number[]|null);

            /** FileDescriptorProto messageType */
            messageType?: (google.protobuf.IDescriptorProto[]|null);

            /** FileDescriptorProto enumType */
            enumType?: (google.protobuf.IEnumDescriptorProto[]|null);

            /** FileDescriptorProto service */
            service?: (google.protobuf.IServiceDescriptorProto[]|null);

            /** FileDescriptorProto extension */
            extension?: (google.protobuf.IFieldDescriptorProto[]|null);

            /** FileDescriptorProto options */
            options?: (google.protobuf.IFileOptions|null);

            /** FileDescriptorProto sourceCodeInfo */
            sourceCodeInfo?: (google.protobuf.ISourceCodeInfo|null);

            /** FileDescriptorProto syntax */
            syntax?: (string|null);

            /** FileDescriptorProto edition */
            edition?: (google.protobuf.Edition|keyof typeof google.protobuf.Edition|null);
        }

        /** Represents a FileDescriptorProto. */
        class FileDescriptorProto implements IFileDescriptorProto {

            /**
             * Constructs a new FileDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFileDescriptorProto);

            /** FileDescriptorProto name. */
            public name: string;

            /** FileDescriptorProto package. */
            public package: string;

            /** FileDescriptorProto dependency. */
            public dependency: string[];

            /** FileDescriptorProto publicDependency. */
            public publicDependency: number[];

            /** FileDescriptorProto weakDependency. */
            public weakDependency: number[];

            /** FileDescriptorProto messageType. */
            public messageType: google.protobuf.IDescriptorProto[];

            /** FileDescriptorProto enumType. */
            public enumType: google.protobuf.IEnumDescriptorProto[];

            /** FileDescriptorProto service. */
            public service: google.protobuf.IServiceDescriptorProto[];

            /** FileDescriptorProto extension. */
            public extension: google.protobuf.IFieldDescriptorProto[];

            /** FileDescriptorProto options. */
            public options?: (google.protobuf.IFileOptions|null);

            /** FileDescriptorProto sourceCodeInfo. */
            public sourceCodeInfo?: (google.protobuf.ISourceCodeInfo|null);

            /** FileDescriptorProto syntax. */
            public syntax: string;

            /** FileDescriptorProto edition. */
            public edition: (google.protobuf.Edition|keyof typeof google.protobuf.Edition);

            /**
             * Creates a new FileDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FileDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IFileDescriptorProto): google.protobuf.FileDescriptorProto;

            /**
             * Encodes the specified FileDescriptorProto message. Does not implicitly {@link google.protobuf.FileDescriptorProto.verify|verify} messages.
             * @param message FileDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFileDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FileDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.FileDescriptorProto.verify|verify} messages.
             * @param message FileDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFileDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FileDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FileDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FileDescriptorProto;

            /**
             * Decodes a FileDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FileDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FileDescriptorProto;

            /**
             * Verifies a FileDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FileDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FileDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FileDescriptorProto;

            /**
             * Creates a plain object from a FileDescriptorProto message. Also converts values to other types if specified.
             * @param message FileDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FileDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FileDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FileDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a DescriptorProto. */
        interface IDescriptorProto {

            /** DescriptorProto name */
            name?: (string|null);

            /** DescriptorProto field */
            field?: (google.protobuf.IFieldDescriptorProto[]|null);

            /** DescriptorProto extension */
            extension?: (google.protobuf.IFieldDescriptorProto[]|null);

            /** DescriptorProto nestedType */
            nestedType?: (google.protobuf.IDescriptorProto[]|null);

            /** DescriptorProto enumType */
            enumType?: (google.protobuf.IEnumDescriptorProto[]|null);

            /** DescriptorProto extensionRange */
            extensionRange?: (google.protobuf.DescriptorProto.IExtensionRange[]|null);

            /** DescriptorProto oneofDecl */
            oneofDecl?: (google.protobuf.IOneofDescriptorProto[]|null);

            /** DescriptorProto options */
            options?: (google.protobuf.IMessageOptions|null);

            /** DescriptorProto reservedRange */
            reservedRange?: (google.protobuf.DescriptorProto.IReservedRange[]|null);

            /** DescriptorProto reservedName */
            reservedName?: (string[]|null);
        }

        /** Represents a DescriptorProto. */
        class DescriptorProto implements IDescriptorProto {

            /**
             * Constructs a new DescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IDescriptorProto);

            /** DescriptorProto name. */
            public name: string;

            /** DescriptorProto field. */
            public field: google.protobuf.IFieldDescriptorProto[];

            /** DescriptorProto extension. */
            public extension: google.protobuf.IFieldDescriptorProto[];

            /** DescriptorProto nestedType. */
            public nestedType: google.protobuf.IDescriptorProto[];

            /** DescriptorProto enumType. */
            public enumType: google.protobuf.IEnumDescriptorProto[];

            /** DescriptorProto extensionRange. */
            public extensionRange: google.protobuf.DescriptorProto.IExtensionRange[];

            /** DescriptorProto oneofDecl. */
            public oneofDecl: google.protobuf.IOneofDescriptorProto[];

            /** DescriptorProto options. */
            public options?: (google.protobuf.IMessageOptions|null);

            /** DescriptorProto reservedRange. */
            public reservedRange: google.protobuf.DescriptorProto.IReservedRange[];

            /** DescriptorProto reservedName. */
            public reservedName: string[];

            /**
             * Creates a new DescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns DescriptorProto instance
             */
            public static create(properties?: google.protobuf.IDescriptorProto): google.protobuf.DescriptorProto;

            /**
             * Encodes the specified DescriptorProto message. Does not implicitly {@link google.protobuf.DescriptorProto.verify|verify} messages.
             * @param message DescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified DescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.DescriptorProto.verify|verify} messages.
             * @param message DescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a DescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns DescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.DescriptorProto;

            /**
             * Decodes a DescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns DescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.DescriptorProto;

            /**
             * Verifies a DescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a DescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns DescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.DescriptorProto;

            /**
             * Creates a plain object from a DescriptorProto message. Also converts values to other types if specified.
             * @param message DescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.DescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this DescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for DescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace DescriptorProto {

            /** Properties of an ExtensionRange. */
            interface IExtensionRange {

                /** ExtensionRange start */
                start?: (number|null);

                /** ExtensionRange end */
                end?: (number|null);

                /** ExtensionRange options */
                options?: (google.protobuf.IExtensionRangeOptions|null);
            }

            /** Represents an ExtensionRange. */
            class ExtensionRange implements IExtensionRange {

                /**
                 * Constructs a new ExtensionRange.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.DescriptorProto.IExtensionRange);

                /** ExtensionRange start. */
                public start: number;

                /** ExtensionRange end. */
                public end: number;

                /** ExtensionRange options. */
                public options?: (google.protobuf.IExtensionRangeOptions|null);

                /**
                 * Creates a new ExtensionRange instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns ExtensionRange instance
                 */
                public static create(properties?: google.protobuf.DescriptorProto.IExtensionRange): google.protobuf.DescriptorProto.ExtensionRange;

                /**
                 * Encodes the specified ExtensionRange message. Does not implicitly {@link google.protobuf.DescriptorProto.ExtensionRange.verify|verify} messages.
                 * @param message ExtensionRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.DescriptorProto.IExtensionRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified ExtensionRange message, length delimited. Does not implicitly {@link google.protobuf.DescriptorProto.ExtensionRange.verify|verify} messages.
                 * @param message ExtensionRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.DescriptorProto.IExtensionRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes an ExtensionRange message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns ExtensionRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.DescriptorProto.ExtensionRange;

                /**
                 * Decodes an ExtensionRange message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns ExtensionRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.DescriptorProto.ExtensionRange;

                /**
                 * Verifies an ExtensionRange message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates an ExtensionRange message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns ExtensionRange
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.DescriptorProto.ExtensionRange;

                /**
                 * Creates a plain object from an ExtensionRange message. Also converts values to other types if specified.
                 * @param message ExtensionRange
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.DescriptorProto.ExtensionRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this ExtensionRange to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for ExtensionRange
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }

            /** Properties of a ReservedRange. */
            interface IReservedRange {

                /** ReservedRange start */
                start?: (number|null);

                /** ReservedRange end */
                end?: (number|null);
            }

            /** Represents a ReservedRange. */
            class ReservedRange implements IReservedRange {

                /**
                 * Constructs a new ReservedRange.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.DescriptorProto.IReservedRange);

                /** ReservedRange start. */
                public start: number;

                /** ReservedRange end. */
                public end: number;

                /**
                 * Creates a new ReservedRange instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns ReservedRange instance
                 */
                public static create(properties?: google.protobuf.DescriptorProto.IReservedRange): google.protobuf.DescriptorProto.ReservedRange;

                /**
                 * Encodes the specified ReservedRange message. Does not implicitly {@link google.protobuf.DescriptorProto.ReservedRange.verify|verify} messages.
                 * @param message ReservedRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.DescriptorProto.IReservedRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified ReservedRange message, length delimited. Does not implicitly {@link google.protobuf.DescriptorProto.ReservedRange.verify|verify} messages.
                 * @param message ReservedRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.DescriptorProto.IReservedRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes a ReservedRange message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns ReservedRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.DescriptorProto.ReservedRange;

                /**
                 * Decodes a ReservedRange message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns ReservedRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.DescriptorProto.ReservedRange;

                /**
                 * Verifies a ReservedRange message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates a ReservedRange message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns ReservedRange
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.DescriptorProto.ReservedRange;

                /**
                 * Creates a plain object from a ReservedRange message. Also converts values to other types if specified.
                 * @param message ReservedRange
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.DescriptorProto.ReservedRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this ReservedRange to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for ReservedRange
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of an ExtensionRangeOptions. */
        interface IExtensionRangeOptions {

            /** ExtensionRangeOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** ExtensionRangeOptions declaration */
            declaration?: (google.protobuf.ExtensionRangeOptions.IDeclaration[]|null);

            /** ExtensionRangeOptions features */
            features?: (google.protobuf.IFeatureSet|null);

            /** ExtensionRangeOptions verification */
            verification?: (google.protobuf.ExtensionRangeOptions.VerificationState|keyof typeof google.protobuf.ExtensionRangeOptions.VerificationState|null);
        }

        /** Represents an ExtensionRangeOptions. */
        class ExtensionRangeOptions implements IExtensionRangeOptions {

            /**
             * Constructs a new ExtensionRangeOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IExtensionRangeOptions);

            /** ExtensionRangeOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /** ExtensionRangeOptions declaration. */
            public declaration: google.protobuf.ExtensionRangeOptions.IDeclaration[];

            /** ExtensionRangeOptions features. */
            public features?: (google.protobuf.IFeatureSet|null);

            /** ExtensionRangeOptions verification. */
            public verification: (google.protobuf.ExtensionRangeOptions.VerificationState|keyof typeof google.protobuf.ExtensionRangeOptions.VerificationState);

            /**
             * Creates a new ExtensionRangeOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ExtensionRangeOptions instance
             */
            public static create(properties?: google.protobuf.IExtensionRangeOptions): google.protobuf.ExtensionRangeOptions;

            /**
             * Encodes the specified ExtensionRangeOptions message. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.verify|verify} messages.
             * @param message ExtensionRangeOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IExtensionRangeOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ExtensionRangeOptions message, length delimited. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.verify|verify} messages.
             * @param message ExtensionRangeOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IExtensionRangeOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an ExtensionRangeOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ExtensionRangeOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.ExtensionRangeOptions;

            /**
             * Decodes an ExtensionRangeOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ExtensionRangeOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.ExtensionRangeOptions;

            /**
             * Verifies an ExtensionRangeOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an ExtensionRangeOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ExtensionRangeOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.ExtensionRangeOptions;

            /**
             * Creates a plain object from an ExtensionRangeOptions message. Also converts values to other types if specified.
             * @param message ExtensionRangeOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.ExtensionRangeOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ExtensionRangeOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ExtensionRangeOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace ExtensionRangeOptions {

            /** Properties of a Declaration. */
            interface IDeclaration {

                /** Declaration number */
                number?: (number|null);

                /** Declaration fullName */
                fullName?: (string|null);

                /** Declaration type */
                type?: (string|null);

                /** Declaration reserved */
                reserved?: (boolean|null);

                /** Declaration repeated */
                repeated?: (boolean|null);
            }

            /** Represents a Declaration. */
            class Declaration implements IDeclaration {

                /**
                 * Constructs a new Declaration.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.ExtensionRangeOptions.IDeclaration);

                /** Declaration number. */
                public number: number;

                /** Declaration fullName. */
                public fullName: string;

                /** Declaration type. */
                public type: string;

                /** Declaration reserved. */
                public reserved: boolean;

                /** Declaration repeated. */
                public repeated: boolean;

                /**
                 * Creates a new Declaration instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns Declaration instance
                 */
                public static create(properties?: google.protobuf.ExtensionRangeOptions.IDeclaration): google.protobuf.ExtensionRangeOptions.Declaration;

                /**
                 * Encodes the specified Declaration message. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.Declaration.verify|verify} messages.
                 * @param message Declaration message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.ExtensionRangeOptions.IDeclaration, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified Declaration message, length delimited. Does not implicitly {@link google.protobuf.ExtensionRangeOptions.Declaration.verify|verify} messages.
                 * @param message Declaration message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.ExtensionRangeOptions.IDeclaration, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes a Declaration message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns Declaration
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.ExtensionRangeOptions.Declaration;

                /**
                 * Decodes a Declaration message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns Declaration
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.ExtensionRangeOptions.Declaration;

                /**
                 * Verifies a Declaration message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates a Declaration message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns Declaration
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.ExtensionRangeOptions.Declaration;

                /**
                 * Creates a plain object from a Declaration message. Also converts values to other types if specified.
                 * @param message Declaration
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.ExtensionRangeOptions.Declaration, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this Declaration to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for Declaration
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }

            /** VerificationState enum. */
            enum VerificationState {
                DECLARATION = 0,
                UNVERIFIED = 1
            }
        }

        /** Properties of a FieldDescriptorProto. */
        interface IFieldDescriptorProto {

            /** FieldDescriptorProto name */
            name?: (string|null);

            /** FieldDescriptorProto number */
            number?: (number|null);

            /** FieldDescriptorProto label */
            label?: (google.protobuf.FieldDescriptorProto.Label|keyof typeof google.protobuf.FieldDescriptorProto.Label|null);

            /** FieldDescriptorProto type */
            type?: (google.protobuf.FieldDescriptorProto.Type|keyof typeof google.protobuf.FieldDescriptorProto.Type|null);

            /** FieldDescriptorProto typeName */
            typeName?: (string|null);

            /** FieldDescriptorProto extendee */
            extendee?: (string|null);

            /** FieldDescriptorProto defaultValue */
            defaultValue?: (string|null);

            /** FieldDescriptorProto oneofIndex */
            oneofIndex?: (number|null);

            /** FieldDescriptorProto jsonName */
            jsonName?: (string|null);

            /** FieldDescriptorProto options */
            options?: (google.protobuf.IFieldOptions|null);

            /** FieldDescriptorProto proto3Optional */
            proto3Optional?: (boolean|null);
        }

        /** Represents a FieldDescriptorProto. */
        class FieldDescriptorProto implements IFieldDescriptorProto {

            /**
             * Constructs a new FieldDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFieldDescriptorProto);

            /** FieldDescriptorProto name. */
            public name: string;

            /** FieldDescriptorProto number. */
            public number: number;

            /** FieldDescriptorProto label. */
            public label: (google.protobuf.FieldDescriptorProto.Label|keyof typeof google.protobuf.FieldDescriptorProto.Label);

            /** FieldDescriptorProto type. */
            public type: (google.protobuf.FieldDescriptorProto.Type|keyof typeof google.protobuf.FieldDescriptorProto.Type);

            /** FieldDescriptorProto typeName. */
            public typeName: string;

            /** FieldDescriptorProto extendee. */
            public extendee: string;

            /** FieldDescriptorProto defaultValue. */
            public defaultValue: string;

            /** FieldDescriptorProto oneofIndex. */
            public oneofIndex: number;

            /** FieldDescriptorProto jsonName. */
            public jsonName: string;

            /** FieldDescriptorProto options. */
            public options?: (google.protobuf.IFieldOptions|null);

            /** FieldDescriptorProto proto3Optional. */
            public proto3Optional: boolean;

            /**
             * Creates a new FieldDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FieldDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IFieldDescriptorProto): google.protobuf.FieldDescriptorProto;

            /**
             * Encodes the specified FieldDescriptorProto message. Does not implicitly {@link google.protobuf.FieldDescriptorProto.verify|verify} messages.
             * @param message FieldDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFieldDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FieldDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.FieldDescriptorProto.verify|verify} messages.
             * @param message FieldDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFieldDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FieldDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FieldDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FieldDescriptorProto;

            /**
             * Decodes a FieldDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FieldDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FieldDescriptorProto;

            /**
             * Verifies a FieldDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FieldDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FieldDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FieldDescriptorProto;

            /**
             * Creates a plain object from a FieldDescriptorProto message. Also converts values to other types if specified.
             * @param message FieldDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FieldDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FieldDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FieldDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace FieldDescriptorProto {

            /** Type enum. */
            enum Type {
                TYPE_DOUBLE = 1,
                TYPE_FLOAT = 2,
                TYPE_INT64 = 3,
                TYPE_UINT64 = 4,
                TYPE_INT32 = 5,
                TYPE_FIXED64 = 6,
                TYPE_FIXED32 = 7,
                TYPE_BOOL = 8,
                TYPE_STRING = 9,
                TYPE_GROUP = 10,
                TYPE_MESSAGE = 11,
                TYPE_BYTES = 12,
                TYPE_UINT32 = 13,
                TYPE_ENUM = 14,
                TYPE_SFIXED32 = 15,
                TYPE_SFIXED64 = 16,
                TYPE_SINT32 = 17,
                TYPE_SINT64 = 18
            }

            /** Label enum. */
            enum Label {
                LABEL_OPTIONAL = 1,
                LABEL_REPEATED = 3,
                LABEL_REQUIRED = 2
            }
        }

        /** Properties of an OneofDescriptorProto. */
        interface IOneofDescriptorProto {

            /** OneofDescriptorProto name */
            name?: (string|null);

            /** OneofDescriptorProto options */
            options?: (google.protobuf.IOneofOptions|null);
        }

        /** Represents an OneofDescriptorProto. */
        class OneofDescriptorProto implements IOneofDescriptorProto {

            /**
             * Constructs a new OneofDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IOneofDescriptorProto);

            /** OneofDescriptorProto name. */
            public name: string;

            /** OneofDescriptorProto options. */
            public options?: (google.protobuf.IOneofOptions|null);

            /**
             * Creates a new OneofDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns OneofDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IOneofDescriptorProto): google.protobuf.OneofDescriptorProto;

            /**
             * Encodes the specified OneofDescriptorProto message. Does not implicitly {@link google.protobuf.OneofDescriptorProto.verify|verify} messages.
             * @param message OneofDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IOneofDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified OneofDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.OneofDescriptorProto.verify|verify} messages.
             * @param message OneofDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IOneofDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an OneofDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns OneofDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.OneofDescriptorProto;

            /**
             * Decodes an OneofDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns OneofDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.OneofDescriptorProto;

            /**
             * Verifies an OneofDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an OneofDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns OneofDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.OneofDescriptorProto;

            /**
             * Creates a plain object from an OneofDescriptorProto message. Also converts values to other types if specified.
             * @param message OneofDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.OneofDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this OneofDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for OneofDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an EnumDescriptorProto. */
        interface IEnumDescriptorProto {

            /** EnumDescriptorProto name */
            name?: (string|null);

            /** EnumDescriptorProto value */
            value?: (google.protobuf.IEnumValueDescriptorProto[]|null);

            /** EnumDescriptorProto options */
            options?: (google.protobuf.IEnumOptions|null);

            /** EnumDescriptorProto reservedRange */
            reservedRange?: (google.protobuf.EnumDescriptorProto.IEnumReservedRange[]|null);

            /** EnumDescriptorProto reservedName */
            reservedName?: (string[]|null);
        }

        /** Represents an EnumDescriptorProto. */
        class EnumDescriptorProto implements IEnumDescriptorProto {

            /**
             * Constructs a new EnumDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IEnumDescriptorProto);

            /** EnumDescriptorProto name. */
            public name: string;

            /** EnumDescriptorProto value. */
            public value: google.protobuf.IEnumValueDescriptorProto[];

            /** EnumDescriptorProto options. */
            public options?: (google.protobuf.IEnumOptions|null);

            /** EnumDescriptorProto reservedRange. */
            public reservedRange: google.protobuf.EnumDescriptorProto.IEnumReservedRange[];

            /** EnumDescriptorProto reservedName. */
            public reservedName: string[];

            /**
             * Creates a new EnumDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns EnumDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IEnumDescriptorProto): google.protobuf.EnumDescriptorProto;

            /**
             * Encodes the specified EnumDescriptorProto message. Does not implicitly {@link google.protobuf.EnumDescriptorProto.verify|verify} messages.
             * @param message EnumDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IEnumDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified EnumDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.EnumDescriptorProto.verify|verify} messages.
             * @param message EnumDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IEnumDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an EnumDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns EnumDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumDescriptorProto;

            /**
             * Decodes an EnumDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns EnumDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumDescriptorProto;

            /**
             * Verifies an EnumDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an EnumDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns EnumDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.EnumDescriptorProto;

            /**
             * Creates a plain object from an EnumDescriptorProto message. Also converts values to other types if specified.
             * @param message EnumDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.EnumDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this EnumDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for EnumDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace EnumDescriptorProto {

            /** Properties of an EnumReservedRange. */
            interface IEnumReservedRange {

                /** EnumReservedRange start */
                start?: (number|null);

                /** EnumReservedRange end */
                end?: (number|null);
            }

            /** Represents an EnumReservedRange. */
            class EnumReservedRange implements IEnumReservedRange {

                /**
                 * Constructs a new EnumReservedRange.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.EnumDescriptorProto.IEnumReservedRange);

                /** EnumReservedRange start. */
                public start: number;

                /** EnumReservedRange end. */
                public end: number;

                /**
                 * Creates a new EnumReservedRange instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns EnumReservedRange instance
                 */
                public static create(properties?: google.protobuf.EnumDescriptorProto.IEnumReservedRange): google.protobuf.EnumDescriptorProto.EnumReservedRange;

                /**
                 * Encodes the specified EnumReservedRange message. Does not implicitly {@link google.protobuf.EnumDescriptorProto.EnumReservedRange.verify|verify} messages.
                 * @param message EnumReservedRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.EnumDescriptorProto.IEnumReservedRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified EnumReservedRange message, length delimited. Does not implicitly {@link google.protobuf.EnumDescriptorProto.EnumReservedRange.verify|verify} messages.
                 * @param message EnumReservedRange message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.EnumDescriptorProto.IEnumReservedRange, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes an EnumReservedRange message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns EnumReservedRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumDescriptorProto.EnumReservedRange;

                /**
                 * Decodes an EnumReservedRange message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns EnumReservedRange
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumDescriptorProto.EnumReservedRange;

                /**
                 * Verifies an EnumReservedRange message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates an EnumReservedRange message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns EnumReservedRange
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.EnumDescriptorProto.EnumReservedRange;

                /**
                 * Creates a plain object from an EnumReservedRange message. Also converts values to other types if specified.
                 * @param message EnumReservedRange
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.EnumDescriptorProto.EnumReservedRange, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this EnumReservedRange to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for EnumReservedRange
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of an EnumValueDescriptorProto. */
        interface IEnumValueDescriptorProto {

            /** EnumValueDescriptorProto name */
            name?: (string|null);

            /** EnumValueDescriptorProto number */
            number?: (number|null);

            /** EnumValueDescriptorProto options */
            options?: (google.protobuf.IEnumValueOptions|null);
        }

        /** Represents an EnumValueDescriptorProto. */
        class EnumValueDescriptorProto implements IEnumValueDescriptorProto {

            /**
             * Constructs a new EnumValueDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IEnumValueDescriptorProto);

            /** EnumValueDescriptorProto name. */
            public name: string;

            /** EnumValueDescriptorProto number. */
            public number: number;

            /** EnumValueDescriptorProto options. */
            public options?: (google.protobuf.IEnumValueOptions|null);

            /**
             * Creates a new EnumValueDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns EnumValueDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IEnumValueDescriptorProto): google.protobuf.EnumValueDescriptorProto;

            /**
             * Encodes the specified EnumValueDescriptorProto message. Does not implicitly {@link google.protobuf.EnumValueDescriptorProto.verify|verify} messages.
             * @param message EnumValueDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IEnumValueDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified EnumValueDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.EnumValueDescriptorProto.verify|verify} messages.
             * @param message EnumValueDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IEnumValueDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an EnumValueDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns EnumValueDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumValueDescriptorProto;

            /**
             * Decodes an EnumValueDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns EnumValueDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumValueDescriptorProto;

            /**
             * Verifies an EnumValueDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an EnumValueDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns EnumValueDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.EnumValueDescriptorProto;

            /**
             * Creates a plain object from an EnumValueDescriptorProto message. Also converts values to other types if specified.
             * @param message EnumValueDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.EnumValueDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this EnumValueDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for EnumValueDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a ServiceDescriptorProto. */
        interface IServiceDescriptorProto {

            /** ServiceDescriptorProto name */
            name?: (string|null);

            /** ServiceDescriptorProto method */
            method?: (google.protobuf.IMethodDescriptorProto[]|null);

            /** ServiceDescriptorProto options */
            options?: (google.protobuf.IServiceOptions|null);
        }

        /** Represents a ServiceDescriptorProto. */
        class ServiceDescriptorProto implements IServiceDescriptorProto {

            /**
             * Constructs a new ServiceDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IServiceDescriptorProto);

            /** ServiceDescriptorProto name. */
            public name: string;

            /** ServiceDescriptorProto method. */
            public method: google.protobuf.IMethodDescriptorProto[];

            /** ServiceDescriptorProto options. */
            public options?: (google.protobuf.IServiceOptions|null);

            /**
             * Creates a new ServiceDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ServiceDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IServiceDescriptorProto): google.protobuf.ServiceDescriptorProto;

            /**
             * Encodes the specified ServiceDescriptorProto message. Does not implicitly {@link google.protobuf.ServiceDescriptorProto.verify|verify} messages.
             * @param message ServiceDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IServiceDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ServiceDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.ServiceDescriptorProto.verify|verify} messages.
             * @param message ServiceDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IServiceDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ServiceDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ServiceDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.ServiceDescriptorProto;

            /**
             * Decodes a ServiceDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ServiceDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.ServiceDescriptorProto;

            /**
             * Verifies a ServiceDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ServiceDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ServiceDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.ServiceDescriptorProto;

            /**
             * Creates a plain object from a ServiceDescriptorProto message. Also converts values to other types if specified.
             * @param message ServiceDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.ServiceDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ServiceDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ServiceDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a MethodDescriptorProto. */
        interface IMethodDescriptorProto {

            /** MethodDescriptorProto name */
            name?: (string|null);

            /** MethodDescriptorProto inputType */
            inputType?: (string|null);

            /** MethodDescriptorProto outputType */
            outputType?: (string|null);

            /** MethodDescriptorProto options */
            options?: (google.protobuf.IMethodOptions|null);

            /** MethodDescriptorProto clientStreaming */
            clientStreaming?: (boolean|null);

            /** MethodDescriptorProto serverStreaming */
            serverStreaming?: (boolean|null);
        }

        /** Represents a MethodDescriptorProto. */
        class MethodDescriptorProto implements IMethodDescriptorProto {

            /**
             * Constructs a new MethodDescriptorProto.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IMethodDescriptorProto);

            /** MethodDescriptorProto name. */
            public name: string;

            /** MethodDescriptorProto inputType. */
            public inputType: string;

            /** MethodDescriptorProto outputType. */
            public outputType: string;

            /** MethodDescriptorProto options. */
            public options?: (google.protobuf.IMethodOptions|null);

            /** MethodDescriptorProto clientStreaming. */
            public clientStreaming: boolean;

            /** MethodDescriptorProto serverStreaming. */
            public serverStreaming: boolean;

            /**
             * Creates a new MethodDescriptorProto instance using the specified properties.
             * @param [properties] Properties to set
             * @returns MethodDescriptorProto instance
             */
            public static create(properties?: google.protobuf.IMethodDescriptorProto): google.protobuf.MethodDescriptorProto;

            /**
             * Encodes the specified MethodDescriptorProto message. Does not implicitly {@link google.protobuf.MethodDescriptorProto.verify|verify} messages.
             * @param message MethodDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IMethodDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified MethodDescriptorProto message, length delimited. Does not implicitly {@link google.protobuf.MethodDescriptorProto.verify|verify} messages.
             * @param message MethodDescriptorProto message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IMethodDescriptorProto, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a MethodDescriptorProto message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns MethodDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.MethodDescriptorProto;

            /**
             * Decodes a MethodDescriptorProto message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns MethodDescriptorProto
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.MethodDescriptorProto;

            /**
             * Verifies a MethodDescriptorProto message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a MethodDescriptorProto message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns MethodDescriptorProto
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.MethodDescriptorProto;

            /**
             * Creates a plain object from a MethodDescriptorProto message. Also converts values to other types if specified.
             * @param message MethodDescriptorProto
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.MethodDescriptorProto, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this MethodDescriptorProto to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for MethodDescriptorProto
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a FileOptions. */
        interface IFileOptions {

            /** FileOptions javaPackage */
            javaPackage?: (string|null);

            /** FileOptions javaOuterClassname */
            javaOuterClassname?: (string|null);

            /** FileOptions javaMultipleFiles */
            javaMultipleFiles?: (boolean|null);

            /** FileOptions javaGenerateEqualsAndHash */
            javaGenerateEqualsAndHash?: (boolean|null);

            /** FileOptions javaStringCheckUtf8 */
            javaStringCheckUtf8?: (boolean|null);

            /** FileOptions optimizeFor */
            optimizeFor?: (google.protobuf.FileOptions.OptimizeMode|keyof typeof google.protobuf.FileOptions.OptimizeMode|null);

            /** FileOptions goPackage */
            goPackage?: (string|null);

            /** FileOptions ccGenericServices */
            ccGenericServices?: (boolean|null);

            /** FileOptions javaGenericServices */
            javaGenericServices?: (boolean|null);

            /** FileOptions pyGenericServices */
            pyGenericServices?: (boolean|null);

            /** FileOptions deprecated */
            deprecated?: (boolean|null);

            /** FileOptions ccEnableArenas */
            ccEnableArenas?: (boolean|null);

            /** FileOptions objcClassPrefix */
            objcClassPrefix?: (string|null);

            /** FileOptions csharpNamespace */
            csharpNamespace?: (string|null);

            /** FileOptions swiftPrefix */
            swiftPrefix?: (string|null);

            /** FileOptions phpClassPrefix */
            phpClassPrefix?: (string|null);

            /** FileOptions phpNamespace */
            phpNamespace?: (string|null);

            /** FileOptions phpMetadataNamespace */
            phpMetadataNamespace?: (string|null);

            /** FileOptions rubyPackage */
            rubyPackage?: (string|null);

            /** FileOptions features */
            features?: (google.protobuf.IFeatureSet|null);

            /** FileOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** FileOptions .google.api.resourceDefinition */
            ".google.api.resourceDefinition"?: (google.api.IResourceDescriptor[]|null);
        }

        /** Represents a FileOptions. */
        class FileOptions implements IFileOptions {

            /**
             * Constructs a new FileOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFileOptions);

            /** FileOptions javaPackage. */
            public javaPackage: string;

            /** FileOptions javaOuterClassname. */
            public javaOuterClassname: string;

            /** FileOptions javaMultipleFiles. */
            public javaMultipleFiles: boolean;

            /** FileOptions javaGenerateEqualsAndHash. */
            public javaGenerateEqualsAndHash: boolean;

            /** FileOptions javaStringCheckUtf8. */
            public javaStringCheckUtf8: boolean;

            /** FileOptions optimizeFor. */
            public optimizeFor: (google.protobuf.FileOptions.OptimizeMode|keyof typeof google.protobuf.FileOptions.OptimizeMode);

            /** FileOptions goPackage. */
            public goPackage: string;

            /** FileOptions ccGenericServices. */
            public ccGenericServices: boolean;

            /** FileOptions javaGenericServices. */
            public javaGenericServices: boolean;

            /** FileOptions pyGenericServices. */
            public pyGenericServices: boolean;

            /** FileOptions deprecated. */
            public deprecated: boolean;

            /** FileOptions ccEnableArenas. */
            public ccEnableArenas: boolean;

            /** FileOptions objcClassPrefix. */
            public objcClassPrefix: string;

            /** FileOptions csharpNamespace. */
            public csharpNamespace: string;

            /** FileOptions swiftPrefix. */
            public swiftPrefix: string;

            /** FileOptions phpClassPrefix. */
            public phpClassPrefix: string;

            /** FileOptions phpNamespace. */
            public phpNamespace: string;

            /** FileOptions phpMetadataNamespace. */
            public phpMetadataNamespace: string;

            /** FileOptions rubyPackage. */
            public rubyPackage: string;

            /** FileOptions features. */
            public features?: (google.protobuf.IFeatureSet|null);

            /** FileOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new FileOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FileOptions instance
             */
            public static create(properties?: google.protobuf.IFileOptions): google.protobuf.FileOptions;

            /**
             * Encodes the specified FileOptions message. Does not implicitly {@link google.protobuf.FileOptions.verify|verify} messages.
             * @param message FileOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFileOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FileOptions message, length delimited. Does not implicitly {@link google.protobuf.FileOptions.verify|verify} messages.
             * @param message FileOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFileOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FileOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FileOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FileOptions;

            /**
             * Decodes a FileOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FileOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FileOptions;

            /**
             * Verifies a FileOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FileOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FileOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FileOptions;

            /**
             * Creates a plain object from a FileOptions message. Also converts values to other types if specified.
             * @param message FileOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FileOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FileOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FileOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace FileOptions {

            /** OptimizeMode enum. */
            enum OptimizeMode {
                SPEED = 1,
                CODE_SIZE = 2,
                LITE_RUNTIME = 3
            }
        }

        /** Properties of a MessageOptions. */
        interface IMessageOptions {

            /** MessageOptions messageSetWireFormat */
            messageSetWireFormat?: (boolean|null);

            /** MessageOptions noStandardDescriptorAccessor */
            noStandardDescriptorAccessor?: (boolean|null);

            /** MessageOptions deprecated */
            deprecated?: (boolean|null);

            /** MessageOptions mapEntry */
            mapEntry?: (boolean|null);

            /** MessageOptions deprecatedLegacyJsonFieldConflicts */
            deprecatedLegacyJsonFieldConflicts?: (boolean|null);

            /** MessageOptions features */
            features?: (google.protobuf.IFeatureSet|null);

            /** MessageOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** MessageOptions .google.api.resource */
            ".google.api.resource"?: (google.api.IResourceDescriptor|null);
        }

        /** Represents a MessageOptions. */
        class MessageOptions implements IMessageOptions {

            /**
             * Constructs a new MessageOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IMessageOptions);

            /** MessageOptions messageSetWireFormat. */
            public messageSetWireFormat: boolean;

            /** MessageOptions noStandardDescriptorAccessor. */
            public noStandardDescriptorAccessor: boolean;

            /** MessageOptions deprecated. */
            public deprecated: boolean;

            /** MessageOptions mapEntry. */
            public mapEntry: boolean;

            /** MessageOptions deprecatedLegacyJsonFieldConflicts. */
            public deprecatedLegacyJsonFieldConflicts: boolean;

            /** MessageOptions features. */
            public features?: (google.protobuf.IFeatureSet|null);

            /** MessageOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new MessageOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns MessageOptions instance
             */
            public static create(properties?: google.protobuf.IMessageOptions): google.protobuf.MessageOptions;

            /**
             * Encodes the specified MessageOptions message. Does not implicitly {@link google.protobuf.MessageOptions.verify|verify} messages.
             * @param message MessageOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IMessageOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified MessageOptions message, length delimited. Does not implicitly {@link google.protobuf.MessageOptions.verify|verify} messages.
             * @param message MessageOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IMessageOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a MessageOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns MessageOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.MessageOptions;

            /**
             * Decodes a MessageOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns MessageOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.MessageOptions;

            /**
             * Verifies a MessageOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a MessageOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns MessageOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.MessageOptions;

            /**
             * Creates a plain object from a MessageOptions message. Also converts values to other types if specified.
             * @param message MessageOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.MessageOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this MessageOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for MessageOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a FieldOptions. */
        interface IFieldOptions {

            /** FieldOptions ctype */
            ctype?: (google.protobuf.FieldOptions.CType|keyof typeof google.protobuf.FieldOptions.CType|null);

            /** FieldOptions packed */
            packed?: (boolean|null);

            /** FieldOptions jstype */
            jstype?: (google.protobuf.FieldOptions.JSType|keyof typeof google.protobuf.FieldOptions.JSType|null);

            /** FieldOptions lazy */
            lazy?: (boolean|null);

            /** FieldOptions unverifiedLazy */
            unverifiedLazy?: (boolean|null);

            /** FieldOptions deprecated */
            deprecated?: (boolean|null);

            /** FieldOptions weak */
            weak?: (boolean|null);

            /** FieldOptions debugRedact */
            debugRedact?: (boolean|null);

            /** FieldOptions retention */
            retention?: (google.protobuf.FieldOptions.OptionRetention|keyof typeof google.protobuf.FieldOptions.OptionRetention|null);

            /** FieldOptions targets */
            targets?: (google.protobuf.FieldOptions.OptionTargetType[]|null);

            /** FieldOptions editionDefaults */
            editionDefaults?: (google.protobuf.FieldOptions.IEditionDefault[]|null);

            /** FieldOptions features */
            features?: (google.protobuf.IFeatureSet|null);

            /** FieldOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** FieldOptions .google.api.fieldBehavior */
            ".google.api.fieldBehavior"?: (google.api.FieldBehavior[]|null);

            /** FieldOptions .google.api.resourceReference */
            ".google.api.resourceReference"?: (google.api.IResourceReference|null);
        }

        /** Represents a FieldOptions. */
        class FieldOptions implements IFieldOptions {

            /**
             * Constructs a new FieldOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFieldOptions);

            /** FieldOptions ctype. */
            public ctype: (google.protobuf.FieldOptions.CType|keyof typeof google.protobuf.FieldOptions.CType);

            /** FieldOptions packed. */
            public packed: boolean;

            /** FieldOptions jstype. */
            public jstype: (google.protobuf.FieldOptions.JSType|keyof typeof google.protobuf.FieldOptions.JSType);

            /** FieldOptions lazy. */
            public lazy: boolean;

            /** FieldOptions unverifiedLazy. */
            public unverifiedLazy: boolean;

            /** FieldOptions deprecated. */
            public deprecated: boolean;

            /** FieldOptions weak. */
            public weak: boolean;

            /** FieldOptions debugRedact. */
            public debugRedact: boolean;

            /** FieldOptions retention. */
            public retention: (google.protobuf.FieldOptions.OptionRetention|keyof typeof google.protobuf.FieldOptions.OptionRetention);

            /** FieldOptions targets. */
            public targets: google.protobuf.FieldOptions.OptionTargetType[];

            /** FieldOptions editionDefaults. */
            public editionDefaults: google.protobuf.FieldOptions.IEditionDefault[];

            /** FieldOptions features. */
            public features?: (google.protobuf.IFeatureSet|null);

            /** FieldOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new FieldOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FieldOptions instance
             */
            public static create(properties?: google.protobuf.IFieldOptions): google.protobuf.FieldOptions;

            /**
             * Encodes the specified FieldOptions message. Does not implicitly {@link google.protobuf.FieldOptions.verify|verify} messages.
             * @param message FieldOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFieldOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FieldOptions message, length delimited. Does not implicitly {@link google.protobuf.FieldOptions.verify|verify} messages.
             * @param message FieldOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFieldOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FieldOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FieldOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FieldOptions;

            /**
             * Decodes a FieldOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FieldOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FieldOptions;

            /**
             * Verifies a FieldOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FieldOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FieldOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FieldOptions;

            /**
             * Creates a plain object from a FieldOptions message. Also converts values to other types if specified.
             * @param message FieldOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FieldOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FieldOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FieldOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace FieldOptions {

            /** CType enum. */
            enum CType {
                STRING = 0,
                CORD = 1,
                STRING_PIECE = 2
            }

            /** JSType enum. */
            enum JSType {
                JS_NORMAL = 0,
                JS_STRING = 1,
                JS_NUMBER = 2
            }

            /** OptionRetention enum. */
            enum OptionRetention {
                RETENTION_UNKNOWN = 0,
                RETENTION_RUNTIME = 1,
                RETENTION_SOURCE = 2
            }

            /** OptionTargetType enum. */
            enum OptionTargetType {
                TARGET_TYPE_UNKNOWN = 0,
                TARGET_TYPE_FILE = 1,
                TARGET_TYPE_EXTENSION_RANGE = 2,
                TARGET_TYPE_MESSAGE = 3,
                TARGET_TYPE_FIELD = 4,
                TARGET_TYPE_ONEOF = 5,
                TARGET_TYPE_ENUM = 6,
                TARGET_TYPE_ENUM_ENTRY = 7,
                TARGET_TYPE_SERVICE = 8,
                TARGET_TYPE_METHOD = 9
            }

            /** Properties of an EditionDefault. */
            interface IEditionDefault {

                /** EditionDefault edition */
                edition?: (google.protobuf.Edition|keyof typeof google.protobuf.Edition|null);

                /** EditionDefault value */
                value?: (string|null);
            }

            /** Represents an EditionDefault. */
            class EditionDefault implements IEditionDefault {

                /**
                 * Constructs a new EditionDefault.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.FieldOptions.IEditionDefault);

                /** EditionDefault edition. */
                public edition: (google.protobuf.Edition|keyof typeof google.protobuf.Edition);

                /** EditionDefault value. */
                public value: string;

                /**
                 * Creates a new EditionDefault instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns EditionDefault instance
                 */
                public static create(properties?: google.protobuf.FieldOptions.IEditionDefault): google.protobuf.FieldOptions.EditionDefault;

                /**
                 * Encodes the specified EditionDefault message. Does not implicitly {@link google.protobuf.FieldOptions.EditionDefault.verify|verify} messages.
                 * @param message EditionDefault message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.FieldOptions.IEditionDefault, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified EditionDefault message, length delimited. Does not implicitly {@link google.protobuf.FieldOptions.EditionDefault.verify|verify} messages.
                 * @param message EditionDefault message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.FieldOptions.IEditionDefault, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes an EditionDefault message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns EditionDefault
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FieldOptions.EditionDefault;

                /**
                 * Decodes an EditionDefault message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns EditionDefault
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FieldOptions.EditionDefault;

                /**
                 * Verifies an EditionDefault message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates an EditionDefault message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns EditionDefault
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.FieldOptions.EditionDefault;

                /**
                 * Creates a plain object from an EditionDefault message. Also converts values to other types if specified.
                 * @param message EditionDefault
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.FieldOptions.EditionDefault, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this EditionDefault to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for EditionDefault
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of an OneofOptions. */
        interface IOneofOptions {

            /** OneofOptions features */
            features?: (google.protobuf.IFeatureSet|null);

            /** OneofOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);
        }

        /** Represents an OneofOptions. */
        class OneofOptions implements IOneofOptions {

            /**
             * Constructs a new OneofOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IOneofOptions);

            /** OneofOptions features. */
            public features?: (google.protobuf.IFeatureSet|null);

            /** OneofOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new OneofOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns OneofOptions instance
             */
            public static create(properties?: google.protobuf.IOneofOptions): google.protobuf.OneofOptions;

            /**
             * Encodes the specified OneofOptions message. Does not implicitly {@link google.protobuf.OneofOptions.verify|verify} messages.
             * @param message OneofOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IOneofOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified OneofOptions message, length delimited. Does not implicitly {@link google.protobuf.OneofOptions.verify|verify} messages.
             * @param message OneofOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IOneofOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an OneofOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns OneofOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.OneofOptions;

            /**
             * Decodes an OneofOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns OneofOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.OneofOptions;

            /**
             * Verifies an OneofOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an OneofOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns OneofOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.OneofOptions;

            /**
             * Creates a plain object from an OneofOptions message. Also converts values to other types if specified.
             * @param message OneofOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.OneofOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this OneofOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for OneofOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an EnumOptions. */
        interface IEnumOptions {

            /** EnumOptions allowAlias */
            allowAlias?: (boolean|null);

            /** EnumOptions deprecated */
            deprecated?: (boolean|null);

            /** EnumOptions deprecatedLegacyJsonFieldConflicts */
            deprecatedLegacyJsonFieldConflicts?: (boolean|null);

            /** EnumOptions features */
            features?: (google.protobuf.IFeatureSet|null);

            /** EnumOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);
        }

        /** Represents an EnumOptions. */
        class EnumOptions implements IEnumOptions {

            /**
             * Constructs a new EnumOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IEnumOptions);

            /** EnumOptions allowAlias. */
            public allowAlias: boolean;

            /** EnumOptions deprecated. */
            public deprecated: boolean;

            /** EnumOptions deprecatedLegacyJsonFieldConflicts. */
            public deprecatedLegacyJsonFieldConflicts: boolean;

            /** EnumOptions features. */
            public features?: (google.protobuf.IFeatureSet|null);

            /** EnumOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new EnumOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns EnumOptions instance
             */
            public static create(properties?: google.protobuf.IEnumOptions): google.protobuf.EnumOptions;

            /**
             * Encodes the specified EnumOptions message. Does not implicitly {@link google.protobuf.EnumOptions.verify|verify} messages.
             * @param message EnumOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IEnumOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified EnumOptions message, length delimited. Does not implicitly {@link google.protobuf.EnumOptions.verify|verify} messages.
             * @param message EnumOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IEnumOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an EnumOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns EnumOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumOptions;

            /**
             * Decodes an EnumOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns EnumOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumOptions;

            /**
             * Verifies an EnumOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an EnumOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns EnumOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.EnumOptions;

            /**
             * Creates a plain object from an EnumOptions message. Also converts values to other types if specified.
             * @param message EnumOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.EnumOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this EnumOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for EnumOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an EnumValueOptions. */
        interface IEnumValueOptions {

            /** EnumValueOptions deprecated */
            deprecated?: (boolean|null);

            /** EnumValueOptions features */
            features?: (google.protobuf.IFeatureSet|null);

            /** EnumValueOptions debugRedact */
            debugRedact?: (boolean|null);

            /** EnumValueOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);
        }

        /** Represents an EnumValueOptions. */
        class EnumValueOptions implements IEnumValueOptions {

            /**
             * Constructs a new EnumValueOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IEnumValueOptions);

            /** EnumValueOptions deprecated. */
            public deprecated: boolean;

            /** EnumValueOptions features. */
            public features?: (google.protobuf.IFeatureSet|null);

            /** EnumValueOptions debugRedact. */
            public debugRedact: boolean;

            /** EnumValueOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new EnumValueOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns EnumValueOptions instance
             */
            public static create(properties?: google.protobuf.IEnumValueOptions): google.protobuf.EnumValueOptions;

            /**
             * Encodes the specified EnumValueOptions message. Does not implicitly {@link google.protobuf.EnumValueOptions.verify|verify} messages.
             * @param message EnumValueOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IEnumValueOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified EnumValueOptions message, length delimited. Does not implicitly {@link google.protobuf.EnumValueOptions.verify|verify} messages.
             * @param message EnumValueOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IEnumValueOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an EnumValueOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns EnumValueOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.EnumValueOptions;

            /**
             * Decodes an EnumValueOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns EnumValueOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.EnumValueOptions;

            /**
             * Verifies an EnumValueOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an EnumValueOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns EnumValueOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.EnumValueOptions;

            /**
             * Creates a plain object from an EnumValueOptions message. Also converts values to other types if specified.
             * @param message EnumValueOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.EnumValueOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this EnumValueOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for EnumValueOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a ServiceOptions. */
        interface IServiceOptions {

            /** ServiceOptions features */
            features?: (google.protobuf.IFeatureSet|null);

            /** ServiceOptions deprecated */
            deprecated?: (boolean|null);

            /** ServiceOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** ServiceOptions .google.api.defaultHost */
            ".google.api.defaultHost"?: (string|null);

            /** ServiceOptions .google.api.oauthScopes */
            ".google.api.oauthScopes"?: (string|null);
        }

        /** Represents a ServiceOptions. */
        class ServiceOptions implements IServiceOptions {

            /**
             * Constructs a new ServiceOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IServiceOptions);

            /** ServiceOptions features. */
            public features?: (google.protobuf.IFeatureSet|null);

            /** ServiceOptions deprecated. */
            public deprecated: boolean;

            /** ServiceOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new ServiceOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ServiceOptions instance
             */
            public static create(properties?: google.protobuf.IServiceOptions): google.protobuf.ServiceOptions;

            /**
             * Encodes the specified ServiceOptions message. Does not implicitly {@link google.protobuf.ServiceOptions.verify|verify} messages.
             * @param message ServiceOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IServiceOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ServiceOptions message, length delimited. Does not implicitly {@link google.protobuf.ServiceOptions.verify|verify} messages.
             * @param message ServiceOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IServiceOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ServiceOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ServiceOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.ServiceOptions;

            /**
             * Decodes a ServiceOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ServiceOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.ServiceOptions;

            /**
             * Verifies a ServiceOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ServiceOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ServiceOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.ServiceOptions;

            /**
             * Creates a plain object from a ServiceOptions message. Also converts values to other types if specified.
             * @param message ServiceOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.ServiceOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ServiceOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ServiceOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a MethodOptions. */
        interface IMethodOptions {

            /** MethodOptions deprecated */
            deprecated?: (boolean|null);

            /** MethodOptions idempotencyLevel */
            idempotencyLevel?: (google.protobuf.MethodOptions.IdempotencyLevel|keyof typeof google.protobuf.MethodOptions.IdempotencyLevel|null);

            /** MethodOptions features */
            features?: (google.protobuf.IFeatureSet|null);

            /** MethodOptions uninterpretedOption */
            uninterpretedOption?: (google.protobuf.IUninterpretedOption[]|null);

            /** MethodOptions .google.api.http */
            ".google.api.http"?: (google.api.IHttpRule|null);

            /** MethodOptions .google.api.methodSignature */
            ".google.api.methodSignature"?: (string[]|null);

            /** MethodOptions .google.longrunning.operationInfo */
            ".google.longrunning.operationInfo"?: (google.longrunning.IOperationInfo|null);
        }

        /** Represents a MethodOptions. */
        class MethodOptions implements IMethodOptions {

            /**
             * Constructs a new MethodOptions.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IMethodOptions);

            /** MethodOptions deprecated. */
            public deprecated: boolean;

            /** MethodOptions idempotencyLevel. */
            public idempotencyLevel: (google.protobuf.MethodOptions.IdempotencyLevel|keyof typeof google.protobuf.MethodOptions.IdempotencyLevel);

            /** MethodOptions features. */
            public features?: (google.protobuf.IFeatureSet|null);

            /** MethodOptions uninterpretedOption. */
            public uninterpretedOption: google.protobuf.IUninterpretedOption[];

            /**
             * Creates a new MethodOptions instance using the specified properties.
             * @param [properties] Properties to set
             * @returns MethodOptions instance
             */
            public static create(properties?: google.protobuf.IMethodOptions): google.protobuf.MethodOptions;

            /**
             * Encodes the specified MethodOptions message. Does not implicitly {@link google.protobuf.MethodOptions.verify|verify} messages.
             * @param message MethodOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IMethodOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified MethodOptions message, length delimited. Does not implicitly {@link google.protobuf.MethodOptions.verify|verify} messages.
             * @param message MethodOptions message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IMethodOptions, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a MethodOptions message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns MethodOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.MethodOptions;

            /**
             * Decodes a MethodOptions message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns MethodOptions
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.MethodOptions;

            /**
             * Verifies a MethodOptions message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a MethodOptions message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns MethodOptions
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.MethodOptions;

            /**
             * Creates a plain object from a MethodOptions message. Also converts values to other types if specified.
             * @param message MethodOptions
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.MethodOptions, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this MethodOptions to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for MethodOptions
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace MethodOptions {

            /** IdempotencyLevel enum. */
            enum IdempotencyLevel {
                IDEMPOTENCY_UNKNOWN = 0,
                NO_SIDE_EFFECTS = 1,
                IDEMPOTENT = 2
            }
        }

        /** Properties of an UninterpretedOption. */
        interface IUninterpretedOption {

            /** UninterpretedOption name */
            name?: (google.protobuf.UninterpretedOption.INamePart[]|null);

            /** UninterpretedOption identifierValue */
            identifierValue?: (string|null);

            /** UninterpretedOption positiveIntValue */
            positiveIntValue?: (number|Long|string|null);

            /** UninterpretedOption negativeIntValue */
            negativeIntValue?: (number|Long|string|null);

            /** UninterpretedOption doubleValue */
            doubleValue?: (number|null);

            /** UninterpretedOption stringValue */
            stringValue?: (Uint8Array|string|null);

            /** UninterpretedOption aggregateValue */
            aggregateValue?: (string|null);
        }

        /** Represents an UninterpretedOption. */
        class UninterpretedOption implements IUninterpretedOption {

            /**
             * Constructs a new UninterpretedOption.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IUninterpretedOption);

            /** UninterpretedOption name. */
            public name: google.protobuf.UninterpretedOption.INamePart[];

            /** UninterpretedOption identifierValue. */
            public identifierValue: string;

            /** UninterpretedOption positiveIntValue. */
            public positiveIntValue: (number|Long|string);

            /** UninterpretedOption negativeIntValue. */
            public negativeIntValue: (number|Long|string);

            /** UninterpretedOption doubleValue. */
            public doubleValue: number;

            /** UninterpretedOption stringValue. */
            public stringValue: (Uint8Array|string);

            /** UninterpretedOption aggregateValue. */
            public aggregateValue: string;

            /**
             * Creates a new UninterpretedOption instance using the specified properties.
             * @param [properties] Properties to set
             * @returns UninterpretedOption instance
             */
            public static create(properties?: google.protobuf.IUninterpretedOption): google.protobuf.UninterpretedOption;

            /**
             * Encodes the specified UninterpretedOption message. Does not implicitly {@link google.protobuf.UninterpretedOption.verify|verify} messages.
             * @param message UninterpretedOption message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IUninterpretedOption, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified UninterpretedOption message, length delimited. Does not implicitly {@link google.protobuf.UninterpretedOption.verify|verify} messages.
             * @param message UninterpretedOption message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IUninterpretedOption, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an UninterpretedOption message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns UninterpretedOption
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.UninterpretedOption;

            /**
             * Decodes an UninterpretedOption message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns UninterpretedOption
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.UninterpretedOption;

            /**
             * Verifies an UninterpretedOption message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an UninterpretedOption message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns UninterpretedOption
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.UninterpretedOption;

            /**
             * Creates a plain object from an UninterpretedOption message. Also converts values to other types if specified.
             * @param message UninterpretedOption
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.UninterpretedOption, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this UninterpretedOption to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for UninterpretedOption
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace UninterpretedOption {

            /** Properties of a NamePart. */
            interface INamePart {

                /** NamePart namePart */
                namePart: string;

                /** NamePart isExtension */
                isExtension: boolean;
            }

            /** Represents a NamePart. */
            class NamePart implements INamePart {

                /**
                 * Constructs a new NamePart.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.UninterpretedOption.INamePart);

                /** NamePart namePart. */
                public namePart: string;

                /** NamePart isExtension. */
                public isExtension: boolean;

                /**
                 * Creates a new NamePart instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns NamePart instance
                 */
                public static create(properties?: google.protobuf.UninterpretedOption.INamePart): google.protobuf.UninterpretedOption.NamePart;

                /**
                 * Encodes the specified NamePart message. Does not implicitly {@link google.protobuf.UninterpretedOption.NamePart.verify|verify} messages.
                 * @param message NamePart message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.UninterpretedOption.INamePart, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified NamePart message, length delimited. Does not implicitly {@link google.protobuf.UninterpretedOption.NamePart.verify|verify} messages.
                 * @param message NamePart message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.UninterpretedOption.INamePart, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes a NamePart message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns NamePart
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.UninterpretedOption.NamePart;

                /**
                 * Decodes a NamePart message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns NamePart
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.UninterpretedOption.NamePart;

                /**
                 * Verifies a NamePart message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates a NamePart message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns NamePart
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.UninterpretedOption.NamePart;

                /**
                 * Creates a plain object from a NamePart message. Also converts values to other types if specified.
                 * @param message NamePart
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.UninterpretedOption.NamePart, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this NamePart to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for NamePart
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of a FeatureSet. */
        interface IFeatureSet {

            /** FeatureSet fieldPresence */
            fieldPresence?: (google.protobuf.FeatureSet.FieldPresence|keyof typeof google.protobuf.FeatureSet.FieldPresence|null);

            /** FeatureSet enumType */
            enumType?: (google.protobuf.FeatureSet.EnumType|keyof typeof google.protobuf.FeatureSet.EnumType|null);

            /** FeatureSet repeatedFieldEncoding */
            repeatedFieldEncoding?: (google.protobuf.FeatureSet.RepeatedFieldEncoding|keyof typeof google.protobuf.FeatureSet.RepeatedFieldEncoding|null);

            /** FeatureSet utf8Validation */
            utf8Validation?: (google.protobuf.FeatureSet.Utf8Validation|keyof typeof google.protobuf.FeatureSet.Utf8Validation|null);

            /** FeatureSet messageEncoding */
            messageEncoding?: (google.protobuf.FeatureSet.MessageEncoding|keyof typeof google.protobuf.FeatureSet.MessageEncoding|null);

            /** FeatureSet jsonFormat */
            jsonFormat?: (google.protobuf.FeatureSet.JsonFormat|keyof typeof google.protobuf.FeatureSet.JsonFormat|null);
        }

        /** Represents a FeatureSet. */
        class FeatureSet implements IFeatureSet {

            /**
             * Constructs a new FeatureSet.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFeatureSet);

            /** FeatureSet fieldPresence. */
            public fieldPresence: (google.protobuf.FeatureSet.FieldPresence|keyof typeof google.protobuf.FeatureSet.FieldPresence);

            /** FeatureSet enumType. */
            public enumType: (google.protobuf.FeatureSet.EnumType|keyof typeof google.protobuf.FeatureSet.EnumType);

            /** FeatureSet repeatedFieldEncoding. */
            public repeatedFieldEncoding: (google.protobuf.FeatureSet.RepeatedFieldEncoding|keyof typeof google.protobuf.FeatureSet.RepeatedFieldEncoding);

            /** FeatureSet utf8Validation. */
            public utf8Validation: (google.protobuf.FeatureSet.Utf8Validation|keyof typeof google.protobuf.FeatureSet.Utf8Validation);

            /** FeatureSet messageEncoding. */
            public messageEncoding: (google.protobuf.FeatureSet.MessageEncoding|keyof typeof google.protobuf.FeatureSet.MessageEncoding);

            /** FeatureSet jsonFormat. */
            public jsonFormat: (google.protobuf.FeatureSet.JsonFormat|keyof typeof google.protobuf.FeatureSet.JsonFormat);

            /**
             * Creates a new FeatureSet instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FeatureSet instance
             */
            public static create(properties?: google.protobuf.IFeatureSet): google.protobuf.FeatureSet;

            /**
             * Encodes the specified FeatureSet message. Does not implicitly {@link google.protobuf.FeatureSet.verify|verify} messages.
             * @param message FeatureSet message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFeatureSet, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FeatureSet message, length delimited. Does not implicitly {@link google.protobuf.FeatureSet.verify|verify} messages.
             * @param message FeatureSet message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFeatureSet, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FeatureSet message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FeatureSet
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FeatureSet;

            /**
             * Decodes a FeatureSet message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FeatureSet
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FeatureSet;

            /**
             * Verifies a FeatureSet message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FeatureSet message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FeatureSet
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FeatureSet;

            /**
             * Creates a plain object from a FeatureSet message. Also converts values to other types if specified.
             * @param message FeatureSet
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FeatureSet, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FeatureSet to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FeatureSet
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace FeatureSet {

            /** FieldPresence enum. */
            enum FieldPresence {
                FIELD_PRESENCE_UNKNOWN = 0,
                EXPLICIT = 1,
                IMPLICIT = 2,
                LEGACY_REQUIRED = 3
            }

            /** EnumType enum. */
            enum EnumType {
                ENUM_TYPE_UNKNOWN = 0,
                OPEN = 1,
                CLOSED = 2
            }

            /** RepeatedFieldEncoding enum. */
            enum RepeatedFieldEncoding {
                REPEATED_FIELD_ENCODING_UNKNOWN = 0,
                PACKED = 1,
                EXPANDED = 2
            }

            /** Utf8Validation enum. */
            enum Utf8Validation {
                UTF8_VALIDATION_UNKNOWN = 0,
                VERIFY = 2,
                NONE = 3
            }

            /** MessageEncoding enum. */
            enum MessageEncoding {
                MESSAGE_ENCODING_UNKNOWN = 0,
                LENGTH_PREFIXED = 1,
                DELIMITED = 2
            }

            /** JsonFormat enum. */
            enum JsonFormat {
                JSON_FORMAT_UNKNOWN = 0,
                ALLOW = 1,
                LEGACY_BEST_EFFORT = 2
            }
        }

        /** Properties of a FeatureSetDefaults. */
        interface IFeatureSetDefaults {

            /** FeatureSetDefaults defaults */
            defaults?: (google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault[]|null);

            /** FeatureSetDefaults minimumEdition */
            minimumEdition?: (google.protobuf.Edition|keyof typeof google.protobuf.Edition|null);

            /** FeatureSetDefaults maximumEdition */
            maximumEdition?: (google.protobuf.Edition|keyof typeof google.protobuf.Edition|null);
        }

        /** Represents a FeatureSetDefaults. */
        class FeatureSetDefaults implements IFeatureSetDefaults {

            /**
             * Constructs a new FeatureSetDefaults.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFeatureSetDefaults);

            /** FeatureSetDefaults defaults. */
            public defaults: google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault[];

            /** FeatureSetDefaults minimumEdition. */
            public minimumEdition: (google.protobuf.Edition|keyof typeof google.protobuf.Edition);

            /** FeatureSetDefaults maximumEdition. */
            public maximumEdition: (google.protobuf.Edition|keyof typeof google.protobuf.Edition);

            /**
             * Creates a new FeatureSetDefaults instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FeatureSetDefaults instance
             */
            public static create(properties?: google.protobuf.IFeatureSetDefaults): google.protobuf.FeatureSetDefaults;

            /**
             * Encodes the specified FeatureSetDefaults message. Does not implicitly {@link google.protobuf.FeatureSetDefaults.verify|verify} messages.
             * @param message FeatureSetDefaults message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFeatureSetDefaults, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FeatureSetDefaults message, length delimited. Does not implicitly {@link google.protobuf.FeatureSetDefaults.verify|verify} messages.
             * @param message FeatureSetDefaults message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFeatureSetDefaults, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FeatureSetDefaults message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FeatureSetDefaults
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FeatureSetDefaults;

            /**
             * Decodes a FeatureSetDefaults message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FeatureSetDefaults
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FeatureSetDefaults;

            /**
             * Verifies a FeatureSetDefaults message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FeatureSetDefaults message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FeatureSetDefaults
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FeatureSetDefaults;

            /**
             * Creates a plain object from a FeatureSetDefaults message. Also converts values to other types if specified.
             * @param message FeatureSetDefaults
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FeatureSetDefaults, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FeatureSetDefaults to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FeatureSetDefaults
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace FeatureSetDefaults {

            /** Properties of a FeatureSetEditionDefault. */
            interface IFeatureSetEditionDefault {

                /** FeatureSetEditionDefault edition */
                edition?: (google.protobuf.Edition|keyof typeof google.protobuf.Edition|null);

                /** FeatureSetEditionDefault features */
                features?: (google.protobuf.IFeatureSet|null);
            }

            /** Represents a FeatureSetEditionDefault. */
            class FeatureSetEditionDefault implements IFeatureSetEditionDefault {

                /**
                 * Constructs a new FeatureSetEditionDefault.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault);

                /** FeatureSetEditionDefault edition. */
                public edition: (google.protobuf.Edition|keyof typeof google.protobuf.Edition);

                /** FeatureSetEditionDefault features. */
                public features?: (google.protobuf.IFeatureSet|null);

                /**
                 * Creates a new FeatureSetEditionDefault instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns FeatureSetEditionDefault instance
                 */
                public static create(properties?: google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault): google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault;

                /**
                 * Encodes the specified FeatureSetEditionDefault message. Does not implicitly {@link google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.verify|verify} messages.
                 * @param message FeatureSetEditionDefault message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified FeatureSetEditionDefault message, length delimited. Does not implicitly {@link google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault.verify|verify} messages.
                 * @param message FeatureSetEditionDefault message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.FeatureSetDefaults.IFeatureSetEditionDefault, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes a FeatureSetEditionDefault message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns FeatureSetEditionDefault
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault;

                /**
                 * Decodes a FeatureSetEditionDefault message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns FeatureSetEditionDefault
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault;

                /**
                 * Verifies a FeatureSetEditionDefault message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates a FeatureSetEditionDefault message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns FeatureSetEditionDefault
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault;

                /**
                 * Creates a plain object from a FeatureSetEditionDefault message. Also converts values to other types if specified.
                 * @param message FeatureSetEditionDefault
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.FeatureSetDefaults.FeatureSetEditionDefault, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this FeatureSetEditionDefault to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for FeatureSetEditionDefault
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of a SourceCodeInfo. */
        interface ISourceCodeInfo {

            /** SourceCodeInfo location */
            location?: (google.protobuf.SourceCodeInfo.ILocation[]|null);
        }

        /** Represents a SourceCodeInfo. */
        class SourceCodeInfo implements ISourceCodeInfo {

            /**
             * Constructs a new SourceCodeInfo.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.ISourceCodeInfo);

            /** SourceCodeInfo location. */
            public location: google.protobuf.SourceCodeInfo.ILocation[];

            /**
             * Creates a new SourceCodeInfo instance using the specified properties.
             * @param [properties] Properties to set
             * @returns SourceCodeInfo instance
             */
            public static create(properties?: google.protobuf.ISourceCodeInfo): google.protobuf.SourceCodeInfo;

            /**
             * Encodes the specified SourceCodeInfo message. Does not implicitly {@link google.protobuf.SourceCodeInfo.verify|verify} messages.
             * @param message SourceCodeInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.ISourceCodeInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified SourceCodeInfo message, length delimited. Does not implicitly {@link google.protobuf.SourceCodeInfo.verify|verify} messages.
             * @param message SourceCodeInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.ISourceCodeInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a SourceCodeInfo message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns SourceCodeInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.SourceCodeInfo;

            /**
             * Decodes a SourceCodeInfo message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns SourceCodeInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.SourceCodeInfo;

            /**
             * Verifies a SourceCodeInfo message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a SourceCodeInfo message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns SourceCodeInfo
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.SourceCodeInfo;

            /**
             * Creates a plain object from a SourceCodeInfo message. Also converts values to other types if specified.
             * @param message SourceCodeInfo
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.SourceCodeInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this SourceCodeInfo to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for SourceCodeInfo
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace SourceCodeInfo {

            /** Properties of a Location. */
            interface ILocation {

                /** Location path */
                path?: (number[]|null);

                /** Location span */
                span?: (number[]|null);

                /** Location leadingComments */
                leadingComments?: (string|null);

                /** Location trailingComments */
                trailingComments?: (string|null);

                /** Location leadingDetachedComments */
                leadingDetachedComments?: (string[]|null);
            }

            /** Represents a Location. */
            class Location implements ILocation {

                /**
                 * Constructs a new Location.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.SourceCodeInfo.ILocation);

                /** Location path. */
                public path: number[];

                /** Location span. */
                public span: number[];

                /** Location leadingComments. */
                public leadingComments: string;

                /** Location trailingComments. */
                public trailingComments: string;

                /** Location leadingDetachedComments. */
                public leadingDetachedComments: string[];

                /**
                 * Creates a new Location instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns Location instance
                 */
                public static create(properties?: google.protobuf.SourceCodeInfo.ILocation): google.protobuf.SourceCodeInfo.Location;

                /**
                 * Encodes the specified Location message. Does not implicitly {@link google.protobuf.SourceCodeInfo.Location.verify|verify} messages.
                 * @param message Location message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.SourceCodeInfo.ILocation, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified Location message, length delimited. Does not implicitly {@link google.protobuf.SourceCodeInfo.Location.verify|verify} messages.
                 * @param message Location message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.SourceCodeInfo.ILocation, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes a Location message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns Location
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.SourceCodeInfo.Location;

                /**
                 * Decodes a Location message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns Location
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.SourceCodeInfo.Location;

                /**
                 * Verifies a Location message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates a Location message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns Location
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.SourceCodeInfo.Location;

                /**
                 * Creates a plain object from a Location message. Also converts values to other types if specified.
                 * @param message Location
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.SourceCodeInfo.Location, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this Location to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for Location
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }
        }

        /** Properties of a GeneratedCodeInfo. */
        interface IGeneratedCodeInfo {

            /** GeneratedCodeInfo annotation */
            annotation?: (google.protobuf.GeneratedCodeInfo.IAnnotation[]|null);
        }

        /** Represents a GeneratedCodeInfo. */
        class GeneratedCodeInfo implements IGeneratedCodeInfo {

            /**
             * Constructs a new GeneratedCodeInfo.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IGeneratedCodeInfo);

            /** GeneratedCodeInfo annotation. */
            public annotation: google.protobuf.GeneratedCodeInfo.IAnnotation[];

            /**
             * Creates a new GeneratedCodeInfo instance using the specified properties.
             * @param [properties] Properties to set
             * @returns GeneratedCodeInfo instance
             */
            public static create(properties?: google.protobuf.IGeneratedCodeInfo): google.protobuf.GeneratedCodeInfo;

            /**
             * Encodes the specified GeneratedCodeInfo message. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.verify|verify} messages.
             * @param message GeneratedCodeInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IGeneratedCodeInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified GeneratedCodeInfo message, length delimited. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.verify|verify} messages.
             * @param message GeneratedCodeInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IGeneratedCodeInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a GeneratedCodeInfo message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns GeneratedCodeInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.GeneratedCodeInfo;

            /**
             * Decodes a GeneratedCodeInfo message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns GeneratedCodeInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.GeneratedCodeInfo;

            /**
             * Verifies a GeneratedCodeInfo message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a GeneratedCodeInfo message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns GeneratedCodeInfo
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.GeneratedCodeInfo;

            /**
             * Creates a plain object from a GeneratedCodeInfo message. Also converts values to other types if specified.
             * @param message GeneratedCodeInfo
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.GeneratedCodeInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this GeneratedCodeInfo to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for GeneratedCodeInfo
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        namespace GeneratedCodeInfo {

            /** Properties of an Annotation. */
            interface IAnnotation {

                /** Annotation path */
                path?: (number[]|null);

                /** Annotation sourceFile */
                sourceFile?: (string|null);

                /** Annotation begin */
                begin?: (number|null);

                /** Annotation end */
                end?: (number|null);

                /** Annotation semantic */
                semantic?: (google.protobuf.GeneratedCodeInfo.Annotation.Semantic|keyof typeof google.protobuf.GeneratedCodeInfo.Annotation.Semantic|null);
            }

            /** Represents an Annotation. */
            class Annotation implements IAnnotation {

                /**
                 * Constructs a new Annotation.
                 * @param [properties] Properties to set
                 */
                constructor(properties?: google.protobuf.GeneratedCodeInfo.IAnnotation);

                /** Annotation path. */
                public path: number[];

                /** Annotation sourceFile. */
                public sourceFile: string;

                /** Annotation begin. */
                public begin: number;

                /** Annotation end. */
                public end: number;

                /** Annotation semantic. */
                public semantic: (google.protobuf.GeneratedCodeInfo.Annotation.Semantic|keyof typeof google.protobuf.GeneratedCodeInfo.Annotation.Semantic);

                /**
                 * Creates a new Annotation instance using the specified properties.
                 * @param [properties] Properties to set
                 * @returns Annotation instance
                 */
                public static create(properties?: google.protobuf.GeneratedCodeInfo.IAnnotation): google.protobuf.GeneratedCodeInfo.Annotation;

                /**
                 * Encodes the specified Annotation message. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.Annotation.verify|verify} messages.
                 * @param message Annotation message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encode(message: google.protobuf.GeneratedCodeInfo.IAnnotation, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Encodes the specified Annotation message, length delimited. Does not implicitly {@link google.protobuf.GeneratedCodeInfo.Annotation.verify|verify} messages.
                 * @param message Annotation message or plain object to encode
                 * @param [writer] Writer to encode to
                 * @returns Writer
                 */
                public static encodeDelimited(message: google.protobuf.GeneratedCodeInfo.IAnnotation, writer?: $protobuf.Writer): $protobuf.Writer;

                /**
                 * Decodes an Annotation message from the specified reader or buffer.
                 * @param reader Reader or buffer to decode from
                 * @param [length] Message length if known beforehand
                 * @returns Annotation
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.GeneratedCodeInfo.Annotation;

                /**
                 * Decodes an Annotation message from the specified reader or buffer, length delimited.
                 * @param reader Reader or buffer to decode from
                 * @returns Annotation
                 * @throws {Error} If the payload is not a reader or valid buffer
                 * @throws {$protobuf.util.ProtocolError} If required fields are missing
                 */
                public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.GeneratedCodeInfo.Annotation;

                /**
                 * Verifies an Annotation message.
                 * @param message Plain object to verify
                 * @returns `null` if valid, otherwise the reason why it is not
                 */
                public static verify(message: { [k: string]: any }): (string|null);

                /**
                 * Creates an Annotation message from a plain object. Also converts values to their respective internal types.
                 * @param object Plain object
                 * @returns Annotation
                 */
                public static fromObject(object: { [k: string]: any }): google.protobuf.GeneratedCodeInfo.Annotation;

                /**
                 * Creates a plain object from an Annotation message. Also converts values to other types if specified.
                 * @param message Annotation
                 * @param [options] Conversion options
                 * @returns Plain object
                 */
                public static toObject(message: google.protobuf.GeneratedCodeInfo.Annotation, options?: $protobuf.IConversionOptions): { [k: string]: any };

                /**
                 * Converts this Annotation to JSON.
                 * @returns JSON object
                 */
                public toJSON(): { [k: string]: any };

                /**
                 * Gets the default type url for Annotation
                 * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
                 * @returns The default type url
                 */
                public static getTypeUrl(typeUrlPrefix?: string): string;
            }

            namespace Annotation {

                /** Semantic enum. */
                enum Semantic {
                    NONE = 0,
                    SET = 1,
                    ALIAS = 2
                }
            }
        }

        /** Properties of a Timestamp. */
        interface ITimestamp {

            /** Timestamp seconds */
            seconds?: (number|Long|string|null);

            /** Timestamp nanos */
            nanos?: (number|null);
        }

        /** Represents a Timestamp. */
        class Timestamp implements ITimestamp {

            /**
             * Constructs a new Timestamp.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.ITimestamp);

            /** Timestamp seconds. */
            public seconds: (number|Long|string);

            /** Timestamp nanos. */
            public nanos: number;

            /**
             * Creates a new Timestamp instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Timestamp instance
             */
            public static create(properties?: google.protobuf.ITimestamp): google.protobuf.Timestamp;

            /**
             * Encodes the specified Timestamp message. Does not implicitly {@link google.protobuf.Timestamp.verify|verify} messages.
             * @param message Timestamp message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.ITimestamp, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Timestamp message, length delimited. Does not implicitly {@link google.protobuf.Timestamp.verify|verify} messages.
             * @param message Timestamp message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.ITimestamp, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a Timestamp message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Timestamp
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.Timestamp;

            /**
             * Decodes a Timestamp message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Timestamp
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.Timestamp;

            /**
             * Verifies a Timestamp message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a Timestamp message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Timestamp
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.Timestamp;

            /**
             * Creates a plain object from a Timestamp message. Also converts values to other types if specified.
             * @param message Timestamp
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.Timestamp, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Timestamp to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Timestamp
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an Any. */
        interface IAny {

            /** Any type_url */
            type_url?: (string|null);

            /** Any value */
            value?: (Uint8Array|string|null);
        }

        /** Represents an Any. */
        class Any implements IAny {

            /**
             * Constructs a new Any.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IAny);

            /** Any type_url. */
            public type_url: string;

            /** Any value. */
            public value: (Uint8Array|string);

            /**
             * Creates a new Any instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Any instance
             */
            public static create(properties?: google.protobuf.IAny): google.protobuf.Any;

            /**
             * Encodes the specified Any message. Does not implicitly {@link google.protobuf.Any.verify|verify} messages.
             * @param message Any message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IAny, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Any message, length delimited. Does not implicitly {@link google.protobuf.Any.verify|verify} messages.
             * @param message Any message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IAny, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an Any message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Any
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.Any;

            /**
             * Decodes an Any message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Any
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.Any;

            /**
             * Verifies an Any message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an Any message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Any
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.Any;

            /**
             * Creates a plain object from an Any message. Also converts values to other types if specified.
             * @param message Any
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.Any, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Any to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Any
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a DoubleValue. */
        interface IDoubleValue {

            /** DoubleValue value */
            value?: (number|null);
        }

        /** Represents a DoubleValue. */
        class DoubleValue implements IDoubleValue {

            /**
             * Constructs a new DoubleValue.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IDoubleValue);

            /** DoubleValue value. */
            public value: number;

            /**
             * Creates a new DoubleValue instance using the specified properties.
             * @param [properties] Properties to set
             * @returns DoubleValue instance
             */
            public static create(properties?: google.protobuf.IDoubleValue): google.protobuf.DoubleValue;

            /**
             * Encodes the specified DoubleValue message. Does not implicitly {@link google.protobuf.DoubleValue.verify|verify} messages.
             * @param message DoubleValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IDoubleValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified DoubleValue message, length delimited. Does not implicitly {@link google.protobuf.DoubleValue.verify|verify} messages.
             * @param message DoubleValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IDoubleValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a DoubleValue message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns DoubleValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.DoubleValue;

            /**
             * Decodes a DoubleValue message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns DoubleValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.DoubleValue;

            /**
             * Verifies a DoubleValue message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a DoubleValue message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns DoubleValue
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.DoubleValue;

            /**
             * Creates a plain object from a DoubleValue message. Also converts values to other types if specified.
             * @param message DoubleValue
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.DoubleValue, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this DoubleValue to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for DoubleValue
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a FloatValue. */
        interface IFloatValue {

            /** FloatValue value */
            value?: (number|null);
        }

        /** Represents a FloatValue. */
        class FloatValue implements IFloatValue {

            /**
             * Constructs a new FloatValue.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFloatValue);

            /** FloatValue value. */
            public value: number;

            /**
             * Creates a new FloatValue instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FloatValue instance
             */
            public static create(properties?: google.protobuf.IFloatValue): google.protobuf.FloatValue;

            /**
             * Encodes the specified FloatValue message. Does not implicitly {@link google.protobuf.FloatValue.verify|verify} messages.
             * @param message FloatValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFloatValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FloatValue message, length delimited. Does not implicitly {@link google.protobuf.FloatValue.verify|verify} messages.
             * @param message FloatValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFloatValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FloatValue message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FloatValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FloatValue;

            /**
             * Decodes a FloatValue message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FloatValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FloatValue;

            /**
             * Verifies a FloatValue message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FloatValue message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FloatValue
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FloatValue;

            /**
             * Creates a plain object from a FloatValue message. Also converts values to other types if specified.
             * @param message FloatValue
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FloatValue, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FloatValue to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FloatValue
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an Int64Value. */
        interface IInt64Value {

            /** Int64Value value */
            value?: (number|Long|string|null);
        }

        /** Represents an Int64Value. */
        class Int64Value implements IInt64Value {

            /**
             * Constructs a new Int64Value.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IInt64Value);

            /** Int64Value value. */
            public value: (number|Long|string);

            /**
             * Creates a new Int64Value instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Int64Value instance
             */
            public static create(properties?: google.protobuf.IInt64Value): google.protobuf.Int64Value;

            /**
             * Encodes the specified Int64Value message. Does not implicitly {@link google.protobuf.Int64Value.verify|verify} messages.
             * @param message Int64Value message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IInt64Value, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Int64Value message, length delimited. Does not implicitly {@link google.protobuf.Int64Value.verify|verify} messages.
             * @param message Int64Value message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IInt64Value, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an Int64Value message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Int64Value
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.Int64Value;

            /**
             * Decodes an Int64Value message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Int64Value
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.Int64Value;

            /**
             * Verifies an Int64Value message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an Int64Value message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Int64Value
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.Int64Value;

            /**
             * Creates a plain object from an Int64Value message. Also converts values to other types if specified.
             * @param message Int64Value
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.Int64Value, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Int64Value to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Int64Value
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a UInt64Value. */
        interface IUInt64Value {

            /** UInt64Value value */
            value?: (number|Long|string|null);
        }

        /** Represents a UInt64Value. */
        class UInt64Value implements IUInt64Value {

            /**
             * Constructs a new UInt64Value.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IUInt64Value);

            /** UInt64Value value. */
            public value: (number|Long|string);

            /**
             * Creates a new UInt64Value instance using the specified properties.
             * @param [properties] Properties to set
             * @returns UInt64Value instance
             */
            public static create(properties?: google.protobuf.IUInt64Value): google.protobuf.UInt64Value;

            /**
             * Encodes the specified UInt64Value message. Does not implicitly {@link google.protobuf.UInt64Value.verify|verify} messages.
             * @param message UInt64Value message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IUInt64Value, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified UInt64Value message, length delimited. Does not implicitly {@link google.protobuf.UInt64Value.verify|verify} messages.
             * @param message UInt64Value message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IUInt64Value, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a UInt64Value message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns UInt64Value
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.UInt64Value;

            /**
             * Decodes a UInt64Value message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns UInt64Value
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.UInt64Value;

            /**
             * Verifies a UInt64Value message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a UInt64Value message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns UInt64Value
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.UInt64Value;

            /**
             * Creates a plain object from a UInt64Value message. Also converts values to other types if specified.
             * @param message UInt64Value
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.UInt64Value, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this UInt64Value to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for UInt64Value
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an Int32Value. */
        interface IInt32Value {

            /** Int32Value value */
            value?: (number|null);
        }

        /** Represents an Int32Value. */
        class Int32Value implements IInt32Value {

            /**
             * Constructs a new Int32Value.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IInt32Value);

            /** Int32Value value. */
            public value: number;

            /**
             * Creates a new Int32Value instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Int32Value instance
             */
            public static create(properties?: google.protobuf.IInt32Value): google.protobuf.Int32Value;

            /**
             * Encodes the specified Int32Value message. Does not implicitly {@link google.protobuf.Int32Value.verify|verify} messages.
             * @param message Int32Value message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IInt32Value, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Int32Value message, length delimited. Does not implicitly {@link google.protobuf.Int32Value.verify|verify} messages.
             * @param message Int32Value message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IInt32Value, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an Int32Value message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Int32Value
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.Int32Value;

            /**
             * Decodes an Int32Value message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Int32Value
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.Int32Value;

            /**
             * Verifies an Int32Value message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an Int32Value message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Int32Value
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.Int32Value;

            /**
             * Creates a plain object from an Int32Value message. Also converts values to other types if specified.
             * @param message Int32Value
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.Int32Value, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Int32Value to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Int32Value
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a UInt32Value. */
        interface IUInt32Value {

            /** UInt32Value value */
            value?: (number|null);
        }

        /** Represents a UInt32Value. */
        class UInt32Value implements IUInt32Value {

            /**
             * Constructs a new UInt32Value.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IUInt32Value);

            /** UInt32Value value. */
            public value: number;

            /**
             * Creates a new UInt32Value instance using the specified properties.
             * @param [properties] Properties to set
             * @returns UInt32Value instance
             */
            public static create(properties?: google.protobuf.IUInt32Value): google.protobuf.UInt32Value;

            /**
             * Encodes the specified UInt32Value message. Does not implicitly {@link google.protobuf.UInt32Value.verify|verify} messages.
             * @param message UInt32Value message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IUInt32Value, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified UInt32Value message, length delimited. Does not implicitly {@link google.protobuf.UInt32Value.verify|verify} messages.
             * @param message UInt32Value message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IUInt32Value, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a UInt32Value message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns UInt32Value
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.UInt32Value;

            /**
             * Decodes a UInt32Value message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns UInt32Value
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.UInt32Value;

            /**
             * Verifies a UInt32Value message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a UInt32Value message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns UInt32Value
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.UInt32Value;

            /**
             * Creates a plain object from a UInt32Value message. Also converts values to other types if specified.
             * @param message UInt32Value
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.UInt32Value, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this UInt32Value to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for UInt32Value
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a BoolValue. */
        interface IBoolValue {

            /** BoolValue value */
            value?: (boolean|null);
        }

        /** Represents a BoolValue. */
        class BoolValue implements IBoolValue {

            /**
             * Constructs a new BoolValue.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IBoolValue);

            /** BoolValue value. */
            public value: boolean;

            /**
             * Creates a new BoolValue instance using the specified properties.
             * @param [properties] Properties to set
             * @returns BoolValue instance
             */
            public static create(properties?: google.protobuf.IBoolValue): google.protobuf.BoolValue;

            /**
             * Encodes the specified BoolValue message. Does not implicitly {@link google.protobuf.BoolValue.verify|verify} messages.
             * @param message BoolValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IBoolValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified BoolValue message, length delimited. Does not implicitly {@link google.protobuf.BoolValue.verify|verify} messages.
             * @param message BoolValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IBoolValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a BoolValue message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns BoolValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.BoolValue;

            /**
             * Decodes a BoolValue message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns BoolValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.BoolValue;

            /**
             * Verifies a BoolValue message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a BoolValue message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns BoolValue
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.BoolValue;

            /**
             * Creates a plain object from a BoolValue message. Also converts values to other types if specified.
             * @param message BoolValue
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.BoolValue, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this BoolValue to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for BoolValue
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a StringValue. */
        interface IStringValue {

            /** StringValue value */
            value?: (string|null);
        }

        /** Represents a StringValue. */
        class StringValue implements IStringValue {

            /**
             * Constructs a new StringValue.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IStringValue);

            /** StringValue value. */
            public value: string;

            /**
             * Creates a new StringValue instance using the specified properties.
             * @param [properties] Properties to set
             * @returns StringValue instance
             */
            public static create(properties?: google.protobuf.IStringValue): google.protobuf.StringValue;

            /**
             * Encodes the specified StringValue message. Does not implicitly {@link google.protobuf.StringValue.verify|verify} messages.
             * @param message StringValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IStringValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified StringValue message, length delimited. Does not implicitly {@link google.protobuf.StringValue.verify|verify} messages.
             * @param message StringValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IStringValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a StringValue message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns StringValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.StringValue;

            /**
             * Decodes a StringValue message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns StringValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.StringValue;

            /**
             * Verifies a StringValue message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a StringValue message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns StringValue
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.StringValue;

            /**
             * Creates a plain object from a StringValue message. Also converts values to other types if specified.
             * @param message StringValue
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.StringValue, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this StringValue to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for StringValue
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a BytesValue. */
        interface IBytesValue {

            /** BytesValue value */
            value?: (Uint8Array|string|null);
        }

        /** Represents a BytesValue. */
        class BytesValue implements IBytesValue {

            /**
             * Constructs a new BytesValue.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IBytesValue);

            /** BytesValue value. */
            public value: (Uint8Array|string);

            /**
             * Creates a new BytesValue instance using the specified properties.
             * @param [properties] Properties to set
             * @returns BytesValue instance
             */
            public static create(properties?: google.protobuf.IBytesValue): google.protobuf.BytesValue;

            /**
             * Encodes the specified BytesValue message. Does not implicitly {@link google.protobuf.BytesValue.verify|verify} messages.
             * @param message BytesValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IBytesValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified BytesValue message, length delimited. Does not implicitly {@link google.protobuf.BytesValue.verify|verify} messages.
             * @param message BytesValue message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IBytesValue, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a BytesValue message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns BytesValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.BytesValue;

            /**
             * Decodes a BytesValue message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns BytesValue
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.BytesValue;

            /**
             * Verifies a BytesValue message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a BytesValue message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns BytesValue
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.BytesValue;

            /**
             * Creates a plain object from a BytesValue message. Also converts values to other types if specified.
             * @param message BytesValue
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.BytesValue, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this BytesValue to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for BytesValue
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a Duration. */
        interface IDuration {

            /** Duration seconds */
            seconds?: (number|Long|string|null);

            /** Duration nanos */
            nanos?: (number|null);
        }

        /** Represents a Duration. */
        class Duration implements IDuration {

            /**
             * Constructs a new Duration.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IDuration);

            /** Duration seconds. */
            public seconds: (number|Long|string);

            /** Duration nanos. */
            public nanos: number;

            /**
             * Creates a new Duration instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Duration instance
             */
            public static create(properties?: google.protobuf.IDuration): google.protobuf.Duration;

            /**
             * Encodes the specified Duration message. Does not implicitly {@link google.protobuf.Duration.verify|verify} messages.
             * @param message Duration message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IDuration, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Duration message, length delimited. Does not implicitly {@link google.protobuf.Duration.verify|verify} messages.
             * @param message Duration message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IDuration, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a Duration message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Duration
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.Duration;

            /**
             * Decodes a Duration message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Duration
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.Duration;

            /**
             * Verifies a Duration message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a Duration message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Duration
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.Duration;

            /**
             * Creates a plain object from a Duration message. Also converts values to other types if specified.
             * @param message Duration
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.Duration, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Duration to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Duration
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a FieldMask. */
        interface IFieldMask {

            /** FieldMask paths */
            paths?: (string[]|null);
        }

        /** Represents a FieldMask. */
        class FieldMask implements IFieldMask {

            /**
             * Constructs a new FieldMask.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IFieldMask);

            /** FieldMask paths. */
            public paths: string[];

            /**
             * Creates a new FieldMask instance using the specified properties.
             * @param [properties] Properties to set
             * @returns FieldMask instance
             */
            public static create(properties?: google.protobuf.IFieldMask): google.protobuf.FieldMask;

            /**
             * Encodes the specified FieldMask message. Does not implicitly {@link google.protobuf.FieldMask.verify|verify} messages.
             * @param message FieldMask message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IFieldMask, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified FieldMask message, length delimited. Does not implicitly {@link google.protobuf.FieldMask.verify|verify} messages.
             * @param message FieldMask message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IFieldMask, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a FieldMask message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns FieldMask
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.FieldMask;

            /**
             * Decodes a FieldMask message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns FieldMask
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.FieldMask;

            /**
             * Verifies a FieldMask message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a FieldMask message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns FieldMask
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.FieldMask;

            /**
             * Creates a plain object from a FieldMask message. Also converts values to other types if specified.
             * @param message FieldMask
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.FieldMask, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this FieldMask to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for FieldMask
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an Empty. */
        interface IEmpty {
        }

        /** Represents an Empty. */
        class Empty implements IEmpty {

            /**
             * Constructs a new Empty.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.protobuf.IEmpty);

            /**
             * Creates a new Empty instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Empty instance
             */
            public static create(properties?: google.protobuf.IEmpty): google.protobuf.Empty;

            /**
             * Encodes the specified Empty message. Does not implicitly {@link google.protobuf.Empty.verify|verify} messages.
             * @param message Empty message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.protobuf.IEmpty, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Empty message, length delimited. Does not implicitly {@link google.protobuf.Empty.verify|verify} messages.
             * @param message Empty message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.protobuf.IEmpty, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an Empty message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Empty
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.protobuf.Empty;

            /**
             * Decodes an Empty message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Empty
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.protobuf.Empty;

            /**
             * Verifies an Empty message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an Empty message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Empty
             */
            public static fromObject(object: { [k: string]: any }): google.protobuf.Empty;

            /**
             * Creates a plain object from an Empty message. Also converts values to other types if specified.
             * @param message Empty
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.protobuf.Empty, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Empty to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Empty
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }
    }

    /** Namespace rpc. */
    namespace rpc {

        /** Properties of a Status. */
        interface IStatus {

            /** Status code */
            code?: (number|null);

            /** Status message */
            message?: (string|null);

            /** Status details */
            details?: (google.protobuf.IAny[]|null);
        }

        /** Represents a Status. */
        class Status implements IStatus {

            /**
             * Constructs a new Status.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.rpc.IStatus);

            /** Status code. */
            public code: number;

            /** Status message. */
            public message: string;

            /** Status details. */
            public details: google.protobuf.IAny[];

            /**
             * Creates a new Status instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Status instance
             */
            public static create(properties?: google.rpc.IStatus): google.rpc.Status;

            /**
             * Encodes the specified Status message. Does not implicitly {@link google.rpc.Status.verify|verify} messages.
             * @param message Status message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.rpc.IStatus, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Status message, length delimited. Does not implicitly {@link google.rpc.Status.verify|verify} messages.
             * @param message Status message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.rpc.IStatus, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a Status message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Status
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.rpc.Status;

            /**
             * Decodes a Status message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Status
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.rpc.Status;

            /**
             * Verifies a Status message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a Status message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Status
             */
            public static fromObject(object: { [k: string]: any }): google.rpc.Status;

            /**
             * Creates a plain object from a Status message. Also converts values to other types if specified.
             * @param message Status
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.rpc.Status, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Status to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Status
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }
    }

    /** Namespace type. */
    namespace type {

        /** Properties of a Color. */
        interface IColor {

            /** Color red */
            red?: (number|null);

            /** Color green */
            green?: (number|null);

            /** Color blue */
            blue?: (number|null);

            /** Color alpha */
            alpha?: (google.protobuf.IFloatValue|null);
        }

        /** Represents a Color. */
        class Color implements IColor {

            /**
             * Constructs a new Color.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.type.IColor);

            /** Color red. */
            public red: number;

            /** Color green. */
            public green: number;

            /** Color blue. */
            public blue: number;

            /** Color alpha. */
            public alpha?: (google.protobuf.IFloatValue|null);

            /**
             * Creates a new Color instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Color instance
             */
            public static create(properties?: google.type.IColor): google.type.Color;

            /**
             * Encodes the specified Color message. Does not implicitly {@link google.type.Color.verify|verify} messages.
             * @param message Color message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.type.IColor, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Color message, length delimited. Does not implicitly {@link google.type.Color.verify|verify} messages.
             * @param message Color message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.type.IColor, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a Color message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Color
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.type.Color;

            /**
             * Decodes a Color message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Color
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.type.Color;

            /**
             * Verifies a Color message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a Color message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Color
             */
            public static fromObject(object: { [k: string]: any }): google.type.Color;

            /**
             * Creates a plain object from a Color message. Also converts values to other types if specified.
             * @param message Color
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.type.Color, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Color to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Color
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a Date. */
        interface IDate {

            /** Date year */
            year?: (number|null);

            /** Date month */
            month?: (number|null);

            /** Date day */
            day?: (number|null);
        }

        /** Represents a Date. */
        class Date implements IDate {

            /**
             * Constructs a new Date.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.type.IDate);

            /** Date year. */
            public year: number;

            /** Date month. */
            public month: number;

            /** Date day. */
            public day: number;

            /**
             * Creates a new Date instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Date instance
             */
            public static create(properties?: google.type.IDate): google.type.Date;

            /**
             * Encodes the specified Date message. Does not implicitly {@link google.type.Date.verify|verify} messages.
             * @param message Date message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.type.IDate, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Date message, length delimited. Does not implicitly {@link google.type.Date.verify|verify} messages.
             * @param message Date message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.type.IDate, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a Date message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Date
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.type.Date;

            /**
             * Decodes a Date message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Date
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.type.Date;

            /**
             * Verifies a Date message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a Date message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Date
             */
            public static fromObject(object: { [k: string]: any }): google.type.Date;

            /**
             * Creates a plain object from a Date message. Also converts values to other types if specified.
             * @param message Date
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.type.Date, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Date to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Date
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a DateTime. */
        interface IDateTime {

            /** DateTime year */
            year?: (number|null);

            /** DateTime month */
            month?: (number|null);

            /** DateTime day */
            day?: (number|null);

            /** DateTime hours */
            hours?: (number|null);

            /** DateTime minutes */
            minutes?: (number|null);

            /** DateTime seconds */
            seconds?: (number|null);

            /** DateTime nanos */
            nanos?: (number|null);

            /** DateTime utcOffset */
            utcOffset?: (google.protobuf.IDuration|null);

            /** DateTime timeZone */
            timeZone?: (google.type.ITimeZone|null);
        }

        /** Represents a DateTime. */
        class DateTime implements IDateTime {

            /**
             * Constructs a new DateTime.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.type.IDateTime);

            /** DateTime year. */
            public year: number;

            /** DateTime month. */
            public month: number;

            /** DateTime day. */
            public day: number;

            /** DateTime hours. */
            public hours: number;

            /** DateTime minutes. */
            public minutes: number;

            /** DateTime seconds. */
            public seconds: number;

            /** DateTime nanos. */
            public nanos: number;

            /** DateTime utcOffset. */
            public utcOffset?: (google.protobuf.IDuration|null);

            /** DateTime timeZone. */
            public timeZone?: (google.type.ITimeZone|null);

            /** DateTime timeOffset. */
            public timeOffset?: ("utcOffset"|"timeZone");

            /**
             * Creates a new DateTime instance using the specified properties.
             * @param [properties] Properties to set
             * @returns DateTime instance
             */
            public static create(properties?: google.type.IDateTime): google.type.DateTime;

            /**
             * Encodes the specified DateTime message. Does not implicitly {@link google.type.DateTime.verify|verify} messages.
             * @param message DateTime message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.type.IDateTime, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified DateTime message, length delimited. Does not implicitly {@link google.type.DateTime.verify|verify} messages.
             * @param message DateTime message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.type.IDateTime, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a DateTime message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns DateTime
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.type.DateTime;

            /**
             * Decodes a DateTime message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns DateTime
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.type.DateTime;

            /**
             * Verifies a DateTime message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a DateTime message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns DateTime
             */
            public static fromObject(object: { [k: string]: any }): google.type.DateTime;

            /**
             * Creates a plain object from a DateTime message. Also converts values to other types if specified.
             * @param message DateTime
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.type.DateTime, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this DateTime to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for DateTime
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a TimeZone. */
        interface ITimeZone {

            /** TimeZone id */
            id?: (string|null);

            /** TimeZone version */
            version?: (string|null);
        }

        /** Represents a TimeZone. */
        class TimeZone implements ITimeZone {

            /**
             * Constructs a new TimeZone.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.type.ITimeZone);

            /** TimeZone id. */
            public id: string;

            /** TimeZone version. */
            public version: string;

            /**
             * Creates a new TimeZone instance using the specified properties.
             * @param [properties] Properties to set
             * @returns TimeZone instance
             */
            public static create(properties?: google.type.ITimeZone): google.type.TimeZone;

            /**
             * Encodes the specified TimeZone message. Does not implicitly {@link google.type.TimeZone.verify|verify} messages.
             * @param message TimeZone message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.type.ITimeZone, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified TimeZone message, length delimited. Does not implicitly {@link google.type.TimeZone.verify|verify} messages.
             * @param message TimeZone message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.type.ITimeZone, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a TimeZone message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns TimeZone
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.type.TimeZone;

            /**
             * Decodes a TimeZone message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns TimeZone
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.type.TimeZone;

            /**
             * Verifies a TimeZone message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a TimeZone message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns TimeZone
             */
            public static fromObject(object: { [k: string]: any }): google.type.TimeZone;

            /**
             * Creates a plain object from a TimeZone message. Also converts values to other types if specified.
             * @param message TimeZone
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.type.TimeZone, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this TimeZone to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for TimeZone
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a Money. */
        interface IMoney {

            /** Money currencyCode */
            currencyCode?: (string|null);

            /** Money units */
            units?: (number|Long|string|null);

            /** Money nanos */
            nanos?: (number|null);
        }

        /** Represents a Money. */
        class Money implements IMoney {

            /**
             * Constructs a new Money.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.type.IMoney);

            /** Money currencyCode. */
            public currencyCode: string;

            /** Money units. */
            public units: (number|Long|string);

            /** Money nanos. */
            public nanos: number;

            /**
             * Creates a new Money instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Money instance
             */
            public static create(properties?: google.type.IMoney): google.type.Money;

            /**
             * Encodes the specified Money message. Does not implicitly {@link google.type.Money.verify|verify} messages.
             * @param message Money message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.type.IMoney, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Money message, length delimited. Does not implicitly {@link google.type.Money.verify|verify} messages.
             * @param message Money message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.type.IMoney, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a Money message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Money
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.type.Money;

            /**
             * Decodes a Money message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Money
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.type.Money;

            /**
             * Verifies a Money message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a Money message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Money
             */
            public static fromObject(object: { [k: string]: any }): google.type.Money;

            /**
             * Creates a plain object from a Money message. Also converts values to other types if specified.
             * @param message Money
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.type.Money, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Money to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Money
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a PostalAddress. */
        interface IPostalAddress {

            /** PostalAddress revision */
            revision?: (number|null);

            /** PostalAddress regionCode */
            regionCode?: (string|null);

            /** PostalAddress languageCode */
            languageCode?: (string|null);

            /** PostalAddress postalCode */
            postalCode?: (string|null);

            /** PostalAddress sortingCode */
            sortingCode?: (string|null);

            /** PostalAddress administrativeArea */
            administrativeArea?: (string|null);

            /** PostalAddress locality */
            locality?: (string|null);

            /** PostalAddress sublocality */
            sublocality?: (string|null);

            /** PostalAddress addressLines */
            addressLines?: (string[]|null);

            /** PostalAddress recipients */
            recipients?: (string[]|null);

            /** PostalAddress organization */
            organization?: (string|null);
        }

        /** Represents a PostalAddress. */
        class PostalAddress implements IPostalAddress {

            /**
             * Constructs a new PostalAddress.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.type.IPostalAddress);

            /** PostalAddress revision. */
            public revision: number;

            /** PostalAddress regionCode. */
            public regionCode: string;

            /** PostalAddress languageCode. */
            public languageCode: string;

            /** PostalAddress postalCode. */
            public postalCode: string;

            /** PostalAddress sortingCode. */
            public sortingCode: string;

            /** PostalAddress administrativeArea. */
            public administrativeArea: string;

            /** PostalAddress locality. */
            public locality: string;

            /** PostalAddress sublocality. */
            public sublocality: string;

            /** PostalAddress addressLines. */
            public addressLines: string[];

            /** PostalAddress recipients. */
            public recipients: string[];

            /** PostalAddress organization. */
            public organization: string;

            /**
             * Creates a new PostalAddress instance using the specified properties.
             * @param [properties] Properties to set
             * @returns PostalAddress instance
             */
            public static create(properties?: google.type.IPostalAddress): google.type.PostalAddress;

            /**
             * Encodes the specified PostalAddress message. Does not implicitly {@link google.type.PostalAddress.verify|verify} messages.
             * @param message PostalAddress message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.type.IPostalAddress, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified PostalAddress message, length delimited. Does not implicitly {@link google.type.PostalAddress.verify|verify} messages.
             * @param message PostalAddress message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.type.IPostalAddress, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a PostalAddress message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns PostalAddress
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.type.PostalAddress;

            /**
             * Decodes a PostalAddress message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns PostalAddress
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.type.PostalAddress;

            /**
             * Verifies a PostalAddress message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a PostalAddress message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns PostalAddress
             */
            public static fromObject(object: { [k: string]: any }): google.type.PostalAddress;

            /**
             * Creates a plain object from a PostalAddress message. Also converts values to other types if specified.
             * @param message PostalAddress
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.type.PostalAddress, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this PostalAddress to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for PostalAddress
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }
    }

    /** Namespace longrunning. */
    namespace longrunning {

        /** Represents an Operations */
        class Operations extends $protobuf.rpc.Service {

            /**
             * Constructs a new Operations service.
             * @param rpcImpl RPC implementation
             * @param [requestDelimited=false] Whether requests are length-delimited
             * @param [responseDelimited=false] Whether responses are length-delimited
             */
            constructor(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean);

            /**
             * Creates new Operations service using the specified rpc implementation.
             * @param rpcImpl RPC implementation
             * @param [requestDelimited=false] Whether requests are length-delimited
             * @param [responseDelimited=false] Whether responses are length-delimited
             * @returns RPC service. Useful where requests and/or responses are streamed.
             */
            public static create(rpcImpl: $protobuf.RPCImpl, requestDelimited?: boolean, responseDelimited?: boolean): Operations;

            /**
             * Calls ListOperations.
             * @param request ListOperationsRequest message or plain object
             * @param callback Node-style callback called with the error, if any, and ListOperationsResponse
             */
            public listOperations(request: google.longrunning.IListOperationsRequest, callback: google.longrunning.Operations.ListOperationsCallback): void;

            /**
             * Calls ListOperations.
             * @param request ListOperationsRequest message or plain object
             * @returns Promise
             */
            public listOperations(request: google.longrunning.IListOperationsRequest): Promise<google.longrunning.ListOperationsResponse>;

            /**
             * Calls GetOperation.
             * @param request GetOperationRequest message or plain object
             * @param callback Node-style callback called with the error, if any, and Operation
             */
            public getOperation(request: google.longrunning.IGetOperationRequest, callback: google.longrunning.Operations.GetOperationCallback): void;

            /**
             * Calls GetOperation.
             * @param request GetOperationRequest message or plain object
             * @returns Promise
             */
            public getOperation(request: google.longrunning.IGetOperationRequest): Promise<google.longrunning.Operation>;

            /**
             * Calls DeleteOperation.
             * @param request DeleteOperationRequest message or plain object
             * @param callback Node-style callback called with the error, if any, and Empty
             */
            public deleteOperation(request: google.longrunning.IDeleteOperationRequest, callback: google.longrunning.Operations.DeleteOperationCallback): void;

            /**
             * Calls DeleteOperation.
             * @param request DeleteOperationRequest message or plain object
             * @returns Promise
             */
            public deleteOperation(request: google.longrunning.IDeleteOperationRequest): Promise<google.protobuf.Empty>;

            /**
             * Calls CancelOperation.
             * @param request CancelOperationRequest message or plain object
             * @param callback Node-style callback called with the error, if any, and Empty
             */
            public cancelOperation(request: google.longrunning.ICancelOperationRequest, callback: google.longrunning.Operations.CancelOperationCallback): void;

            /**
             * Calls CancelOperation.
             * @param request CancelOperationRequest message or plain object
             * @returns Promise
             */
            public cancelOperation(request: google.longrunning.ICancelOperationRequest): Promise<google.protobuf.Empty>;

            /**
             * Calls WaitOperation.
             * @param request WaitOperationRequest message or plain object
             * @param callback Node-style callback called with the error, if any, and Operation
             */
            public waitOperation(request: google.longrunning.IWaitOperationRequest, callback: google.longrunning.Operations.WaitOperationCallback): void;

            /**
             * Calls WaitOperation.
             * @param request WaitOperationRequest message or plain object
             * @returns Promise
             */
            public waitOperation(request: google.longrunning.IWaitOperationRequest): Promise<google.longrunning.Operation>;
        }

        namespace Operations {

            /**
             * Callback as used by {@link google.longrunning.Operations|listOperations}.
             * @param error Error, if any
             * @param [response] ListOperationsResponse
             */
            type ListOperationsCallback = (error: (Error|null), response?: google.longrunning.ListOperationsResponse) => void;

            /**
             * Callback as used by {@link google.longrunning.Operations|getOperation}.
             * @param error Error, if any
             * @param [response] Operation
             */
            type GetOperationCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;

            /**
             * Callback as used by {@link google.longrunning.Operations|deleteOperation}.
             * @param error Error, if any
             * @param [response] Empty
             */
            type DeleteOperationCallback = (error: (Error|null), response?: google.protobuf.Empty) => void;

            /**
             * Callback as used by {@link google.longrunning.Operations|cancelOperation}.
             * @param error Error, if any
             * @param [response] Empty
             */
            type CancelOperationCallback = (error: (Error|null), response?: google.protobuf.Empty) => void;

            /**
             * Callback as used by {@link google.longrunning.Operations|waitOperation}.
             * @param error Error, if any
             * @param [response] Operation
             */
            type WaitOperationCallback = (error: (Error|null), response?: google.longrunning.Operation) => void;
        }

        /** Properties of an Operation. */
        interface IOperation {

            /** Operation name */
            name?: (string|null);

            /** Operation metadata */
            metadata?: (google.protobuf.IAny|null);

            /** Operation done */
            done?: (boolean|null);

            /** Operation error */
            error?: (google.rpc.IStatus|null);

            /** Operation response */
            response?: (google.protobuf.IAny|null);
        }

        /** Represents an Operation. */
        class Operation implements IOperation {

            /**
             * Constructs a new Operation.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.longrunning.IOperation);

            /** Operation name. */
            public name: string;

            /** Operation metadata. */
            public metadata?: (google.protobuf.IAny|null);

            /** Operation done. */
            public done: boolean;

            /** Operation error. */
            public error?: (google.rpc.IStatus|null);

            /** Operation response. */
            public response?: (google.protobuf.IAny|null);

            /** Operation result. */
            public result?: ("error"|"response");

            /**
             * Creates a new Operation instance using the specified properties.
             * @param [properties] Properties to set
             * @returns Operation instance
             */
            public static create(properties?: google.longrunning.IOperation): google.longrunning.Operation;

            /**
             * Encodes the specified Operation message. Does not implicitly {@link google.longrunning.Operation.verify|verify} messages.
             * @param message Operation message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.longrunning.IOperation, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified Operation message, length delimited. Does not implicitly {@link google.longrunning.Operation.verify|verify} messages.
             * @param message Operation message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.longrunning.IOperation, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an Operation message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns Operation
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.longrunning.Operation;

            /**
             * Decodes an Operation message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns Operation
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.longrunning.Operation;

            /**
             * Verifies an Operation message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an Operation message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns Operation
             */
            public static fromObject(object: { [k: string]: any }): google.longrunning.Operation;

            /**
             * Creates a plain object from an Operation message. Also converts values to other types if specified.
             * @param message Operation
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.longrunning.Operation, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this Operation to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for Operation
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a GetOperationRequest. */
        interface IGetOperationRequest {

            /** GetOperationRequest name */
            name?: (string|null);
        }

        /** Represents a GetOperationRequest. */
        class GetOperationRequest implements IGetOperationRequest {

            /**
             * Constructs a new GetOperationRequest.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.longrunning.IGetOperationRequest);

            /** GetOperationRequest name. */
            public name: string;

            /**
             * Creates a new GetOperationRequest instance using the specified properties.
             * @param [properties] Properties to set
             * @returns GetOperationRequest instance
             */
            public static create(properties?: google.longrunning.IGetOperationRequest): google.longrunning.GetOperationRequest;

            /**
             * Encodes the specified GetOperationRequest message. Does not implicitly {@link google.longrunning.GetOperationRequest.verify|verify} messages.
             * @param message GetOperationRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.longrunning.IGetOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified GetOperationRequest message, length delimited. Does not implicitly {@link google.longrunning.GetOperationRequest.verify|verify} messages.
             * @param message GetOperationRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.longrunning.IGetOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a GetOperationRequest message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns GetOperationRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.longrunning.GetOperationRequest;

            /**
             * Decodes a GetOperationRequest message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns GetOperationRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.longrunning.GetOperationRequest;

            /**
             * Verifies a GetOperationRequest message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a GetOperationRequest message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns GetOperationRequest
             */
            public static fromObject(object: { [k: string]: any }): google.longrunning.GetOperationRequest;

            /**
             * Creates a plain object from a GetOperationRequest message. Also converts values to other types if specified.
             * @param message GetOperationRequest
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.longrunning.GetOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this GetOperationRequest to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for GetOperationRequest
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a ListOperationsRequest. */
        interface IListOperationsRequest {

            /** ListOperationsRequest name */
            name?: (string|null);

            /** ListOperationsRequest filter */
            filter?: (string|null);

            /** ListOperationsRequest pageSize */
            pageSize?: (number|null);

            /** ListOperationsRequest pageToken */
            pageToken?: (string|null);
        }

        /** Represents a ListOperationsRequest. */
        class ListOperationsRequest implements IListOperationsRequest {

            /**
             * Constructs a new ListOperationsRequest.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.longrunning.IListOperationsRequest);

            /** ListOperationsRequest name. */
            public name: string;

            /** ListOperationsRequest filter. */
            public filter: string;

            /** ListOperationsRequest pageSize. */
            public pageSize: number;

            /** ListOperationsRequest pageToken. */
            public pageToken: string;

            /**
             * Creates a new ListOperationsRequest instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ListOperationsRequest instance
             */
            public static create(properties?: google.longrunning.IListOperationsRequest): google.longrunning.ListOperationsRequest;

            /**
             * Encodes the specified ListOperationsRequest message. Does not implicitly {@link google.longrunning.ListOperationsRequest.verify|verify} messages.
             * @param message ListOperationsRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.longrunning.IListOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ListOperationsRequest message, length delimited. Does not implicitly {@link google.longrunning.ListOperationsRequest.verify|verify} messages.
             * @param message ListOperationsRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.longrunning.IListOperationsRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ListOperationsRequest message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ListOperationsRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.longrunning.ListOperationsRequest;

            /**
             * Decodes a ListOperationsRequest message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ListOperationsRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.longrunning.ListOperationsRequest;

            /**
             * Verifies a ListOperationsRequest message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ListOperationsRequest message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ListOperationsRequest
             */
            public static fromObject(object: { [k: string]: any }): google.longrunning.ListOperationsRequest;

            /**
             * Creates a plain object from a ListOperationsRequest message. Also converts values to other types if specified.
             * @param message ListOperationsRequest
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.longrunning.ListOperationsRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ListOperationsRequest to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ListOperationsRequest
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a ListOperationsResponse. */
        interface IListOperationsResponse {

            /** ListOperationsResponse operations */
            operations?: (google.longrunning.IOperation[]|null);

            /** ListOperationsResponse nextPageToken */
            nextPageToken?: (string|null);
        }

        /** Represents a ListOperationsResponse. */
        class ListOperationsResponse implements IListOperationsResponse {

            /**
             * Constructs a new ListOperationsResponse.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.longrunning.IListOperationsResponse);

            /** ListOperationsResponse operations. */
            public operations: google.longrunning.IOperation[];

            /** ListOperationsResponse nextPageToken. */
            public nextPageToken: string;

            /**
             * Creates a new ListOperationsResponse instance using the specified properties.
             * @param [properties] Properties to set
             * @returns ListOperationsResponse instance
             */
            public static create(properties?: google.longrunning.IListOperationsResponse): google.longrunning.ListOperationsResponse;

            /**
             * Encodes the specified ListOperationsResponse message. Does not implicitly {@link google.longrunning.ListOperationsResponse.verify|verify} messages.
             * @param message ListOperationsResponse message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.longrunning.IListOperationsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified ListOperationsResponse message, length delimited. Does not implicitly {@link google.longrunning.ListOperationsResponse.verify|verify} messages.
             * @param message ListOperationsResponse message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.longrunning.IListOperationsResponse, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a ListOperationsResponse message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns ListOperationsResponse
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.longrunning.ListOperationsResponse;

            /**
             * Decodes a ListOperationsResponse message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns ListOperationsResponse
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.longrunning.ListOperationsResponse;

            /**
             * Verifies a ListOperationsResponse message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a ListOperationsResponse message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns ListOperationsResponse
             */
            public static fromObject(object: { [k: string]: any }): google.longrunning.ListOperationsResponse;

            /**
             * Creates a plain object from a ListOperationsResponse message. Also converts values to other types if specified.
             * @param message ListOperationsResponse
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.longrunning.ListOperationsResponse, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this ListOperationsResponse to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for ListOperationsResponse
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a CancelOperationRequest. */
        interface ICancelOperationRequest {

            /** CancelOperationRequest name */
            name?: (string|null);
        }

        /** Represents a CancelOperationRequest. */
        class CancelOperationRequest implements ICancelOperationRequest {

            /**
             * Constructs a new CancelOperationRequest.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.longrunning.ICancelOperationRequest);

            /** CancelOperationRequest name. */
            public name: string;

            /**
             * Creates a new CancelOperationRequest instance using the specified properties.
             * @param [properties] Properties to set
             * @returns CancelOperationRequest instance
             */
            public static create(properties?: google.longrunning.ICancelOperationRequest): google.longrunning.CancelOperationRequest;

            /**
             * Encodes the specified CancelOperationRequest message. Does not implicitly {@link google.longrunning.CancelOperationRequest.verify|verify} messages.
             * @param message CancelOperationRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.longrunning.ICancelOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified CancelOperationRequest message, length delimited. Does not implicitly {@link google.longrunning.CancelOperationRequest.verify|verify} messages.
             * @param message CancelOperationRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.longrunning.ICancelOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a CancelOperationRequest message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns CancelOperationRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.longrunning.CancelOperationRequest;

            /**
             * Decodes a CancelOperationRequest message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns CancelOperationRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.longrunning.CancelOperationRequest;

            /**
             * Verifies a CancelOperationRequest message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a CancelOperationRequest message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns CancelOperationRequest
             */
            public static fromObject(object: { [k: string]: any }): google.longrunning.CancelOperationRequest;

            /**
             * Creates a plain object from a CancelOperationRequest message. Also converts values to other types if specified.
             * @param message CancelOperationRequest
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.longrunning.CancelOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this CancelOperationRequest to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for CancelOperationRequest
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a DeleteOperationRequest. */
        interface IDeleteOperationRequest {

            /** DeleteOperationRequest name */
            name?: (string|null);
        }

        /** Represents a DeleteOperationRequest. */
        class DeleteOperationRequest implements IDeleteOperationRequest {

            /**
             * Constructs a new DeleteOperationRequest.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.longrunning.IDeleteOperationRequest);

            /** DeleteOperationRequest name. */
            public name: string;

            /**
             * Creates a new DeleteOperationRequest instance using the specified properties.
             * @param [properties] Properties to set
             * @returns DeleteOperationRequest instance
             */
            public static create(properties?: google.longrunning.IDeleteOperationRequest): google.longrunning.DeleteOperationRequest;

            /**
             * Encodes the specified DeleteOperationRequest message. Does not implicitly {@link google.longrunning.DeleteOperationRequest.verify|verify} messages.
             * @param message DeleteOperationRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.longrunning.IDeleteOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified DeleteOperationRequest message, length delimited. Does not implicitly {@link google.longrunning.DeleteOperationRequest.verify|verify} messages.
             * @param message DeleteOperationRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.longrunning.IDeleteOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a DeleteOperationRequest message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns DeleteOperationRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.longrunning.DeleteOperationRequest;

            /**
             * Decodes a DeleteOperationRequest message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns DeleteOperationRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.longrunning.DeleteOperationRequest;

            /**
             * Verifies a DeleteOperationRequest message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a DeleteOperationRequest message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns DeleteOperationRequest
             */
            public static fromObject(object: { [k: string]: any }): google.longrunning.DeleteOperationRequest;

            /**
             * Creates a plain object from a DeleteOperationRequest message. Also converts values to other types if specified.
             * @param message DeleteOperationRequest
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.longrunning.DeleteOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this DeleteOperationRequest to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for DeleteOperationRequest
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of a WaitOperationRequest. */
        interface IWaitOperationRequest {

            /** WaitOperationRequest name */
            name?: (string|null);

            /** WaitOperationRequest timeout */
            timeout?: (google.protobuf.IDuration|null);
        }

        /** Represents a WaitOperationRequest. */
        class WaitOperationRequest implements IWaitOperationRequest {

            /**
             * Constructs a new WaitOperationRequest.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.longrunning.IWaitOperationRequest);

            /** WaitOperationRequest name. */
            public name: string;

            /** WaitOperationRequest timeout. */
            public timeout?: (google.protobuf.IDuration|null);

            /**
             * Creates a new WaitOperationRequest instance using the specified properties.
             * @param [properties] Properties to set
             * @returns WaitOperationRequest instance
             */
            public static create(properties?: google.longrunning.IWaitOperationRequest): google.longrunning.WaitOperationRequest;

            /**
             * Encodes the specified WaitOperationRequest message. Does not implicitly {@link google.longrunning.WaitOperationRequest.verify|verify} messages.
             * @param message WaitOperationRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.longrunning.IWaitOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified WaitOperationRequest message, length delimited. Does not implicitly {@link google.longrunning.WaitOperationRequest.verify|verify} messages.
             * @param message WaitOperationRequest message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.longrunning.IWaitOperationRequest, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes a WaitOperationRequest message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns WaitOperationRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.longrunning.WaitOperationRequest;

            /**
             * Decodes a WaitOperationRequest message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns WaitOperationRequest
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.longrunning.WaitOperationRequest;

            /**
             * Verifies a WaitOperationRequest message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates a WaitOperationRequest message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns WaitOperationRequest
             */
            public static fromObject(object: { [k: string]: any }): google.longrunning.WaitOperationRequest;

            /**
             * Creates a plain object from a WaitOperationRequest message. Also converts values to other types if specified.
             * @param message WaitOperationRequest
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.longrunning.WaitOperationRequest, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this WaitOperationRequest to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for WaitOperationRequest
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }

        /** Properties of an OperationInfo. */
        interface IOperationInfo {

            /** OperationInfo responseType */
            responseType?: (string|null);

            /** OperationInfo metadataType */
            metadataType?: (string|null);
        }

        /** Represents an OperationInfo. */
        class OperationInfo implements IOperationInfo {

            /**
             * Constructs a new OperationInfo.
             * @param [properties] Properties to set
             */
            constructor(properties?: google.longrunning.IOperationInfo);

            /** OperationInfo responseType. */
            public responseType: string;

            /** OperationInfo metadataType. */
            public metadataType: string;

            /**
             * Creates a new OperationInfo instance using the specified properties.
             * @param [properties] Properties to set
             * @returns OperationInfo instance
             */
            public static create(properties?: google.longrunning.IOperationInfo): google.longrunning.OperationInfo;

            /**
             * Encodes the specified OperationInfo message. Does not implicitly {@link google.longrunning.OperationInfo.verify|verify} messages.
             * @param message OperationInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encode(message: google.longrunning.IOperationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Encodes the specified OperationInfo message, length delimited. Does not implicitly {@link google.longrunning.OperationInfo.verify|verify} messages.
             * @param message OperationInfo message or plain object to encode
             * @param [writer] Writer to encode to
             * @returns Writer
             */
            public static encodeDelimited(message: google.longrunning.IOperationInfo, writer?: $protobuf.Writer): $protobuf.Writer;

            /**
             * Decodes an OperationInfo message from the specified reader or buffer.
             * @param reader Reader or buffer to decode from
             * @param [length] Message length if known beforehand
             * @returns OperationInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decode(reader: ($protobuf.Reader|Uint8Array), length?: number): google.longrunning.OperationInfo;

            /**
             * Decodes an OperationInfo message from the specified reader or buffer, length delimited.
             * @param reader Reader or buffer to decode from
             * @returns OperationInfo
             * @throws {Error} If the payload is not a reader or valid buffer
             * @throws {$protobuf.util.ProtocolError} If required fields are missing
             */
            public static decodeDelimited(reader: ($protobuf.Reader|Uint8Array)): google.longrunning.OperationInfo;

            /**
             * Verifies an OperationInfo message.
             * @param message Plain object to verify
             * @returns `null` if valid, otherwise the reason why it is not
             */
            public static verify(message: { [k: string]: any }): (string|null);

            /**
             * Creates an OperationInfo message from a plain object. Also converts values to their respective internal types.
             * @param object Plain object
             * @returns OperationInfo
             */
            public static fromObject(object: { [k: string]: any }): google.longrunning.OperationInfo;

            /**
             * Creates a plain object from an OperationInfo message. Also converts values to other types if specified.
             * @param message OperationInfo
             * @param [options] Conversion options
             * @returns Plain object
             */
            public static toObject(message: google.longrunning.OperationInfo, options?: $protobuf.IConversionOptions): { [k: string]: any };

            /**
             * Converts this OperationInfo to JSON.
             * @returns JSON object
             */
            public toJSON(): { [k: string]: any };

            /**
             * Gets the default type url for OperationInfo
             * @param [typeUrlPrefix] your custom typeUrlPrefix(default "type.googleapis.com")
             * @returns The default type url
             */
            public static getTypeUrl(typeUrlPrefix?: string): string;
        }
    }
}
